=== modified file 'IAdblockPlus.idl'
--- IAdblockPlus.idl	2010-01-07 17:25:17 +0000
+++ IAdblockPlus.idl	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):

=== added file 'buildtools/LocaleTester.pm'
--- buildtools/LocaleTester.pm	1970-01-01 00:00:00 +0000
+++ buildtools/LocaleTester.pm	2010-05-04 14:45:07 +0000
@@ -0,0 +1,316 @@
+package LocaleTester;
+
+use strict;
+use warnings;
+
+my %keepAccessKeys = map {$_ => $_} (
+  'ja-JP',
+  'ja',
+  'ko-KR',
+  'ko',
+  'zh-CN',
+  'zh-TW',
+);
+
+my @placeholders = (
+  '?1?',
+  '?2?',
+  '?3?',
+  '?4?',
+  '?5?',
+  '?6?',
+  '?7?',
+  '?8?',
+  '?9?',
+  '--',
+  '%S',
+  '[link]',
+  '[/link]',
+);
+
+sub testLocales
+{
+  my %params = @_;
+  die "Need at least one locale path to work on" unless exists($params{paths}) && %{$params{paths}};
+  $params{mustDiffer} = [] unless exists($params{mustDiffer});
+  $params{mustEqual} = [] unless exists($params{mustEqual});
+  $params{ignoreUntranslated} = [] unless exists($params{ignoreUntranslated});
+  $params{lengthRestrictions} = {} unless exists($params{lengthRestrictions});
+
+  my @locales = sort {$a cmp $b} (exists($params{locales}) && @{$params{locales}} ? @{$params{locales}} : makeLocaleList($params{paths}));
+  
+  my $referenceLocale = readLocaleFiles($params{paths}, "en-US");
+  
+  foreach my $locale (@locales)
+  {
+    my $currentLocale = $locale eq "en-US" ? $referenceLocale : readLocaleFiles($params{paths}, $locale);
+  
+    compareLocales($locale, $currentLocale, $referenceLocale) unless $currentLocale == $referenceLocale;
+  
+    foreach my $entry (@{$params{must_differ}})
+    {
+      my %values = ();
+      foreach my $key (@$entry)
+      {
+        my ($dir, $file, $name) = split(/:/, $key);
+        next unless exists($currentLocale->{"$dir:$file"}) && exists($currentLocale->{"$dir:$file"}{$name});
+        my $value = lc($currentLocale->{"$dir:$file"}{$name});
+  
+        print "$locale: values for '$values{$value}' and '$key' are identical, must differ\n" if exists $values{$value};
+        $values{$value} = $key;
+      }
+    }
+  
+    foreach my $entry (@{$params{must_equal}})
+    {
+      my $stdValue;
+      my $stdName;
+      foreach my $key (@$entry)
+      {
+        my ($dir, $file, $name) = split(/:/, $key);
+        next unless exists($currentLocale->{"$dir:$file"}) && exists($currentLocale->{"$dir:$file"}{$name});
+        my $value = lc($currentLocale->{"$dir:$file"}{$name});
+  
+        $stdValue = $value unless defined $stdValue;
+        $stdName = $key unless defined $stdName;
+        print "$locale: values for '$stdName' and '$key' differ, must be equal\n" if $value ne $stdValue;
+      }
+    }
+
+    foreach my $key (keys %{$params{lengthRestrictions}})
+    {
+      my $maxLength = $params{lengthRestrictions}{$key};
+      my ($dir, $file, $name) = split(/:/, $key);
+      print "$locale: value of '$key' is too long, must not be longer than $maxLength characters\n" if exists($currentLocale->{"$dir:$file"}) && exists($currentLocale->{"$dir:$file"}{$name}) && length($currentLocale->{"$dir:$file"}{$name}) > $maxLength;
+    }
+  
+    foreach my $file (keys %$currentLocale)
+    {
+      my $fileData = $currentLocale->{$file};
+      foreach my $key (keys %$fileData)
+      {
+        if (($key =~ /\.accesskey$/ || $key =~ /\.key$/) && length($fileData->{$key}) != 1)
+        {
+          print "$locale: Length of accesskey '$file:$key' isn't 1 character\n";
+        }
+  
+        if ($key =~ /\.accesskey$/)
+        {
+          if (exists($keepAccessKeys{$locale}))
+          {
+            if (exists($referenceLocale->{$file}{$key}) && lc($fileData->{$key}) ne lc($referenceLocale->{$file}{$key}))
+            {
+              print "$locale: Accesskey '$file:$key' should be the same as in the reference locale\n";
+            }
+          }
+          else
+          {
+            my $labelKey = $key;
+            $labelKey =~ s/\.accesskey$/.label/;
+            if (exists($fileData->{$labelKey}) && $fileData->{$labelKey} !~ /\Q$fileData->{$key}/i)
+            {
+              print "$locale: Accesskey '$file:$key' not found in the corresponding label '$file:$labelKey'\n";
+            }
+          }
+        }
+  
+        if ($currentLocale != $referenceLocale && $locale ne "en-GB" && exists($referenceLocale->{$file}{$key}) && length($fileData->{$key}) > 1 && $fileData->{$key} eq $referenceLocale->{$file}{$key})
+        {
+          my $ignore = 0;
+          foreach my $re (@{$params{ignoreUntranslated}})
+          {
+            $ignore = 1 if "$file:$key" =~ $re;
+          }
+          print "$locale: Value of '$file:$key' is the same as in the reference locale, probably an untranslated string\n" unless $ignore;
+        }
+
+        if ($currentLocale != $referenceLocale && exists($referenceLocale->{$file}{$key}))
+        {
+          foreach my $placeholder (@placeholders)
+          {
+            print "$locale: Placeholder '$placeholder' missing in '$file:$key'\n" if index($referenceLocale->{$file}{$key}, $placeholder) >= 0 && index($currentLocale->{$file}{$key}, $placeholder) < 0;
+          }
+        }
+      }
+    }
+  }
+}
+
+sub makeLocaleList
+{
+  my $paths = shift;
+
+  my %locales = ();
+  foreach my $dir (keys %$paths)
+  {
+    opendir(local* DIR, $paths->{$dir}) or next;
+    my @locales = grep {!/[^\w\-]/ && !-e("$paths->{$dir}/$_/.incomplete")} readdir(DIR);
+    $locales{$_} = 1 foreach @locales;
+    closedir(DIR);
+  }
+  return keys %locales;
+}
+
+sub readFile
+{
+  my $file = shift;
+
+  open(local *FILE, "<", $file) || die "Could not read file '$file'";
+  binmode(FILE);
+  local $/;
+  my $result = <FILE>;
+  close(FILE);
+
+  print "Byte Order Mark found in file '$file'\n" if $result =~ /\xEF\xBB\xBF/;
+  print "File '$file' is not valid UTF-8\n" unless (utf8::decode($result));
+
+  return $result;
+}
+
+sub parseDTDFile
+{
+  my $file = shift;
+  
+  my %result = ();
+
+  my $data = readFile($file);
+
+  my $S = qr/[\x20\x09\x0D\x0A]/;
+  my $Name = qr/[A-Za-z_:][\w.\-:]*/;
+  my $Reference = qr/&$Name;|&#\d+;|&#x[\da-fA-F]+;/;
+  my $PEReference = qr/%$Name;/;
+  my $EntityValue = qr/\"((?:[^%&\"]|$PEReference|$Reference)*)\"|'((?:[^%&']|$PEReference|$Reference)*)'/;
+
+  sub processEntityValue
+  {
+    my $text = shift;
+    $text =~ s/&#(\d+);/chr($1)/ge;
+    $text =~ s/&#x([\da-fA-F]+);/chr(hex($1))/ge;
+    $text =~ s/&apos;/'/g;
+    return $text;
+  }
+
+  # Remove comments
+  $data =~ s/<!--([^\-]|-[^\-])*-->//gs;
+
+  # Process entities
+  while ($data =~ /<!ENTITY$S+($Name)$S+$EntityValue$S*>/gs)
+  {
+    my ($name, $value) = ($1, $2 || $3);
+    $result{$name} = processEntityValue($value);
+  }
+
+  # Remove entities
+  $data =~ s/<!ENTITY$S+$Name$S+$EntityValue$S*>//gs;
+
+  # Remove spaces
+  $data =~ s/^\s+//gs;
+  $data =~ s/\s+$//gs;
+  $data =~ s/\s+/ /gs;
+
+  print "Unrecognized data in file '$file': $data\n" if $data ne '';
+
+  return \%result;
+}
+
+sub parsePropertiesFile
+{
+  my $file = shift;
+
+  my %result = ();
+
+  my $data = readFile($file);
+  while ($data =~ /^(.*)$/mg)
+  {
+    my $line = $1;
+
+    # ignore comments
+    next if $line =~ /^\s*[#!]/;
+
+    if ($line =~ /=/)
+    {
+      my ($key, $value) = split(/=/, $line, 2);
+      $result{$key} = $value;
+    }
+    elsif ($line =~ /\S/)
+    {
+      print "Unrecognized data in file '$file': $line\n";
+    }
+  }
+  close(FILE);
+
+  return \%result;
+}
+
+sub readLocaleFiles
+{
+  my $paths = shift;
+  my $locale = shift;
+
+  my %result = ();
+  foreach my $dir (keys %$paths)
+  {
+    opendir(local *DIR, "$paths->{$dir}/$locale") or next;
+    foreach my $file (readdir(DIR))
+    {
+      if ($file =~ /(.*)\.dtd$/)
+      {
+        $result{"$dir:$1"} = parseDTDFile("$paths->{$dir}/$locale/$file");
+      }
+      elsif ($file =~ /(.*)\.properties$/)
+      {
+        $result{"$dir:$1"} = parsePropertiesFile("$paths->{$dir}/$locale/$file");
+      }
+    }
+    closedir(DIR);
+  }
+
+  return \%result;
+}
+
+sub compareLocales
+{
+  my ($locale, $current, $reference) = @_;
+
+  my %hasFile = ();
+  foreach my $file (keys %$current)
+  {
+    unless (exists($reference->{$file}))
+    {
+      print "$locale: Extra file '$file'\n";
+      next;
+    }
+    $hasFile{$file} = 1;
+
+    my %hasValue = ();
+    foreach my $key (keys %{$current->{$file}})
+    {
+      unless (exists($reference->{$file}{$key}))
+      {
+        print "$locale: Extra value '$file:$key'\n";
+        next;
+      }
+      $hasValue{$key} = 1;
+    }
+
+    foreach my $key (keys %{$reference->{$file}})
+    {
+      unless (exists($current->{$file}{$key}))
+      {
+        print "$locale: Missing value '$file:$key'\n";
+        next;
+      }
+    }
+  }
+
+  foreach my $file (keys %$reference)
+  {
+    unless (exists($current->{$file}))
+    {
+      print "$locale: Missing file '$file'\n";
+      next;
+    }
+  }
+}
+
+1;

=== modified file 'buildtools/Packager.pm'
--- buildtools/Packager.pm	2010-01-07 17:25:17 +0000
+++ buildtools/Packager.pm	2010-05-04 14:45:07 +0000
@@ -33,6 +33,17 @@
   close(FILE);
 }
 
+sub readBasename
+{
+  my ($self, $manifestFile) = @_;
+
+  my $data = $self->readFile($manifestFile);
+  die "Could not open manifest file $manifestFile" unless defined $data;
+  die "Could not find JAR file name in $manifestFile" unless $data =~ /\bjar:chrome\/(\S+?)\.jar\b/;
+
+  $self->{baseName} = $1;
+}
+
 sub readLocales
 {
   my ($self, $localesDir, $includeIncomplete) = @_;
@@ -62,7 +73,7 @@
     $self->{localeData}{$locale} = {id => $locale};
     while ($data =~ /^\s*(?![!#])(\S+)\s*=\s*(.+)$/mg)
     {
-      if ($1 eq "name" || $1 eq "description" || $1 eq "translator")
+      if ($1 eq "name" || $1 eq "description" || $1 eq "translator" || $1 eq "description.short" || $1 eq "description.long")
       {
         $self->{localeData}{$locale}{$1} = $2;
       }
@@ -73,34 +84,68 @@
   {
     $self->{name} = $self->{localeData}{"en-US"}{name} if exists($self->{localeData}{"en-US"}{name});
     $self->{description} = $self->{localeData}{"en-US"}{description} if exists($self->{localeData}{"en-US"}{description});
-    delete $self->{localeData}{"en-US"};
   }
 
   my $info = "";
-  foreach my $locale (values %{$self->{localeData}})
+  my %translators = ();
+  foreach my $locale (sort {$a->{id} cmp $b->{id}} values %{$self->{localeData}})
   {
     next unless (exists($locale->{translator}) && $locale->{translator}) ||
                 (exists($locale->{name}) && $locale->{name} && $locale->{name} ne $self->{name}) ||
                 (exists($locale->{description}) && $locale->{description} && $locale->{description} ne $self->{description});
 
-    my $translator = (exists($locale->{translator}) && $locale->{translator} ? "\t\t\t<em:translator>$locale->{translator}</em:translator>" : "");
+    if (exists($locale->{translator}))
+    {
+      foreach my $translator (split(/,/, $locale->{translator}))
+      {
+        $translator =~ s/^\s+//g;
+        $translator =~ s/\s+$//g;
+        $translators{$translator} = 1 if $translator ne "";
+      }
+    }
     $locale->{name} = $self->{name} unless exists($locale->{name}) && $locale->{name} && $locale->{name} ne $self->{name};
     $locale->{description} = $self->{description} unless exists($locale->{description}) && $locale->{description} && $locale->{description} ne $self->{description};
 
+    my $id = $self->encodeXML($locale->{id});
+    my $name = $self->encodeXML($locale->{name});
+    my $description = $self->encodeXML($locale->{description});
+
     $info .= <<EOT;
 \t<em:localized>
 \t\t<Description>
-\t\t\t<em:locale>$locale->{id}</em:locale>
-\t\t\t<em:name>$locale->{name}</em:name>
-\t\t\t<em:description>$locale->{description}</em:description>
-$translator
+\t\t\t<em:locale>$id</em:locale>
+\t\t\t<em:name>$name</em:name>
+\t\t\t<em:description>$description</em:description>
 \t\t</Description>
 \t</em:localized>
 EOT
   }
+
+  $info .= "\n";
+
+  foreach my $translator (sort keys %translators)
+  {
+    $translator = $self->encodeXML($translator);
+    $info .= <<EOT;
+\t<em:translator>$translator</em:translator>
+EOT
+  }
+
   $self->{localizedInfo} = $info;
 }
 
+sub readNameFromManifest
+{
+  my ($self, $installManifestFile) = @_;
+
+  my $installRDF = $self->readFile($installManifestFile);
+  return unless $installRDF;
+
+  $installRDF =~ s/<em:(requires|targetApplication)>.*?<\/em:\1>//gs;
+
+  $self->{name} = $1 if $installRDF =~ /<em:name>\s*([^<>]+?)\s*<\/em:name>/;
+}
+
 sub rm_rec
 {
   my ($self, $dir) = @_;
@@ -137,8 +182,8 @@
     }
   }
 
-  my $textMode = ($fromFile =~ /\.(manifest|xul|js|xml|xhtml|rdf|dtd|properties|css)$/);
-  my $extendedTextMode = ($fromFile =~ /\.(?:js|rdf|manifest)$/);
+  my $textMode = ($fromFile =~ /\.(manifest|xul|jsm?|xml|xhtml|rdf|dtd|properties|css)$/);
+  my $extendedTextMode = ($fromFile =~ /\.(?:jsm?|rdf|manifest)$/);
 
   open(local *FROM, $fromFile) or return;
   open(local *TO, ">$toFile") or return;
@@ -230,6 +275,16 @@
   }
 }
 
+sub encodeXML
+{
+  my ($self, $str) = @_;
+  $str =~ s/&/&amp;/g;
+  $str =~ s/</&lt;/g;
+  $str =~ s/>/&gt;/g;
+  $str =~ s/"/&quot;/g; #"
+  return $str;
+}
+
 sub createFileDir
 {
   my ($self, $fileName) = @_;

=== modified file 'buildtools/create_xpi.pl'
--- buildtools/create_xpi.pl	2010-01-07 17:25:17 +0000
+++ buildtools/create_xpi.pl	2010-05-04 14:45:07 +0000
@@ -10,16 +10,9 @@
 use lib qw(buildtools);
 use Packager;
 
-my $manifest = readFile("chrome.manifest");
-unless ($manifest =~ /\bjar:chrome\/(\S+?)\.jar\b/)
-{
-  die "Could not find JAR file name in chrome.manifest";
-}
-my $baseName = $1;
-
 my %params = ();
 
-my $xpiFile = shift @ARGV || "$baseName.xpi";
+my $xpiFile = shift @ARGV;
 if (@ARGV && $ARGV[0] =~ /^\+/)
 {
   $params{devbuild} = $ARGV[0];
@@ -34,36 +27,28 @@
 
 my $pkg = Packager->new(\%params);
 $pkg->readVersion('version');
+$pkg->readBasename('chrome.manifest');
 $pkg->readLocales('chrome/locale') unless exists $params{locales};
 $pkg->readLocaleData('chrome/locale');
 
+$xpiFile = "$pkg->{baseName}.xpi" unless $xpiFile;
+
 chdir('chrome');
-$pkg->makeJAR("$baseName.jar", 'content', 'skin', 'locale', '-/tests', '-/mochitest', '-/.incomplete', '-/meta.properties');
+$pkg->makeJAR("$pkg->{baseName}.jar", 'content', 'skin', 'locale', '-/tests', '-/mochitest', '-/.incomplete', '-/meta.properties');
 chdir('..');
 
-my @files = grep {-e $_} ('components', 'defaults', 'install.rdf', 'chrome.manifest', 'icon.png');
+my @files = grep {-e $_} ('components', <modules/*.jsm>, 'defaults', 'install.rdf', 'chrome.manifest', 'icon.png');
+@files = grep {$_ ne "modules/TimeLine.jsm"} @files unless exists($params{devbuild});
 
-$pkg->makeXPI($xpiFile, "chrome/$baseName.jar", @files);
-unlink("chrome/$baseName.jar");
+$pkg->makeXPI($xpiFile, "chrome/$pkg->{baseName}.jar", @files);
+unlink("chrome/$pkg->{baseName}.jar");
 
 sub removeTimeLine
 {
   my ($file, $line) = @_;
 
-  return "\n" if $file =~ /\.js$/ && $line =~ /\btimeLine\.(\w+)\(/;
+  return "\n" if $file =~ /\.jsm?$/ && $line =~ /\b[tT]imeLine\.(\w+)\(/;
+  return "\n" if $file =~ /\.jsm?$/ && $line =~ /Cu\.import\([^()]*\bTimeLine\.jsm\"\)/;
 
   return $line;
 }
-
-sub readFile
-{
-  my $file = shift;
-
-  open(local *FILE, "<", $file) || die "Could not read file '$file'";
-  binmode(FILE);
-  local $/;
-  my $result = <FILE>;
-  close(FILE);
-
-  return $result;
-}

=== modified file 'buildtools/make_babelzilla_build.pl'
--- buildtools/make_babelzilla_build.pl	2010-01-07 17:25:17 +0000
+++ buildtools/make_babelzilla_build.pl	2010-05-04 14:45:07 +0000
@@ -12,28 +12,23 @@
 
 sub Packager::fixLocales() {}
 
-my $manifest = readFile("chrome.manifest");
-unless ($manifest =~ /\bjar:chrome\/(\S+?)\.jar\b/)
-{
-  die "Could not find JAR file name in chrome.manifest";
-}
-my $baseName = $1;
-
 my %params = ();
 $params{version} = shift @ARGV;
 die "Please specify version number on command line" unless $params{version};
 
-my $xpiFile = "$baseName-$params{version}.xpi";
-
 my $pkg = Packager->new(\%params);
+$pkg->readBasename('chrome.manifest');
 $pkg->readLocales('chrome/locale', 1);
 $pkg->readLocaleData('chrome/locale');
 
+my $baseName = $pkg->{baseName};
+my $xpiFile = "$baseName-$params{version}.xpi";
+
 chdir('chrome');
 $pkg->makeJAR("$baseName.jar", 'content', 'skin', 'locale', '-/tests', '-/mochitest', '-/.incomplete');
 chdir('..');
 
-my @files = grep {-e $_} ('components', 'defaults', 'install.rdf', 'chrome.manifest', 'icon.png');
+my @files = grep {-e $_} ('components', 'modules', 'defaults', 'install.rdf', 'chrome.manifest', 'icon.png');
 
 my $targetAppNum = 0;
 $pkg->{postprocess_line} = \&postprocessInstallRDF;
@@ -56,16 +51,3 @@
 
   return $line;
 }
-
-sub readFile
-{
-  my $file = shift;
-
-  open(local *FILE, "<", $file) || die "Could not read file '$file'";
-  binmode(FILE);
-  local $/;
-  my $result = <FILE>;
-  close(FILE);
-
-  return $result;
-}

=== modified file 'buildtools/make_devbuild.pl'
--- buildtools/make_devbuild.pl	2010-01-07 17:25:17 +0000
+++ buildtools/make_devbuild.pl	2010-05-04 14:45:07 +0000
@@ -21,40 +21,24 @@
 #############################################################################
 
 use strict;
-
-my $manifest = readFile("chrome.manifest");
-unless ($manifest =~ /\bjar:chrome\/(\S+?)\.jar\b/)
-{
-  die "Could not find JAR file name in chrome.manifest";
-}
-my $baseName = $1;
-
-open(VERSION, "version");
-my $version = <VERSION>;
-$version =~ s/[^\w\.]//gs;
-close(VERSION);
+use lib qw(buildtools);
+use Packager;
+
+my $pkg = Packager->new();
+$pkg->readBasename('chrome.manifest');
+$pkg->readVersion('version');
+
+my $baseName = $pkg->{baseName};
+my $version = $pkg->{version};
 
 # Pad the version with zeroes to get version comparisons
 # right (1.2+ > 1.2.1 but 1.2.0+ < 1.2.1)
 $version .= ".0" while ($version =~ tr/././ < 2);
 
 my ($sec, $min, $hour, $day, $mon, $year) = localtime;
-my $build = sprintf("%04i%02i%02i%02i", $year+1900, $mon+1, $day, $hour);
+my $build = sprintf("%04i%02i%02i", $year+1900, $mon+1, $day);
 
 my $locale = (@ARGV ? "-" . join("-", @ARGV) : "");
 @ARGV = ("$baseName-$version+.$build$locale.xpi", "+.$build", @ARGV);
 do 'buildtools/create_xpi.pl';
 die $@ if $@;
-
-sub readFile
-{
-  my $file = shift;
-
-  open(local *FILE, "<", $file) || die "Could not read file '$file'";
-  binmode(FILE);
-  local $/;
-  my $result = <FILE>;
-  close(FILE);
-
-  return $result;
-}

=== modified file 'buildtools/make_release.pl'
--- buildtools/make_release.pl	2010-01-07 17:25:17 +0000
+++ buildtools/make_release.pl	2010-05-04 14:45:07 +0000
@@ -7,26 +7,21 @@
 #############################################################################
 
 use strict;
-use Cwd;
+use lib qw(buildtools);
+use Packager;
 
 our $BRANCH_NAME;
 
 die "This script cannot be called directly, please call the script for a particular extension" unless $BRANCH_NAME;
 
-my $manifest = readFile("chrome.manifest");
-unless ($manifest =~ /\bjar:chrome\/(\S+?)\.jar\b/)
-{
-  die "Could not find JAR file name in chrome.manifest";
-}
-my $baseName = $1;
+my $pkg = Packager->new({locales => ['en-US']});
+$pkg->readBasename('chrome.manifest');
+$pkg->readLocaleData('chrome/locale');
+$pkg->readNameFromManifest('install.rdf') unless $pkg->{name};
+die "Could not extract extension name" unless $pkg->{name};
 
-my $installRDF = readFile("install.rdf");
-$installRDF =~ s/<em:(requires|targetApplication)>.*?<\/em:\1>//gs;
-unless ($installRDF =~ /<em:name>\s*([^<>]+?)\s*<\/em:name>/)
-{
-  die "Could not find extension name in install.rdf";
-}
-my $extensionName = $1;
+my $baseName = $pkg->{baseName};
+my $extensionName = $pkg->{name};
 
 die "Version number not specified" unless @ARGV;
 
@@ -41,9 +36,6 @@
 do 'buildtools/create_xpi.pl';
 die $@ if $@;
 
-die "Failed to determine current directory name" unless cwd() =~ /([^\\\/]+)[\\\/]?$/;
-my $dir = $1;
-
 system("hg add -R ../downloads ../downloads/$baseName-$version.xpi");
 system(qq(hg commit -m "Releasing $extensionName $version"));
 system(qq(hg commit -R ../downloads -m "Releasing $extensionName $version"));
@@ -58,16 +50,3 @@
 system(qq(hg push));
 system(qq(hg push -R ../downloads));
 system(qq(hg push -R ../buildtools));
-
-sub readFile
-{
-  my $file = shift;
-
-  open(local *FILE, "<", $file) || die "Could not read file '$file'";
-  binmode(FILE);
-  local $/;
-  my $result = <FILE>;
-  close(FILE);
-
-  return $result;
-}

=== modified file 'buildtools/setupTestEnvironment.pl'
--- buildtools/setupTestEnvironment.pl	2010-01-07 17:25:17 +0000
+++ buildtools/setupTestEnvironment.pl	2010-05-04 14:45:07 +0000
@@ -38,9 +38,6 @@
 $cleanManifest =~ s/<(\w+:)?targetApplication>.*?<\/\1targetApplication>//gs;
 $cleanManifest =~ s/<(\w+:)?requires>.*?<\/\1requires>//gs;
 
-die "Failed to extract extension name from install manifest" unless $cleanManifest =~ /<(\w+:)?name>([^<>]+)<\/\1name>/;
-my $name = $2;
-
 die "Failed to extract extension ID from install manifest" unless $cleanManifest =~ /<(\w+:)?id>([^<>]+)<\/\1id>/;
 my $id = $2;
 
@@ -50,6 +47,7 @@
 $baseURL = "file:///$baseURL";
 $chromeManifest =~ s~jar:chrome/\w+\.jar!~$baseURL/chrome~g;
 $chromeManifest =~ s~^\s*resource\s+\S+\s+~$&$baseURL/~gmi;
+$chromeManifest =~ s~^(\s*content\s+\S+\s+)(\w+/)~$1$baseURL/$2~gmi;
 $chromeManifest =~ s~^content ~content   mochikit $baseURL/chrome/content/mochitest/\n$&~m if -d "chrome/content/mochitest";
 
 push @files, ["chrome.manifest", $chromeManifest];
@@ -65,7 +63,7 @@
   print STDERR <<EOT;
 This script requires a file with the name .profileDirs to be in the current
 directory. Please create this file and specify the directories of the profiles
-where you want to install a test version of $name, one per line.
+where you want to install a test version of the extension, one per line.
 For example:
 
   c:\\Documents and Setting\\<user>\\Application Data\\Mozilla\\Firefox\\Profiles\\<seed>.default

=== modified file 'chrome.manifest'
--- chrome.manifest	2010-01-07 17:25:17 +0000
+++ chrome.manifest	2010-05-04 14:45:07 +0000
@@ -1,15 +1,14 @@
 overlay   chrome://browser/content/browser.xul chrome://adblockplus/content/ui/firefoxOverlay.xul application={ec8030f7-c20a-464f-9b0e-13a3a9e97384} application=songbird@songbirdnest.com
 overlay   chrome://browser/content/browser.xul chrome://adblockplus/content/ui/fennecOverlay.xul application={a23983c0-fd0e-11dc-95ff-0800200c9a66}
+overlay   chrome://messenger/content/msgHdrViewOverlay.xul chrome://adblockplus/content/ui/thunderbirdOverlay.xul application={3550f703-e582-4d05-9a08-453d09bdfdc6}
 overlay   chrome://navigator/content/navigator.xul chrome://adblockplus/content/ui/seamonkeyOverlay.xul application={92650c4d-4b8e-4d2a-b7eb-24ecf4f6b63a}
-overlay   chrome://messenger/content/mailWindowOverlay.xul chrome://adblockplus/content/ui/mailOverlay.xul application={3550f703-e582-4d05-9a08-453d09bdfdc6} application={92650c4d-4b8e-4d2a-b7eb-24ecf4f6b63a}
+overlay   chrome://messenger/content/mailWindowOverlay.xul chrome://adblockplus/content/ui/mailOverlay.xul application={92650c4d-4b8e-4d2a-b7eb-24ecf4f6b63a}
 overlay   chrome://midbrowser/content/midbrowser.xul chrome://adblockplus/content/ui/firefoxOverlay.xul application={aa5ca914-c309-495d-91cf-3141bbb04115}
 overlay   chrome://emusic/content/startup.xul chrome://adblockplus/content/ui/firefoxOverlay.xul application=dlm@emusic.com
 overlay   chrome://webrunner/content/webrunner.xul chrome://adblockplus/content/ui/prismOverlay.xul application=prism@developer.mozilla.org
 content   adblockplus jar:chrome/adblockplus.jar!/content/
 skin      adblockplus classic/1.0 jar:chrome/adblockplus.jar!/skin/
 style     chrome://global/content/customizeToolbar.xul  chrome://adblockplus/skin/overlay.css
-style     chrome://adblockplus/content/ui/seamonkeyOverlay.xul chrome://adblockplus/skin/seaMonkeyHack.css application={92650c4d-4b8e-4d2a-b7eb-24ecf4f6b63a}
-style     chrome://adblockplus/content/ui/mailOverlay.xul chrome://adblockplus/skin/seaMonkeyHack.css application={92650c4d-4b8e-4d2a-b7eb-24ecf4f6b63a}
 locale    adblockplus {{LOCALE}} jar:chrome/adblockplus.jar!/locale/{{LOCALE}}/
 
 # Hack to prevent .Net Framework Assistant from messing up the browser

=== modified file 'chrome/content/elemhide.js'
--- chrome/content/elemhide.js	2010-01-07 17:25:17 +0000
+++ chrome/content/elemhide.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -27,7 +27,7 @@
  * This file is included from AdblockPlus.js.
  */
 
-var styleService = Cc["@mozilla.org/content/style-sheet-service;1"].getService(Ci.nsIStyleSheetService); 
+XPCOMUtils.defineLazyServiceGetter(this, "styleService", "@mozilla.org/content/style-sheet-service;1", "nsIStyleSheetService");
 
 /**
  * Element hiding component

=== modified file 'chrome/content/errors.html'
--- chrome/content/errors.html	2010-01-07 17:25:17 +0000
+++ chrome/content/errors.html	2010-05-04 14:45:07 +0000
@@ -7,6 +7,7 @@
       border: 1px dashed black;
       margin: 5px;
       padding: 2px;
+      white-space: pre-wrap;
     }
 
     .error 

=== modified file 'chrome/content/filterClasses.js'
--- chrome/content/filterClasses.js	2010-01-07 17:25:17 +0000
+++ chrome/content/filterClasses.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -193,7 +193,7 @@
 /**
  * Abstract base class for filters that can get hits
  * @param {String} text see Filter()
- * @param {Array of String} domains  (optional) Domains that the filter is restricted to, e.g. ["foo.com", "bar.com", "~baz.com"]
+ * @param {String} domains  (optional) Domains that the filter is restricted to separated by domainSeparator e.g. "foo.com|bar.com|~baz.com"
  * @constructor
  * @augments Filter
  */
@@ -201,25 +201,11 @@
 {
   Filter.call(this, text);
 
-  if (domains != null)
+  if (domains)
   {
-    for each (let domain in domains)
-    {
-      if (domain == "")
-        continue;
-
-      let hash = "includeDomains";
-      if (domain[0] == "~")
-      {
-        hash = "excludeDomains";
-        domain = domain.substr(1);
-      }
-
-      if (!this[hash])
-        this[hash] = {__proto__: null};
-
-      this[hash][domain] = true;
-    }
+    this.domainSource = domains;
+    this.__defineGetter__("includeDomains", this._getIncludeDomains);
+    this.__defineGetter__("excludeDomains", this._getExcludeDomains);
   }
 }
 ActiveFilter.prototype =
@@ -243,6 +229,18 @@
   lastHit: 0,
 
   /**
+   * String that the includeDomains and excludeDomains properties should be generated from
+   * @type String
+   */
+  domainSource: null,
+
+  /**
+   * Separator character used in domainSource property, must be overridden by subclasses
+   * @type String
+   */
+  domainSeparator: null,
+
+  /**
    * Map containing domains that this filter should match on or null if the filter should match on all domains
    * @type Object
    */
@@ -254,6 +252,62 @@
   excludeDomains: null,
 
   /**
+   * Called first time includeDomains property is requested, triggers _generateDomains method.
+   */
+  _getIncludeDomains: function()
+  {
+    this._generateDomains();
+    return this.includeDomains;
+  },
+  /**
+   * Called first time excludeDomains property is requested, triggers _generateDomains method.
+   */
+  _getExcludeDomains: function()
+  {
+    this._generateDomains();
+    return this.excludeDomains;
+  },
+
+  /**
+   * Generates includeDomains and excludeDomains properties when one of them is requested for the first time.
+   */
+  _generateDomains: function()
+  {
+    let domains = this.domainSource.split(this.domainSeparator);
+
+    delete this.domainSource;
+    delete this.includeDomains;
+    delete this.excludeDomains;
+
+    if (domains.length == 1 && domains[0][0] != "~")
+    {
+      // Fast track for the common one-domain scenario
+      this.includeDomains = {__proto__: null};
+      this.includeDomains[domains[0]] = true;
+    }
+    else
+    {
+      for each (let domain in domains)
+      {
+        if (domain == "")
+          continue;
+  
+        let hash = "includeDomains";
+        if (domain[0] == "~")
+        {
+          hash = "excludeDomains";
+          domain = domain.substr(1);
+        }
+  
+        if (!this[hash])
+          this[hash] = {__proto__: null};
+  
+        this[hash][domain] = true;
+      }
+    }
+  },
+
+  /**
    * Checks whether this filter is active on a domain.
    */
   isActiveOnDomain: function(/**String*/ docDomain) /**Boolean*/
@@ -293,7 +347,7 @@
     docDomain = docDomain.replace(/\.+$/, "").toUpperCase();
 
     for (let domain in this.includeDomains)
-      if (domain != docDomain && domain.indexOf("." + docDomain) != domain.length - docDomain.length - 1)
+      if (domain != docDomain && (domain.length <= docDomain.length || domain.indexOf("." + docDomain) != domain.length - docDomain.length - 1))
         return false;
 
     return true;
@@ -321,7 +375,7 @@
 /**
  * Abstract base class for RegExp-based filters
  * @param {String} text see Filter()
- * @param {String} regexp       regular expression this filter should use
+ * @param {String} regexpSource filter part that the regular expression should be build from
  * @param {Number} contentType  (optional) Content types the filter applies to, combination of values from RegExpFilter.typeMap
  * @param {Boolean} matchCase   (optional) Defines whether the filter should distinguish between lower and upper case letters
  * @param {String} domains      (optional) Domains that the filter is restricted to, e.g. "foo.com|bar.com|~baz.com"
@@ -329,9 +383,9 @@
  * @constructor
  * @augments ActiveFilter
  */
-function RegExpFilter(text, regexp, contentType, matchCase, domains, thirdParty)
+function RegExpFilter(text, regexpSource, contentType, matchCase, domains, thirdParty)
 {
-  ActiveFilter.call(this, text, domains ? domains.split("|") : null);
+  ActiveFilter.call(this, text, domains);
 
   if (contentType != null)
     this.contentType = contentType;
@@ -340,13 +394,33 @@
   if (thirdParty != null)
     this.thirdParty = thirdParty;
 
-  this.regexp = new RegExp(regexp, this.matchCase ? "" : "i");
+  if (regexpSource[0] == "/" && regexpSource[regexpSource.length - 1] == "/")
+  {
+    // The filter is a regular expression - convert it immediately to catch syntax errors
+    this.regexp = new RegExp(regexpSource.substr(1, regexpSource.length - 2), this.matchCase ? "" : "i");
+  }
+  else
+  {
+    // No need to convert this filter to regular expression yet, do it on demand
+    this.regexpSource = regexpSource;
+    this.__defineGetter__("regexp", this._generateRegExp);
+  }
 }
 RegExpFilter.prototype =
 {
   __proto__: ActiveFilter.prototype,
 
   /**
+   * @see ActiveFilter.domainSeparator
+   */
+  domainSeparator: "|",
+
+  /**
+   * Expression from which a regular expression should be generated - for delayed creation of the regexp property
+   * @type String
+   */
+  regexpSource: null,
+  /**
    * Regular expression to be used when testing against this filter
    * @type RegExp
    */
@@ -373,6 +447,40 @@
   thirdParty: null,
 
   /**
+   * Generates regexp property when it is requested for the first time.
+   * @return {RegExp}
+   */
+  _generateRegExp: function()
+  {
+    // Remove multiple wildcards
+    let source = this.regexpSource.replace(/\*+/g, "*");
+
+    // Remove leading wildcards
+    if (source[0] == "*")
+      source = source.substr(1);
+
+    // Remove trailing wildcards
+    let pos = source.length - 1;
+    if (source[pos] == "*")
+      source = source.substr(0, pos);
+
+    source = source.replace(/\^\|$/, "^")       // remove anchors following separator placeholder
+                   .replace(/\W/g, "\\$&")    // escape special symbols
+                   .replace(/\\\*/g, ".*")      // replace wildcards by .*
+                   // process separator placeholders (all ANSI charaters but alphanumeric characters and _%.-)
+                   .replace(/\\\^/g, "(?:[\\x00-\\x24\\x26-\\x2C\\x2F\\x3A-\\x40\\x5B-\\x5E\\x60\\x7B-\\x80]|$)")
+                   .replace(/^\\\|\\\|/, "^[\\w\\-]+:\\/+(?!\\/)(?:[^\\/]+\\.)?") // process extended anchor at expression start
+                   .replace(/^\\\|/, "^")       // process anchor at expression start
+                   .replace(/\\\|$/, "$");      // process anchor at expression end
+
+    let regexp = new RegExp(source, this.matchCase ? "" : "i");
+
+    delete this.regexp;
+    delete this.regexpSource;
+    return (this.regexp = regexp);
+  },
+
+  /**
    * Tests whether the URL matches this filters
    * @param {String} location URL to be tested
    * @param {String} contentType content type identifier of the URL
@@ -413,11 +521,11 @@
   if (Filter.optionsRegExp.test(text))
   {
     options = RegExp.$1.toUpperCase().split(",");
-    text = text.replace(Filter.optionsRegExp, "");
+    text = RegExp.leftContext;
     for each (let option in options)
     {
       let value;
-      [option, value] = option.split("=");
+      [option, value] = option.split("=", 2);
       option = option.replace(/-/, "_");
       if (option in RegExpFilter.typeMap)
       {
@@ -428,7 +536,7 @@
       else if (option[0] == "~" && option.substr(1) in RegExpFilter.typeMap)
       {
         if (contentType == null)
-          contentType = 0x7FFFFFFF;
+          contentType = RegExpFilter.prototype.contentType;
         contentType &= ~RegExpFilter.typeMap[option.substr(1)];
       }
       else if (option == "MATCH_CASE")
@@ -446,39 +554,18 @@
     }
   }
 
-  let regexp;
-  if (text[0] == "/" && text[text.length - 1] == "/")   // filter is a regexp already
-  {
-    regexp = text.substr(1, text.length - 2);
-  }
-  else
-  {
-    regexp = text.replace(/\*+/g, "*")        // remove multiple wildcards
-                 .replace(/\^\|$/, "^")       // remove anchors following separator placeholder
-                 .replace(/(\W)/g, "\\$1")    // escape special symbols
-                 .replace(/\\\*/g, ".*")      // replace wildcards by .*
-                 .replace(/\\\^/g, "(?:[^\\w\\-.%\\u0080-\\uFFFF]|$)")            // process separator placeholders
-                 .replace(/^\\\|\\\|/, "^[\\w\\-]+:\\/+(?!\\/)(?:[^\\/]+\\.)?") // process extended anchor at expression start
-                 .replace(/^\\\|/, "^")       // process anchor at expression start
-                 .replace(/\\\|$/, "$")       // process anchor at expression end
-                 .replace(/^(\.\*)/,"")       // remove leading wildcards
-                 .replace(/(\.\*)$/,"");      // remove trailing wildcards 
-  }
-  if (regexp == "")
-    regexp = ".*";
-
   if (constructor == WhitelistFilter && (contentType == null || (contentType & RegExpFilter.typeMap.DOCUMENT)) &&
       (!options || options.indexOf("DOCUMENT") < 0) && !/^\|?[\w\-]+:/.test(text))
   {
     // Exception filters shouldn't apply to pages by default unless they start with a protocol name
     if (contentType == null)
-      contentType = 0x7FFFFFFF;
+      contentType = RegExpFilter.prototype.contentType;
     contentType &= ~RegExpFilter.typeMap.DOCUMENT;
   }
 
   try
   {
-    return new constructor(origText, regexp, contentType, matchCase, domains, thirdParty, collapse);
+    return new constructor(origText, text, contentType, matchCase, domains, thirdParty, collapse);
   }
   catch (e)
   {
@@ -504,13 +591,18 @@
   OBJECT_SUBREQUEST: 4096,
   DTD: 8192,
   MEDIA: 16384,
-  FONT: 32768
+  FONT: 32768,
+
+  ELEMHIDE: 0x40000000
 };
 
+// ELEMHIDE option shouldn't be there by default
+RegExpFilter.prototype.contentType &= ~RegExpFilter.typeMap.ELEMHIDE;
+
 /**
  * Class for blocking filters
  * @param {String} text see Filter()
- * @param {String} regexp see RegExpFilter()
+ * @param {String} regexpSource see RegExpFilter()
  * @param {Number} contentType see RegExpFilter()
  * @param {Boolean} matchCase see RegExpFilter()
  * @param {String} domains see RegExpFilter()
@@ -519,9 +611,9 @@
  * @constructor
  * @augments RegExpFilter
  */
-function BlockingFilter(text, regexp, contentType, matchCase, domains, thirdParty, collapse)
+function BlockingFilter(text, regexpSource, contentType, matchCase, domains, thirdParty, collapse)
 {
-  RegExpFilter.call(this, text, regexp, contentType, matchCase, domains, thirdParty);
+  RegExpFilter.call(this, text, regexpSource, contentType, matchCase, domains, thirdParty);
 
   this.collapse = collapse;
 }
@@ -540,7 +632,7 @@
 /**
  * Class for whitelist filters
  * @param {String} text see Filter()
- * @param {String} regexp see RegExpFilter()
+ * @param {String} regexpSource see RegExpFilter()
  * @param {Number} contentType see RegExpFilter()
  * @param {Boolean} matchCase see RegExpFilter()
  * @param {String} domains see RegExpFilter()
@@ -548,9 +640,9 @@
  * @constructor
  * @augments RegExpFilter
  */
-function WhitelistFilter(text, regexp, contentType, matchCase, domains, thirdParty)
+function WhitelistFilter(text, regexpSource, contentType, matchCase, domains, thirdParty)
 {
-  RegExpFilter.call(this, text, regexp, contentType, matchCase, domains, thirdParty);
+  RegExpFilter.call(this, text, regexpSource, contentType, matchCase, domains, thirdParty);
 }
 WhitelistFilter.prototype =
 {
@@ -568,12 +660,10 @@
  */
 function ElemHideFilter(text, domains, selector)
 {
-  if (domains)
-    domains = domains.toUpperCase().split(",");
-  ActiveFilter.call(this, text, domains);
+  ActiveFilter.call(this, text, domains ? domains.toUpperCase() : null);
 
   if (domains)
-    this.selectorDomain = domains.filter(function(domain) domain[0] != "~").join(",").toLowerCase();
+    this.selectorDomain = domains.replace(/,~[^,]+/g, "").replace(/^~[^,]+,?/, "").toLowerCase();
   this.selector = selector;
 }
 ElemHideFilter.prototype =
@@ -581,6 +671,11 @@
   __proto__: ActiveFilter.prototype,
 
   /**
+   * @see ActiveFilter.domainSeparator
+   */
+  domainSeparator: ",",
+
+  /**
    * Host name or domain the filter should be restricted to (can be null for no restriction)
    * @type String
    */
@@ -611,8 +706,6 @@
  */
 ElemHideFilter.fromText = function(text, domain, tagName, attrRules, selector)
 {
-  domain = domain.replace(/^,+/, "").replace(/,+$/, "").replace(/,+/g, ",");
-
   if (!selector)
   {
     if (tagName == "*")

=== modified file 'chrome/content/filterListener.js'
--- chrome/content/filterListener.js	2010-01-07 17:25:17 +0000
+++ chrome/content/filterListener.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):

=== modified file 'chrome/content/filterStorage.js'
--- chrome/content/filterStorage.js	2010-01-07 17:25:17 +0000
+++ chrome/content/filterStorage.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -27,7 +27,7 @@
  * This file is included from AdblockPlus.js.
  */
 
-var dirService = Cc["@mozilla.org/file/directory_service;1"].getService(Ci.nsIProperties);
+XPCOMUtils.defineLazyServiceGetter(this, "dirService", "@mozilla.org/file/directory_service;1", "nsIProperties");
 
 /**
  * This class reads user's filters from disk, manages them in memory and writes them back.
@@ -239,6 +239,13 @@
     this._addSubscriptionFilters(subscription);
     this.triggerSubscriptionObservers("update", [subscription]);
     delete subscription.oldFilters;
+
+    // Do not keep empty subscriptions disabled
+    if (subscription instanceof SpecialSubscription && !subscription.filters.length && subscription.disabled)
+    {
+      subscription.disabled = false;
+      this.triggerSubscriptionObservers("enable", [subscription]);
+    }
   },
 
   /**
@@ -301,6 +308,14 @@
             subscription.filters.splice(j, 1);
             if (!silent)
               this.triggerFilterObservers("remove", [filter]);
+
+            // Do not keep empty subscriptions disabled
+            if (!subscription.filters.length && subscription.disabled)
+            {
+              subscription.disabled = false;
+              if (!silent)
+                this.triggerSubscriptionObservers("enable", [subscription]);
+            }
             return;
           }
         }

=== modified file 'chrome/content/matcher.js'
--- chrome/content/matcher.js	2010-01-07 17:25:17 +0000
+++ chrome/content/matcher.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -162,9 +162,24 @@
     if (Filter.regexpRegExp.test(text))
       return null;
 
-    text = text.replace(Filter.optionsRegExp, "").replace(/^@@/, "")
-               .replace(/^\|{1,2}/, "").replace(/\|$/, "")
-               .replace(/\^/g, "*").toLowerCase();
+    // Remove options
+    if (Filter.optionsRegExp.test(text))
+      text = RegExp.leftContext;
+
+    // Remove whitelist marker
+    if (text.substr(0, 2) == "@@")
+      text = text.substr(2);
+
+    // Remove anchors
+    let pos = text.length - 1;
+    if (text[pos] == "|")
+      text = text.substr(0, pos);
+    if (text[0] == "|")
+      text = text.substr(1);
+    if (text[0] == "|")
+      text = text.substr(1);
+
+    text = text.replace(/\^/g, "*").toLowerCase();
 
     let len = Matcher.shortcutLength;
     let numCandidates = text.length - len + 1;

=== modified file 'chrome/content/mochitest/tests/common.js'
--- chrome/content/mochitest/tests/common.js	2010-01-07 17:25:17 +0000
+++ chrome/content/mochitest/tests/common.js	2010-05-04 14:45:07 +0000
@@ -9,7 +9,17 @@
 
 Cu.import("resource://gre/modules/XPCOMUtils.jsm");
 
-var versionComparator = Cc["@mozilla.org/xpcom/version-comparator;1"].createInstance(Ci.nsIVersionComparator)
+// Always overwrite defineLazyServiceGetter - the default one will get the object wrapped and fail
+XPCOMUtils.defineLazyServiceGetter = function XPCU_defineLazyServiceGetter(obj, prop, contract, iface)
+{
+  obj.__defineGetter__(prop, function XPCU_serviceGetter()
+  {
+    delete obj[prop];
+    return obj[prop] = Cc[contract].getService(Ci[iface]);
+  });
+};
+
+XPCOMUtils.defineLazyServiceGetter(this, "versionComparator", "@mozilla.org/xpcom/version-comparator;1", "nsIVersionComparator");
 
 var abp = {
   getString: function(name)

=== added file 'chrome/content/mochitest/tests/performance/common.js'
--- chrome/content/mochitest/tests/performance/common.js	1970-01-01 00:00:00 +0000
+++ chrome/content/mochitest/tests/performance/common.js	2010-05-04 14:45:07 +0000
@@ -0,0 +1,60 @@
+function runTests(testFunc, cleanupFunc)
+{
+  const minRuns = 15;
+  const maxRuns = 400;
+  const targetConfidenceInterval = 0.04;
+
+  let currentRun = 0;
+  let results = [];
+  function runNextTest()
+  {
+    currentRun++;
+
+    if (currentRun > minRuns)
+    {
+      let [avg, interval] = getConfidenceInterval(results);
+
+      if (currentRun > maxRuns || interval <= avg * targetConfidenceInterval)
+      {
+        let text = "Average time: " + avg.toFixed(1) + " ms +/- " + interval.toFixed(1) + " ms (95% confidence)\n\n";
+        for (let i = 0; i < results.length; i++)
+          text += "Run no. " + (i + 1) + ": " + results[i] + " ms\n";
+
+        document.getElementById("result").textContent = text;
+        return;
+      }
+    }
+
+    // Make sure garbage collection doesn't run during the test
+    Components.utils.forceGC();
+
+    let startTime = Date.now();
+    testFunc();
+    let endTime = Date.now();
+    results.push(endTime - startTime);
+
+    if (cleanupFunc)
+      cleanupFunc();
+
+    setTimeout(runNextTest, 0);
+  }
+
+  setTimeout(runNextTest, 0);
+}
+
+function getConfidenceInterval(results)
+{
+  let sum = 0;
+  let sqrsum = 0;
+
+  for each (let result in results)
+  {
+    sum += result;
+    sqrsum += result * result;
+  }
+
+  let avg = sum / results.length;
+  let stddev = Math.sqrt((sqrsum - 2 * sum * avg + avg * avg * results.length) / results.length);
+  let confidence = 1.96 * stddev; // 95% confidence, assuming Gaussian distribution
+  return [avg, stddev];
+}

=== added file 'chrome/content/mochitest/tests/performance/filter_fromText.html'
--- chrome/content/mochitest/tests/performance/filter_fromText.html	1970-01-01 00:00:00 +0000
+++ chrome/content/mochitest/tests/performance/filter_fromText.html	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5299 @@
+<!DOCTYPE HTML>
+<html>
+<head>
+  <title>Filter initialization performance measurements</title>
+  <script type="application/x-javascript;version=1.7" src="common.js"></script>
+  <script type="application/x-javascript;version=1.7" src="../common.js"></script>
+  <script type="application/x-javascript;version=1.7" src="chrome://adblockplus/content/filterClasses.js"></script>
+</head>
+<body>
+  <p id="progress">Please wait while performance measurement is in progress... <span id="current"></span></p>
+
+  <pre id="result"></pre>
+
+  <script type="application/x-javascript;version=1.7">
+    let filters = [
+      "! Checksum: D9WOmVox9uh2SWX6Dg5tGg",
+      "!",
+      "! Rick752's EasyList - Global English ad blocking subscription",
+      "! https://easylist.adblockplus.org/",
+      "! License: http://creativecommons.org/licenses/by-sa/3.0/",
+      "! Last modified: 19 Mar 2010 07:00 UTC",
+      "! Expires: 5 days (updates automatically every 5 days)",
+      "!",
+      "! Please report unblocked ads or mistakenly blocked content:",
+      "! Forum: http://forums.lanik.us/",
+      "! E-Mail: ares2mail -at- gmail.com",
+      "!",
+      "!------------------------------------General ad blocking rules-------------------------------------!",
+      "! *** easylist_general_block.txt ***",
+      "&ad_type_id=",
+      "-ad.html",
+      "-banner-ads/",
+      ".aspx?zoneid=*&task=",
+      ".au/_ads/",
+      ".au/ads/",
+      ".ca/ads/",
+      ".com/ad-",
+      ".com/ad/",
+      ".com/ads/",
+      ".com/ads?",
+      ".com/adv/",
+      ".com/advt/",
+      ".com/gad/",
+      ".com/gads/",
+      ".com/ss/ad/",
+      ".html?ad=",
+      ".net/_ads/",
+      ".net/ad/$~object_subrequest",
+      ".net/ads/",
+      ".net/adv/",
+      ".nz/ads/",
+      ".org/ads/",
+      ".org/gads/",
+      ".php?bannerid=",
+      ".php?zoneid=*&loc=",
+      ".swf?clicktag=",
+      ".tv/ads/",
+      ".uk/ads/",
+      ".us/ads/",
+      ".za/ads/",
+      "/*;cue=pre;$object_subrequest",
+      "/.adserv/*",
+      "/468xads.",
+      "/_adv.gif?",
+      "/_media/ads/*",
+      "/a8-ads/*",
+      "/aamsz=*/acc_random=",
+      "/aamsz=*/pageid=",
+      "/aamsz=*/position=",
+      "/abm.asp?z=",
+      "/abmw.asp?z=",
+      "/abmw.aspx",
+      "/acc_random=*/aamsz=",
+      "/ad-1.5.",
+      "/ad-amz.",
+      "/ad-box-single.",
+      "/ad-cdn.",
+      "/ad-frame.",
+      "/ad-iframe-wrapper.",
+      "/ad-inject/*",
+      "/ad-leaderboard.",
+      "/ad-loader-frame.",
+      "/ad-server/*",
+      "/ad-top-fr.",
+      "/ad-topbanner-single.",
+      "/ad-vertical-single.",
+      "/ad.asp?",
+      "/ad.aspx",
+      "/ad.cgi?",
+      "/ad.html",
+      "/ad.jsp?",
+      "/ad.mason?",
+      "/ad.php?",
+      "/ad.pl?z",
+      "/ad/?id=",
+      "/ad/adtech",
+      "/ad/banner",
+      "/ad/code",
+      "/ad/common",
+      "/ad/frame",
+      "/ad/google",
+      "/ad/header",
+      "/ad/iframe/*",
+      "/ad/img/*",
+      "/ad/inad",
+      "/ad/init",
+      "/ad/lrec",
+      "/ad/mercury",
+      "/ad/mrec",
+      "/ad/script/*",
+      "/ad/serve",
+      "/ad/side_",
+      "/ad/skyscraper",
+      "/ad/sponsor",
+      "/ad/text",
+      "/ad/view",
+      "/ad/wr.php",
+      "/ad160.php",
+      "/ad1x1home.",
+      "/ad2.aspx",
+      "/ad2.html",
+      "/ad350.html",
+      "/ad728.php",
+      "/ad728x15.",
+      "/ad?count=",
+      "/ad_banner_left/*",
+      "/ad_banner_right/*",
+      "/ad_configuration.",
+      "/ad_creatives.",
+      "/ad_engine?",
+      "/ad_feed.js?",
+      "/ad_forum_",
+      "/ad_frame.",
+      "/ad_functions.",
+      "/ad_google.",
+      "/ad_holder/*",
+      "/ad_iframe.",
+      "/ad_iframe_",
+      "/ad_insert.",
+      "/ad_js.php",
+      "/ad_label_",
+      "/ad_left.",
+      "/ad_legend_",
+      "/ad_manager.",
+      "/ad_notice.",
+      "/ad_page_frame.",
+      "/ad_rectangle_",
+      "/ad_refresher.",
+      "/ad_reloader_",
+      "/ad_right.",
+      "/ad_serv.",
+      "/ad_serve.",
+      "/ad_server.",
+      "/ad_server/*",
+      "/ad_sizes=",
+      "/ad_sky.",
+      "/ad_space.",
+      "/ad_square.",
+      "/ad_supertile/*",
+      "/ad_tag_",
+      "/ad_tile/*",
+      "/ad_top.",
+      "/ad_vert.",
+      "/ad_view_",
+      "/adbanner.",
+      "/adbanner/*",
+      "/adbanners/*",
+      "/adbot_promos/*",
+      "/adbox.gif",
+      "/adbrite.",
+      "/adbureau.",
+      "/adchannel_",
+      "/adclick.",
+      "/adclient.",
+      "/adclient/*",
+      "/adcode.",
+      "/adcodes/*",
+      "/adconfig.js",
+      "/adconfig.xml?",
+      "/adconfig/*",
+      "/adcontent.$~object_subrequest",
+      "/adcreative.",
+      "/adcycle.",
+      "/adcycle/*",
+      "/addelivery/*",
+      "/addyn/3.0/*",
+      "/addyn|*|adtech;",
+      "/adengage1.",
+      "/adengage_",
+      "/adengine/*",
+      "/adexclude/*",
+      "/adf.cgi?",
+      "/adfarm.",
+      "/adfetch?",
+      "/adfetcher?",
+      "/adfooter.",
+      "/adframe.",
+      "/adframe/*",
+      "/adframe?",
+      "/adframe_",
+      "/adfshow?",
+      "/adfunction.",
+      "/adfunctions.",
+      "/adgraphics/*",
+      "/adguru.",
+      "/adhandler/*",
+      "/adheader.",
+      "/adhomepage.jsp",
+      "/adhtml/*",
+      "/adiframe.",
+      "/adiframe/*",
+      "/adimage.aspx",
+      "/adimage.php?",
+      "/adimages.",
+      "/adimages/*",
+      "/adindex/*",
+      "/adinjector.",
+      "/adinsert.",
+      "/adinterax.",
+      "/adjs.php?",
+      "/adjsmp.php?",
+      "/adlabel.",
+      "/adlabel_",
+      "/adlayer.php?",
+      "/adlayer/*",
+      "/adleader.",
+      "/adlink.",
+      "/adlink_",
+      "/adlinks.",
+      "/adm/ad/*",
+      "/adman.js",
+      "/adman/image/*",
+      "/adman/www/*",
+      "/admanagement/*",
+      "/admanagementadvanced.",
+      "/admanager.$~object_subrequest",
+      "/admanager/*$~object_subrequest",
+      "/admanager3.",
+      "/admanagerstatus/*",
+      "/admaster.",
+      "/admaster?",
+      "/admedia.",
+      "/admentor/*",
+      "/admin/ad_",
+      "/adnetwork.",
+      "/adng.html",
+      "/adonline.",
+      "/adpage.",
+      "/adpage/*",
+      "/adpeeps.",
+      "/adpeeps/*",
+      "/adplayer.",
+      "/adplayer/*",
+      "/adplugin.",
+      "/adpoint.",
+      "/adpopup.",
+      "/adproducts/*",
+      "/adproxy.",
+      "/adproxy/*",
+      "/adrelated.",
+      "/adreload?",
+      "/adremote.",
+      "/adrevenue/*",
+      "/adrevolver/*",
+      "/adrolays.",
+      "/adroot/*",
+      "/adrot.js",
+      "/adruptive.",
+      "/ads-1.js",
+      "/ads-2.js",
+      "/ads-banner.",
+      "/ads-leader|",
+      "/ads-rec|",
+      "/ads-service.",
+      "/ads-sky|",
+      "/ads.asp?",
+      "/ads.dll/*",
+      "/ads.htm",
+      "/ads.php?",
+      "/ads/acctid",
+      "/ads/ad-",
+      "/ads/common/*",
+      "/ads/frame",
+      "/ads/freewheel/*",
+      "/ads/house/*",
+      "/ads/html",
+      "/ads/i_ads.",
+      "/ads/interstitial/*",
+      "/ads/java",
+      "/ads/labels/*",
+      "/ads/layer.",
+      "/ads/pa/*",
+      "/ads/paid",
+      "/ads/right",
+      "/ads/text",
+      "/ads/top",
+      "/ads/www",
+      "/ads2.php",
+      "/ads2_2.",
+      "/ads_iframe.",
+      "/ads_php/*",
+      "/ads_reporting/*",
+      "/ads_v2.",
+      "/ads_yahoo.",
+      "/adsadclient31.",
+      "/adsadview.",
+      "/adsatt.",
+      "/adsbanner.",
+      "/adscluster.",
+      "/adscontent.",
+      "/adscontent2.",
+      "/adscript.",
+      "/adscripts/*",
+      "/adsearch.",
+      "/adsense.",
+      "/adsense/*",
+      "/adsense23.",
+      "/adsense24.",
+      "/adsense_",
+      "/adserve/*",
+      "/adserver.",
+      "/adserver/*",
+      "/adserver2.",
+      "/adserver2/*",
+      "/adserver?",
+      "/adserver_",
+      "/adserversolutions/*",
+      "/adservice|",
+      "/adserving.",
+      "/adsfac.",
+      "/adsfetch.",
+      "/adsfolder/*",
+      "/adshandler.",
+      "/adsheader.",
+      "/adshow?",
+      "/adsiframe/*",
+      "/adsign.",
+      "/adsimage/*",
+      "/adsinclude.",
+      "/adsinsert.",
+      "/adsky.php",
+      "/adslots.",
+      "/adslug_",
+      "/adsmanagement/*",
+      "/adsmanager/*",
+      "/adsnew.",
+      "/adsonar.",
+      "/adspace.",
+      "/adsponsor.",
+      "/adspro/*",
+      "/adsremote.",
+      "/adsreporting/*",
+      "/adssrv.",
+      "/adstorage.",
+      "/adstracking.",
+      "/adstream.",
+      "/adstream_nx.",
+      "/adswap.",
+      "/adswap/*",
+      "/adsync/*",
+      "/adsyndication.",
+      "/adsystem/*",
+      "/adtago.",
+      "/adtags.",
+      "/adtags/*",
+      "/adtagtranslator.",
+      "/adtech.",
+      "/adtech/*",
+      "/adtech;",
+      "/adtech_",
+      "/adtext.",
+      "/adtext_",
+      "/adtology.",
+      "/adtop.js",
+      "/adtrack/*",
+      "/adtraff.",
+      "/adtype.php?",
+      "/adunit.",
+      "/adunits/*",
+      "/adv-title.",
+      "/adv.asp?",
+      "/advert.",
+      "/advert/*",
+      "/advert?",
+      "/advert_",
+      "/advertise.",
+      "/advertise/*",
+      "/advertisement-",
+      "/advertisement.",
+      "/advertisement_",
+      "/advertisements/*",
+      "/advertisementview/*",
+      "/advertising.",
+      "/advertising/*",
+      "/advertising_js/*",
+      "/advertisingmanual.",
+      "/advertisment.",
+      "/advertize_on_",
+      "/advertorials/*",
+      "/advertpro/*",
+      "/adverts.",
+      "/adverts/*",
+      "/adverts_",
+      "/adview.",
+      "/adviewer.",
+      "/advision.",
+      "/advpartnerinit.",
+      "/advt.gif",
+      "/adworks.",
+      "/adworks/*",
+      "/adwrapper/*",
+      "/adwrapperiframe.",
+      "/aff_frame.",
+      "/affad?q=",
+      "/affads/*",
+      "/affilatebanner.",
+      "/affiliate*.php?",
+      "/affiliate/banners/*",
+      "/affiliate_banners/*",
+      "/affiliatebanners/*",
+      "/affiliates.*.aspx?",
+      "/affiliates/banner",
+      "/affiliatewiz/*",
+      "/affiliationcash.",
+      "/afimages.",
+      "/afr.php?",
+      "/ajax/ads/*",
+      "/ajrotator/*",
+      "/ajs.php?",
+      "/ak/ads/*",
+      "/annonser/*",
+      "/api/ads/*",
+      "/app/ads.js",
+      "/article_ad.",
+      "/aseadnshow.",
+      "/audioads/*",
+      "/auto_ad_change.",
+      "/ban_m.php?",
+      "/banimpress.",
+      "/banman.asp?",
+      "/banman/*",
+      "/banner/affiliate/*",
+      "/banner_ad.",
+      "/banner_ad_",
+      "/banner_ads.",
+      "/banner_ads_",
+      "/banner_control.php?",
+      "/banner_db.php?",
+      "/banner_file.php?",
+      "/banner_js.*?",
+      "/banner_management/*",
+      "/banner_skyscraper.",
+      "/bannerad.",
+      "/bannerads-",
+      "/bannerads/*",
+      "/banneradviva.",
+      "/bannercode.php",
+      "/bannerfarm/*",
+      "/bannerframe.*?",
+      "/bannermanager/*",
+      "/bannermedia/*",
+      "/bannerrotation.",
+      "/banners.*&iframe=",
+      "/banners/affiliate/*",
+      "/banners_rotation.",
+      "/bannerscript/*",
+      "/bannerserver/*",
+      "/bannersyndication.",
+      "/bannerview.*?",
+      "/bannery/*?banner=",
+      "/baselinead.",
+      "/behaviorads/*",
+      "/bg_ads_",
+      "/bigboxad.",
+      "/bkgrndads/*",
+      "/blogad_",
+      "/blogads.",
+      "/blogads3/*",
+      "/bmndoubleclickad.",
+      "/bnrsrv.*?",
+      "/boomad.",
+      "/bottomad/*",
+      "/br_ad_courier.",
+      "/butler.php?type=",
+      "/buttonads.",
+      "/buyclicks/*",
+      "/bw_adsys.",
+      "/bytemark_ad.",
+      "/cashad.",
+      "/cashad2.",
+      "/central/ads/*",
+      "/cgi-bin/ads/*",
+      "/chitika-ad?",
+      "/circads.",
+      "/cnnslads.",
+      "/cnwk.1d/ads/*",
+      "/commercial_horizontal.",
+      "/commercial_top.",
+      "/commercials/*",
+      "/common/ad/*",
+      "/common/ads/*",
+      "/contentad|",
+      "/contextad.",
+      "/controller/ads/*",
+      "/corner_ads/*",
+      "/country_ad.",
+      "/cpxads.",
+      "/ctamlive160x160.",
+      "/customad.",
+      "/cvs/ads/*",
+      "/dart_ads/*",
+      "/dartads.",
+      "/dc_ads.",
+      "/dcloadads/*",
+      "/deliver.nmi?",
+      "/deliverad/*",
+      "/deliverjs.nmi?",
+      "/delivery/ag.php",
+      "/descpopup.js",
+      "/direct_ads.",
+      "/directads.",
+      "/displayad.",
+      "/displayads/*",
+      "/dj_ad.js",
+      "/dne_ad.",
+      "/dnsads.html?",
+      "/doors/ads/*",
+      "/doubleclick.phpi?",
+      "/doubleclick/iframe.",
+      "/doubleclickcontainer.",
+      "/doubleclicktag.",
+      "/drawad.php?",
+      "/dsg/bnn/*",
+      "/dt.cms.ad.page.",
+      "/dyn_banner.",
+      "/dyn_banners_",
+      "/dynamicad?",
+      "/dynamiccsad?",
+      "/dynbanner/flash/*",
+      "/ebay_ads/*",
+      "/emailads/*",
+      "/external/ad.js",
+      "/eyewondermanagement.",
+      "/fatads.",
+      "/featuredadshome.",
+      "/files/ads/*",
+      "/fimserve.",
+      "/flash/ads/*",
+      "/flashads.",
+      "/flashads/*",
+      "/footad-",
+      "/footer_ad_include.",
+      "/fuseads/*",
+      "/gamersad.",
+      "/genericrichmediabannerad/*",
+      "/get-ad.php?",
+      "/get_player_ads_",
+      "/getad.php?",
+      "/getad.php|",
+      "/getad?n=",
+      "/getadframe.",
+      "/getadvertimageservlet?",
+      "/getarticleadvertimageservlet?",
+      "/getbanner.cfm?",
+      "/getsponslinks.",
+      "/getsponslinksauto.",
+      "/getvideoad.",
+      "/gfx/ads/*",
+      "/glam_ads.",
+      "/google-ad?",
+      "/google-ads.",
+      "/google-adsense-",
+      "/google-adsense.",
+      "/google_ad_",
+      "/google_ads.",
+      "/google_ads/*",
+      "/google_adsense.",
+      "/google_adsense_",
+      "/google_afc.",
+      "/googlead-",
+      "/googlead.",
+      "/googleadhtml/*",
+      "/googleads-",
+      "/googleads.html",
+      "/googleads.js",
+      "/googleads2.",
+      "/googleads_",
+      "/googleadsense.",
+      "/gt6skyadtop.",
+      "/hat_ad_label.",
+      "/homepage_ads/*",
+      "/housead/*",
+      "/houseads/*",
+      "/houseads?",
+      "/html.ng/*",
+      "/htmlads/*",
+      "/httpads/*",
+      "/icon_ad.",
+      "/iframe-ads/*",
+      "/iframe/ad/*",
+      "/iframe_ad.",
+      "/iframe_ads/*",
+      "/iframe_ads?",
+      "/iframe_chitika_",
+      "/iframead.",
+      "/im-ad/im-",
+      "/images/ad-",
+      "/images/ad/*",
+      "/images/ad_",
+      "/images/ads-",
+      "/images/ads/*",
+      "/img/ad_",
+      "/img/ads/*",
+      "/in/adv/*",
+      "/inc/ads/*",
+      "/include/ads/*",
+      "/includes/ad_",
+      "/includes/ads/*",
+      "/inline_ad.",
+      "/instreamad/*",
+      "/intextads.",
+      "/invideoad.",
+      "/ireel/ad*.jpg",
+      "/iwadsense.",
+      "/j/ads.js",
+      "/ji_advertise.",
+      "/jivoxadplayer.",
+      "/jlist-affiliates/*",
+      "/js.ng/c",
+      "/js.ng/s",
+      "/js/ad_eo_",
+      "/js/ads.js",
+      "/js/ads/*",
+      "/jsfiles/ads/*",
+      "/kredit-ad.",
+      "/layer-ad.",
+      "/layer-ads.",
+      "/layerads_",
+      "/layout/ads/*",
+      "/lbl_ad.",
+      "/leader_ad.",
+      "/links_sponsored_",
+      "/linkshare/*",
+      "/loadad.aspx?",
+      "/m4_advertorials/*",
+      "/m=advert/*",
+      "/mac-ad?",
+      "/magic-ads/*",
+      "/main/ad_",
+      "/mainad.",
+      "/mbn_ad.",
+      "/media/ads/*",
+      "/megaad.",
+      "/metaadserver/*",
+      "/miva_ads.",
+      "/mnetorfad.js",
+      "/mod_ad/*",
+      "/modules/ads/*",
+      "/mpumessage.",
+      "/mstextad?",
+      "/mtvi_ads_",
+      "/mylayer-ad/*",
+      "/neoads.",
+      "/new/ad/*",
+      "/newrightcolad.",
+      "/news_ad.",
+      "/newtopmsgad.",
+      "/nextad/*",
+      "/oasadframe.",
+      "/oascentral.$~object_subrequest",
+      "/oasdefault/*",
+      "/oasisi-*.php?",
+      "/oasisi.php?",
+      "/oiopub-direct/*",
+      "/openads-",
+      "/openads.",
+      "/openads/*",
+      "/openads2/*",
+      "/openx/www/*",
+      "/openx_fl.",
+      "/other/ads/*",
+      "/overlay_ad_",
+      "/ovt_show.asp?",
+      "/p2/ads/*",
+      "/page-ads.",
+      "/pagead/ads?*_fetch=",
+      "/pagead/ads?*_start_delay=1",
+      "/pageadimg/*",
+      "/pageads/*",
+      "/pageear.",
+      "/pageear/*",
+      "/pagepeel-",
+      "/pagepeel.",
+      "/pagepeel/*",
+      "/pagepeelads.",
+      "/paidlisting/*",
+      "/partnerbanner.",
+      "/partnerbanner/*",
+      "/peel.js",
+      "/peel1.js",
+      "/peelad/*",
+      "/peeljs.php",
+      "/perfads.",
+      "/performancingads/*",
+      "/phpads.",
+      "/phpads/*",
+      "/phpads2/*",
+      "/phpadserver/*",
+      "/phpadsnew/*",
+      "/pictures/ads/*",
+      "/pilot_ad.",
+      "/pitattoad.",
+      "/pix/ad/*",
+      "/play/ad/*",
+      "/popads.",
+      "/popunder.",
+      "/position=*/aamsz=",
+      "/premium_ad.",
+      "/printad.",
+      "/printads/*",
+      "/processads.",
+      "/promobuttonad.",
+      "/promotions/ads?",
+      "/protection/ad/*",
+      "/pub/ad/*",
+      "/pub/ads/*",
+      "/public/ad/*",
+      "/public/ad?",
+      "/publicidad.$~object_subrequest",
+      "/publicidad/*",
+      "/pyv_watch_request_ad.",
+      "/questions/ads/*",
+      "/radopenx?",
+      "/railads.",
+      "/random=*/aamsz=",
+      "/realmedia/ads/*",
+      "/rec_ad1.",
+      "/reclame/*",
+      "/reklam.",
+      "/reklama.",
+      "/relatedads.",
+      "/requestadvertisement.",
+      "/requestmyspacead.",
+      "/rightad.",
+      "/rotateads.",
+      "/rotatingpeels.js",
+      "/rsads/c",
+      "/rsads/r",
+      "/scripts/ad-",
+      "/scripts/ad.",
+      "/scripts/ads/*",
+      "/scripts/clickjs.php",
+      "/search/ads?",
+      "/searchads/*",
+      "/services/ads/*",
+      "/sevenl_ad.",
+      "/share/ads/*",
+      "/shared/ads/*",
+      "/show_ad.",
+      "/show_ad_",
+      "/show_ads.js?",
+      "/show_ads_",
+      "/show_afs_ads.",
+      "/showad.",
+      "/showad/*",
+      "/showads.",
+      "/showflashad.",
+      "/showlayer.",
+      "/sideads/*",
+      "/sideads|",
+      "/sidebarad/*",
+      "/sidecol_ad.",
+      "/silver/ads/*",
+      "/siteads.",
+      "/siteafs.txt?",
+      "/sites/ad_",
+      "/skyad.php",
+      "/skyadjs/*",
+      "/slideinad.",
+      "/small_ad.",
+      "/smartad.",
+      "/socialads.",
+      "/socialads/*",
+      "/spc.php?",
+      "/spcjs.php?",
+      "/special-ads/*",
+      "/special_ads/*",
+      "/spo_show.asp?",
+      "/sponsimages/*",
+      "/sponslink_",
+      "/sponsor-ad|",
+      "/sponsorad.",
+      "/sponsoradds/*",
+      "/sponsorads/*",
+      "/sponsored_links_",
+      "/sponsored_text.",
+      "/sponsoredlinks.",
+      "/sponsoredlinks/*",
+      "/square-ads/*",
+      "/squaread.",
+      "/srv/ad/*",
+      "/static/ad_",
+      "/static/ads/*",
+      "/stickyad.",
+      "/storage/ads/*",
+      "/swf/ad-",
+      "/synad2.",
+      "/system/ad/*",
+      "/systemad.",
+      "/systemad_",
+      "/testingad.",
+      "/textad.",
+      "/textad?",
+      "/textads/*",
+      "/textads_",
+      "/thirdparty/ad/*",
+      "/tii_ads.",
+      "/tikilink?",
+      "/tmo/ads/*",
+      "/toigoogleads.",
+      "/toolkitads.",
+      "/top_ad.",
+      "/top_ads/*",
+      "/trackads/*",
+      "/tracked_ad.",
+      "/tradead_",
+      "/tribalad.",
+      "/ttz_ad.",
+      "/tx_macinabanners/*",
+      "/update_ads/*",
+      "/upload/ads/*",
+      "/uploads/ads/*",
+      "/valueclick.",
+      "/vclkads.",
+      "/video/ads/*",
+      "/video_ad.",
+      "/video_ad_right.",
+      "/videoad.",
+      "/videoads.",
+      "/videoads/*",
+      "/videowall-ad.",
+      "/view/banner/*/zone?zid=",
+      "/vr-ad.png",
+      "/vtextads.",
+      "/webad?a",
+      "/webadimg/*",
+      "/webads.",
+      "/webads_",
+      "/webadverts/*",
+      "/wipeads/*",
+      "/wp-content/ads/*",
+      "/wp-srv/ad/*",
+      "/wpads/iframe.",
+      "/writelayerad.",
+      "/www/delivery/*",
+      "/xmladparser.",
+      "/your-ad.",
+      "/ysmads.",
+      "/zanox/banner/*",
+      "/zanox_ad/*",
+      "8080/ads/",
+      ";iframeid=ad_",
+      "?*&ad_keyword=",
+      "?*&adname=",
+      "?*&adspace=",
+      "?*&clientype=*&adid=",
+      "?*&google_adpage=",
+      "?*&googleadword=",
+      "?ad_ids=*&referer=",
+      "?ad_type=",
+      "?ad_width=",
+      "?adarea=",
+      "?adclass=",
+      "?adpage=",
+      "?adtype=",
+      "?advertising=",
+      "?advtile=",
+      "?file=ads&",
+      "?getad=&$~object_subrequest",
+      "_ad.aspx",
+      "_ad.php?",
+      "_ad_big.",
+      "_ad_code.",
+      "_ads.php?",
+      "_ads_reporting.",
+      "_adserve/",
+      "_adspaces.",
+      "_adtitle.",
+      "_advert.",
+      "_advert1.",
+      "_blogads.",
+      "_box_ads/",
+      "_buttonad.",
+      "_companionad.",
+      "_custom_ad.",
+      "_custom_ad_sets.",
+      "_dynamicads/",
+      "_fd_adbg1a.",
+      "_fd_adbg2.",
+      "_fd_adbg2a.",
+      "_fd_adtop.",
+      "_overlay_ad.",
+      "_topad.php",
+      "_videoad.",
+      "a/adx.js",
+      "d/adx.js",
+      "e/adx.js",
+      "e/js.ng/",
+      "e/js_ng/",
+      "k/ads.pl",
+      "m/adbox/",
+      "m/ads.pl",
+      "m/adx.js",
+      "m/js.ng/",
+      "m/topads|",
+      "n/adx.js",
+      "r/ad.htm",
+      "s/adx.js",
+      "t/adx.js",
+      "u/adx.js",
+      "z/adx.js",
+      "|http://a.ads.",
+      "|http://ad-uk.",
+      "|http://ad.$~object_subrequest,domain=~europa.eu|~sjsu.edu|~uitm.edu.my|~uni-freiburg.de",
+      "|http://ad0.",
+      "|http://ad1.",
+      "|http://ad2.",
+      "|http://ad3.",
+      "|http://ad4.",
+      "|http://ad5.",
+      "|http://ad6.",
+      "|http://ad7.",
+      "|http://adimg.",
+      "|http://adnet.",
+      "|http://ads.",
+      "|http://ads0.",
+      "|http://ads1.",
+      "|http://ads2.",
+      "|http://ads3.",
+      "|http://ads4.",
+      "|http://ads5.",
+      "|http://adsrv.",
+      "|http://adsvr.",
+      "|http://adsys.",
+      "|http://adv.",
+      "|http://adver.",
+      "|http://bwp.*/search",
+      "|http://feeds.*/~a/",
+      "|http://getad.",
+      "|http://jazad.",
+      "|http://openx.",
+      "|http://rss.*/~a/",
+      "|http://synad.",
+      "|http://wrapper.*/a?",
+      "!Dimensions",
+      "*-120x600*",
+      "*-160x600*",
+      "*-300x250*",
+      "*-336x280*",
+      "*-360x110.*",
+      "*-468_60.*",
+      "*-468x60-*",
+      "*-468x60.*",
+      "*-468x60/*",
+      "*-468x60_*",
+      "*-468x80-*",
+      "*-468x80.*",
+      "*-468x80/*",
+      "*-468x80_*",
+      "*-480x60-*",
+      "*-480x60.*",
+      "*-480x60/*",
+      "*-480x60_*",
+      "*-728x90-*",
+      "*-728x90.*",
+      "*-728x90/*",
+      "*-728x90_*",
+      "*.120x600*",
+      "*.160x600*",
+      "*.300x250*",
+      "*.336x280*",
+      "*.468x60-*",
+      "*.468x60.*",
+      "*.468x60/*",
+      "*.468x60_*",
+      "*.468x80-*",
+      "*.468x80.*",
+      "*.468x80/*",
+      "*.468x80_*",
+      "*.480x60-*",
+      "*.480x60.*",
+      "*.480x60/*",
+      "*.480x60_*",
+      "*.728x90-*",
+      "*.728x90.*",
+      "*.728x90/*",
+      "*.728x90_*",
+      "*/120x600*",
+      "*/160x600*",
+      "*/300x250*",
+      "*/336x280*",
+      "*/468by60*",
+      "*/468x60-*",
+      "*/468x60.*",
+      "*/468x60/*",
+      "*/468x60_*",
+      "*/468x80-*",
+      "*/468x80.*",
+      "*/468x80/*",
+      "*/468x80_*",
+      "*/480x60-*",
+      "*/480x60.*",
+      "*/480x60/*",
+      "*/480x60_*",
+      "*/728_90/*",
+      "*/728x90-*",
+      "*/728x90.*",
+      "*/728x90/*",
+      "*/728x90_*",
+      "*300x250.*",
+      "*468x60.g*",
+      "*468x60.j*",
+      "*468x60ba*",
+      "*728banne*",
+      "*728x90.g*",
+      "*728x90.h*",
+      "*728x90.j*",
+      "*728x90.p*",
+      "*728x90.s*",
+      "*_120_600*",
+      "*_120x60.*",
+      "*_120x600*",
+      "*_120x60_*",
+      "*_160x290*",
+      "*_160x600*",
+      "*_300x250*",
+      "*_336x280*",
+      "*_460x60.*",
+      "*_468-60.*",
+      "*_468.gif*",
+      "*_468.htm*",
+      "*_468_60.*",
+      "*_468_60_*",
+      "*_468x60-*",
+      "*_468x60.*",
+      "*_468x60/*",
+      "*_468x60_*",
+      "*_468x80-*",
+      "*_468x80.*",
+      "*_468x80/*",
+      "*_468x80_*",
+      "*_468x90.*",
+      "*_480x60-*",
+      "*_480x60.*",
+      "*_480x60/*",
+      "*_480x60_*",
+      "*_580x100*",
+      "*_720x90.*",
+      "*_728_90.*",
+      "*_728_90_*",
+      "*_728by90*",
+      "*_728x90-*",
+      "*_728x90.*",
+      "*_728x90/*",
+      "*_728x90_*",
+      "*_768x90_*",
+      "*e120x600*",
+      "*n728x90_*",
+      "!-----------------------------------General element hiding rules-----------------------------------!",
+      "! *** easylist_general_hide.txt ***",
+      "###A9AdsMiddleBoxTop",
+      "###A9AdsOutOfStockWidgetTop",
+      "###A9AdsServicesWidgetTop",
+      "###ADsmallWrapper",
+      "###Ad1",
+      "###Ad2",
+      "###Ad3Left",
+      "###Ad3Right",
+      "###AdContainerTop",
+      "###AdHeader",
+      "###AdMiddle",
+      "###AdRectangle",
+      "###AdShowcase_F1",
+      "###AdSky23",
+      "###AdSkyscraper",
+      "###AdSponsor_SF",
+      "###AdTargetControl1_iframe",
+      "###AdText",
+      "###Ad_Block",
+      "###Ad_Center1",
+      "###Ad_Top",
+      "~cynamite.de###Adbanner",
+      "###Adrectangle",
+      "###AdsContent",
+      "###AdsWrap",
+      "###AdvertMPU23b",
+      "~designspotter.com###AdvertiseFrame",
+      "###Advertorial",
+      "###BigBoxAd",
+      "###CompanyDetailsNarrowGoogleAdsPresentationControl",
+      "###CompanyDetailsWideGoogleAdsPresentationControl",
+      "###ContentAd",
+      "###ContentAd1",
+      "###ContentAd2",
+      "###ContentAdPlaceHolder1",
+      "###ContentAdPlaceHolder2",
+      "###FP_Ad",
+      "###FooterAd",
+      "###FooterAdContainer",
+      "###HEADERAD",
+      "###HeaderAdsBlock",
+      "###HeroAd",
+      "###HouseAd",
+      "###Journal_Ad_125",
+      "###Journal_Ad_300",
+      "###LeftAdF1",
+      "###LeftAdF2",
+      "###PageLeaderAd",
+      "###RightSponsoredAd",
+      "###SectionAd300-250",
+      "###SidebarAdContainer",
+      "###SkyAd",
+      "###SponsoredAd",
+      "###TOP_ADROW",
+      "###TopAdPos",
+      "###VM-MPU-adspace",
+      "###VM-header-adwrap",
+      "###XEadLeaderboard",
+      "###XEadSkyscraper",
+      "###ad-160x600",
+      "###ad-250x300",
+      "###ad-300x250",
+      "###ad-300x250Div",
+      "###ad-728",
+      "###ad-banner",
+      "###ad-bottom",
+      "###ad-colB-1",
+      "~apple.com###ad-container",
+      "###ad-footer",
+      "###ad-footprint-160x600",
+      "###ad-front-footer",
+      "###ad-front-sponsoredlinks",
+      "###ad-halfpage",
+      "###ad-label",
+      "###ad-leaderboard",
+      "###ad-leaderboard-bottom",
+      "###ad-leaderboard-top",
+      "###ad-left",
+      "###ad-lrec",
+      "###ad-medium-rectangle",
+      "###ad-middlethree",
+      "###ad-middletwo",
+      "###ad-module",
+      "###ad-mpu",
+      "###ad-placard",
+      "###ad-rectangle",
+      "###ad-righttop",
+      "###ad-skyscraper",
+      "###ad-space",
+      "###ad-splash",
+      "###ad-target",
+      "###ad-target-Leaderbord",
+      "###ad-top",
+      "###ad-tower",
+      "###ad-typ1",
+      "~apple.com###ad-wrap",
+      "###ad-wrap-right",
+      "###ad-wrapper1",
+      "###ad-yahoo-simple",
+      "~tphousing.com,~tvgorge.com###ad1",
+      "###ad125x125",
+      "###ad160x600",
+      "###ad160x600right",
+      "###ad1Sp",
+      "###ad2",
+      "###ad2Sp",
+      "###ad3",
+      "###ad300",
+      "###ad300-250",
+      "###ad300_x_250",
+      "###ad300x150",
+      "###ad300x250",
+      "###ad300x250Module",
+      "###ad300x60",
+      "###ad336",
+      "###ad375x85",
+      "###ad526x250",
+      "###ad600",
+      "~natgeo.tv###ad728x90",
+      "###adB",
+      "###adBadges",
+      "~campusdish.com###adBanner",
+      "###adBanner120x600",
+      "###adBannerTable",
+      "###adBar",
+      "~jobs.wa.gov.au,~pricewatch.com###adContainer",
+      "###adFps",
+      "###adFtofrs",
+      "###adGroup1",
+      "###adHeader",
+      "###adL",
+      "###adLB",
+      "###adMPU",
+      "###adMiddle0Frontpage",
+      "###adMiniPremiere",
+      "###adPlaceHolderRight",
+      "###adRight",
+      "###adSenseModule",
+      "###adServer_marginal",
+      "###adSidebar",
+      "###adSidebarSq",
+      "###adSky",
+      "###adSlider",
+      "###adSpace3",
+      "###adSpace300_ifrMain",
+      "###adSpace4",
+      "###adSpace5",
+      "###adSpace6",
+      "###adSpace7",
+      "###adSpace_footer",
+      "###adSpace_top",
+      "###adSpecial",
+      "###adSpot-Leader",
+      "###adSpot-banner",
+      "###adSpot-mrec1",
+      "###adSpot-sponsoredlinks",
+      "###adSpot-textbox1",
+      "###adSpot-widestrip",
+      "###adSpotAdvertorial",
+      "###adSpotIsland",
+      "###adSpotSponsoredLinks",
+      "###adSquare",
+      "###adStaticA",
+      "###adStrip",
+      "###adSuperPremiere",
+      "###adTableCell",
+      "###adTag1",
+      "###adTag2",
+      "###adTop",
+      "###adTopboxright",
+      "###adUnit",
+      "###adZoneTop",
+      "###ad_160x600",
+      "###ad_190x90",
+      "###ad_300",
+      "###ad_300x250",
+      "###ad_468_60",
+      "###ad_5",
+      "###ad_728_foot",
+      "###ad_728x90",
+      "###ad_Banner",
+      "###ad_C2",
+      "###ad_YieldManager-300x250",
+      "###ad_anchor",
+      "###ad_banner",
+      "###ad_banner_top",
+      "###ad_bar",
+      "###ad_bottom",
+      "###ad_box_colspan",
+      "###ad_branding",
+      "###ad_bs_area",
+      "###ad_center_monster",
+      "~academics.de###ad_container",
+      "###ad_content_wrap",
+      "###ad_feature",
+      "###ad_haha_1",
+      "###ad_haha_4",
+      "###ad_halfpage",
+      "###ad_head",
+      "###ad_header",
+      "###ad_island",
+      "###ad_layer2",
+      "###ad_leader",
+      "###ad_leaderBoard",
+      "###ad_leaderboard",
+      "###ad_lwr_square",
+      "###ad_medium_rectangle",
+      "###ad_medium_rectangular",
+      "###ad_middle",
+      "###ad_mpu",
+      "###ad_play_300",
+      "###ad_rect",
+      "###ad_rect_body",
+      "###ad_rect_bottom",
+      "###ad_rectangle",
+      "###ad_related_links_div",
+      "###ad_related_links_div_program",
+      "###ad_report_leaderboard",
+      "###ad_report_rectangle",
+      "###ad_right",
+      "###ad_sidebar1",
+      "###ad_sidebar2",
+      "###ad_sidebar3",
+      "###ad_skyscraper",
+      "###ad_slot_livesky",
+      "###ad_space",
+      "~wretch.cc###ad_square",
+      "###ad_ss",
+      "###ad_top",
+      "###ad_top_holder",
+      "###ad_vertical",
+      "~amnestyusa.org###ad_wrapper",
+      "###adbanner",
+      "###adbnr",
+      "###adbottom",
+      "~kalaydo.de###adbox",
+      "###adbox2",
+      "###adclear",
+      "###adcode1",
+      "###adcode2",
+      "###adcode3",
+      "###adcode4",
+      "###adcolumnwrapper",
+      "###adcontainer",
+      "###adcontainsm",
+      "###addiv-bottom",
+      "###addiv-top",
+      "###adframe:not(frameset)",
+      "###adhead",
+      "###adhead_g",
+      "###adheader",
+      "###adimg",
+      "###adlabel",
+      "###adlabelFooter",
+      "###adlinks",
+      "###adlinkws",
+      "###admid",
+      "###admiddle3center",
+      "###admiddle3left",
+      "###adposition",
+      "###adposition-C",
+      "###adposition2",
+      "~mercurynews.com###adposition3",
+      "###adposition4",
+      "###adright",
+      "###adright2",
+      "~2gb-hosting.com,~addoway.com,~apple.com,~dailykos.com,~facebook.com,~harpers.org,~radio.de,~tomwans.com,~www.google.com,~zuploads.com###ads",
+      "###ads-468",
+      "###ads-block",
+      "###ads-bot",
+      "###ads-bottom",
+      "###ads-dell",
+      "###ads-horizontal",
+      "###ads-indextext",
+      "###ads-lrec",
+      "###ads-rhs",
+      "###ads-top",
+      "###ads2",
+      "###ads300",
+      "###ads336x280",
+      "###ads7",
+      "###adsID",
+      "###ads_160",
+      "###ads_300",
+      "###ads_728",
+      "###ads_belowforumlist",
+      "###ads_belownav",
+      "###ads_bottom_outer",
+      "###ads_catDiv",
+      "###ads_right",
+      "###ads_sidebar_roadblock",
+      "###ads_top",
+      "###adsbottom",
+      "###adsense",
+      "###adsense-text",
+      "###adsenseWrap",
+      "###adsensetopplay",
+      "###adsonar",
+      "~metblogs.com,~oreilly.com###adspace",
+      "###adspace-300x250",
+      "###adspace300x250",
+      "###adspaceBox",
+      "###adspaceBox300",
+      "###adspace_header",
+      "###adsright",
+      "###adstop",
+      "###adtech_takeover",
+      "###adtop",
+      "###adv",
+      "###adv-box",
+      "###adv-masthead",
+      "###adv_bg",
+      "###adv_google_300",
+      "###adv_google_728",
+      "###adv_text_link_bar",
+      "###adv_top",
+      "###adv_wide_banner",
+      "~finn.no,~gcrg.org,~kalaydo.de,~secondamano.it,~sepa.org.uk###advert",
+      "###advert-boomer",
+      "###advert-header",
+      "###advert-leaderboard",
+      "###advert-top",
+      "###advert_250x250",
+      "###advert_box",
+      "###advert_leaderboard",
+      "###advert_lrec_format",
+      "###advert_mpu",
+      "###advertbox",
+      "###advertbox2",
+      "###advertbox3",
+      "###advertbox4",
+      "###adverthome",
+      "###advertise",
+      "###advertise-now",
+      "~ping-timeout.de###advertisement",
+      "###advertisement160x600",
+      "###advertisement728x90",
+      "###advertisementLigatus",
+      "###advertisementPrio2",
+      "###advertiserLinks",
+      "###advertising",
+      "###advertising-skyscraper",
+      "###adwin_rec",
+      "###adwith",
+      "###adwords-4-container",
+      "###adwrapper",
+      "###adxtop",
+      "###adzoneBANNER",
+      "###agi-ad300x250",
+      "###agi-ad300x250overlay",
+      "###agi-sponsored",
+      "###annoying_ad",
+      "###ap_adframe",
+      "###article-box-ad",
+      "###articleAdReplacement",
+      "###articleSideAd",
+      "###article_ad",
+      "###article_box_ad",
+      "###atlasAdDivGame",
+      "###banner-ad",
+      "###banner-ads",
+      "###banner468x60",
+      "###banner728x90",
+      "###bannerAdTop",
+      "###banner_ad",
+      "###banner_topad",
+      "###bannerad",
+      "###bannerad2",
+      "###bg_YieldManager-300x250",
+      "###bigAd",
+      "###bigBoxAd",
+      "###bigadbox",
+      "###bigadspot",
+      "###billboard_ad",
+      "###block-ad_cube-1",
+      "###block_advert",
+      "###blox-big-ad",
+      "###blox-halfpage-ad",
+      "###blox-tile-ad",
+      "###botad",
+      "###bottom-ad-container",
+      "###bottom-ads",
+      "###bottomAd",
+      "###bottomAdSenseDiv",
+      "###bottomRightAdSpace",
+      "###bottom_ad",
+      "###bottom_ad_area",
+      "###bottom_ads",
+      "###bottom_overture",
+      "###bottom_player_adv",
+      "###bottom_sponsor_ads",
+      "###bottom_sponsored_links",
+      "###bottom_text_ad",
+      "###bottomad",
+      "###box-googleadsense-1",
+      "###box-googleadsense-r",
+      "###boxAd300",
+      "###boxAdContainer",
+      "###boxad1",
+      "###boxad2",
+      "###boxad3",
+      "###boxad4",
+      "###boxad5",
+      "###bps-header-ad-container",
+      "###btr_horiz_ad",
+      "###button-ads-horizontal",
+      "###button-ads-vertical",
+      "###button_ad_wrap",
+      "###cellAd",
+      "###channel_ad",
+      "###channel_ads",
+      "###cnnRR336ad",
+      "###cnnTopAd",
+      "###colRightAd",
+      "###column4-google-ads",
+      "###commercial_ads",
+      "###common_right_lower_player_adspace",
+      "###common_right_player_adspace",
+      "###common_top_adspace",
+      "###containerLocalAds",
+      "###containerMrecAd",
+      "###content-ad-header",
+      "###contentAd",
+      "###content_ad_square",
+      "###content_ad_top",
+      "###content_ads_content",
+      "###content_box_300body_sponsoredoffers",
+      "###content_box_adright300_google",
+      "###contentad",
+      "###contentad_imtext",
+      "###contentad_right",
+      "###contentads",
+      "###contentinlineAd",
+      "###contextualad",
+      "###ctl00_MasterHolder_IBanner_adHolder",
+      "###ctl00_VBanner_adHolder",
+      "###ctl00_adFooter",
+      "###ctrlsponsored",
+      "###cubeAd",
+      "###cube_ads",
+      "###cube_ads_inner",
+      "###cubead",
+      "###cubead-2",
+      "###divAd",
+      "###divAdBox",
+      "###divWrapper_Ad",
+      "###div_video_ads",
+      "###dlads",
+      "###download_ads",
+      "###ds-mpu",
+      "###evotopTen_advert",
+      "###exads",
+      "~discuss.com.hk,~uwants.com###featuread",
+      "###featuredAdContainer2",
+      "###featuredAds",
+      "###feed_links_ad_container",
+      "###first_ad_unit",
+      "###fl_hdrAd",
+      "###footer-ad",
+      "###footer-sponsored",
+      "###footerAd",
+      "###footerAdDiv",
+      "###footerAdverts",
+      "###footer_ad",
+      "###footer_ad_block",
+      "~investopedia.com###footer_ads",
+      "###footer_adspace",
+      "###footer_text_ad",
+      "###fr_ad_center",
+      "###frnContentAd",
+      "###front_mpu",
+      "###ft-ad",
+      "###ft-ad-1",
+      "###ft-ad-container",
+      "###fusionad",
+      "###g_ad",
+      "###g_adsense",
+      "###ga_300x250",
+      "###gad",
+      "###gallery-ad-m0",
+      "###gallery_ads",
+      "###game-info-ad",
+      "###global_header_ad_area",
+      "###google-ad",
+      "###google-ad-art",
+      "###google-ad-tower",
+      "###google-ads",
+      "###google-ads-bottom",
+      "###google-ads-left-side",
+      "###google-adsense-mpusize",
+      "###googleAd",
+      "###googleAds",
+      "###googleAdsense",
+      "###googleAdsenseBanner",
+      "###googleAdsenseBannerBlog",
+      "###googleAdwordsModule",
+      "###googleAfcContainer",
+      "###google_ad",
+      "###google_ad_test",
+      "###google_ads",
+      "###google_ads_frame1",
+      "###google_ads_test",
+      "###googlead",
+      "###googleads",
+      "###googlesponsor",
+      "###gsyadrectangleload",
+      "###gsyadrightload",
+      "###gsyadtop",
+      "###gsyadtopload",
+      "###gtopadvts",
+      "###halfPageAd",
+      "###halfe-page-ad-box",
+      "###hdtv_ad_ss",
+      "~uwcu.org###head-ad",
+      "###header-ad",
+      "###header-ads",
+      "###header-advert",
+      "###headerAd",
+      "###headerAdBackground",
+      "###headerAdContainer",
+      "###headerAdsWrapper",
+      "###headerTopAd",
+      "~cmt.com###header_ad",
+      "###header_advertisement_top",
+      "###header_leaderboard_ad_container",
+      "###headerad",
+      "###headeradbox",
+      "###headline_ad",
+      "###hiddenadAC",
+      "###homeTopRightAd",
+      "###home_ad",
+      "###home_spensoredlinks",
+      "###homepage-ad",
+      "###hometop_234x60ad",
+      "###horizontal-banner-ad",
+      "###horizontal_ad",
+      "###houseAd",
+      "###hp-store-ad",
+      "###icePage_SearchLinks_AdRightDiv",
+      "###inlinead",
+      "###inlinegoogleads",
+      "###inner-advert-row",
+      "###insider_ad_wrapper",
+      "###instoryad",
+      "###int-ad",
+      "###interstitial_ad_wrapper",
+      "###islandAd",
+      "###j_ad",
+      "###landing-adserver",
+      "###lateAd",
+      "###lb-sponsor-left",
+      "###lb-sponsor-right",
+      "###leader-board-ad",
+      "###leader-sponsor",
+      "###leaderad",
+      "###leaderboard-ad",
+      "###leaderboard-bottom-ad",
+      "###leaderboard_ad",
+      "###leftSectionAd300-100",
+      "###left_ad",
+      "###left_adspace",
+      "###leftad",
+      "###leftads",
+      "###lg-banner-ad",
+      "###linkAds",
+      "###live-ad",
+      "###longAdSpace",
+      "###mBannerAd",
+      "###main-ad",
+      "###main-ad160x600",
+      "###main-ad160x600-img",
+      "###main-ad728x90",
+      "###mainAdvert",
+      "###main_ad",
+      "###main_rec_ad",
+      "###mastAdvert",
+      "###mastad",
+      "###masthead_ad",
+      "###medRecAd",
+      "###media_ad",
+      "###menuAds",
+      "###mid-ad300x250",
+      "###mid-table-ad",
+      "###mid_ad_title",
+      "###mid_mpu",
+      "###middlead",
+      "###middleads",
+      "###midrect_ad",
+      "###midstrip_ad",
+      "###mini-ad",
+      "###module-google_ads",
+      "###module_box_ad",
+      "###mpu",
+      "###mpu-advert",
+      "###mpuAd",
+      "###mpuDiv",
+      "###mpuWrapperAd",
+      "###mpu_banner",
+      "###mpu_holder",
+      "###mpuad",
+      "###mrecAdContainer",
+      "###multiLinkAdContainer",
+      "###n_sponsor_ads",
+      "###natadad300x250",
+      "###navi_banner_ad_780",
+      "###new_topad",
+      "###noresultsads",
+      "###northad",
+      "###oanda_ads",
+      "###onespot-ads",
+      "###p-googleadsense",
+      "###page-header-ad",
+      "###page_content_top_ad",
+      "###pcworldAdBottom",
+      "###pcworldAdTop",
+      "###player_ad",
+      "###portlet-advertisement-left",
+      "###portlet-advertisement-right",
+      "###post5_adbox",
+      "###priceGrabberAd",
+      "###product-adsense",
+      "###promo-ad",
+      "###promoAds",
+      "###ps-vertical-ads",
+      "###pub468x60",
+      "###r1SoftAd",
+      "###rail_ad1",
+      "###rail_ad2",
+      "###realEstateAds",
+      "###rect_ad",
+      "###rectangle-ad",
+      "###rectangle_ad",
+      "###refine-300-ad",
+      "###region-top-ad",
+      "###rh-ad-container",
+      "###rh_tower_ad",
+      "###right-ad",
+      "###rightAd",
+      "###rightAd300x250",
+      "###rightAdColumn",
+      "###rightColAd",
+      "###rightColumnMpuAd",
+      "###rightColumnSkyAd",
+      "###right_ad_wrapper",
+      "###right_advertisement",
+      "###right_advertising",
+      "###rightad",
+      "###rightadvertbar-doubleclickads",
+      "###rightbar-ad",
+      "###rightside_ad",
+      "###rotatingads",
+      "###rtMod_ad",
+      "###sAdsBox",
+      "###search-google-ads",
+      "###secondBoxAdContainer",
+      "###servfail-ads",
+      "###sew-ad1",
+      "###shoppingads",
+      "###show-ad",
+      "###side-ad-container",
+      "###sideAd",
+      "###sideBarAd",
+      "###side_ad_wrapper",
+      "###side_ads_by_google",
+      "###sidead",
+      "###sidebar-125x125-ads",
+      "###sidebar-125x125-ads-below-index",
+      "###sidebar-ad-boxes",
+      "###sidebar-ad-space",
+      "###sidebar-ad-wrap",
+      "###sidebar-ads",
+      "~facebook.com,~japantoday.com###sidebar_ads",
+      "###sidebar_sponsoredresult_body",
+      "###sidebarad",
+      "###sideline-ad",
+      "###site-leaderboard-ads",
+      "###site_top_ad",
+      "###sky-ad",
+      "###skyAd",
+      "###skyScrapperAd",
+      "###sky_ad",
+      "###skyscraperAd",
+      "###skyscraper_advert",
+      "###sliderAdHolder",
+      "###sm-banner-ad",
+      "###small_ad",
+      "###smallerAd",
+      "###speeds_ads",
+      "###sphereAd",
+      "###splinks",
+      "###sponLinkDiv_1",
+      "###sponlink",
+      "###spons_left",
+      "###sponseredlinks",
+      "###sponsorAd1",
+      "###sponsorAd2",
+      "###sponsorLinks",
+      "###sponsor_banderole",
+      "###sponsor_box",
+      "###sponsor_panSponsor",
+      "###sponsored",
+      "###sponsored-links",
+      "###sponsored-resources",
+      "###sponsored1",
+      "###sponsoredBox1",
+      "###sponsoredBox2",
+      "###sponsoredLinks",
+      "###sponsoredList",
+      "###sponsoredResults",
+      "###sponsoredSiteMainline",
+      "###sponsoredSiteSidebar",
+      "###sponsored_game_row_listing",
+      "###sponsored_links",
+      "###sponsoredlinks",
+      "###sponsoredlinks_cntr",
+      "###sponsoredresults_top",
+      "###sponsorlink",
+      "###spotlightAds",
+      "###spotlightad",
+      "###squareAd",
+      "###squareAdSpace",
+      "###square_ad",
+      "###sticky-ad",
+      "###stickyBottomAd",
+      "###story-ad-a",
+      "###story-ad-b",
+      "###story-sponsoredlinks",
+      "###storyAdWrap",
+      "###subpage-ad-right",
+      "###subpage-ad-top",
+      "###swads",
+      "###synch-ad",
+      "###tblAd",
+      "###tbl_googlead",
+      "###template_ad_leaderboard",
+      "###tertiary_advertising",
+      "###textAd",
+      "###textAds",
+      "###text_ad",
+      "###text_advert",
+      "###thefooterad",
+      "###themis-ads",
+      "###tile-ad",
+      "###tmglBannerAd",
+      "###top-ad",
+      "###top-ad-menu",
+      "###top-ads",
+      "###top-ads-tabs",
+      "###top-advertisement",
+      "###top-banner-ad",
+      "###top-search-ad-wrapper",
+      "###topAd",
+      "###topAd728x90",
+      "###topAdBanner",
+      "###topAdSenseDiv",
+      "###topAds",
+      "###topBannerAd",
+      "###topNavLeaderboardAdHolder",
+      "###top_ad",
+      "###top_ad_area",
+      "###top_ad_game",
+      "###top_ad_wrapper",
+      "###top_ads",
+      "###top_advertise",
+      "###top_advertising",
+      "###top_player_adv",
+      "~bumpshack.com###topad",
+      "###topad_left",
+      "###topad_right",
+      "###topads",
+      "###topcustomad",
+      "###towerad",
+      "###twogamesAd",
+      "###txt_link_ads",
+      "###undergameAd",
+      "###upperMpu",
+      "###upperad",
+      "###v_ad",
+      "###vert_ad",
+      "###vertical_ad",
+      "###vertical_ads",
+      "###video_overlay_ad",
+      "###walltopad",
+      "###welcomeAdsContainer",
+      "###welcome_ad_mrec",
+      "###wgtAd",
+      "###wrapAdRight",
+      "###wrapAdTop",
+      "###yahoo-ads",
+      "###yahoo-sponsors",
+      "###yahoo_ads",
+      "###yahoo_ads_2010",
+      "###yan-sponsored",
+      "###ybf-ads",
+      "###yfi_fp_ad_mort",
+      "###yfi_fp_ad_nns",
+      "###ygrp-sponsored-links",
+      "###ymap_adbanner",
+      "###yn-gmy-ad-lrec",
+      "###yreSponsoredLinks",
+      "###ysm_ad_iframe",
+      "###zoneAdserverMrec",
+      "###zoneAdserverSuper",
+      "##.ADBAR",
+      "##.Ad120x600",
+      "##.Ad160x600",
+      "##.Ad300x250L",
+      "~co-operative.coop##.AdBox",
+      "##.AdBox7",
+      "##.AdContainerBox308",
+      "##.AdHere",
+      "##.AdPlaceHolder",
+      "##.AdRingtone",
+      "##.AdSense",
+      "##.AdSpace",
+      "~buy.com##.AdTitle",
+      "##.AdUnit",
+      "##.AdUnit300",
+      "##.Ad_C",
+      "##.Ad_D_Wrapper",
+      "##.Ad_E_Wrapper",
+      "##.Ad_Right",
+      "##.Ads",
+      "##.AdvertisementTextTag",
+      "##.ArticleInlineAd",
+      "##.BannerAd",
+      "##.BlockAd",
+      "##.CG_adkit_leaderboard",
+      "##.DeptAd",
+      "##.FT_Ad",
+      "##.FlatAds",
+      "##.HPNewAdsBannerDiv",
+      "##.HomeContentAd",
+      "##.LeftTowerAd",
+      "##.MD_adZone",
+      "##.MPU",
+      "##.MPUHolder",
+      "##.PU_DoubleClickAdsContent",
+      "##.Post5ad",
+      "##.RelatedAds",
+      "##.RightRailTop300x250Ad",
+      "##.RightSponsoredAdTitle",
+      "##.RightTowerAd",
+      "##.SidebarAd",
+      "##.SponsoredAdTitle",
+      "##.SponsoredLinksGrayBox",
+      "##.StandardAdLeft",
+      "##.StandardAdRight",
+      "##.TextAd",
+      "##.TheEagleGoogleAdSense300x250",
+      "##.TopAd",
+      "##.TopAdL",
+      "##.TopAdR",
+      "##.UIStandardFrame_SidebarAds",
+      "##.UIWashFrame_SidebarAds",
+      "##.VerticalAd",
+      "##.WidgetAdvertiser",
+      "##.ad-160x600",
+      "##.ad-300",
+      "##.ad-300-block",
+      "##.ad-300-blog",
+      "##.ad-300x100",
+      "##.ad-300x250",
+      "##.ad-728",
+      "##.ad-background",
+      "##.ad-banner",
+      "##.ad-bigsize",
+      "##.ad-block",
+      "##.ad-bottom",
+      "##.ad-button",
+      "##.ad-cell",
+      "~arbetsformedlingen.se##.ad-container",
+      "##.ad-div",
+      "##.ad-footer",
+      "##.ad-footer-leaderboard",
+      "##.ad-google",
+      "##.ad-gray",
+      "##.ad-hdr",
+      "##.ad-holder",
+      "##.ad-homeleaderboard",
+      "##.ad-island",
+      "##.ad-leaderboard",
+      "##.ad-links",
+      "##.ad-medium",
+      "##.ad-medium-two",
+      "##.ad-mpu",
+      "##.ad-other",
+      "##.ad-placeholder",
+      "##.ad-poster",
+      "##.ad-rect",
+      "##.ad-rectangle",
+      "##.ad-rectangle-text",
+      "##.ad-related",
+      "##.ad-rh",
+      "##.ad-ri",
+      "##.ad-right",
+      "##.ad-right-txt",
+      "##.ad-section",
+      "##.ad-sidebar300",
+      "##.ad-slot",
+      "##.ad-space",
+      "##.ad-space-mpu-box",
+      "##.ad-spot",
+      "##.ad-text",
+      "##.ad-tile",
+      "##.ad-top",
+      "##.ad-top-left",
+      "##.ad-wrap",
+      "##.ad-wrapper",
+      "##.ad0",
+      "##.ad1",
+      "##.ad10",
+      "##.ad120",
+      "##.ad160",
+      "##.ad18",
+      "##.ad19",
+      "##.ad2",
+      "##.ad21",
+      "##.ad3",
+      "##.ad300",
+      "##.ad300x250",
+      "##.ad300x250Top",
+      "##.ad300x600",
+      "##.ad310",
+      "##.ad336x280",
+      "##.ad468",
+      "##.ad6",
+      "##.ad620x70",
+      "##.ad7",
+      "##.ad728",
+      "##.ad728x90",
+      "##.ad8",
+      "##.adAgate",
+      "##.adBanner",
+      "##.adBannerTyp1",
+      "##.adBannerTypSortableList",
+      "##.adBannerTypW300",
+      "##.adBgBottom",
+      "##.adBgMId",
+      "##.adBgTop",
+      "~ksl.com##.adBox",
+      "##.adBoxSingle",
+      "##.adCMRight",
+      "##.adColumn",
+      "~mycareer.com.au,~nytimes.com##.adContainer",
+      "##.adCreative",
+      "~mercurynews.com##.adElement",
+      "##.adFrame",
+      "##.adFtr",
+      "##.adFullWidthMiddle",
+      "##.adGoogle",
+      "##.adHeader",
+      "##.adHeadline",
+      "##.adHolder",
+      "##.adHome300x250",
+      "##.adInNews",
+      "##.adLabel",
+      "##.adLeader",
+      "##.adLeaderForum",
+      "##.adLeaderboard",
+      "##.adLeft",
+      "##.adMkt2Colw",
+      "~outspark.com##.adModule",
+      "##.adNewsChannel",
+      "##.adNoticeOut",
+      "##.adObj",
+      "##.adRight",
+      "##.adServer",
+      "##.adSlot",
+      "##.adSpBelow",
+      "~o2online.de##.adSpace",
+      "##.adSpacer",
+      "##.adSpot",
+      "##.adSpot-textBox",
+      "##.adSpotIsland",
+      "##.adSquare",
+      "##.adSuperboard",
+      "##.adTag",
+      "##.adText",
+      "##.adTileWrap",
+      "##.adTitle",
+      "##.adTout",
+      "##.adTxt",
+      "##.adWithTab",
+      "##.adWrapper",
+      "##.ad_1",
+      "##.ad_125",
+      "##.ad_130x90",
+      "##.ad_160",
+      "##.ad_160x600",
+      "##.ad_2",
+      "##.ad_3",
+      "##.ad_300",
+      "##.ad_300_250",
+      "##.ad_300x250",
+      "##.ad_336x280",
+      "##.ad_350x250",
+      "##.ad_468",
+      "##.ad_600",
+      "##.ad_728",
+      "##.ad_728x90",
+      "##.ad_amazon",
+      "##.ad_biz",
+      "##.ad_block_338",
+      "##.ad_bottom_leaderboard",
+      "##.ad_box",
+      "##.ad_box2",
+      "##.ad_caption",
+      "##.ad_contain",
+      "##.ad_container",
+      "~salon.com##.ad_content",
+      "##.ad_content_wide",
+      "##.ad_footer",
+      "##.ad_framed",
+      "~news.yahoo.com##.ad_header",
+      "##.ad_hpm",
+      "##.ad_launchpad",
+      "##.ad_leader",
+      "##.ad_leaderboard",
+      "##.ad_left",
+      "##.ad_loc",
+      "##.ad_lrec",
+      "##.ad_medrect",
+      "##.ad_mpu",
+      "##.ad_mrec",
+      "##.ad_mrec_title_article",
+      "##.ad_notice",
+      "##.ad_p360",
+      "##.ad_partner",
+      "##.ad_plus",
+      "##.ad_post",
+      "##.ad_power",
+      "##.ad_rectangle",
+      "~didaktik-der-mathematik.de##.ad_right",
+      "##.ad_sidebar",
+      "##.ad_skyscraper",
+      "##.ad_slug_table",
+      "##.ad_space",
+      "##.ad_sponsor",
+      "##.ad_spot_b",
+      "##.ad_spot_c",
+      "##.ad_square_r",
+      "##.ad_square_top",
+      "~bbs.newhua.com,~leboncoin.fr##.ad_text",
+      "##.ad_top",
+      "##.ad_top_leaderboard",
+      "##.ad_tower",
+      "##.ad_unit",
+      "##.ad_wide",
+      "##.ad_wrap",
+      "##.ad_wrapper",
+      "##.ad_wrapper_fixed",
+      "##.ad_zone",
+      "##.adarea",
+      "~nownews.com##.adbanner",
+      "##.adbannerright",
+      "##.adbar",
+      "##.adborder",
+      "##.adbot",
+      "##.adbottom",
+      "##.adbox",
+      "##.adbox-outer",
+      "##.adbox_366x280",
+      "##.adbox_468X60",
+      "##.adbox_bottom",
+      "##.adcode",
+      "##.adcolumn_wrapper",
+      "##.adcontainer",
+      "##.adcopy",
+      "##.addiv",
+      "##.adfoot",
+      "~linux.com##.adframe",
+      "##.adhead",
+      "##.adheader",
+      "##.adheader100",
+      "##.adhere",
+      "##.adi",
+      "##.adinfo",
+      "##.adinside",
+      "##.adjlink",
+      "##.adkit-advert",
+      "##.adkit-lb-footer",
+      "##.adlabel-horz",
+      "##.adlabel-vert",
+      "##.adline",
+      "~bipbip.co.il##.adlist",
+      "##.adlnklst",
+      "##.admarker",
+      "##.admedrec",
+      "##.admodule",
+      "##.admpu",
+      "##.adnotice",
+      "##.adpadding",
+      "~bipbip.co.il##.adpic",
+      "~tomwans.com##.adright",
+      "##.adrow",
+      "##.adrow-post",
+      "##.ads-banner",
+      "##.ads-categories-bsa",
+      "##.ads-links-general",
+      "##.ads-profile",
+      "##.ads-right",
+      "##.ads-sidebar",
+      "##.ads-text",
+      "##.ads2",
+      "##.ads3",
+      "~chw.net,~cub.com,~joinmyband.co.uk,~lets-sell.info##.ads:not(body)",
+      "##.adsArea",
+      "##.adsBox",
+      "##.adsImages",
+      "##.adsTextHouse",
+      "##.adsWithUs",
+      "##.ads_300",
+      "##.ads_728x90",
+      "##.ads_big",
+      "##.ads_big-half",
+      "##.ads_container",
+      "##.ads_disc_anchor",
+      "##.ads_disc_leader",
+      "##.ads_disc_lwr_square",
+      "##.ads_disc_skyscraper",
+      "##.ads_disc_square",
+      "##.ads_div",
+      "##.ads_header",
+      "##.ads_mpu",
+      "##.ads_right",
+      "##.ads_sc_tl_i",
+      "##.ads_side",
+      "##.ads_takeover",
+      "##.adsborder",
+      "##.adscreen",
+      "##.adsection_a2",
+      "##.adsection_c2",
+      "##.adsense",
+      "##.adsense-heading",
+      "##.adsense-title",
+      "##.adsenseContainer",
+      "##.adsingle",
+      "##.adslogan",
+      "##.adspace",
+      "##.adspace-MR",
+      "##.adspacer",
+      "##.adstrip",
+      "##.adtag",
+      "~anzwers.com.au,~u-file.net##.adtext",
+      "##.adtop",
+      "##.adv-mpu",
+      "##.adv250",
+      "##.advBottomHome",
+      "##.advHr",
+      "##.advIdentifier",
+      "##.adv_container",
+      "##.adv_right",
+      "##.adverTag",
+      "##.adver_cont_below",
+      "~beginyouridea.com,~jobs.wa.gov.au##.advert",
+      "##.advert-box",
+      "~mobifrance.com##.advert-horizontal",
+      "##.advert-mpu",
+      "##.advert-skyscraper",
+      "##.advert-text",
+      "##.advertCont",
+      "##.advertContainer",
+      "##.advertHeadline",
+      "##.advertRight",
+      "##.advertText",
+      "##.advert_468x60",
+      "##.advert_box",
+      "##.advert_cont",
+      "##.advert_leaderboard",
+      "##.advert_note",
+      "##.advertise",
+      "##.advertise-homestrip",
+      "##.advertise-horz",
+      "##.advertise-leaderboard",
+      "##.advertise-vert",
+      "##.advertiseContainer",
+      "##.advertisement",
+      "##.advertisement-728x90",
+      "##.advertisement-block",
+      "##.advertisement-top",
+      "##.advertisement468",
+      "##.advertisementColumnGroup",
+      "##.advertisementContainer",
+      "##.advertisementPanel",
+      "##.advertisement_caption",
+      "##.advertisement_header",
+      "##.advertisement_horizontal",
+      "##.advertiser",
+      "##.advertising",
+      "##.advertising-header",
+      "##.advertisingTable",
+      "~macwelt.de##.advertisment",
+      "##.advertisment_two",
+      "##.advertorial",
+      "##.adverts",
+      "##.advt",
+      "##.advt-banner-3",
+      "##.advt300",
+      "##.advt720",
+      "##.adwrapper",
+      "##.adwrapper-lrec",
+      "~virginmobile.fr##.affiliate",
+      "##.affiliate-link",
+      "##.affiliate-sidebar",
+      "##.affiliateAdvertText",
+      "##.agi-adsaleslinks",
+      "##.alt_ad",
+      "##.anchorAd",
+      "##.aolSponsoredLinks",
+      "##.aopsadvert",
+      "##.article-ads",
+      "##.articleAd",
+      "##.articleAds",
+      "##.articleAdsL",
+      "##.articleEmbeddedAdBox",
+      "##.article_ad",
+      "##.article_adbox",
+      "##.aseadn",
+      "##.aux-ad-widget-2",
+      "##.b-astro-sponsored-links_horizontal",
+      "##.b-astro-sponsored-links_vertical",
+      "##.banner-ad",
+      "##.banner-ads",
+      "##.banner-adverts",
+      "##.banner300x100",
+      "##.banner300x250",
+      "##.banner468",
+      "##.bannerAd",
+      "##.bannerAdWrapper300x250",
+      "##.bannerAdWrapper730x86",
+      "##.banner_300x250",
+      "##.banner_728x90",
+      "##.banner_ad",
+      "##.banner_ad_footer",
+      "##.banner_ad_leaderboard",
+      "##.bannerad",
+      "##.barkerAd",
+      "##.bgnavad",
+      "##.bigAd",
+      "##.big_ads",
+      "##.bigad",
+      "##.billboard_ad",
+      "##.block-ad",
+      "##.block_ad",
+      "##.blocked-ads",
+      "##.blog-ads-container",
+      "##.blogAdvertisement",
+      "##.blogBigAd",
+      "##.blog_ad",
+      "##.body_ad",
+      "##.body_sponsoredresults_bottom",
+      "##.body_sponsoredresults_middle",
+      "##.body_sponsoredresults_top",
+      "##.bookseller-header-advt",
+      "##.bottomAd",
+      "##.bottomAds",
+      "##.bottom_ad_block",
+      "##.bottom_sponsor",
+      "##.bottomad",
+      "##.bottomrightrailAd",
+      "##.boxAd",
+      "##.box_ad",
+      "##.box_advertisment_62_border",
+      "##.box_content_ad",
+      "##.box_content_ads",
+      "~blurst.com##.boxad",
+      "##.bps-ad-wrapper",
+      "##.bps-advertisement",
+      "##.bps-advertisement-inline-ads",
+      "##.bullet-sponsored-links",
+      "##.bullet-sponsored-links-gray",
+      "##.burstContentAdIndex",
+      "##.buttonAd",
+      "##.buttonadbox",
+      "##.cA-adStrap",
+      "##.cb_footer_sponsor",
+      "##.cb_navigation_ad",
+      "##.cdAdTitle",
+      "##.cdmainlineSearchAdParent",
+      "##.cdsidebarSearchAdParent",
+      "##.centerAd",
+      "##.center_ad",
+      "##.centerad",
+      "##.clearerad",
+      "##.cm_ads",
+      "##.cnn160AdFooter",
+      "##.cnnAd",
+      "##.cnnMosaic160Container",
+      "##.cnnStoreAd",
+      "##.cnnStoryElementBoxAd",
+      "##.cnnWCAdBox",
+      "##.cnnWireAdLtgBox",
+      "##.cnn_adcntr300x100",
+      "##.cnn_adspc336cntr",
+      "##.cnn_adtitle",
+      "##.column2-ad",
+      "##.confirm_ad_left",
+      "##.confirm_ad_right",
+      "##.confirm_leader_ad",
+      "##.consoleAd",
+      "##.container_serendipity_plugin_google_adsense",
+      "~theology.edu##.contentAd",
+      "##.content_ad",
+      "##.content_adsq",
+      "##.contentad",
+      "##.contenttextad",
+      "##.cp_ad",
+      "##.cpmstarHeadline",
+      "##.cpmstarText",
+      "##.ct_ad",
+      "##.cubeAd",
+      "##.cube_ads",
+      "##.darla_ad",
+      "##.dartAdImage",
+      "##.dart_ad",
+      "##.dart_tag",
+      "##.dartadvert",
+      "##.dartiframe",
+      "##.dc-ad",
+      "##.dcAdvertHeader",
+      "##.deckAd",
+      "##.detailMpu",
+      "##.divads",
+      "##.dmco_advert_iabrighttitle",
+      "##.download_ad",
+      "##.downloadad",
+      "##.dynamic_ad",
+      "##.ec-ads",
+      "##.entryad",
+      "##.ez-clientAd",
+      "##.f_Ads",
+      "##.featuredAds",
+      "##.featuredadvertising",
+      "##.flagads",
+      "##.flash_advert",
+      "##.flashad",
+      "##.flexiad",
+      "##.flipbook_v2_sponsor_ad",
+      "##.footerAd",
+      "##.footerAdModule",
+      "##.footerTextAd",
+      "##.footer_ad",
+      "##.footer_ads",
+      "##.footer_block_ad",
+      "##.footer_line_ad",
+      "##.ft-ad",
+      "##.ftdContentAd",
+      "##.full_ad_box",
+      "##.g3rtn-ad-site",
+      "##.g_ggl_ad",
+      "##.gads_cb",
+      "##.gglAds",
+      "##.google-ad-container",
+      "##.google-ads",
+      "##.google-ads-boxout",
+      "##.google-right-ad",
+      "##.google-sponsored-ads",
+      "##.google468_60",
+      "##.googleAd",
+      "##.googleAd-content",
+      "##.googleAd-list",
+      "##.googleAdBox",
+      "##.googleAdSense",
+      "##.googleAd_body",
+      "##.googleAds",
+      "##.googleAdsense",
+      "##.googleProfileAd",
+      "##.googlead",
+      "##.googleads",
+      "##.googleads_300x250",
+      "##.googleads_title",
+      "##.gpAds",
+      "##.gradientAd",
+      "##.gt_ad_300x250",
+      "##.gt_ad_728x90",
+      "##.gutter-ad-left",
+      "##.gutter-ad-right",
+      "##.h_Ads",
+      "##.h_ad",
+      "##.hd_advert",
+      "~burningangel.com##.header-ad",
+      "##.header-advert",
+      "~photobucket.com##.headerAd",
+      "##.headerAdvert",
+      "##.header_ad",
+      "~associatedcontent.com##.header_ad_center",
+      "##.header_advertisment",
+      "##.hi5-ad",
+      "##.highlightsAd",
+      "##.hm_advertisment",
+      "##.home-ad-links",
+      "##.homeAd",
+      "##.homeMediumAdGroup",
+      "##.homepage-ad",
+      "##.homepageFlexAdOuter",
+      "##.homepageMPU",
+      "##.hor_ad",
+      "##.horizontalAd",
+      "~radaronline.com##.horizontal_ad",
+      "##.hortad",
+      "##.houseAdsStyle",
+      "##.hp2-adtag",
+      "##.hp_ad_cont",
+      "##.hp_ad_text",
+      "##.hp_t_ad",
+      "##.hp_w_ad",
+      "##.ic-ads",
+      "##.idMultiAd",
+      "##.image-advertisement",
+      "##.imageads",
+      "##.in-page-ad",
+      "##.in-story-text-ad",
+      "##.indy_googleads",
+      "##.inline-mpu-left",
+      "##.inlineSideAd",
+      "##.inline_ad_title",
+      "##.inlinead",
+      "##.inlist-ad",
+      "##.inner-advt-banner-3",
+      "##.innerAds",
+      "##.innerad",
+      "##.inpostad",
+      "##.islandAd",
+      "##.js-advert",
+      "##.kw_advert",
+      "##.kw_advert_pair",
+      "##.l_ad_sub",
+      "##.largeRectangleAd",
+      "##.leader_ad",
+      "##.leaderboardAd",
+      "##.left-ad",
+      "##.leftAd",
+      "##.leftad",
+      "##.linead",
+      "##.link_advertise",
+      "##.live-search-list-ad-container",
+      "##.log_ads",
+      "##.lowerAds",
+      "##.m_banner_ads",
+      "##.macAd",
+      "##.macad",
+      "##.main-tabs-ad-block",
+      "##.main_ad",
+      "##.main_adbox",
+      "##.map_media_banner_ad",
+      "##.marginadsthin",
+      "##.marketing-ad",
+      "##.mdl-ad",
+      "##.media-advert",
+      "##.medium-rectangle-ad",
+      "##.messageBoardAd",
+      "##.micro_ad",
+      "##.mid_ad",
+      "##.midad",
+      "##.min_navi_ad",
+      "##.miniad",
+      "##.mod-ad-lrec",
+      "##.mod-ad-n",
+      "##.mod-adopenx",
+      "##.mod_admodule",
+      "##.module-ad-small",
+      "##.module-ads",
+      "##.modulegad",
+      "##.moduletable-advert",
+      "##.moduletablesquaread",
+      "~gamespot.com##.mpu",
+      "##.mpu-ad",
+      "##.mpu-title",
+      "##.mpuAd",
+      "##.mpuBox",
+      "##.mpuContainer",
+      "##.mpuTextAd",
+      "##.mpu_ad",
+      "##.mpu_gold",
+      "##.mpu_platinum",
+      "##.mpuholderportalpage",
+      "##.msfg-shopping-mpu",
+      "##.mwaads",
+      "##.nadvt300",
+      "##.naviad",
+      "##.nba300Ad",
+      "##.nbaT3Ad160",
+      "##.nbaTwo130Ads",
+      "##.nbc_ad_carousel_wrp",
+      "##.newTopAdContainer",
+      "##.newad",
+      "##.nf-adbox",
+      "##.nn-mpu",
+      "##.normalAds",
+      "##.nrAds",
+      "##.oas-bottom-ads",
+      "##.oio-banner-zone",
+      "##.oio-link-sidebar",
+      "##.oio-zone-position",
+      "##.onethirdadholder",
+      "##.openx",
+      "##.openx-ad",
+      "##.ov_spns",
+      "##.padadv",
+      "##.pageLeaderAd",
+      "##.pagead",
+      "##.partnersTextLinks",
+      "##.pencil_ad",
+      "##.player_ad_box",
+      "##.player_page_ad_box",
+      "##.pnp_ad",
+      "##.podSponsoredLink",
+      "##.post-ad",
+      "##.post_ad",
+      "##.post_sponsor_unit",
+      "##.postbit_adcode",
+      "##.prebodyads",
+      "##.premium_ad_container",
+      "##.promoAd",
+      "##.promoAds",
+      "##.publication-ad",
+      "##.puff-advertorials",
+      "##.quigo-ad",
+      "##.qzvAdDiv",
+      "##.r_ad_box",
+      "##.rad_container",
+      "##.rectad",
+      "##.rectangleAd",
+      "##.rectanglead",
+      "##.redads_cont",
+      "##.regularad",
+      "##.relatedAds",
+      "##.result_ad",
+      "##.results_sponsor",
+      "##.results_sponsor_right",
+      "##.rght300x250",
+      "##.rhads",
+      "##.rhs-ad",
+      "##.rhs-ads-panel",
+      "##.right-ad",
+      "##.right-ad-holder",
+      "##.right-ad2",
+      "##.rightAd",
+      "##.right_ad",
+      "##.right_ad_text",
+      "##.right_hand_advert_column",
+      "##.rightad",
+      "##.rightad_1",
+      "##.rightad_2",
+      "##.rightads",
+      "##.rightadunit",
+      "##.rightcol_boxad",
+      "##.rightcoladvert",
+      "##.rt_ad1_300x90",
+      "##.rt_ad_300x250",
+      "##.rt_ad_call",
+      "##.savvyad_unit",
+      "##.sb-ad-sq-bg",
+      "##.sbAdUnitContainer",
+      "##.sb_adsN",
+      "##.sb_adsNv2",
+      "##.sb_adsW",
+      "##.sb_adsWv2",
+      "##.scanAd",
+      "##.sci-ad-main",
+      "##.sci-ad-sub",
+      "##.search-sponsor",
+      "##.search-sponsored",
+      "##.searchAd",
+      "##.searchSponsoredResultsBox",
+      "##.search_column_results_sponsored",
+      "##.search_results_sponsored_top",
+      "##.section-sponsor",
+      "##.section_mpu_wrapper",
+      "##.selfServeAds",
+      "##.sidbaread",
+      "##.side-ad",
+      "##.side_ad",
+      "##.sidead",
+      "##.sideadsbox",
+      "##.sideadvert",
+      "##.sidebar-ad",
+      "##.sidebar-text-ad",
+      "##.sidebarAd",
+      "##.sidebarAdUnit",
+      "##.sidebarAdvert",
+      "##.sidebar_ad",
+      "##.sidebar_box_ad",
+      "##.sidebarad",
+      "##.sidebarad_bottom",
+      "##.sideheadnarrowad",
+      "##.sideheadsponsorsad",
+      "##.singleAd",
+      "##.singleAdsContainer",
+      "##.singlead",
+      "##.sitesponsor",
+      "##.skinAd",
+      "##.skin_ad_638",
+      "##.sky-ad",
+      "##.skyAd",
+      "##.skyAdd",
+      "##.sky_ad",
+      "##.skyscraper-ad",
+      "##.smallSkyAd1",
+      "##.smallSkyAd2",
+      "##.small_ad",
+      "##.small_ads",
+      "##.smallad-left",
+      "##.smallsponsorad",
+      "##.specialAd175x90",
+      "##.spl_ad",
+      "##.spl_ad2",
+      "##.spl_ad_plus",
+      "##.splitAd",
+      "##.spons-link",
+      "##.sponslink",
+      "##.sponsor-ad",
+      "##.sponsor-links",
+      "##.sponsorArea",
+      "##.sponsorPost",
+      "##.sponsorPostWrap",
+      "##.sponsor_line",
+      "##.sponsoradtitle",
+      "##.sponsorbox",
+      "~gamespot.com,~mint.com,~slidetoplay.com,~zattoo.com##.sponsored",
+      "##.sponsored-chunk",
+      "##.sponsored-links",
+      "##.sponsored-post",
+      "##.sponsored-text",
+      "##.sponsoredLinks",
+      "##.sponsoredLinksHeader",
+      "##.sponsored_ads",
+      "##.sponsored_box",
+      "##.sponsored_by",
+      "##.sponsored_links",
+      "##.sponsored_links_title_container",
+      "##.sponsored_links_title_container_top",
+      "##.sponsored_links_top",
+      "##.sponsoredibbox",
+      "##.sponsoredlinks",
+      "##.sponsorlink",
+      "##.squareAd",
+      "##.square_ad",
+      "##.squared_ad",
+      "##.ss-ad-mpu",
+      "##.store-ads",
+      "##.story_AD",
+      "##.story_right_adv",
+      "##.subad",
+      "##.subcontent-ad",
+      "##.supercommentad_left",
+      "##.supercommentad_right",
+      "##.surveyad",
+      "##.t10ad",
+      "##.tab_ad",
+      "##.tab_ad_area",
+      "##.tablebordersponsor",
+      "##.tadsanzeige",
+      "##.tadsbanner",
+      "##.tadselement",
+      "##.tblTopAds",
+      "##.tbl_ad",
+      "##.teaserAdContainer",
+      "##.teaser_adtiles",
+      "##.text-ad-links",
+      "##.text-g-advertisement",
+      "##.text-g-group-short-rec-ad",
+      "##.text-g-net-grp-google-ads-article-page",
+      "##.textAd",
+      "##.textAds",
+      "##.text_ads",
+      "##.textad",
+      "~frogueros.com##.textads",
+      "##.textlink-ads",
+      "##.thisIsAd",
+      "##.thisIsAnAd",
+      "##.ticket-ad",
+      "##.tileAds",
+      "##.title_adbig",
+      "##.toolad",
+      "##.toolbar-ad",
+      "##.top-ad",
+      "##.top-ad-space",
+      "##.top-ads",
+      "##.topAdWrap",
+      "~timescall.com##.topAds",
+      "##.topAdvertisement",
+      "##.topBannerAd",
+      "##.top_ad",
+      "##.top_ad_disclaimer",
+      "##.top_ad_wrapper",
+      "##.top_advert",
+      "##.top_sponsor",
+      "##.topad",
+      "##.topadbox",
+      "##.topadspot",
+      "##.topcontentadvertisement",
+      "##.topstoriesad",
+      "##.towerAds",
+      "##.tower_ad_disclaimer",
+      "##.ts-ad_unit_bigbox",
+      "##.ts-banner_ad",
+      "##.ttlAdsensel",
+      "##.twoColumnAd",
+      "##.twoadcoll",
+      "##.twoadcolr",
+      "##.tx_smartadserver_pi1",
+      "##.txt-ads",
+      "##.type_promoads",
+      "##.usenext",
+      "##.vertad",
+      "##.videoAd",
+      "##.view-promo-mpu-right",
+      "##.wide-ad",
+      "##.wide-skyscraper-ad",
+      "##.wideAdTable",
+      "##.wide_ads",
+      "##.widget-entry-ads-160",
+      "##.wikia_ad_placeholder",
+      "##.withAds",
+      "##.wnMultiAd",
+      "##.y7-advertisement",
+      "##.yahoo-sponsored",
+      "##.yahoo_ads",
+      "##.ygrp-ad",
+      "##.yrail_ad_wrap",
+      "##.yrail_ads",
+      "##.ysmsponsor",
+      "##.ysponsor",
+      "##a[href^=\"http://adserving.liveuniversenetwork.com/\"]",
+      "##a[href^=\"http://latestdownloads.net/download.php?\"]",
+      "##a[href^=\"http://www.FriendlyDuck.com/AF_\"]",
+      "##a[href^=\"http://www.adbrite.com/mb/commerce/purchase_form.php?\"]",
+      "##a[href^=\"http://www.liutilities.com/aff\"]",
+      "##a[href^=\"http://www.my-dirty-hobby.com/?sub=\"]",
+      "##a[href^=\"http://www.ringtonematcher.com/\"]",
+      "!Google",
+      "~all.google.domains###adt[align=\"right\"][style=\"border-left: 1px solid rgb(201, 215, 241);\"]",
+      "~all.google.domains###mbEnd[width=\"30%\"][style]",
+      "~all.google.domains###mboxEnd[width=\"30%\"][style]",
+      "~all.google.domains##div#mclip_container:first-child:last-child",
+      "~all.google.domains##div#tads.c",
+      "~all.google.domains##div.ch[id^=\"tba\"][style]",
+      "~all.google.domains##div.ch[id^=\"tpa\"][style]",
+      "~all.google.domains##div[style=\"font-size: small; background-color: rgb(255, 249, 221);\"]",
+      "~all.google.domains##div[style^=\"background: rgb(255, 248, 221) none repeat scroll 0% 0%; margin-top: 10px;\"]",
+      "~all.google.domains##table.ra[align=\"left\"][width=\"30%\"]",
+      "~all.google.domains##table.ra[align=\"right\"][width=\"30%\"]",
+      "~all.google.domains##table[align=\"center\"][cellpadding=\"0\"][style*=\"padding: 8px;\"][style*=\"rgb(255, 248, 221);\"][width=\"100%\"]",
+      "~all.google.domains##table[style^=\"padding: 8px; background: rgb(255, 248, 221) none repeat scroll 0% 0%; -moz-background-clip:\"]",
+      "!--------------------------------------Third-party adservers---------------------------------------!",
+      "! *** easylist_adservers.txt ***",
+      "||1100i.com^$third-party",
+      "||188server.com^$third-party",
+      "||247realmedia.com^$third-party",
+      "||2mdn.net^$third-party",
+      "||360ads.com^$third-party",
+      "||3rdads.com^$third-party",
+      "||43plc.com^$third-party",
+      "||600z.com^$third-party",
+      "||777seo.com^$third-party",
+      "||7search.com^$third-party",
+      "||aa.voice2page.com^$third-party",
+      "||accuserveadsystem.com^$third-party",
+      "||acf-webmaster.net^$third-party",
+      "||acronym.com^$third-party",
+      "||ad-flow.com^$third-party",
+      "||ad20.net^$third-party",
+      "||ad2games.com^$third-party",
+      "||ad4game.com^$third-party",
+      "||adaction.se^$third-party",
+      "||adaos-ads.net^$third-party",
+      "||adbard.net^$third-party",
+      "||adblade.com^$third-party",
+      "||adbrite.com^$third-party",
+      "||adbureau.net^$third-party",
+      "||adbutler.com^$third-party",
+      "||adcde.com^$third-party",
+      "||adcentriconline.com^$third-party",
+      "||adchap.com^$third-party",
+      "||adclickmedia.com^$third-party",
+      "||adcru.com^$third-party",
+      "||addynamo.com^$third-party",
+      "||adecn.com^$third-party",
+      "||adengage.com^$third-party",
+      "||adf01.net^$third-party",
+      "||adfactory88.com^$third-party",
+      "||adfrontiers.com^$third-party",
+      "||adfusion.com^$third-party",
+      "||adgardener.com^$third-party",
+      "||adgent007.com^$third-party",
+      "||adgine.net^$third-party",
+      "||adgroups.com^$third-party",
+      "||adhese.be^$third-party",
+      "||adhese.net^$third-party",
+      "||adicate.com^$third-party",
+      "||adinterax.com^$third-party",
+      "||adireland.com^$third-party",
+      "||adisfy.com^$third-party",
+      "||adisn.com^$third-party",
+      "||adition.com^$third-party",
+      "||adjal.com^$third-party",
+      "||adjug.com^$third-party",
+      "||adjuggler.com^$third-party",
+      "||adjuggler.net^$third-party",
+      "||adlink.net^$third-party",
+      "||admarketplace.net^$third-party",
+      "||admeld.com^$third-party",
+      "||admeta.com^$third-party",
+      "||admpads.com^$third-party",
+      "||adnet.biz^$third-party",
+      "||adnet.com^$third-party",
+      "||adnet.ru^$third-party",
+      "||adocean.pl^$third-party",
+      "||adoperator.com^$third-party",
+      "||adotube.com^$third-party",
+      "||adparlor.com^$third-party",
+      "||adperium.com^$third-party",
+      "||adpinion.com^$third-party",
+      "||adpionier.de^$third-party",
+      "||adpremo.com^$third-party",
+      "||adroll.com^$third-party",
+      "||ads-stats.com^$third-party",
+      "||ads4cheap.com^$third-party",
+      "||adsdk.com^$third-party",
+      "||adsensecamp.com^$third-party",
+      "||adserver.yahoo.com^$third-party",
+      "||adservinginternational.com^$third-party",
+      "||adsfactor.net^$third-party",
+      "||adsfast.com^$third-party",
+      "||adsforindians.com^$third-party",
+      "||adshopping.com^$third-party",
+      "||adshuffle.com^$third-party",
+      "||adsmarket.com^$third-party",
+      "||adsonar.com^$third-party",
+      "||adspeed.com^$third-party",
+      "||adsrevenue.net^$third-party",
+      "||adtaily.eu^$third-party",
+      "||adtech.de^$third-party",
+      "||adtechus.com^$third-party",
+      "||adtoll.com^$third-party",
+      "||adtology1.com^$third-party",
+      "||adtology2.com^$third-party",
+      "||adtology3.com^$third-party",
+      "||adtoma.com^$third-party",
+      "||adtrgt.com^$third-party",
+      "||adtrix.com^$third-party",
+      "||adult-adv.com^$third-party",
+      "||adultadworld.com^$third-party",
+      "||adversalservers.com^$third-party",
+      "||adverserve.net^$third-party",
+      "||advertarium.com.ua^$third-party",
+      "||adverticum.net^$third-party",
+      "||advertise.com^$third-party",
+      "||advertiseyourgame.com^$third-party",
+      "||advertising-department.com^$third-party",
+      "||advertising.com^$third-party",
+      "||advertlets.com^$third-party",
+      "||advertserve.com^$third-party",
+      "||advertstatic.com^$third-party",
+      "||advg.jp/$third-party",
+      "||adviva.net^$third-party",
+      "||advpoints.com^$third-party",
+      "||adxpower.com^$third-party",
+      "||adyoz.com^$third-party",
+      "||afcyhf.com^$third-party",
+      "||affiliate.com^$third-party",
+      "||affiliatefuel.com^$third-party",
+      "||affiliatefuture.com^$third-party",
+      "||affiliatesensor.com^$third-party",
+      "||affiliproducts.com^$third-party",
+      "||affinity.com^$third-party",
+      "||afy11.net^$third-party",
+      "||agentcenters.com^$third-party",
+      "||aggregateknowledge.com^$third-party",
+      "||aim4media.com^$third-party",
+      "||alimama.cn^$third-party",
+      "||alphagodaddy.com^$third-party",
+      "||amgdgt.com^$third-party",
+      "||anrdoezrs.net^$third-party",
+      "||apmebf.com^$third-party",
+      "||arcadebannerexchange.net^$third-party",
+      "||arcadebanners.com^$third-party",
+      "||arcadebe.com^$third-party",
+      "||arti-mediagroup.com^$third-party",
+      "||as5000.com^$third-party",
+      "||asklots.com^$third-party",
+      "||assoc-amazon.co.uk^$third-party",
+      "||assoc-amazon.com^$third-party",
+      "||atdmt.com^$third-party",
+      "||atwola.com^$third-party",
+      "||audienceprofiler.com^$third-party",
+      "||auditude.com^$third-party",
+      "||auspipe.com^$third-party",
+      "||avads.co.uk^$third-party",
+      "||avantlink.com^$third-party",
+      "||awaps.net^$third-party",
+      "||awin1.com^$third-party",
+      "||awltovhc.com^$third-party",
+      "||axill.com^$third-party",
+      "||azads.com^$third-party",
+      "||azjmp.com^$third-party",
+      "||azoogleads.com^$third-party",
+      "||backbeatmedia.com^$third-party",
+      "||bannerbank.ru^$third-party",
+      "||bannerconnect.com^$third-party",
+      "||bannerconnect.net^$third-party",
+      "||bannerlot.com^$third-party",
+      "||bannersmania.com^$third-party",
+      "||bbelements.com^$third-party",
+      "||begun.ru^$third-party",
+      "||belointeractive.com^$third-party",
+      "||bestofferdirect.com^$third-party",
+      "||bfast.com^$third-party",
+      "||bidvertiser.com^$third-party",
+      "||biemedia.com^$third-party",
+      "||bin-layer.de^$third-party",
+      "||bin-layer.ru^$third-party",
+      "||binlayer.de^$third-party",
+      "||bittads.com^$third-party",
+      "||blogad.com.tw^$third-party",
+      "||blogads.com^$third-party",
+      "||bloggerads.net^$third-party",
+      "||bluestreak.com^$third-party",
+      "||bmanpn.com^$third-party",
+      "||bnetworx.com^$third-party",
+      "||bnr.sys.lv^$third-party",
+      "||boo-box.com^$third-party",
+      "||boylesportsreklame.com^$third-party",
+      "||branchr.com^$third-party",
+      "||bravenetmedianetwork.com^$third-party",
+      "||bridgetrack.com^$third-party",
+      "||btrll.com^$third-party",
+      "||bu520.com^$third-party",
+      "||buildtrafficx.com^$third-party",
+      "||burstnet.com^$third-party",
+      "||buysellads.com^$third-party",
+      "||buzzparadise.com^$third-party",
+      "||c-on-text.com^$third-party",
+      "||c8.net.ua^$third-party",
+      "||captainad.com^$third-party",
+      "||casalemedia.com^$third-party",
+      "||cc-dt.com^$third-party",
+      "||cdna.tremormedia.com^$third-party",
+      "||cgecwm.org^$third-party",
+      "||checkm8.com^$third-party",
+      "||checkmystats.com.au^$third-party",
+      "||checkoutfree.com^$third-party",
+      "||chitika.net^$third-party",
+      "||cjt1.net^$third-party",
+      "||clash-media.com^$third-party",
+      "||claxonmedia.com^$third-party",
+      "||clickad.pl^$third-party",
+      "||clickbooth.com^$third-party",
+      "||clickexa.com^$third-party",
+      "||clickexperts.net^$third-party",
+      "||clickfuse.com^$third-party",
+      "||clickintext.net^$third-party",
+      "||clickthrucash.com^$third-party",
+      "||clixgalore.com^$third-party",
+      "||cogsdigital.com^$third-party",
+      "||collective-media.net^$third-party",
+      "||commission-junction.com^$third-party",
+      "||commissionmonster.com^$third-party",
+      "||conduit-banners.com^$third-party",
+      "||connectedads.net^$third-party",
+      "||connextra.com^$third-party",
+      "||contenture.com^$third-party",
+      "||contextuads.com^$third-party",
+      "||contextweb.com^$third-party",
+      "||cpaclicks.com^$third-party",
+      "||cpalead.com^$third-party",
+      "||cpays.com^$third-party",
+      "||cpmstar.com^$third-party",
+      "||cpuim.com^$third-party",
+      "||cpxinteractive.com^$third-party",
+      "||crispads.com^$third-party",
+      "||crowdgravity.com^$third-party",
+      "||ctrhub.com^$third-party",
+      "||cubics.com^$third-party",
+      "||d.m3.net^$third-party",
+      "||da.feedsportal.com^$third-party",
+      "||dbbsrv.com^$third-party",
+      "||decisionmark.com^$third-party",
+      "||decisionnews.com^$third-party",
+      "||deepmetrix.com^$third-party",
+      "||destinationurl.com^$third-party",
+      "||dexplatform.com^$third-party",
+      "||dgmaustralia.com^$third-party",
+      "||digitrevenue.com^$third-party",
+      "||dinclinx.com^$third-party",
+      "||directorym.com^$third-party",
+      "||directtrack.com^$third-party",
+      "||dl-rms.com^$third-party",
+      "||domainsponsor.com^$third-party",
+      "||doubleclick.net/pfadx/*.mtvi$object_subrequest,third-party",
+      "||doubleclick.net/pfadx/*adcat=$object_subrequest,third-party",
+      "||doubleclick.net^$object_subrequest,third-party,domain=addictinggames.com|atom.com|break.com|businessweek.com|cbs4denver.com|darkhorizons.com|eonline.com|fandango.com|foxbusiness.com|foxnews.com|g4tv.com|gametrailers.com|joblo.com|mtv.co.uk|myfoxphoenix.com|newsweek.com|nick.com|nytimes.com|play.it|ps3news.com|sbsun.com|shockwave.com|space.com|spike.com|thedailygreen.com|thedailyshow.com|thewire.com|washingtonpost.com|wired.com|wsj.com|wwe.com|youtube.com|zoomin.tv",
+      "||doubleclick.net^$~object_subrequest,third-party",
+      "||doubleclick.net^*;sz=$object_subrequest,third-party,domain=1up.com|breitbart.tv|digitaltrends.com|gamesradar.com|heavy.com|myspace.com|nbc.com|nfl.com",
+      "||dpbolvw.net^$third-party",
+      "||dt00.net^$third-party,domain=~marketgid.com",
+      "||e-planning.net^$third-party",
+      "||ebannertraffic.com^$third-party",
+      "||ebayobjects.com.au^$third-party",
+      "||ebayobjects.com^$third-party",
+      "||edge-dl.andomedia.com^$third-party",
+      "||egamingonline.com^$third-party",
+      "||ekmas.com^$third-party",
+      "||emediate.eu^$third-party",
+      "||emediate.se^$third-party",
+      "||ero-advertising.com^$third-party",
+      "||etology.com^$third-party",
+      "||euroclick.com^$third-party",
+      "||euros4click.de^$third-party",
+      "||exelator.com^$third-party",
+      "||exitexplosion.com^$third-party",
+      "||exitjunction.com^$third-party",
+      "||exponential.com^$third-party",
+      "||eyereturn.com^$third-party",
+      "||eyewonder.com^$third-party",
+      "||fairadsnetwork.com^$third-party",
+      "||fairfax.com.au^$~stylesheet,third-party",
+      "||falkag.net^$third-party",
+      "||fastclick.net^$third-party",
+      "||fimserve.com^$third-party",
+      "||firstadsolution.com^$third-party",
+      "||firstlightera.com^$third-party",
+      "||fixionmedia.com^$third-party",
+      "||flashtalking.com^$third-party",
+      "||fluxads.com^$third-party",
+      "||fmpub.net^$third-party",
+      "||footerslideupad.com^$third-party",
+      "||forms.aweber.com^$third-party",
+      "||forrestersurveys.com^$third-party",
+      "||friendlyduck.com^$third-party",
+      "||ftjcfx.com^$third-party",
+      "||funklicks.com^$third-party",
+      "||fusionads.net^$third-party",
+      "||fwmrm.net^$third-party",
+      "||g.doubleclick.net^$third-party",
+      "||game-advertising-online.com^$third-party",
+      "||gameads.com^$third-party",
+      "||gamecetera.com^$third-party",
+      "||gamersbanner.com^$third-party",
+      "||gannett.gcion.com^$third-party",
+      "||geo-idm.fr^$third-party",
+      "||geopromos.com^$third-party",
+      "||gestionpub.com^$third-party",
+      "||gimiclub.com^$third-party",
+      "||gklmedia.com^$third-party",
+      "||globaladsales.com^$third-party",
+      "||globaladv.net^$third-party",
+      "||go2media.org^$third-party",
+      "||googleadservices.com^$third-party",
+      "||grabmyads.com^$third-party",
+      "||gratisnetwork.com^$third-party",
+      "||gumgum.com^$third-party",
+      "||halogennetwork.com^$third-party",
+      "||havamedia.net^$third-party",
+      "||hb-247.com^$third-party",
+      "||hit-now.com^$third-party",
+      "||hopfeed.com^$third-party",
+      "||hosticanaffiliate.com^$third-party",
+      "||httpool.com^$third-party",
+      "||hypemakers.net^$third-party",
+      "||hypervre.com^$third-party",
+      "||ic-live.com^$third-party",
+      "||icdirect.com^$third-party",
+      "||imagesatlantic.com^$third-party",
+      "||imedia.co.il^$third-party",
+      "||imglt.com^$third-party",
+      "||imho.ru/$third-party",
+      "||imiclk.com^$third-party",
+      "||impact-ad.jp^$third-party",
+      "||impresionesweb.com^$third-party",
+      "||indiads.com^$third-party",
+      "||industrybrains.com^$third-party",
+      "||inetinteractive.com^$third-party",
+      "||infinite-ads.com^$third-party",
+      "||infolinks.com^$third-party",
+      "||innity.com^$third-party",
+      "||insightexpressai.com^$third-party",
+      "||inskinad.com^$third-party",
+      "||intellitxt.com^$third-party",
+      "||interclick.com^$third-party",
+      "||interpolls.com^$third-party",
+      "||investingchannel.com^$third-party",
+      "||ipromote.com^$third-party",
+      "||jangonetwork.com^$third-party",
+      "||jdoqocy.com^$third-party",
+      "||jumboaffiliates.com^$third-party",
+      "||justrelevant.com^$third-party",
+      "||kanoodle.com^$third-party",
+      "||kerg.net^$third-party",
+      "||ketoo.com^$third-party",
+      "||kitnmedia.com^$third-party",
+      "||klipmart.com^$third-party",
+      "||kontera.com^$third-party",
+      "||kqzyfj.com^$third-party",
+      "||lakequincy.com^$third-party",
+      "||lduhtrp.net^$third-party",
+      "||leadacceptor.com^$third-party",
+      "||ligatus.com^$third-party",
+      "||lightningcast.net^$~object_subrequest,third-party",
+      "||lingospot.com^$third-party",
+      "||linkbucks.com^$third-party",
+      "||linkexchange.com^$third-party",
+      "||linkshowoff.com^$third-party",
+      "||linkstorm.net^$third-party",
+      "||linksynergy.com^$third-party",
+      "||linkworth.com^$third-party",
+      "||linkz.net^$third-party",
+      "||liverail.com^$third-party",
+      "||liveuniversenetwork.com^$third-party",
+      "||ltassrv.com.s3.amazonaws.com^$third-party",
+      "||ltassrv.com^$third-party",
+      "||lzjl.com^$third-party",
+      "||madisonlogic.com^$third-party",
+      "||marketingsolutions.yahoo.com^$third-party",
+      "||maxserving.com^$third-party",
+      "||mb01.com^$third-party",
+      "||mbn.com.ua^$third-party",
+      "||media6degrees.com^$third-party",
+      "||mediag4.com^$third-party",
+      "||mediagridwork.com^$third-party",
+      "||medialand.ru^$third-party",
+      "||mediaonenetwork.net^$third-party",
+      "||mediaplex.com^$third-party",
+      "||mediatarget.com^$third-party",
+      "||medleyads.com^$third-party",
+      "||medrx.sensis.com.au^$third-party",
+      "||megaclick.com^$third-party",
+      "||mercuras.com^$third-party",
+      "||metaffiliation.com^$third-party",
+      "||mezimedia.com^$third-party",
+      "||microsoftaffiliates.net^$third-party",
+      "||milabra.com^$third-party",
+      "||mirago.com^$third-party",
+      "||miva.com^$third-party",
+      "||mktseek.com^$third-party",
+      "||mochiads.com/srv/",
+      "||money4ads.com^$third-party",
+      "||mootermedia.com^$third-party",
+      "||moregamers.com^$third-party",
+      "||moreplayerz.com^$third-party",
+      "||mpression.net^$third-party",
+      "||nabbr.com^$third-party",
+      "||nbjmp.com^$third-party",
+      "||neodatagroup.com^$third-party",
+      "||neoffic.com^$third-party",
+      "||net3media.com^$third-party",
+      "||netavenir.com^$third-party",
+      "||netseer.com^$third-party",
+      "||networldmedia.net^$third-party",
+      "||newsadstream.com^$third-party",
+      "||newtention.net^$third-party",
+      "||nexac.com^$third-party",
+      "||nicheads.com^$third-party",
+      "||northmay.com^$third-party",
+      "||nvero.net^$third-party",
+      "||nyadmcncserve-05y06a.com^$third-party",
+      "||obeus.com^$third-party",
+      "||obibanners.com^$third-party",
+      "||objects.tremormedia.com^$~object_subrequest,third-party",
+      "||objectservers.com^$third-party",
+      "||oclus.com^$third-party",
+      "||omg2.com^$third-party",
+      "||omguk.com^$third-party",
+      "||onads.com^$third-party",
+      "||onenetworkdirect.net^$third-party",
+      "||openx.net^$third-party",
+      "||openx.org^$third-party",
+      "||othersonline.com^$third-party",
+      "||overture.com^$third-party",
+      "||oxado.com^$third-party",
+      "||p-advg.com^$third-party",
+      "||pagead2.googlesyndication.com^$~object_subrequest,third-party",
+      "||paperg.com^$third-party",
+      "||partner.video.syndication.msn.com^$~object_subrequest,third-party",
+      "||partypartners.com^$third-party",
+      "||payperpost.com^$third-party",
+      "||pc-ads.com^$third-party",
+      "||peer39.net^$third-party",
+      "||pepperjamnetwork.com^$third-party",
+      "||perfb.com^$third-party",
+      "||performancingads.com^$third-party",
+      "||pgmediaserve.com^$third-party",
+      "||pgpartner.com^$third-party",
+      "||pheedo.com^$third-party",
+      "||picadmedia.com^$third-party",
+      "||pinballpublishernetwork.com^$third-party",
+      "||platinumadvertisement.com^$third-party",
+      "||playertraffic.com^$third-party",
+      "||pntra.com^$third-party",
+      "||pntrac.com^$third-party",
+      "||pntrs.com^$third-party",
+      "||pointroll.com^$third-party",
+      "||precisionclick.com^$third-party",
+      "||predictad.com^$third-party",
+      "||primaryads.com^$third-party",
+      "||pro-advertising.com^$third-party",
+      "||pro-market.net^$third-party",
+      "||probannerswap.com^$third-party",
+      "||prod.untd.com^$third-party",
+      "||profitpeelers.com^$third-party",
+      "||projectwonderful.com^$third-party",
+      "||proximic.com^$third-party",
+      "||psclicks.com^$third-party",
+      "||ptp.lolco.net^$third-party",
+      "||pubmatic.com^$third-party",
+      "||pulse360.com^$third-party",
+      "||qksrv.net^$third-party",
+      "||qksz.net^$third-party",
+      "||questionmarket.com^$third-party",
+      "||questus.com^$third-party",
+      "||quisma.com^$third-party",
+      "||radiusmarketing.com^$third-party",
+      "||rapt.com^$third-party",
+      "||rbcdn.com^$third-party",
+      "||realmedia.com^$third-party",
+      "||reelcentric.com^$third-party",
+      "||reklamz.com^$third-party",
+      "||resultlinks.com^$third-party",
+      "||revfusion.net^$third-party",
+      "||revresda.com^$third-party",
+      "||ricead.com^$third-party",
+      "||ringtonematcher.com^$third-party",
+      "||rmxads.com^$third-party",
+      "||roirocket.com^$third-party",
+      "||rotatingad.com^$third-party",
+      "||rover.ebay.com^*&adtype=$third-party",
+      "||rovion.com^$third-party",
+      "||ru4.com/$third-party",
+      "||rubiconproject.com^$third-party",
+      "||rwpads.com^$third-party",
+      "||sa.entireweb.com^$third-party",
+      "||safelistextreme.com^$third-party",
+      "||salvador24.com^$third-party",
+      "||sbaffiliates.com^$third-party",
+      "||scanscout.com^$third-party",
+      "||sendptp.com^$third-party",
+      "||sev4ifmxa.com^$third-party",
+      "||shareasale.com^$third-party",
+      "||shareresults.com^$third-party",
+      "||shinobi.jp^$third-party",
+      "||simply.com^$third-party",
+      "||skimlinks.com^$third-party",
+      "||smart.allocine.fr^$third-party",
+      "||smartadserver.com^$third-party",
+      "||smarttargetting.co.uk^$third-party",
+      "||smarttargetting.com^$third-party",
+      "||smarttargetting.net^$third-party",
+      "||smpgfx.com^$third-party",
+      "||snap.com^$third-party",
+      "||sochr.com^$third-party",
+      "||sociallypublish.com^$third-party",
+      "||socialmedia.com^$third-party",
+      "||socialspark.com^$third-party",
+      "||socialvibe.com^$third-party",
+      "||sonnerie.net^$third-party",
+      "||sparkstudios.com^$third-party",
+      "||specificclick.net^$third-party",
+      "||specificmedia.com^$third-party",
+      "||speedsuccess.net^$third-party",
+      "||spinbox.freedom.com^$third-party",
+      "||sponsorads.de^$third-party",
+      "||sponsoredtweets.com^$third-party",
+      "||sponsorpalace.com^$third-party",
+      "||sportsyndicator.com^$third-party",
+      "||spottt.com^$third-party",
+      "||spotxchange.com^$third-party,domain=~supernovatube.com",
+      "||srtk.net^$third-party",
+      "||sta-ads.com^$third-party",
+      "||stocker.bonnint.net^$third-party",
+      "||sublimemedia.net^$third-party",
+      "||survey-poll.com^$third-party",
+      "||tacoda.net^$third-party",
+      "||tailsweep.com^$third-party",
+      "||targetnet.com^$third-party",
+      "||targetpoint.com^$third-party",
+      "||targetspot.com^$third-party",
+      "||teracent.net^$third-party",
+      "||testnet.nl^$third-party",
+      "||text-link-ads.com^$third-party",
+      "||thewebgemnetwork.com^$third-party",
+      "||tiser.com^$third-party",
+      "||tkqlhce.com^$third-party",
+      "||total-media.net^$third-party",
+      "||tqlkg.com^$third-party",
+      "||tradedoubler.com^$third-party",
+      "||tradepub.com^$third-party",
+      "||trafficjunky.net^$third-party",
+      "||trafficmasterz.net^$third-party",
+      "||traveladvertising.com^$third-party",
+      "||travelscream.com^$third-party",
+      "||travidia.com^$third-party",
+      "||triadmedianetwork.com^$third-party",
+      "||tribalfusion.com^$third-party",
+      "||trigami.com^$third-party",
+      "||trker.com^$third-party",
+      "||twinplan.com^$third-party",
+      "||twittad.com^$third-party",
+      "||tyroo.com^$third-party",
+      "||udmserve.net^$third-party",
+      "||uimserv.net^$third-party",
+      "||unanimis.co.uk^$third-party",
+      "||unicast.com^$third-party",
+      "||unrulymedia.com^$third-party",
+      "||usemax.de^$third-party",
+      "||usercash.com^$third-party",
+      "||utarget.co.uk^$third-party",
+      "||v.movad.de^*/ad.xml$third-party",
+      "||valuead.com^$third-party",
+      "||valueclick.com^$third-party",
+      "||vcmedia.com^$third-party",
+      "||velmedia.net^$third-party",
+      "||verticalacuity.com^$third-party",
+      "||vibrantmedia.com^$third-party",
+      "||videoegg.com^$third-party",
+      "||videostrip.com^$~object_subrequest,third-party",
+      "||videostrip.com^*/admatcherclient.$object_subrequest,third-party",
+      "||vidpay.com^$third-party",
+      "||viglink.com^$third-party",
+      "||vipquesting.com^$third-party",
+      "||visitdetails.com^$third-party",
+      "||vpico.com^$third-party",
+      "||vs20060817.com^$third-party",
+      "||vsservers.net^$third-party",
+      "||webads.co.nz^$third-party",
+      "||webgains.com^$third-party",
+      "||webmasterplan.com^$third-party",
+      "||webtraffic.ttinet.com^$third-party",
+      "||wgreatdream.com^$third-party",
+      "||widgetbucks.com^$third-party",
+      "||widgets.fccinteractive.com^$third-party",
+      "||worlddatinghere.com^$third-party",
+      "||worthathousandwords.com^$third-party",
+      "||x4300tiz.com^$third-party",
+      "||xcelltech.com^$third-party",
+      "||xcelsiusadserver.com^$third-party",
+      "||xchangebanners.com^$third-party",
+      "||xgraph.net^$third-party",
+      "||yceml.net^$third-party",
+      "||yieldbuild.com^$third-party",
+      "||yieldmanager.com^$third-party",
+      "||yieldmanager.net^$third-party",
+      "||yottacash.com^$third-party",
+      "||yumenetworks.com^$third-party",
+      "||zangocash.com^$third-party",
+      "||zanox.com^$third-party",
+      "||zeads.com^$third-party",
+      "||zedo.com^$third-party",
+      "||zoomdirect.com.au^$third-party",
+      "||zxxds.net^$third-party",
+      "!-----------------------------------------Third-party ads------------------------------------------!",
+      "! *** easylist_thirdparty.txt ***",
+      "||ablacrack.com/popup-pvd.js$third-party",
+      "||adultfriendfinder.com/banners/$third-party",
+      "||advanced-intelligence.com/banner$third-party",
+      "||affil.mupromo.com^$third-party",
+      "||affiliate.astraweb.com^$third-party",
+      "||affiliates.a2hosting.com^$third-party",
+      "||affiliates.generatorsoftware.com^$third-party",
+      "||affiliates.jlist.com^$third-party",
+      "||affiliates.supergreenhosting.com^$third-party",
+      "||apple.com/itunesaffiliates/$third-party",
+      "||aweber.com/banners/$third-party",
+      "||b.sell.com^$third-party",
+      "||banner.1and1.com^$third-party",
+      "||banner.3ddownloads.com^$third-party",
+      "||banner.telefragged.com^$third-party",
+      "||banners.adultfriendfinder.com^$third-party",
+      "||banners.friendfinder.com^$third-party",
+      "||banners.getiton.com^$third-party",
+      "||banners.ixitools.com^$third-party",
+      "||bc.coupons.com^$third-party",
+      "||beta.down2crazy.com^$third-party",
+      "||box.anchorfree.net^$third-party",
+      "||buy.com^*/affiliate/$third-party",
+      "||cas.clickability.com^$third-party",
+      "||cashmakingpowersites.com^*/banners/$third-party",
+      "||cbanners.virtuagirlhd.com^$third-party",
+      "||cbclickbank.com/affiliate/$third-party",
+      "||connect.summit.co.uk^$third-party",
+      "||creatives.summitconnect.co.uk^$third-party",
+      "||datakl.com/banner/$third-party",
+      "||dianomioffers.co.uk/smartlinks.epl?$third-party",
+      "||dynw.com/banner$third-party",
+      "||enticelabs.com/el/$third-party",
+      "||eplreplays.com/wl/$third-party",
+      "||feedburner.com/~a/$third-party",
+      "||frontsight.com^*/banners/$third-party",
+      "||fugger.netfirms.com/moa.swf$third-party",
+      "||gfxa.sheetmusicplus.com^$third-party",
+      "||googlesyndication.com^*/domainpark.cgi?$third-party",
+      "||grammar.coursekey.com/inter/$third-party",
+      "||gsniper.com/images/$third-party",
+      "||hostingcatalog.com/banner.php?$third-party",
+      "||iselectmedia.com^*/banners/$third-party",
+      "||jlist.com/feed.php?affid=$third-party",
+      "||kallout.com^*.php?id=$third-party",
+      "||l.yimg.com^*&partner=*&url=$subdocument,third-party",
+      "||lastlocation.com/images/banner$third-party",
+      "||lightningcast.net^*/getplaylist?$object_subrequest,third-party",
+      "||liutilities.com/partners/affiliate/$third-party",
+      "||livejasmin.com/?t_id=*&psid=$third-party",
+      "||longtailvideo.com/adtonomy.swf$third-party",
+      "||longtailvideo.com/ltas.swf$third-party",
+      "||match.com^*/prm/$third-party",
+      "||mazda.com.au/banners/$third-party",
+      "||meta4-group.com^*/promotioncorner.js?$third-party",
+      "||metaboli.fr^*/adgude_$third-party",
+      "||mfeed.newzfind.com^$third-party",
+      "||missnowmrs.com/images/banners/$third-party",
+      "||my-dirty-hobby.com/getmdhlink.$third-party",
+      "||mydirtyhobby.com/?sub=$third-party",
+      "||mydirtyhobby.com/getmdhlink.$third-party",
+      "||mydirtyhobby.com/gpromo/$third-party",
+      "||mydirtyhobby.com^*/gpromo/$third-party",
+      "||myhpf.co.uk/banners/$third-party",
+      "||mytrafficstrategy.com/images/$third-party",
+      "||nzpages.co.nz^*/banners/$third-party",
+      "||nzphoenix.com/nzgamer/$third-party",
+      "||onegameplace.com/iframe.php$third-party",
+      "||play-asia.com/paos-$third-party",
+      "||plugins.longtailvideo.com/adtvideo.swf$third-party",
+      "||ppc-coach.com/jamaffiliates/$third-party",
+      "||pricegrabber.com/cb_table.php$third-party",
+      "||promos.fling.com^$third-party",
+      "||promote.pair.com^$third-party",
+      "||pub.betclick.com^$third-party",
+      "||pubs.hiddennetwork.com^$third-party",
+      "||r.kelkoo.com^$third-party",
+      "||rapidjazz.com/banner_rotation/$third-party",
+      "||rcm*.amazon.$third-party",
+      "||robofish.com/cgi-bin/banner.cgi?$third-party",
+      "||searchportal.information.com/?$third-party",
+      "||servali.net^$third-party",
+      "||smartclip.net/delivery/tag?$third-party",
+      "||thebigchair.com.au^$subdocument,third-party",
+      "||themis-media.com^*/sponsorships/$third-party",
+      "||ticketmaster.com/promotionalcontent/$third-party",
+      "||top5result.com/promo/$third-party",
+      "||toptenreviews.com/widgets/af_widget.js$third-party",
+      "||torrentfreebie.com/index.asp?pid=$third-party",
+      "||tosol.co.uk/international.php?$third-party",
+      "||unsereuni.at/resources/img/$third-party",
+      "||veospot.com^*.html$third-party",
+      "||vianadserver.com/xmlservice/overlaycampaigninfo.aspx?$third-party",
+      "||visit.homepagle.com^$third-party",
+      "||ws.amazon.*/widgets/q?$third-party",
+      "||xgaming.com/rotate*.php?$third-party",
+      "!---------------------------------Site specific ad blocking rules----------------------------------!",
+      "! *** easylist_specific_block.txt ***",
+      "||1up.com^*/promos/",
+      "||216.151.186.5^*/serve.php?$domain=sendspace.com",
+      "||2cpu.com/2cpu/*side*.html",
+      "||4chan.org/support/gf_$image",
+      "||77.247.178.36/layer/$domain=movie2k.com",
+      "||a.giantrealm.com^",
+      "||a.thefreedictionary.com^",
+      "||about.com/0g/$subdocument",
+      "||ac2.msn.com^",
+      "||activewin.com^*/blaze_static2.",
+      "||ads.netlog.com^",
+      "||adserver.yahoo.com^",
+      "||adshare.freedocast.com^",
+      "||adultswim.com^*/admanager.swf?",
+      "||advt.manoramaonline.com^",
+      "||akipress.com/_ban/",
+      "||akipress.org/ban/",
+      "||akipress.org/bimages/",
+      "||allthelyrics.com^*/popup.js",
+      "||analytics.mmosite.com^",
+      "||animekuro.com/layout/google$subdocument",
+      "||animenewsnetwork.com^*.aframe?",
+      "||anonib.com/zimages/",
+      "||armorgames.com^*/banners/",
+      "||armorgames.com^*/site-skins/",
+      "||armorgames.com^*/siteskin.css",
+      "||athena-ads.wikia.com^",
+      "||azlyrics.com^*_az.js",
+      "||banner.atomicgamer.com^",
+      "||banners.expressindia.com^",
+      "||banners.sys-con.com^",
+      "||bbc.co.uk^*/bbccom.js?",
+      "||beingpc.com^*/banners/",
+      "||bit-tech.net/style/skin/$stylesheet",
+      "||blackberryforums.net/banners/",
+      "||blinkx.com/adhocnetwork/",
+      "||blinkx.com/f2/overlays/adhoc",
+      "||bloomberg.com^*/banner.js",
+      "||bnrs.ilm.ee^",
+      "||boyplz.com^*/layer.js",
+      "||break.com^*/sponsors/",
+      "||burnsoftware.info*/!",
+      "||c21media.net/uploads/flash/*.swf",
+      "||cdmediaworld.com*/!",
+      "||centos.org/donors/",
+      "||ciao.co.uk/load_file.php?",
+      "||click.livedoor.com^",
+      "||clk.about.com^",
+      "||cms.myspacecdn.com^*/splash_assets/",
+      "||codeasily.com^*/codeasily.js",
+      "||codeproject.com^*/adm/",
+      "||complexmedianetwork.com^*/takeovers/",
+      "||computerworld.com^*/jobroll/",
+      "||consumerreports.org^*/sx.js",
+      "||countrychannel.tv/telvos_banners/",
+      "||covertarget.com^*_*.php$subdocument",
+      "||crazymotion.net/video_*.php?key=",
+      "||crushorflush.com/html/promoframe.html",
+      "||da.feedsportal.com^*/a2.img$image",
+      "||dailymail.co.uk^*/promoboxes/",
+      "||dailymotion.com^*masscast/",
+      "||dcad.watersoul.com^",
+      "||demonoid.com/cached/ab_",
+      "||demonoid.com/cached/bnr_",
+      "||dig.abclocal.go.com/preroll/",
+      "||digdug.divxnetworks.com^",
+      "||dimshare.com/empire.",
+      "||distrowatch.com/images/czmor",
+      "||divxstage.net/images/download.png",
+      "||dl4all.com/data4.files/dpopupwindow.",
+      "||earthlink.net^*/promos/",
+      "||ebayrtm.com/rtm?",
+      "||ebuddy.com/banners/",
+      "||ebuddy.com/textlink.php?",
+      "||ebuddy.com/web_banners/",
+      "||ecommerce-journal.com/specdata.php?",
+      "||el33tonline.com^*/el33t_bg_",
+      "||episodic.com^*/logos/player-",
+      "||espn.vad.go.com^$domain=youtube.com",
+      "||eva.ucas.com^",
+      "||eweek.com/images/stories/marketing/",
+      "||excite.com/gca_iframe.html?",
+      "||expertreviews.co.uk/images/skins/",
+      "||ffiles.com/counters.js",
+      "||filefront.com/linkto/",
+      "||filetarget.com*/!",
+      "||filetarget.com^*_*.php$subdocument",
+      "||flyordie.com/games/free/b/*--?p=",
+      "||foxbusiness.com/html/google_homepage_promo",
+      "||freeworldgroup.com/banner",
+      "||fudzilla.com^*/banners/",
+      "||gamecopyworld.com*/!",
+      "||gametrailers.com^*/gt6_siteskin_$stylesheet",
+      "||geocities.com/js_source/",
+      "||geocities.yahoo.*/js/sq.",
+      "||getprice.com.au/searchwidget.aspx?$subdocument",
+      "||glam.com^*/affiliate/",
+      "||goauto.com.au/mellor/mellor.nsf/toy$subdocument",
+      "||grapevine.is/media/flash/*.swf",
+      "||gumtree.com^*/dart_wrapper_",
+      "||gwinnettdailypost.com/1.iframe.asp?",
+      "||hostsearch.com/creative/",
+      "||hotfrog.com/adblock.ashx?",
+      "||hummy.org.uk^*/brotator/",
+      "||i.com.com^*/vendor_bg_",
+      "||i.neoseeker.com/d/$subdocument",
+      "||i4u.com/_banner/",
+      "||ibanners.empoweredcomms.com.au^",
+      "||idg.com.au/images/*_promo$image",
+      "||idg.com.au^*_skin.jpg",
+      "||illimitux.net/js/abp.js",
+      "||images-amazon.com^*/marqueepushdown/",
+      "||imageshack.us/ym.php?$subdocument",
+      "||independent.co.uk/multimedia/archive/$subdocument",
+      "||infoseek.co.jp/isweb/clip.html",
+      "||interfacelift.com/inc_new/$subdocument",
+      "||internet.ziffdavis.com^",
+      "||iptools.com/sky.php",
+      "||itpro.co.uk/images/skins/",
+      "||jame-world.com^*/adv/",
+      "||jarkey.net^*/for_jarkey.",
+      "||jpost.com/images/*/promos/",
+      "||kermit.macnn.com^",
+      "||kestrel.ospreymedialp.com^",
+      "||kewlshare.com/reward.",
+      "||kitz.co.uk/files/jump2/",
+      "||labtimes.org/banner/",
+      "||linuxtopia.org/includes/$subdocument",
+      "||loaded.it^*/iframe_vid.",
+      "||loaded.it^*/my_banner",
+      "||lookbook.nu/sponsors_box.",
+      "||macobserver.com^*/deal_brothers/",
+      "||macworld.co.uk^*/textdeals/",
+      "||majorgeeks.com^*/banners/",
+      "||medhelp.org/hserver/",
+      "||mediafire.com^*/linkto/default-$subdocument",
+      "||mediafire.com^*/remove_ads.gif",
+      "||mediamgr.ugo.com^",
+      "||meetic.com/js/*/site_under_",
+      "||merriam-webster.com^*/accipiter.js",
+      "||mgnetwork.com/dealtaker/",
+      "||mirror.co.uk^*/gutters/",
+      "||mirror.co.uk^*/m4_gutters/",
+      "||mirror.co.uk^*/m4_partners/",
+      "||mmorpg.com/images/skins/",
+      "||mp3mediaworld.com*/!",
+      "||msn.com/?adunitid",
+      "||musictarget.com*/!",
+      "||myspace.com^*.adtooltip&",
+      "||myway.com/gca_iframe.html",
+      "||nearlygood.com^*/_aff.php?",
+      "||news.com.au/news/vodafone/$object",
+      "||news.com.au^*-promo$image",
+      "||news.com.au^*/promos/",
+      "||nirsoft.net/banners/",
+      "||ntdtv.com^*/adv/",
+      "||nymag.com^*/metrony_",
+      "||nytimes.com/adx/",
+      "||ocforums.com/adj/",
+      "||ocp.com.com/ad.js",
+      "||payplay.fm^*/mastercs.js",
+      "||pbsrc.com/sponsor/",
+      "||pbsrc.com^*/sponsor/",
+      "||pcauthority.com.au^*/skins/",
+      "||pcpro.co.uk/images/*_siteskin",
+      "||pcpro.co.uk/images/skins/",
+      "||pcpro.co.uk^*/pcprositeskin",
+      "||pcpro.co.uk^*skin_wide.",
+      "||photosupload.net/photosupload.js",
+      "||pinknews.co.uk/newweb/",
+      "||prisonplanet.com^*advert.",
+      "||prisonplanet.com^*banner",
+      "||prisonplanet.com^*sky.",
+      "||project-for-sell.com/_google.php",
+      "||proxy.org/af.html",
+      "||proxy.org/ah.html",
+      "||ps3news.com/banner/",
+      "||ps3news.com^*.swf",
+      "||qrz.com/pix/*.gif",
+      "||retrevo.com^*/pcwframe.jsp?",
+      "||richmedia.yimg.com^",
+      "||sciencedaily.com^*/google-story2-rb.js",
+      "||sendspace.com^*?zone=",
+      "||shop.com/cc.class/dfp?",
+      "||shops.tgdaily.com^*&widget=",
+      "||showstreet.com/banner.",
+      "||snopes.com^*/*ad$subdocument",
+      "||softcab.com/google.php?",
+      "||softonic.com/specials_leaderboard/",
+      "||soundtracklyrics.net^*_az.js",
+      "||space.com/promo/",
+      "||stlyrics.com^*_az.js",
+      "||stuff.tv/client/skinning/",
+      "||techpowerup.com/images/bnnrs/",
+      "||techsupportforum.com^*/banners/",
+      "||techtree.com^*/jquery.catfish.js",
+      "||telegraphindia.com^*/banners/",
+      "||telegraphindia.com^*/hoabanner.",
+      "||tentonhammer.com^*/takeovers/",
+      "||thehighstreetweb.com^*/banners/",
+      "||themis-media.com/media/global/images/cskins/",
+      "||themis.yahoo.com^",
+      "||thewb.com/thewb/swf/tmz-adblock/",
+      "||timeslive.co.za^*/adtonomy.",
+      "||tripadvisor.com/adp/",
+      "||tripadvisor.com^*/skyscraper.jpg",
+      "||turbobit.net/js/popunder2.js",
+      "||typepad.com/sponsors/",
+      "||ua.badongo.com^",
+      "||uimserv.net^",
+      "||unicast.msn.com^",
+      "||universalhub.com/bban/",
+      "||videogamer.com^*/css/skins/$stylesheet",
+      "||videos.mediaite.com/decor/live/white_alpha_60.",
+      "||videosift.com/bnr.php?",
+      "||w3schools.com/banners/",
+      "||wareseeker.com/banners/",
+      "||webhostingtalk.com/js/hail.js",
+      "||whispersinthecorridors.com/banner2009/",
+      "||wikia.com/__varnish_",
+      "||windowsitpro.com^*/doubleclick/",
+      "||windowsitpro.com^*/googleafc",
+      "||windowsitpro.com^*/roadblock.js",
+      "||www2.sys-con.com^*.cfm",
+      "||xbitlabs.com^*/xbanner.php?",
+      "||yahoo.*/serv?s=",
+      "||yahoo.com/darla/",
+      "||yahoo.com/ysmload.html?",
+      "||yahoo.com^*.ads.darla.",
+      "||yahoo.com^*/eyc-themis?",
+      "||yfrog.com/ym.php?",
+      "||yimg.com/a/1-$~stylesheet",
+      "||yimg.com^*/fairfax/$image",
+      "||yourmovies.com.au^*/side_panels_",
+      "||zam.com/i/promos/*-skin.",
+      "||zattoo.com/static/images/sponsors/",
+      "||zophar.net/files/tf_",
+      "!--------------------------------Site specific element hiding rules--------------------------------!",
+      "! *** easylist_specific_hide.txt ***",
+      "123people.co.uk###l_banner",
+      "1911encyclopedia.org##.google_block_style",
+      "4chan.org###ad",
+      "7tutorials.com##.block-openx",
+      "9to5mac.com###block-dealmac-0",
+      "9to5mac.com###page-top",
+      "a10.com###gameunderbanner",
+      "abclocal.go.com###bannerTop",
+      "about.com##.gB",
+      "achieve360points.com###a1",
+      "achieve360points.com###a3",
+      "actiontrip.com###banner300",
+      "adultswim.com###ad",
+      "afterdawn.com##.uniblue",
+      "alarabiya.net###side_banner",
+      "allakhazam.com###bannerMain",
+      "allakhazam.com###towerRt",
+      "allexperts.com###sl",
+      "altavista.com###spons",
+      "altavista.com##a[href*=\".overture.com/d/sr/\"]",
+      "amazon.co.uk##div[id$=\"_adcontent\"]",
+      "amazon.com##.pa_containerWrapper",
+      "amazon.com##div[id$=\"_adcontent\"]",
+      "america.fm###banbo",
+      "anandtech.com###boxfooter",
+      "anandtech.com###topmarq",
+      "anandtech.com##.HeaderSurround > div[style=\"padding: 4px;\"]:last-child > div[style^=\"padding-bottom: 7px; padding-left: 2px;\"]",
+      "anandtech.com##.docTopMiddle > div[style=\"text-align: left; padding-left: 15px; padding-top: 5px; padding-bottom: 32px;\"]",
+      "anandtech.com##.newTopTop",
+      "animenewsnetwork.com###page-header-banner",
+      "animetake.com##.top-banner",
+      "anonymouse.org###mouselayer",
+      "ansearch.com.au##.sponsor",
+      "answerology.com##.leaderboard",
+      "aol.co.uk###rA",
+      "aol.co.uk##.sidebarBanner",
+      "aol.com###rA",
+      "aol.com##.g_slm",
+      "aol.com##.gsl",
+      "aol.com##.sad_cont",
+      "aolnews.com##.fauxArticleIMU",
+      "app.com,argusleader.com,battlecreekenquirer.com,baxterbulletin.com,bucyrustelegraphforum.com,burlingtonfreepress.com,centralohio.com,chillicothegazette.com,cincinnati.com,citizen-times.com,clarionledger.com,coloradoan.com,coshoctontribune.com,courier-journal.com,courierpostonline.com,dailyrecord.com,dailyworld.com,delawareonline.com,delmarvanow.com,democratandchronicle.com,desmoinesregister.com,dnj.com,fdlreporter.com,freep.com,greatfallstribune.com,greenbaypressgazette.com,greenvilleonline.com,guampdn.com,hattiesburgamerican.com,hometownlife.com,honoluluadvertiser.com,htrnews.com,indystar.com,jacksonsun.com,jconline.com,lancastereaglegazette.com,lansingstatejournal.com,livingstondaily.com,lohud.com,mansfieldnewsjournal.com,marionstar.com,marshfieldnewsherald.com,montgomeryadvertiser.com,mycentraljersey.com,mydesert.com,newarkadvocate.com,news-leader.com,news-press.com,newsleader.com,pal-item.com,pnj.com,portclintonnewsherald.com,postcrescent.com,poughkeepsiejournal.com,press-citizen.com,pressconnects.com,rgj.com,sctimes.com,sheboyganpress.com,shreveporttimes.com,stargazette.com,statesmanjournal.com,stevenspointjournal.com,tallahassee.com,tennessean.com,theadvertiser.com,thecalifornian.com,thedailyjournal.com,theithacajournal.com,theleafchronicle.com,thenews-messenger.com,thenewsstar.com,thenorthwestern.com,thespectrum.com,thestarpress.com,thetimesherald.com,thetowntalk.com,visaliatimesdelta.com,wausaudailyherald.com,wisconsinrapidstribune.com,zanesvilletimesrecorder.com##.articleflex-container",
+      "app.com,argusleader.com,battlecreekenquirer.com,baxterbulletin.com,bucyrustelegraphforum.com,burlingtonfreepress.com,centralohio.com,chillicothegazette.com,cincinnati.com,citizen-times.com,clarionledger.com,coloradoan.com,coshoctontribune.com,courier-journal.com,courierpostonline.com,dailyrecord.com,dailyworld.com,delawareonline.com,delmarvanow.com,democratandchronicle.com,desmoinesregister.com,dnj.com,fdlreporter.com,freep.com,greatfallstribune.com,greenbaypressgazette.com,greenvilleonline.com,guampdn.com,hattiesburgamerican.com,hometownlife.com,honoluluadvertiser.com,htrnews.com,indystar.com,jacksonsun.com,jconline.com,lancastereaglegazette.com,lansingstatejournal.com,livingstondaily.com,lohud.com,mansfieldnewsjournal.com,marionstar.com,marshfieldnewsherald.com,montgomeryadvertiser.com,mycentraljersey.com,mydesert.com,newarkadvocate.com,news-leader.com,news-press.com,newsleader.com,pal-item.com,pnj.com,portclintonnewsherald.com,postcrescent.com,poughkeepsiejournal.com,press-citizen.com,pressconnects.com,rgj.com,sctimes.com,sheboyganpress.com,shreveporttimes.com,stargazette.com,statesmanjournal.com,stevenspointjournal.com,tallahassee.com,tennessean.com,theadvertiser.com,thecalifornian.com,thedailyjournal.com,theithacajournal.com,theleafchronicle.com,thenews-messenger.com,thenewsstar.com,thenorthwestern.com,thespectrum.com,thestarpress.com,thetimesherald.com,thetowntalk.com,visaliatimesdelta.com,wausaudailyherald.com,wisconsinrapidstribune.com,zanesvilletimesrecorder.com##.leaderboard-container",
+      "app.com,argusleader.com,battlecreekenquirer.com,baxterbulletin.com,bucyrustelegraphforum.com,burlingtonfreepress.com,centralohio.com,chillicothegazette.com,cincinnati.com,citizen-times.com,clarionledger.com,coloradoan.com,coshoctontribune.com,courier-journal.com,courierpostonline.com,dailyrecord.com,dailyworld.com,delawareonline.com,delmarvanow.com,democratandchronicle.com,desmoinesregister.com,dnj.com,fdlreporter.com,freep.com,greatfallstribune.com,greenbaypressgazette.com,greenvilleonline.com,guampdn.com,hattiesburgamerican.com,hometownlife.com,honoluluadvertiser.com,htrnews.com,indystar.com,jacksonsun.com,jconline.com,lancastereaglegazette.com,lansingstatejournal.com,livingstondaily.com,lohud.com,mansfieldnewsjournal.com,marionstar.com,marshfieldnewsherald.com,montgomeryadvertiser.com,mycentraljersey.com,mydesert.com,newarkadvocate.com,news-leader.com,news-press.com,newsleader.com,pal-item.com,pnj.com,portclintonnewsherald.com,postcrescent.com,poughkeepsiejournal.com,press-citizen.com,pressconnects.com,rgj.com,sctimes.com,sheboyganpress.com,shreveporttimes.com,stargazette.com,statesmanjournal.com,stevenspointjournal.com,tallahassee.com,tennessean.com,theadvertiser.com,thecalifornian.com,thedailyjournal.com,theithacajournal.com,theleafchronicle.com,thenews-messenger.com,thenewsstar.com,thenorthwestern.com,thespectrum.com,thestarpress.com,thetimesherald.com,thetowntalk.com,visaliatimesdelta.com,wausaudailyherald.com,wisconsinrapidstribune.com,zanesvilletimesrecorder.com##.leaderboard-container-top",
+      "appleinsider.com###aadbox",
+      "appleinsider.com##.bottombox",
+      "appleinsider.com##.leaderboard",
+      "appleinsider.com##.main_box4",
+      "appleinsider.com##td[width=\"150\"][valign=\"top\"]",
+      "appleinsider.com##td[width=\"180\"][valign=\"top\"]",
+      "arnnet.com.au###marketplace",
+      "arnnet.com.au##.careerone_search",
+      "arsenal.com###banner",
+      "arstechnica.com###daehtsam-da",
+      "arto.com###BannerInfobox",
+      "asia.cnet.com###sp-box",
+      "asia.cnet.com##.splink",
+      "associatedcontent.com##div[style=\"width: 300px; height: 250px; float: left;\"]",
+      "asylum.co.uk##.sidebarBanner",
+      "asylum.com##.sidebarBanner",
+      "asylum.com##.topBanner",
+      "atom.com###iframe_container300x250",
+      "atomicgamer.com###bannerFeatures",
+      "au.movies.yahoo.com##table.y7mv-wraptable[width=\"750\"][height=\"112\"]",
+      "au.yahoo.com###y708-windowshade",
+      "audioreview.com##.MiddleTableRightColumn",
+      "audioreview.com##script + table[width=\"539\"]",
+      "audioreview.com##table[width=\"300\"][style=\"border: 1px solid rgb(65, 103, 122); margin-left: 10px;\"]",
+      "autoblog.com##.leader",
+      "autoblog.com##.medrect",
+      "autoblog.com##.topleader",
+      "autobloggreen.com##.medrect",
+      "autosport.com##.content[width] td[height=\"17\"][bgcolor=\"#dcdcdc\"]",
+      "autosport.com##td[align=\"center\"][valign=\"top\"][height=\"266\"][bgcolor=\"#dcdcdc\"]",
+      "autotrader.co.uk###placeholderTopLeaderboard",
+      "avsforum.com##td[width=\"125\"][valign=\"top\"][style=\"padding-left: 15px;\"]",
+      "avsforum.com##td[width=\"193\"][valign=\"top\"]",
+      "avsforum.com##td[width=\"300\"][valign=\"top\"][rowspan=\"3\"]",
+      "azstarnet.com##.bannerinstory",
+      "babble.com.au###leaderboard-bottom",
+      "babble.com.au###leaderboard-top",
+      "babble.com.au###medium-rectangle",
+      "bangkokpost.com##.boomboxSize1",
+      "bangkokpost.com##.buzzBoombox",
+      "basketball.com##td[width=\"530\"] + td[width=\"120\"]",
+      "bbc.co.uk##.bbccom_display_none",
+      "bdnews24.com###bannerdiv2",
+      "bdnews24.com##.add",
+      "bebo.com##table[style=\"background-color: rgb(247, 246, 246);\"]",
+      "bigblueball.com###text-384255551",
+      "bigpond.com##div[id^=\"sensis_island_ad_\"]",
+      "bit-tech.net###broadband-finder-co-uk-120",
+      "bit-tech.net###mobile-phones-co-uk-120",
+      "bit-tech.net###shopping_box",
+      "bit-tech.net##a[href^=\"http://ad.doubleclick.net/\"]",
+      "bit-tech.net##div[style*=\"width: 925px; height: 115px;\"]",
+      "biz.yahoo.com##a[href*=\".overture.com/\"]",
+      "bizrate.com###banner_top",
+      "bizrate.com###rectangular",
+      "blackberryforums.com##td[align=\"left\"][width=\"160\"][valign=\"top\"]",
+      "blackmesasource.com##.ad",
+      "block.opendns.com###acbox",
+      "bloggingbuyouts.com##.topleader",
+      "bloggingstocks.com##.topleader",
+      "blogoscoped.com##.adBlock",
+      "blogoscoped.com##.adBlockBottom",
+      "blogoscoped.com##.adBlockBottomBreak",
+      "blogtv.com##center > div.posRel.BOGL[style*=\"height:\"][style*=\"padding-top: 5px;\"][style*=\"width:\"]",
+      "bloomberg.com##.leaderboard",
+      "boingboing.net##div[style=\"height: 630px; width: 300px;\"]",
+      "books.google.ca###rhswrapper font[size=\"-1\"]",
+      "books.google.co.nz###rhswrapper font[size=\"-1\"]",
+      "books.google.co.uk###rhswrapper font[size=\"-1\"]",
+      "books.google.co.za###rhswrapper font[size=\"-1\"]",
+      "books.google.com###rhswrapper font[size=\"-1\"]",
+      "books.google.com.au###rhswrapper font[size=\"-1\"]",
+      "bostonherald.com##div[style^=\"padding: 0pt 5px; background-color: rgb(239, 239, 239);\"][style*=\"letter-spacing: 5px; font-variant: small-caps;\"]",
+      "bostonherald.com##div[style^=\"padding: 0pt 5px; background-color: rgb(239, 239, 239);\"][style*=\"letter-spacing: 5px; font-variant: small-caps;\"] + div",
+      "break.com##.ad",
+      "break.com##.breaking_news",
+      "breakingviews.com###floatit",
+      "breitbart.com##.sidebar",
+      "brighouseecho.co.uk###banner01",
+      "brisbanetimes.com.au##.ad",
+      "broadcastnewsroom.com###shopperartbox",
+      "broadcastnewsroom.com##.bfua",
+      "broadcastnewsroom.com##.bottombanner",
+      "browsershots.org###sponsors",
+      "browsershots.org##div[style^=\"width: 300px; height: 25\"]",
+      "buffalonews.com###bot-main",
+      "buffalonews.com##.leaderboard_top",
+      "build.co.uk##a[href^=\"http://www.build.co.uk/buttonredirect.asp?\"]",
+      "businessinsider.com###FM1",
+      "businessweek.com###bwMall",
+      "businessweek.com##.ad",
+      "buxtonadvertiser.co.uk###banner01",
+      "buzzfocus.com###eyebrowtop",
+      "buzznet.com###topSection",
+      "c21media.net##table[border=\"0\"][width=\"130\"]",
+      "campustechnology.com###leaderboard",
+      "canmag.com##td[align=\"center\"][height=\"278\"]",
+      "canoe.ca###commerce",
+      "canoe.ca###subbanner",
+      "cartoonnetwork.com###leaderboard",
+      "caymannewsservice.com###content-top",
+      "caymannewsservice.com##[style=\"width: 175px; height: 200px;\"]",
+      "caymannewsservice.com##[style=\"width: 450px; height: 100px;\"]",
+      "caymannewsservice.com##[style=\"width: 550px; height: 100px;\"]",
+      "ccfcforum.com##.tablepad",
+      "ccfcforum.com##img[alt=\"ISS\"]",
+      "celebnipslipblog.com###HeaderBanner",
+      "cell.com###main_banner",
+      "cgenie.com###ja-banner",
+      "cgenie.com##.cgenie_banner4",
+      "channel3000.com###leaderboard-sticky",
+      "channel4.com###c4ad-Middle1",
+      "chicagotribune.com###story-body-parent + .rail",
+      "chickipedia.com##div[style*=\"/ad_bg.gif)\"]",
+      "chinasmack.com##.ad",
+      "chinatechnews.com###banner1",
+      "christianitytoday.com##.bgbanner",
+      "christianitytoday.com##.bgshop",
+      "chrome-hacks.net##div[style=\"width: 600px; height: 250px;\"]",
+      "chronicle.northcoastnow.com##table[width=\"100%\"][height=\"90\"][bgcolor=\"#236aa7\"]",
+      "cio.com.au##.careerone_search",
+      "cio.com.au##.careerone_tj_box",
+      "citynews.ca###SuperBannerContainer",
+      "citynews.ca##.Box.BigBox",
+      "classifieds.aol.co.uk###dmn_results",
+      "classifieds.aol.co.uk###dmn_results1",
+      "cnet.com###sidedoor",
+      "cnet.com##.ad",
+      "cnet.com##.bidWarContainer",
+      "cnet.com##.bidwar",
+      "cnet.com##.dh_vend_pad",
+      "cnet.com##.sponsWrap",
+      "cnet.com.au##.ad",
+      "cnet.com.au##.explain-promo",
+      "cnn.com##.cnnSearchSponsorBox",
+      "codeasily.com##.money",
+      "codinghorror.com##.welovecodinghorror",
+      "coffeegeek.com##a[href^=\"/banner/\"]",
+      "collegehumor.com##.partner_links",
+      "columbiatribune.com##.ad",
+      "columbiatribune.com##.skyscraper",
+      "com.au##table.fdMember",
+      "comicgenesis.com###ks_da",
+      "comicsalliance.com##.sidebarBanner",
+      "comicsalliance.com##.topBanner",
+      "comingsoon.net###col2TopPub",
+      "complex.com##.ad",
+      "computeractive.co.uk##.leaderboard",
+      "computerandvideogames.com###skyslot",
+      "computerworld.com##table[align=\"center\"][width=\"336\"][valign=\"top\"]",
+      "computerworld.com##table[width=\"342\"][height=\"290\"][bgcolor=\"#bbbbbb\"]",
+      "computerworld.com.au##.careerone_search",
+      "computerworld.com.au##.careerone_tj_box",
+      "computerworlduk.com###bottomBanner",
+      "computerworlduk.com###topBanner",
+      "computerworlduk.com###trendmicro",
+      "computerworlduk.com##a[target=\"_blank\"][href^=\"http://adserver.adtech.de/?\"]",
+      "computingondemand.com###sub-nav",
+      "coolest-gadgets.com##.banner1",
+      "coolest-gadgets.com##.contentbox",
+      "coolest-gadgets.com##.contentboxred",
+      "cpu-world.com##table[width=\"760\"][style=\"border: 1px solid rgb(64, 64, 64);\"]",
+      "cracked.com##.Ad",
+      "cracker.com.au##div[id$=\"AffiliateAdvert\"]",
+      "crazymotion.net###fadeinbox",
+      "cricinfo.com###ciHomeRHSAdslot",
+      "cricinfo.com##.ciHomeSponcerLink",
+      "cricinfo.com##.hpSpncrHead",
+      "cricinfo.com##.seriesSpncr",
+      "cricinfo.com##.spncrSmry",
+      "crikey.com.au###top",
+      "crmbuyer.com##.content-block-slinks",
+      "crmbuyer.com##.content-tab-slinks",
+      "crn.com###channelwebmarketplacewrapper",
+      "crunchgear.com##.ad",
+      "crunchgear.com##.sponsor_units",
+      "crunchyroll.com##.anime-mrec",
+      "cyberciti.biz###leaderboard",
+      "dailyfinance.com###attic",
+      "dailyfinance.com##.medrect",
+      "dailyfinance.com##div[style=\"padding: 6px; float: right; width: 242px; height: 272px;\"]",
+      "dailyfreegames.com###banner_886x40",
+      "dailyfreegames.com###topratedgames",
+      "dailyhaha.com###sponheader",
+      "dailymail.co.uk##a[href*=\"/adfeatures/\"]",
+      "dailymotion.com##.masscast_box_Middle",
+      "dailymotion.com##a[href*=\"/OasDefault/\"]",
+      "daringfireball.net###SidebarTheDeck",
+      "darkhorizons.com###content-island",
+      "dataopedia.com##.container_banner",
+      "deadspin.com###skyscraper",
+      "dealbrothers.com##.specials",
+      "dealmac.com###banner-bottom",
+      "dealnews.com##.banner",
+      "delicious.com###spns",
+      "demonoid.com##.pad9px_right",
+      "derbyshiretimes.co.uk###banner01",
+      "derbyshiretimes.co.uk##.roundedboxesgoogle",
+      "deseretnews.com##.continue",
+      "destructoid.com##div[style=\"overflow: hidden; width: 300px; height: 250px;\"]",
+      "develop-online.net##.newsinsert",
+      "deviantart.com###adso-magnifico",
+      "deviantart.com##.ad-blocking-makes-fella-confused",
+      "deviantart.com##.hidoframe",
+      "deviantart.com##.promo-text",
+      "deviantart.com##.sleekadbubble",
+      "deviantart.com##div[gmi-name=\"ad_zone\"]",
+      "deviantart.com##div[style=\"float: right; position: relative; width: 410px; text-align: left;\"]",
+      "digitalspy.co.uk###rhs728 > table[width=\"300\"][height=\"250\"]",
+      "digitalspy.co.uk##div[style=\"border-style: solid; border-color: rgb(209, 209, 225); border-width: 0pt 0pt 1px 1px; margin: 0pt 0pt 10px 10px; padding: 0pt 0pt 7px 7px; float: right; width: 300px;\"]",
+      "digitalspy.co.uk##table[align=\"center\"][width=\"728\"]",
+      "dimshare.com##a[href^=\"http://campaigns.ireel.com/\"]",
+      "dimshare.com##a[href^=\"http://www.affbuzzads.com/affiliate/\"]",
+      "dimshare.com##a[href^=\"http://www.flvdirect.com/movies/?aff=\"]",
+      "dimshare.com##a[href^=\"http://www.graboid.com/affiliates/\"]",
+      "dir.yahoo.com##td[width=\"215\"]",
+      "discovery.com##.rectangle",
+      "disney.go.com###banner",
+      "distrowatch.com##.iqcfrr",
+      "distrowatch.com##.uiexx",
+      "distrowatch.com##a[href=\"http://distrowatch.com/onnbznf\"]",
+      "distrowatch.com##a[href=\"http://distrowatch.com/qffli\"]",
+      "divxstage.net##.ad",
+      "dl4all.com##div[style*=\"border: 1px solid rgb(255, 64, 64);\"][style*=\"rgb(245, 245, 224);\"][style*=\"text-align: justify;\"]",
+      "dogpile.com##.paidSearchResult",
+      "domaintools.com##a[href^=\"http://www.domaintools.com/redirect/target/\"] > img",
+      "dosgamesarchive.com###banner",
+      "dosgamesarchive.com##.rectangle",
+      "dosgamesarchive.com##.skyscraper",
+      "downloadhelper.net##.pub",
+      "downloadhelper.net##.pub_top",
+      "downloadsquad.com###topleader-wrap",
+      "downloadsquad.com##.medrect",
+      "dragcave.net###prefooter",
+      "drive.com.au##.cA-twinPromo",
+      "drugs.com###topbannerWrap",
+      "dumblittleman.com##.ad",
+      "dumblittleman.com##.cats_box2",
+      "dv.com##table[width=\"665\"]",
+      "eartheasy.com##td[width=\"200\"][height=\"4451\"][bgcolor=\"#e1e3de\"][rowspan=\"19\"]",
+      "earthweb.com##.footerbanner",
+      "ebaumsworld.com###eacs-sidebar",
+      "ebuddy.com###banner_rectangle",
+      "ecommerce-journal.com###runnews",
+      "ecommercetimes.com##.slink-text",
+      "ecommercetimes.com##.slink-title",
+      "economist.com###classified_wrapper",
+      "economist.com###footer-classifieds",
+      "economist.com###leaderboard",
+      "economist.com###top_banner",
+      "ectnews.com###welcome-box",
+      "ectnews.com##.content-block-slinks",
+      "ectnews.com##.content-tab-slinks",
+      "edn.com###headerwildcard",
+      "edn.com##.sponsorcontent",
+      "edn.com##div[style=\"font-family: verdana,sans-serif; font-style: normal; font-variant: normal; font-weight: normal; font-size: 10px; line-height: normal; font-size-adjust: none; font-stretch: normal; -x-system-font: none; color: rgb(51, 51, 51); background-color: rgb(160, 186, 200); padding-bottom: 7px;\"]",
+      "electronista.com###leaderboard",
+      "electronista.com###supportbod",
+      "elitistjerks.com##div[class^=\"dc\"]",
+      "empireonline.com##table[align=\"center\"][width=\"950\"][height=\"130\"]",
+      "empireonline.com##td.smallgrey[width=\"300\"][height=\"250\"]",
+      "engadget.com##.medrect",
+      "england.fm###banbo",
+      "englishforums.com###facebox",
+      "englishforums.com###facebox_overlay",
+      "englishforums.com##div[class^=\"cp-Ad:\"]",
+      "environmentalgraffiti.com##.box2:first-child",
+      "environmentalgraffiti.com##.seven28",
+      "environmentalgraffiti.com##div.box2[style=\"float: right;\"]",
+      "eonline.com###module_sky_scraper",
+      "eq2flames.com##td[width=\"120\"][style=\"padding-left: 5px; white-space: normal;\"]",
+      "esecurityplanet.com###gemhover",
+      "esecurityplanet.com###partners",
+      "esecurityplanet.com##.vspace",
+      "esl.eu##.bannerContainer",
+      "esoft.web.id###content-top",
+      "espn.go.com##.spons_optIn",
+      "etonline.com##.superbanner",
+      "etonline.com##a[href^=\"http://ad.doubleclick.net/\"]",
+      "eurogamer.net###tabbaz",
+      "euronews.net##.col-pub-skyscraper",
+      "euronews.net##.google-banner",
+      "eweek.com###Table_01",
+      "eweek.com###container_ibm",
+      "eweek.com###hp_special_reports",
+      "eweek.com##.omniture_module_tracker",
+      "eweek.com##a[href^=\"http://ad.doubleclick.net/\"]",
+      "eweek.com##div[style=\"border: 1px solid rgb(192, 192, 192); margin-bottom: 10px; width: 250px; background-color: rgb(255, 255, 255);\"]",
+      "eweek.com##div[style=\"border: 1px solid rgb(192, 192, 192); margin-bottom: 10px; width: 500px; background-color: rgb(255, 255, 255);\"]",
+      "eweek.com##table[width=\"500\"][style=\"border: 1px solid rgb(204, 204, 204); margin: 5px 10px 5px 20px;\"]",
+      "examiner.co.uk##.promotop",
+      "examiner.com##.headerbg",
+      "excelforum.com##.contentLeft",
+      "excelforum.com##[style*=\"width: 300px; height: 250px;\"]",
+      "excite.com##.mexContentBdr",
+      "expertreviews.co.uk###skyScrapper",
+      "expertreviews.co.uk##.leaderBoard",
+      "expertreviews.co.uk##.leaderLeft",
+      "expertreviews.co.uk##.leaderRight",
+      "experts-exchange.com###compCorpAcc",
+      "experts-exchange.com###compSky",
+      "experts-exchange.com##.ontopBanner",
+      "explosm.net##td[height=\"90\"][bgcolor=\"#000000\"][style=\"border: 3px solid rgb(55, 62, 70);\"]",
+      "facebook.com###home_sponsor_nile",
+      "facebook.com##.ego_spo",
+      "fairyshare.com##.google_top",
+      "fanpop.com###rgad",
+      "fanpop.com##div[style=\"width: 300px; height: 250px; background-color: rgb(0, 0, 0); color: rgb(153, 153, 153);\"]",
+      "fark.com###rightSideRightMenubar",
+      "fasterlouder.com.au##.ad",
+      "fatwallet.com###promoBand",
+      "feedicons.com###footerboard",
+      "feministing.com##div[class^=\"banner\"]",
+      "ffiles.com###right_col",
+      "file-extensions.org###uniBan",
+      "filedropper.com###sidebar",
+      "filefront.com##div[style=\"width: 300px; min-height: 250px;\"]",
+      "filehippo.com##.ad",
+      "filespump.com##table[width=\"100%\"][border=\"0\"][bgcolor=\"#dce0e3\"][align=\"center\"]",
+      "filestube.com##.nova",
+      "filestube.com##.remads",
+      "filestube.com##a[href^=\"http://www.filestube.com/sponsored_go.html?\"]",
+      "filestube.com##div[style=\"width: 750px; height: 100px;\"]",
+      "filetrip.net###products",
+      "finance.yahoo.com###yfi_pf_ad_mort",
+      "finance.yahoo.com###yfi_pf_ysm",
+      "finance.yahoo.com###yfi_ysm",
+      "finance.yahoo.com##.ysm",
+      "firewallguide.com##td[width=\"300\"][height=\"250\"]",
+      "firstcoastnews.com##div[id=\"top ad\"]",
+      "flashgot.net##.tla",
+      "flixster.com##div[style=\"position: relative; height: 270px;\"]",
+      "foodnetwork.com##.mrec",
+      "fool.com###promoAndLeaderboard",
+      "forbes.com##.fifthN",
+      "foreca.com##.top-banners",
+      "forum.notebookreview.com##td[width=\"400\"][height=\"280\"]",
+      "forums.battle.net##td[align=\"center\"][width^=\"130\"][valign=\"top\"]",
+      "forums.scifi.com###flippingBanner",
+      "forums.vr-zone.com##.perm_announcement",
+      "forums.worldofwarcraft.com##td[align=\"center\"][width^=\"130\"][valign=\"top\"]",
+      "forums.wow-europe.com##td[align=\"center\"][width^=\"130\"][valign=\"top\"]",
+      "forumserver.twoplustwo.com##td[width=\"120\"][valign=\"top\"][style=\"padding-left: 10px;\"]",
+      "fox.com##.ad",
+      "foxnews.com###console300x100",
+      "foxnews.com###marketplace",
+      "foxnews.com##.quigo",
+      "freecodesource.com###banner",
+      "freshmeat.net##.banner-imu",
+      "freshmeat.net##.banner1",
+      "ft.com###leaderboard",
+      "fudzilla.com###showcase",
+      "fudzilla.com##.artbannersxtd",
+      "fxnetworks.com###adBlock",
+      "gadgetzone.com.au###Leaderboard-placeholder",
+      "gadgetzone.com.au##td[style=\"width: 300px;\"]",
+      "gadling.com##.medrect",
+      "gadling.com##.topleader",
+      "gamebanshee.com##.banner",
+      "gamepro.com.au##.rhs_300x250",
+      "gamerevolution.com##td[height=\"100\"][style=\"padding-left: 5px; padding-top: 5px; padding-right: 5px;\"]",
+      "gamernode.com##.ad",
+      "gamersyde.com##.placeholder-top",
+      "gamesindustry.biz###leader",
+      "gamesradar.com##.tablets",
+      "gawker.com###marquee",
+      "gawker.com###marquee-frame",
+      "gawker.com###skyscraper",
+      "gawker.com##.highlite",
+      "geek.com##.leaderboard",
+      "geekologie.com###leaderboard",
+      "get-ip.de##div[style*=\"width: 250px; height: 250px;\"]",
+      "gethuman.com##td[style=\"width: 200px;\"]",
+      "getprice.com.au##table[id*=\"AdAware\"]",
+      "gigwise.com###skyscraper",
+      "giveawayoftheday.com##.before_hot_tags",
+      "gizmodo.com###marquee",
+      "gizmodo.com###marquee-frame",
+      "gizmodo.com###skyscraper",
+      "gizmodo.com###spacer160",
+      "gizmodo.com##.highlite",
+      "goal.com###marketplaceModule",
+      "goauto.com.au###leftnavcontainer + table[width=\"130\"]",
+      "gocurrency.com##td[height=\"120\"]",
+      "golivewire.com##div[style=\"height: 292px; margin-left: 10px; background-image: url(http://img.golivewire.com/stickynote-gray.gif); background-repeat: no-repeat; background-position: 0px 3px; padding-left: 26px; padding-top: 26px;\"]",
+      "goodgearguide.com.au##a[href^=\"http://ad.doubleclick.net/\"]",
+      "google.com##table[cellpadding=\"0\"][width=\"100%\"][style^=\"border: 1px solid rgb(\"][style$=\");\"]",
+      "googletutor.com##div[style=\"width: 125px; text-align: center;\"]",
+      "googlewatch.eweek.com###topBanner",
+      "governmentvideo.com##table[width=\"665\"]",
+      "gpsreview.net###lead",
+      "gpsreview.net##div[style^=\"border: 1px none rgb(255, 255, 255); padding: 0px; background-color: rgb(255, 255, 255); font-family: Verdana,Arial,sans-serif; font-size: 10px; line-height: 11px; color: rgb(0, 0, 0); width:\"]",
+      "gpxplus.net##div[title=\"Click here to learn how to disable AdBlock on GPXPlus only\"]",
+      "grindtv.com###LREC",
+      "grindtv.com###SKY",
+      "grindtv.com###hLREC",
+      "growingbusiness.co.uk##.siteLeaderBoard",
+      "guardian.co.uk##.kelkoo",
+      "h-online.com##.bcadv",
+      "haaretz.com##a[target=\"_blank\"][href^=\"http://dclk.themarker.com/\"]",
+      "haaretz.com##td[width=\"120\"][valign=\"top\"]",
+      "halifaxcourier.co.uk###banner01",
+      "hardocp.com##.ad",
+      "harpers.org##.topbanner",
+      "healthboards.com##img[height=\"103\"][src*=\"/health/health_\"]",
+      "healthboards.com##td[align=\"left\"][width=\"300\"]:first-child",
+      "hebdenbridgetimes.co.uk###banner01",
+      "helenair.com##table.bordered[align=\"center\"][width=\"728\"]",
+      "helpwithwindows.com###ad",
+      "helpwithwindows.com###desc",
+      "heraldscotland.com###leaderboard",
+      "hi5.com###hi5-common-header-banner",
+      "hi5.com##.hi5-common-header-banner-ad",
+      "highdefdigest.com##table[width=\"300\"][cellspacing=\"0\"][cellpadding=\"0\"]",
+      "hitfix.com##.googlewide",
+      "hollywoodreporter.com##.ad",
+      "hotjobs.yahoo.com###sponsorResults",
+      "hotlinkfiles.com###leaderboard",
+      "howstuffworks.com###MedRectHome",
+      "howstuffworks.com###SponLogo",
+      "howstuffworks.com##.search-span",
+      "howstuffworks.com##.searchSponsorItem",
+      "hplusmagazine.com###bottom",
+      "huffingtonpost.com##.contin_below",
+      "hvac-talk.com##td[align=\"center\"][valign=\"top\"][style=\"padding-left: 10px;\"]",
+      "i4u.com###topBanner > div#right",
+      "idg.com.au###top_adblock_fix",
+      "illimitux.net###screens",
+      "illimitux.net##.pub_bot",
+      "illimitux.net##.pub_top",
+      "images.search.yahoo.com###r-e",
+      "imageshack.us###add_frame",
+      "imtranslator.net##td[align=\"right\"][valign=\"bottom\"][height=\"96\"]",
+      "indeed.com##.sjl",
+      "indeed.com##.slc",
+      "indeed.com##.slh",
+      "independent.co.uk###article > .box",
+      "independent.co.uk###yahooLinks",
+      "independent.co.uk##.commercialpromo",
+      "indiatimes.com##.hover2bg",
+      "indiatimes.com##.tpgrynw > .topbrnw:first-child + div",
+      "indystar.com##.ad",
+      "info.co.uk##.p",
+      "infoplease.com###gob",
+      "informationweek.com##.ad",
+      "informit.com###leaderboard",
+      "inquirer.net###bottom_container",
+      "inquirer.net###leaderboard_frame",
+      "inquirer.net###marketplace_vertical_container",
+      "inquirer.net##.bgadgray10px",
+      "inquirer.net##.fontgraysmall",
+      "inquirer.net##.padtopbot5",
+      "inquirer.net##table[width=\"780\"][height=\"90\"]",
+      "inquisitr.com###topx2",
+      "insanelymac.com##.ad",
+      "instapaper.com###deckpromo",
+      "intelligencer.ca###banZone",
+      "intelligencer.ca##.bnr",
+      "interfacelift.com##.ad",
+      "internet-live-radio.blogspot.com##a[href^=\"http://www.dapatwang.com/\"]",
+      "internetautoguide.com##div[id^=\"GOOGLE_ADS_\"]",
+      "internetautoguide.com##table[id$=\"_tableAdsTop\"]",
+      "internetevolution.com##div[style=\"border: 2px solid rgb(230, 230, 230); margin-top: 30px;\"]",
+      "investopedia.com###leader",
+      "investopedia.com##.mainbodyleftcolumntrade",
+      "investopedia.com##div[style=\"float: left; width: 250px; height: 250px; margin-right: 5px;\"]",
+      "io9.com###marquee",
+      "io9.com###marquee-frame",
+      "io9.com###skyscraper",
+      "io9.com##.highlite",
+      "irishtimes.com###banner-area",
+      "itnews.com.au##div[style=\"width: 300px; height: 250px;\"]",
+      "itnews.com.au##div[style^=\"width: 728px; height: 90px;\"]",
+      "itnewsonline.com##table[width=\"300\"][height=\"250\"]",
+      "itnewsonline.com##td[width=\"120\"]",
+      "itp.net##div[id^=\"oas-\"]",
+      "itpro.co.uk###skyScraper",
+      "itproportal.com###hp-accordion",
+      "itproportal.com##.teaser",
+      "itworld.com###more_resources",
+      "itworld.com###partner_strip",
+      "ixbtlabs.com##div[style*=\"width: 336px; height: 280px;\"]",
+      "ixquick.com##td[bgcolor=\"#f7f9ff\"]",
+      "jakeludington.com###ablock",
+      "jalopnik.com###marquee",
+      "jalopnik.com###marquee-frame",
+      "jalopnik.com###skyscraper",
+      "jalopnik.com##.highlite",
+      "jamendo.com###ad",
+      "jamendo.com##.col_extra",
+      "japantimes.co.jp###FooterAdBlock",
+      "jarrowandhebburngazette.com###banner01",
+      "jayisgames.com##.bfg-feature",
+      "jeuxvideo-flash.com###pub_header",
+      "jewtube.com###div[style=\"border: 1px solid rgb(221, 221, 221); padding: 5px; display: block; width: 468px; height: 60px; text-align: left;\"]",
+      "jezebel.com###marquee",
+      "jezebel.com###marquee-frame",
+      "jezebel.com###skyscraper",
+      "jezebel.com##.highlite",
+      "joystickdivision.com###Page_Header",
+      "joystiq.com###topleader-wrap",
+      "joystiq.com##.medrect",
+      "jpost.com###topBanner",
+      "jpost.com##.padtopblubar",
+      "justin.tv##div[style$=\"width: 728px; height: 90px;\"]",
+      "kaldata.net###header2",
+      "katu.com###mrktplace_tabbed",
+      "katu.com##.callout",
+      "katzforums.com###aff",
+      "keepvid.com##.sponsors",
+      "keepvid.com##.sponsors-s",
+      "kewlshare.com###rollAdRKLA",
+      "kids-in-mind.com##td[align=\"center\"][height=\"270\"]",
+      "kidzworld.com##.layout_stub",
+      "kidzworld.com##div[style*=\"margin: auto;\"][style*=\"width: 200px; height: 617px;\"]",
+      "knowyourmeme.com##.a160x600",
+      "knowyourmeme.com##.a250x250",
+      "knowyourmeme.com##.a728x90",
+      "knoxnews.com###leaderboard",
+      "knoxnews.com##.big_box",
+      "komonews.com###leader-sponsor",
+      "kotaku.com###marquee",
+      "kotaku.com###marquee-frame",
+      "kotaku.com###skyscraper",
+      "kotaku.com##.highlite",
+      "kovideo.net##.h-728",
+      "kovideo.net##.right-def-160",
+      "kovideo.net##.search-728",
+      "kuklaskorner.com###ultimate",
+      "kval.com###mrktplace_tabbed",
+      "kval.com##.callout",
+      "law.com###leaderboard",
+      "layoutstreet.com##.ad",
+      "learninginfo.org##table[align=\"left\"][width=\"346\"]",
+      "lemondrop.com##.sidebarBanner",
+      "lemondrop.com##.topBanner",
+      "letssingit.com##iframe[id^=\"adslot_\"]",
+      "licensing.biz##.newsinsert",
+      "life.com##.ad",
+      "lifehack.org##.offer",
+      "lifehacker.com###marquee",
+      "lifehacker.com###marquee-frame",
+      "lifehacker.com###skyscraper",
+      "lifehacker.com##.highlite",
+      "lifespy.com##.SRR",
+      "lightreading.com##div[align=\"center\"][style=\"height: 114px;\"]",
+      "linux-mag.com##.sponsor-widget",
+      "linuxforums.org###rightColumn",
+      "linuxforums.org##div[style$=\" float: right; width: 290px; font-size: 12px; font-weight: bold; color: rgb(85, 85, 85); text-align: center;\"]",
+      "linuxforums.org##div[style=\"margin: 2px; float: right; width: 300px; height: 250px;\"]",
+      "linuxinsider.com###welcome-box",
+      "linuxinsider.com##.content-block-slinks",
+      "linuxinsider.com##.content-tab-slinks",
+      "linuxquestions.org##div[style=\"margin: -3px -3px 5px 5px; float: right;\"]",
+      "linuxtopia.org###bookcover_sky",
+      "lionsdenu.com###banner300-top-right",
+      "lionsdenu.com###sidebar-bottom-left",
+      "lionsdenu.com###sidebar-bottom-right",
+      "live365.com##.ad",
+      "livejournal.com##.ljad",
+      "liverpooldailypost.co.uk##.promotop",
+      "living.aol.co.uk##.wide.horizontal_promo_HPHT",
+      "lmgtfy.com###sponsor",
+      "loaded.it###apDiv1",
+      "loaded.it###bottomcorner",
+      "loaded.it###ppad1",
+      "local.yahoo.com##.yls-rs-paid",
+      "londonstockexchange.com##.banner",
+      "londonstockexchange.com##.bannerTop",
+      "loombo.com##.ad",
+      "lotro-lore.com###banner",
+      "lowbird.com##.teaser",
+      "luxist.com###topleader-wrap",
+      "luxist.com##.medrect",
+      "lyrics007.com##td[bgcolor=\"#ffcc00\"][width=\"770\"][height=\"110\"]",
+      "lyricsfreak.com##.ad",
+      "lyricwiki.org###p-navigation + .portlet",
+      "lyrster.com##.el_results",
+      "maannews.net##td[style=\"border: 1px solid rgb(204, 204, 204); width: 250px; height: 120px;\"]",
+      "maannews.net##td[style=\"border: 1px solid rgb(204, 204, 204); width: 640px; height: 80px;\"]",
+      "macdailynews.com###right",
+      "macleans.ca###leaderboard",
+      "macnewsworld.com##.content-block-slinks",
+      "macnewsworld.com##.content-tab-slinks",
+      "macnn.com###leaderboard",
+      "macnn.com###supportbod",
+      "macobserver.com##.dealsontheweb",
+      "macobserver.com##.specials",
+      "macosxhints.com##div[style=\"border-bottom: 2px solid rgb(123, 123, 123); padding-bottom: 8px; margin-bottom: 5px;\"]",
+      "macrumors.com###googleblock300",
+      "macrumors.com###mr_banner_topad",
+      "macstories.net###ad",
+      "macthemes2.net###imagelinks",
+      "macupdate.com###promoSidebar",
+      "macupdate.com##div[style*=\"width: 728px; height: 90px;\"][style*=\"margin: 0px auto;\"][style$=\"display: block;\"]",
+      "macworld.co.uk###footer",
+      "macworld.co.uk###topBannerSpot",
+      "macworld.com###shopping",
+      "magme.com###top_banner",
+      "mail.google.com##.oM",
+      "mail.google.com##.rh > #ra",
+      "mail.yahoo.com###MNW",
+      "mail.yahoo.com###northbanner",
+      "mail.yahoo.com###nwPane",
+      "mail.yahoo.com###swPane",
+      "majorgeeks.com##a[href^=\"http://www.liutilities.com/products/campaigns/adv/\"]",
+      "majorgeeks.com##a[href^=\"https://secure.avangate.com/affiliate.php?\"]",
+      "majorgeeks.com##div > table.author > tbody > tr > td",
+      "majorgeeks.com##table[align=\"right\"][width=\"336\"][style=\"padding-left: 5px;\"]",
+      "makeuseof.com##a[href^=\"http://makeuseof.com/short/ads/\"]",
+      "malaysiastory.com##.box2",
+      "map24.com###cont_m24up",
+      "mapquest.com###offers",
+      "marketingpilgrim.com###ad",
+      "mashable.com##.header-banner",
+      "massively.com###topleader-wrap",
+      "mcvuk.com##.newsinsert",
+      "mediafire.com##.download_banner_container",
+      "mediafire.com##.ninesixty_container:last-child td[align=\"right\"][valign=\"top\"]:first-child",
+      "mediaite.com###magnify_widget_rect_handle",
+      "meebo.com##div[id$=\"MediaBar\"]",
+      "megagames.com##table[width^=\"7\"][border=\"1\"][height=\"92\"]",
+      "mercurynews.com###mn_SP_Links",
+      "mercurynews.com##.articleEmbeddedAdBox",
+      "merriam-webster.com###google_creative_3",
+      "metadivx.com##.ad",
+      "metblogs.com###a_medrect",
+      "metblogs.com###a_widesky",
+      "mg.co.za###masthead > table[style=\"padding-right: 5px;\"]:first-child",
+      "mg.co.za###miway-creative",
+      "mg.co.za##.articlecontinues",
+      "mg.co.za##div[style=\"width: 300px; height: 250px;\"]",
+      "miamiherald.com###leaderboard",
+      "microsoft-watch.com###topBannerContainer",
+      "miniclip.com##.block_300x250",
+      "miniclip.com##.letterbox",
+      "mininova.org##div[id^=\"adspot-\"]",
+      "missoulian.com###yahoo-contentmatch",
+      "mlive.com##.adops",
+      "mmorpg.com##a[target=\"_blank\"][href*=\"?utm_campaign=\"]",
+      "mmorpg.com##a[target=\"_blank\"][href^=\"http://ad.\"]",
+      "mmorpg.com##div[class^=\"ndoors\"]",
+      "mmosite.com##.c_gg",
+      "mmosite.com##.mmo_gg",
+      "mmosite.com##.mmo_gg2",
+      "mmosite.com##.mmo_textsponsor",
+      "mobile-ent.biz##.newsinsert",
+      "mobilecrunch.com##.ad",
+      "mobilecrunch.com##.sponsor_units",
+      "mofunzone.com###ldrbrd_td",
+      "mofunzone.com##td[onclick^=\"window.open('http://server.cpmstar.com/\"]",
+      "money.cnn.com###moneySponsorBox",
+      "montanasnewsstation.com###COLUMN4",
+      "montanasnewsstation.com##div[id^=\"wrapper_wnsz_\"]",
+      "morningstar.com##.LeaderWrap",
+      "morningstar.com##.aadsection_b1",
+      "morningstar.com##.aadsection_b2",
+      "morningstar.com##a#cover_div[href^=\"http://ads.morningstar.com/\"]",
+      "mortgageguide101.com###ppc",
+      "mosnews.com##.right_pop",
+      "motorcycle-usa.com##.bannergoogle",
+      "movie2k.com###ball",
+      "movie2k.com##a[href^=\"http://www.ireel.com/signup?ref=\"]",
+      "moviecritic.com.au###glinks",
+      "moviefone.com###WIAModule",
+      "moviefone.com##.ent_promo_sidetexttitle",
+      "movies.yahoo.com##.lrec",
+      "moviesplanet.com##.Banner468X60",
+      "moviesplanet.com##.gb",
+      "movshare.net##.ad",
+      "movshare.net##a[href^=\"http://secure.signup-page.com/\"]",
+      "mp3raid.com##a[href^=\"http://www.mp3va.com/search.php?\"]",
+      "msn.com###lgad",
+      "msn.com###mlad",
+      "msn.com###rtMod_wonderwall",
+      "msn.com##.abs",
+      "msn.com##.ad",
+      "msn.com##.prtnrtbs",
+      "msn.com##a[href^=\"http://g.msn.com/0AD0\"]",
+      "msn.com##div[id^=\"sponsored_\"]",
+      "msnbc.msn.com###Dcolumn",
+      "msnbc.msn.com###marketplace",
+      "msnbc.msn.com##.w460",
+      "mstar.com##.MPFBannerWrapper",
+      "multiupload.com##div[style^=\"position: relative; width: 701px; height: 281px;\"][style*=\"img/ad_bgr.gif\"]",
+      "mumbaimirror.com##.bottombanner",
+      "mumbaimirror.com##.topbanner",
+      "music.yahoo.com###YMusicRegion_T3_R2C2_R1",
+      "music.yahoo.com###lrec",
+      "music.yahoo.com###lrecTop",
+      "musicsonglyrics.com##td[width=\"300\"][valign=\"top\"]",
+      "myfoxphoenix.com###leaderboard",
+      "myfoxphoenix.com##.marketplace",
+      "myfoxphoenix.com##.module.horizontal",
+      "myfoxphoenix.com##.vert.expanded",
+      "myoutsourcedbrain.com###HTML2",
+      "myretrotv.com##img[width=\"875\"][height=\"110\"]",
+      "myspace.com###marketing",
+      "myspace.com###medRec",
+      "myspace.com###music_googlelinks",
+      "myspace.com###music_medrec",
+      "myspace.com###tkn_medrec",
+      "mywebsearch.com##a[id^=\"rst\"].desc",
+      "nasdaq.com##div[style=\"vertical-align: middle; width: 336px; height: 284px;\"]",
+      "nationalpost.com##.ad",
+      "nearlygood.com###abf",
+      "neopets.com###ban",
+      "neopets.com###ban_bottom",
+      "neoseeker.com##div[style*=\"background: rgb(239, 239, 239)\"][style*=\"float: right; width: 162px;\"]",
+      "neowin.net###header-banner",
+      "neowin.net###header-promos",
+      "neowin.net###sidebar > #latest-community + #social-links + .sidebar-block",
+      "neowin.net###sidebar > #latest-community + #social-links + .sidebar-block + .sidebar-block + #poll + .sidebar-block + .sidebar-block",
+      "neowin.net###sidebar > #sidebar-author + .sidebar-block",
+      "neowin.net###sidebar > #sidebar-author + .sidebar-block + #promo + .sidebar-block + .sidebar-block",
+      "neowin.net##div[style$=\"height: 250px; width: 300px;\"]",
+      "nerve.com###topBanner",
+      "netchunks.com###af_adblock",
+      "netchunks.com###m_top_adblock",
+      "netchunks.com###sponsorsM",
+      "netmag.co.uk##div[style=\"margin: 0px auto; padding-right: 0px; float: left; padding-bottom: 0px; width: 320px; padding-top: 0px; height: 290px; background-color: rgb(255, 255, 255);\"]",
+      "networkworld.com###lb_container_top",
+      "networkworld.com##.sponsor",
+      "nevadaappeal.com##.youradhere",
+      "newgrounds.com##.wide_storepromo",
+      "newgrounds.com##.wide_storepromobot",
+      "news.aol.co.uk###tdiv71",
+      "news.aol.co.uk###tdiv74",
+      "news.cnet.com###bottom-leader",
+      "news.com.au##.ad",
+      "news.com.au##.sponsors",
+      "news.yahoo.com###ymh-invitational-recs",
+      "news4jax.com##a[target=\"_blank\"][href^=\"http://ad.doubleclick.net/\"]",
+      "newsarama.com##.marketplace",
+      "newscientist.com##a[href^=\"http://www.google.com/aclk?\"]",
+      "newsfactor.com##td[background$=\"/back-ad.gif\"]",
+      "newsmax.com###noprint1",
+      "newsmax.com##.sponsors_spacer",
+      "newsonjapan.com###squarebanner300x250",
+      "newstatesman.com###footerbanner",
+      "newsweek.com##.sponsor",
+      "newzealandsites.co.nz##td[align=\"center\"][width=\"775\"][height=\"90\"]",
+      "nicknz.co.nz##.lrec",
+      "nicknz.co.nz##.top-banner",
+      "ninemsn.com.au###ad",
+      "ninemsn.seek.com.au###msnhd_div3",
+      "nintendolife.com##.the300x250",
+      "nitrome.com##div[id^=\"banner_\"]",
+      "nitrome.com##div[id^=\"skyscraper_\"]",
+      "nola.com##.adops",
+      "noupe.com##.ad",
+      "novamov.com##a[href^=\"http://secure.signup-page.com/\"]",
+      "novamov.com##a[href^=\"http://secure.signup-way.com/\"]",
+      "nwsource.com###skyscraperwide",
+      "nwsource.com##.adblock",
+      "nwsource.com##.googlemiddle",
+      "nyaatorrents.org##a[href^=\"http://www.nyaatorrents.org/a?\"]",
+      "nydailynews.com###nydn-topbar",
+      "nydailynews.com##.z_sponsor",
+      "nymag.com##.google-bottom",
+      "nypost.com##.ad",
+      "nytimes.com##.ad",
+      "nytimes.com##[id^=\"adx\"]",
+      "nzgamer.com###premierholder",
+      "nzgamer.com##.article_banner_holder",
+      "ocregister.com###bannertop2",
+      "omg.yahoo.com###omg-lrec",
+      "omgili.com###ad",
+      "onlineathens.com##.story-insert",
+      "onlineathens.com##.yahoo_hoz",
+      "opendrivers.com###google336x280",
+      "orange.co.uk###home_leaderboard",
+      "orange.co.uk###home_mpu",
+      "orange.co.uk###home_partnerlinks",
+      "orange.co.uk###home_shoppinglinks",
+      "orange.co.uk##.spon_sored",
+      "oreillynet.com###leaderboard",
+      "osnews.com##.ad",
+      "ovguide.com##.banner-rectangleMedium",
+      "p2pnet.net###sidebar > ul:first-child + table[width=\"19%\"]",
+      "p2pnet.net###sidebar2",
+      "p2pnet.net##td[align=\"center\"][width=\"100%\"] > a[style=\"border: 0px none ; margin: 0px;\"][target=\"_blank\"] > img",
+      "pcauthority.com.au##.featured-retailers",
+      "pcmag.com###homeRegionPremiumPartner",
+      "pcmag.com###w_leaderboard",
+      "pcmag.com##.content-links",
+      "pcmag.com##.partners",
+      "pcmag.com##.special-offers",
+      "pcpro.co.uk###skyScrapper",
+      "pcpro.co.uk##.leaderBoard",
+      "pcpro.co.uk##.mpuBox",
+      "pcpro.co.uk##a[target=\"_blank\"][href^=\"http://ad.doubleclick.net/clk;\"]",
+      "pcr-online.biz##.newsinsert",
+      "pcstats.com##table[cellpadding=\"2\"][align=\"right\"][width=\"300\"][style=\"border: 1px solid ;\"]",
+      "pctipsbox.com###daikos-text-4",
+      "pcworld.co.nz###sponsor_div",
+      "pcworld.com###LenovoBackToSchool",
+      "pcworld.com###bizPromo",
+      "pcworld.com###blox3Deals",
+      "pcworld.com###editPromo",
+      "pcworld.com###featuredResources",
+      "pcworld.com###featuredWhitepapers",
+      "pcworld.com###industryWebcasts",
+      "pcworld.com##a[href^=\"http://ad.doubleclick.net/\"]",
+      "pcworld.com##div[id^=\"daftad_\"]",
+      "pcworld.idg.com.au##a[href^=\"http://ad.doubleclick.net/\"]",
+      "pdfmyurl.com##.banner",
+      "pdfzone.com##.Skyscraper_BG",
+      "pdfzone.com##.sponsors_container",
+      "pdfzone.com##div[style=\"float: left; width: 336px; margin-right: 16px; margin-bottom: 5px;\"]",
+      "pedulum.com###header_top",
+      "penny-arcade.com###funding-h",
+      "phazeddl.com##a[href^=\"http://www.downloadpost.com/\"]",
+      "phonescoop.com###botlink",
+      "phonescoop.com###promob",
+      "photobucket.com##.bannerContainer",
+      "ping.eu##table[width=\"728\"][cellpadding=\"10\"]",
+      "pingtest.net##.ad",
+      "pinknews.co.uk##a[href^=\"http://www.pinknews.co.uk/clicks/\"]",
+      "planetxbox360.com###rightCol3gameHome",
+      "planetxbox360.com##div[style*=\"width: 300px; height: 250px;\"]",
+      "planetxbox360.com##td#rightCol1[align=\"right\"][valign=\"top\"]",
+      "planetxbox360.com##td[align=\"center\"][height=\"100\"][bgcolor=\"#3f3f3f\"]",
+      "playkidsgames.com##table[bgcolor=\"#333333\"][width=\"320\"][height=\"219\"]",
+      "playkidsgames.com##table[width=\"100%\"][height=\"105\"]",
+      "politico.com##.in-story-banner",
+      "politics.co.uk###top-banner",
+      "politifact.com##.pfad",
+      "ponged.com##.adv",
+      "popeater.com##.sidebarBanner",
+      "press-citizen.com##.rightrail-promo",
+      "pressf1.co.nz###sponsor_div",
+      "pricegrabber.com##.topBanner",
+      "pricespy.co.nz##.ad",
+      "prisonplanet.com###bottombanners",
+      "prisonplanet.com###efoods",
+      "proaudioreview.com##table[width=\"665\"]",
+      "ps3news.com###sidebar > div > div > table[cellspacing=\"5px\"]:first-child",
+      "ptinews.com##.fullstoryadd",
+      "ptinews.com##.fullstorydivright",
+      "pureoverclock.com###adblock1",
+      "pureoverclock.com###adblock2",
+      "pureoverclock.com###mainbanner",
+      "qj.net###shoppingapi",
+      "radaronline.com###videoExternalBanner",
+      "radaronline.com###videoSkyscraper",
+      "rapidlibrary.com##a[href*=\"/adv.php?\"]",
+      "ratemyprofessors.com##.rmp_leaderboard",
+      "rawstory.com##td[width=\"101\"][align=\"center\"][style][margin=\"0\"]",
+      "readwriteweb.com###ad_block",
+      "realitytvobsession.com###glinks",
+      "reddit.com##.promotedlink",
+      "reference.com###Resource_Center",
+      "reference.com###abvFold",
+      "reference.com###bannerTop",
+      "reference.com###bnrTop",
+      "reference.com###centerbanner_game",
+      "reference.com###rc",
+      "reference.com##.spl_unshd",
+      "reference.com##.spl_unshd_NC",
+      "restaurants.com##.latad",
+      "rivals.com###thecontainer",
+      "robotswithfeelings.com##div[style^=\"height: 250px; width: 300px;\"]",
+      "robotswithfeelings.com##div[style^=\"height: 90px; width: 728px;\"]",
+      "rockpapershotgun.com##.marketing",
+      "rollcall.com##.ad",
+      "rollingstone.com##.ad",
+      "rollyo.com##dl[onclick*=\".overture.com/\"]",
+      "rollyo.com##strong[style=\"padding: 5px; color: rgb(153, 153, 153); float: right;\"]",
+      "rottentomatoes.com###afc_sidebar",
+      "roughlydrafted.com###banner",
+      "royalgazette.com##div[style=\"height: 60px; width: 468px;\"]",
+      "rte.ie###island300x250-inside",
+      "rte.ie###story_island",
+      "rte.ie###tilesHolder",
+      "runescape.com###tb",
+      "rushlimbaugh.com###top_leaderboard",
+      "rwonline.com##table[width=\"665\"]",
+      "sankakucomplex.com##div[class^=\"side120\"]",
+      "sankakucomplex.com##div[class^=\"sidebartop\"]",
+      "sbsun.com##.articleEmbeddedAdBox",
+      "sci-tech-today.com##td[background$=\"/back-ad.gif\"]",
+      "scienceblogs.com###leaderboard",
+      "scienceblogs.com##.skyscraper",
+      "sciencedaily.com##.rectangle",
+      "sciencedaily.com##.skyscraper",
+      "sciencedirect.com###leaderboard",
+      "scientificamerican.com##.clearfix[style=\"border-top: 1px solid rgb(204, 204, 204); height: 158px; text-align: center; margin-top: 17px; padding-top: 10px; color: rgb(204, 204, 204);\"]",
+      "scoop.co.nz###top-banner",
+      "scoop.co.nz###top-banner-base",
+      "scoop.co.nz###topHeader",
+      "scotsman.com###banner01",
+      "search.aol.co.uk##.PMB",
+      "search.aol.co.uk##.SLL",
+      "search.aol.co.uk##.WOL",
+      "search.aol.com##.PMB",
+      "search.aol.com##.SLL",
+      "search.aol.com##.WOL",
+      "search.icq.com##.more_sp",
+      "search.icq.com##.res_sp",
+      "search.netscape.com##.SLL",
+      "search.netscape.com##.SWOL",
+      "search.winamp.com##.SLL",
+      "search.winamp.com##.SWOL",
+      "search.yahoo.com###east",
+      "search.yahoo.com###sec-col",
+      "search.yahoo.com##.bbox",
+      "searchenginejournal.com##a[id^=\"bsa_\"]",
+      "seattlepi.com##.wingadblock",
+      "secretmaryo.org##div[style^=\"width: 120px; height: 600px;\"]",
+      "secretmaryo.org##div[style^=\"width: 728px; height: 90px;\"]",
+      "securityfocus.com##td[width=\"160\"][bgcolor=\"#eaeaea\"]",
+      "sensis.com.au##.pfpRightParent",
+      "sensis.com.au##.pfplist",
+      "sevenload.com###superbaannerContainer",
+      "sevenload.com###yahoo-container",
+      "sfx.co.uk###banner",
+      "shacknews.com##.recentcategories",
+      "shacknews.com##div[style^=\"margin-left: auto; margin-right: auto; width: 728px; height: 90px;\"]",
+      "shopping.yahoo.com##.shmod-ysm",
+      "siliconchip.com.au##td[align=\"RIGHT\"][width=\"50%\"][valign=\"BOTTOM\"]",
+      "silverlight.net##.banner_header",
+      "simplyhired.com##.featured",
+      "siteadvisor.com##.midPageSmallOuterDiv",
+      "sitepoint.com##.industrybrains",
+      "skins.be##.shortBioShadowB.w240",
+      "skyrock.com###pub_up",
+      "slate.com##.bizbox_promo",
+      "smarter.com##.favboxmiddlesearch",
+      "smarter.com##.favwrapper",
+      "smash247.com###RT1",
+      "smashingmagazine.com###commentsponsortarget",
+      "smashingmagazine.com###mediumrectangletarget",
+      "smashingmagazine.com###sidebaradtarget",
+      "smashingmagazine.com###sponsorlisttarget",
+      "smashingmagazine.com##.ed",
+      "smh.com.au##.ad",
+      "smh.com.au##div[id^=\"adSpot-\"]",
+      "snapfiles.com###bannerbar",
+      "snapfiles.com###borderbar",
+      "snapfiles.com###prodmsg",
+      "snow.co.nz###content-footer-wrap",
+      "snow.co.nz###header-banner",
+      "snowtv.co.nz###header-banner",
+      "softonic.com##.topbanner",
+      "softonic.com##.topbanner_program",
+      "softpedia.com##.logotable[align=\"right\"] > a[target=\"_blank\"]",
+      "softpedia.com##.pagehead_op2",
+      "softpedia.com##img[width=\"600\"][height=\"90\"]",
+      "softpedia.com##td[align=\"right\"][style=\"padding-bottom: 5px; padding-left: 22px; padding-right: 17px;\"]",
+      "someecards.com###shop",
+      "someecards.com###some-ads",
+      "someecards.com###some-more-ads",
+      "someecards.com###store",
+      "somethingawful.com##.oma_pal",
+      "songlyrics.com##.content-bottom-banner",
+      "sowetan.co.za###leaderboard_container",
+      "sowetan.co.za##.ad",
+      "space.com###expandedBanner",
+      "space.com##table[width=\"321\"][height=\"285\"][bgcolor=\"#000000\"]",
+      "space.com##td[colspan=\"2\"]:first-child > table[width=\"968\"]:first-child",
+      "speedtest.net##.ad",
+      "spikedhumor.com###ctl00_CraveBanners",
+      "spikedhumor.com##.ad",
+      "spokesman.com##.ad",
+      "squidoo.com###header_banner",
+      "startpage.com###inlinetable",
+      "startribune.com###bottomLeaderboard",
+      "startribune.com###topLeaderboard",
+      "staticice.com.au##table[rules=\"none\"][style=\"border: 1px solid rgb(135, 185, 245);\"]",
+      "staticice.com.au##td[align=\"center\"][valign=\"middle\"][height=\"80\"]",
+      "stickam.com###h_TopBanner",
+      "storagereview.com##td[width=\"410\"]:first-child + td[align=\"right\"]",
+      "stv.tv###collapsedBanner",
+      "sunderlandecho.com###banner01",
+      "sunderlandecho.com##.sitesponsor",
+      "superfastfile.com###topbar",
+      "superfastfile.com###topbar_fuckyou",
+      "superpages.com##.sponsreulst",
+      "swamppolitics.com###leaderboard",
+      "switched.com###topleader-wrap",
+      "switched.com##.medrect",
+      "sys-con.com###elementDiv",
+      "sys-con.com##td[width=\"180\"][valign=\"top\"][rowspan=\"3\"]",
+      "talkingpointsmemo.com##.seventwentyeight",
+      "talksport.net###headerPromoContainer",
+      "talksport.net##a[href^=\"http://adserver.adtech.de/?\"]",
+      "talkxbox.com###features-sub",
+      "tarot.com###leaderboardOuter",
+      "tcmagazine.com###bannerfulltext",
+      "tcmagazine.com###topbanner",
+      "tcmagazine.info###bannerfulltext",
+      "tcmagazine.info###topbanner",
+      "tech-recipes.com###first-300-ad",
+      "tech-recipes.com###leaderboard",
+      "techcrunch.com###post_unit_medrec",
+      "techcrunch.com##.ad",
+      "techcrunch.com##.sponsor_units",
+      "techcrunchit.com##.ad",
+      "techcrunchit.com##.sponsor_units",
+      "techdigest.tv##.leaderboard",
+      "techguy.org##div[style=\"height: 100px; width: 100%; text-align: center;\"]",
+      "technewsworld.com##.content-block-slinks",
+      "technewsworld.com##.content-tab-slinks",
+      "technologyreview.com##div[style=\"padding-bottom: 8px;\"]",
+      "technorati.com###ad",
+      "technorati.com##.ad",
+      "techrepublic.com.com###medusa",
+      "techrepublic.com.com###ppeHotspot",
+      "techrepublic.com.com###spotlight",
+      "techrepublic.com.com###wpPromo",
+      "techrepublic.com.com##.essentialTopics",
+      "techrepublic.com.com##.hotspot",
+      "techspot.com##a[href^=\"http://www.techspot.com/openxads/\"]",
+      "techwatch.co.uk##table[width=\"250\"][height=\"300\"]",
+      "techweb.com###h_banner",
+      "techweb.com##div[id^=\"p_p_id_SponsoredLinks_\"]",
+      "tectonic.co.za##.tdad125",
+      "teenhut.net##td[align=\"left\"][width=\"160\"][valign=\"top\"]",
+      "telegraph.co.uk###gafsslot1",
+      "telegraph.co.uk##.comPuff",
+      "telegraphindia.com##.Caption",
+      "televisionbroadcast.com##table[width=\"665\"]",
+      "tesco.com###dartLeftSkipper",
+      "tesco.com###dartRightSkipper",
+      "tesco.com##.dart",
+      "tgdaily.com###right-banner",
+      "thatvideogameblog.com##table[width=\"310\"][height=\"260\"]",
+      "theaa.com###unanimis1",
+      "theage.com.au##.ad",
+      "thebizzare.com##.adblock",
+      "thecelebritycafe.com##table[width=\"135\"][height=\"240\"]",
+      "thecellfreak.com##.banheader",
+      "thecellfreak.com##.block-tcftv",
+      "thecellfreak.com##.hotdeals2",
+      "thecellfreak.com##div[id^=\"block-adscence\"]",
+      "theeagle.com##.SectionRightRail300x600Box",
+      "thefashionspot.com###roadblock",
+      "thegameslist.com##.leader",
+      "theglobeandmail.com##.ad",
+      "thegrumpiest.com##td[align=\"left\"][width=\"135px\"]",
+      "thegrumpiest.com##td[align=\"left\"][width=\"135px\"] + td#table1",
+      "thehill.com###topbanner",
+      "thehill.com##.banner",
+      "thehill.com##.lbanner",
+      "thehill.com##.vbanner",
+      "themaineedge.com##td[height=\"80\"][style=\"background-color: rgb(0, 0, 0);\"]",
+      "themaineedge.com##td[width=\"180\"][style=\"background-color: rgb(51, 95, 155); text-align: center;\"]",
+      "thenation.com##.ad",
+      "thenation.com##.modalContainer",
+      "thenation.com##.modalOverlay",
+      "thepspblog.com###featured",
+      "thepspblog.com###mta_bar",
+      "theregister.co.uk###msdn-promo",
+      "theregister.co.uk##.box.papers-promo",
+      "thesixthaxis.com##.map-header-mainblock",
+      "thesixthaxis.com##.map-main-right-takeover",
+      "thesixtyone.com##div[style=\"width: 968px; text-align: center; margin-top: 12px; clear: both; float: left;\"]",
+      "thesmokinggun.com###skyscraper",
+      "thestandard.com###leaderboard_banner",
+      "thestates.fm###banbo",
+      "thestreet.com###brokerage",
+      "thestreet.com###textLinks",
+      "thestreet.com###textLinksContainer",
+      "thesuperficial.com###leaderboard",
+      "thevarguy.com###middlebannerwrapper",
+      "thevarguy.com##.squarebanner160x160",
+      "thewrap.com##div[id^=\"block-thewrap_ads_250x300\"]",
+      "thisisbath.co.uk###mast-head",
+      "thisisleicestershire.co.uk###mast-head",
+      "thisisleicestershire.co.uk##.banner-extButton",
+      "thisismoney.co.uk###Sky",
+      "thisisplymouth.co.uk##.leaderboard",
+      "tidbits.com###top_banner",
+      "tidbits.com##div[class^=\"sponsor\"]",
+      "timeanddate.com##fieldset[style=\"float: right; width: 180px;\"]",
+      "timeout.com##.MD_textLinks01",
+      "timesdispatch.com###dealoftheday",
+      "timesdispatch.com##.adrule",
+      "timesonline.co.uk##.bg-f0eff5.padding-left-right-9.padding-top-6.link-width.word-wrap",
+      "timesonline.co.uk##.bg-f0eff5.padding-left-right-9.padding-top-6.padding-bottom-7.word-wrap",
+      "timesonline.co.uk##.classifieds-long-container",
+      "tinypic.com##.ad",
+      "tinypic.com##.medrec",
+      "tips.net###googlebig",
+      "tmz.com###leaderboard",
+      "tmz.com###skyscraper",
+      "todaystmj4.com###leaderboard1",
+      "tomsgames.com###pub_header",
+      "tomsgames.it###pub_header",
+      "tomsguide.com##.sideOffers",
+      "tomwans.com##.big_button",
+      "top4download.com##div[style=\"float: left; width: 620px; height: 250px; clear: both;\"]",
+      "top4download.com##div[style=\"width: 450px; height: 205px; clear: both;\"]",
+      "toptechnews.com##.regtext[style=\"border: 1px solid rgb(192, 192, 192); padding: 5px;\"]",
+      "toptechnews.com##table[width=\"370\"][cellpadding=\"10\"][style=\"border: 1px solid rgb(204, 204, 204); border-collapse: collapse;\"]",
+      "toptechnews.com##table[width=\"990\"][cellpadding=\"5\"]",
+      "toptenreviews.com##.google_add_container",
+      "torrent-finder.com##.cont_lb",
+      "torrentz.com##a[href^=\"http://www.binverse.com/offers/\"]",
+      "torrentz.com##div[style=\"margin: 0pt auto; width: 728px; height: 90px;\"]",
+      "totalfark.com###rightSideRightMenubar",
+      "tothepc.com##.sidebsa",
+      "toynews-online.biz##.newsinsert",
+      "travel.yahoo.com##.spon",
+      "travel.yahoo.com##.tgl-block",
+      "treehugger.com##.google-indiv-box2",
+      "treehugger.com##.leaderboard",
+      "tripadvisor.com###COMMERCE_REPEAT",
+      "tripadvisor.com###COMMERCE_RHS",
+      "tripadvisor.com###COMMERCE_TOP",
+      "trueslant.com##.bot_banner",
+      "trustedreviews.com###bottom-sky",
+      "trustedreviews.com###top-sky",
+      "trutv.com##.banner",
+      "tuaw.com##.medrect",
+      "tuaw.com##.topleader",
+      "tucows.com##.w952.h85",
+      "tucsoncitizen.com##.bigbox_container",
+      "tucsoncitizen.com##.leaderboard_container_top",
+      "tucsoncitizen.com##.skyscraper_container",
+      "tutsplus.com###AdobeBanner",
+      "tutsplus.com##.leader_board",
+      "tv.yahoo.com##.spons",
+      "tvguide.co.uk##table[width=\"160\"][height=\"620\"]",
+      "tvtechnology.com##table[width=\"665\"]",
+      "twilightwap.com##.ahblock2",
+      "u-file.net##.spottt_tb",
+      "ultimate-guitar.com##.b[align=\"center\"][valign=\"middle\"][height=\"110\"]",
+      "ultimate-guitar.com##.b[cellpadding=\"5\"] td[align=\"center\"][valign=\"bottom\"][height=\"110\"]",
+      "ultimate-guitar.com##table[align=\"right\"][width=\"300\"][height=\"250\"]",
+      "ultimate-guitar.com##td[align=\"center\"][width=\"160\"][bgcolor=\"#141414\"]",
+      "ultimate-guitar.com##td[style*=\"height: 110px;\"][style*=\"text-align: center;\"][style*=\"vertical-align: middle;\"]",
+      "unknown-horizons.org###akct",
+      "unrealitymag.com###header",
+      "unrealitymag.com###sidebar300X250",
+      "uploading.com##div[style=\"background: rgb(246, 246, 246) none repeat scroll 0% 0%; width: 35%; -moz-background-clip: border; -moz-background-origin: padding; -moz-background-inline-policy: continuous; height: 254px;\"]",
+      "uploading.com##div[style=\"margin: -2px auto 19px; display: block; position: relative;\"]",
+      "urbandictionary.com###rollup",
+      "urbandictionary.com##.zazzle_links",
+      "urlesque.com##.sidebarBanner",
+      "urlesque.com##.topBanner",
+      "usatoday.com###footerSponsorOne",
+      "usatoday.com###footerSponsorTwo",
+      "usatoday.com##.ad",
+      "userscripts.org##.sponsor",
+      "userstyles.org##.ad",
+      "usnews.com##.ad",
+      "v3.co.uk###superSky",
+      "v3.co.uk##.ad",
+      "v3.co.uk##.hpu",
+      "v3.co.uk##.leaderboard",
+      "v8x.com.au##td[align=\"RIGHT\"][width=\"50%\"][valign=\"BOTTOM\"]",
+      "variety.com###googlesearch",
+      "variety.com###w300x250",
+      "variety.com##.sponsor",
+      "veehd.com##.isad",
+      "venturebeat.com###leader",
+      "vgchartz.com###topFooter",
+      "vgchartz.com##div[style=\"width: 160px; height: 600px; background-color: rgb(0, 0, 0);\"]",
+      "vgchartz.com##div[style=\"width: 728px; height: 90px; margin-bottom: 5px; background-color: rgb(0, 0, 0);\"]",
+      "videogamer.com##.skinClick",
+      "videography.com##table[width=\"665\"]",
+      "videojug.com##.forceMPUSize",
+      "videoweed.com##.ad",
+      "videoweed.com##div[style*=\"border: 1px solid rgb(204, 204, 204);\"][style*=\"width: 160px;\"][style*=\"height: 600px;\"]",
+      "videoweed.com##div[style*=\"border: 1px solid rgb(204, 204, 204);\"][style*=\"width: 460px;\"][style*=\"height: 60px;\"]",
+      "vimeo.com##.ad",
+      "virus.gr###block-block-19",
+      "vladtv.com###banner-bottom",
+      "w3schools.com##div[style*=\"width: 890px; height: 94px; position: relative;\"]",
+      "w3schools.com##tr[style=\"height: 90px;\"]",
+      "walesonline.co.uk##.promobottom",
+      "walesonline.co.uk##.promotop",
+      "walletpop.com###attic",
+      "walletpop.com##.medrect",
+      "walletpop.com##.sponsWidget",
+      "walletpop.com##div[style=\"padding: 6px; float: right; width: 242px; height: 272px;\"]",
+      "walletpop.com##div[style^=\"margin: 20px 0px 0px; background: rgb(240, 240, 240) url(http://www.aolcdn.com/ch_pf/advertisement-text)\"]",
+      "washingtonpost.com###textlinkWrapper",
+      "watch-movies.ro##a[href^=\"http://secure.signup-way.com/\"]",
+      "watoday.com.au##.ad",
+      "weather.ninemsn.com.au###msnhd_div3",
+      "weatherbug.com##.wXcds1",
+      "weatherbug.com##.wXcds2",
+      "webdesignstuff.com###headbanner",
+      "webpronews.com##.articleleftcol",
+      "webpronews.com##.tallad > *",
+      "webresourcesdepot.com##.Banners",
+      "webresourcesdepot.com##img[width=\"452px\"][height=\"60px\"]",
+      "weeklyworldnews.com##.top-banner",
+      "wenn.com###topbanner",
+      "westlothianhp.co.uk###banner01",
+      "westsussextoday.co.uk###banner01",
+      "wftv.com###leaderboard-sticky",
+      "whatismyip.com##span[style=\"margin: 2px; float: left; width: 301px; height: 251px;\"]",
+      "whistlestopper.com##td[align=\"left\"][width=\"160\"][valign=\"top\"]",
+      "whitepages.com###nr_results_multiple_lisitng_sponsored_links",
+      "whitepages.com###results_single_results_link_ads",
+      "whitepages.com##div[id^=\"wp_ad_\"]",
+      "who.is##div[id^=\"namecom_ad_\"]",
+      "wikia.com###HOME_LEFT_SKYSCRAPER_1",
+      "wikia.com###HOME_TOP_LEADERBOARD",
+      "wikia.com###HOME_TOP_RIGHT_BOXAD",
+      "wikia.com###LEFT_SKYSCRAPER_1",
+      "wikia.com###LEFT_SKYSCRAPER_2",
+      "wikia.com###PREFOOTER_BIG",
+      "wikia.com###PREFOOTER_LEFT_BOXAD",
+      "wikia.com###PREFOOTER_RIGHT_BOXAD",
+      "wikia.com###TOP_LEADERBOARD",
+      "winamp.com###subheader",
+      "windowsbbs.com##span[style=\"margin: 2px; float: left; width: 337px; height: 281px;\"]",
+      "windowsitpro.com###dnn_pentonRoadblock_pnlRoadblock",
+      "windowsxlive.net##div[style=\"width: 160px; height: 600px; margin-left: 12px; margin-top: 16px;\"]",
+      "windowsxlive.net##div[style=\"width: 336px; height: 380px; float: right; margin-top: 6px;\"]",
+      "windowsxlive.net##p[style=\"padding-left: 80px; color: white; position: relative; top: -36px;\"]",
+      "winsupersite.com###footerLinks > table[width=\"100%\"]:first-child",
+      "winsupersite.com##td[style=\"border-top: 1px none rgb(224, 224, 224); color: rgb(0, 0, 0); font-weight: normal; font-style: normal; font-family: sans-serif; font-size: 8pt; padding-right: 3px; padding-bottom: 3px; padding-top: 3px; text-align: left;\"]",
+      "wirelessforums.org##td[width=\"160\"][valign=\"top\"]",
+      "wordreference.com##.bannertop",
+      "worksopguardian.co.uk###banner01",
+      "worldmag.com##a[href*=\"/counter.cfm?ad=\"]",
+      "worldmag.com##a[onclick*=\"/counter.cfm?ad=\"]",
+      "worthingherald.co.uk###banner01",
+      "wow.com###topleader-wrap",
+      "wow.com##.medrect",
+      "wsj.com##.spn_links_box",
+      "wunderground.com##div[style^=\"background: transparent url(http://icons-pe.wxug.com/graphics/statefarm_bg.gif)\"]",
+      "wwtdd.com##.post_insert",
+      "xbox360rally.com###topbanner",
+      "xml.com###leaderboard",
+      "xml.com##.recommended_div2",
+      "xml.com##.secondary[width=\"153\"][bgcolor=\"#efefef\"]",
+      "yahoo.com###ad",
+      "yahoo.com###marketplace",
+      "yahoo.com###ygmapromo",
+      "yahoo.com###yn-gmy-promo-answers",
+      "yahoo.com###yn-gmy-promo-groups",
+      "yahoo.com###yschsec > h2 + ul > li",
+      "yahoo.com##.fpad",
+      "yahoo.com##.overture",
+      "yahoo.com##.ovtmainbody",
+      "yahoo.com##.ovtsponsor",
+      "yahoo.com##.type_miniad",
+      "yahoo.com##.y708-commpartners",
+      "yahoo.com##.yschbbox",
+      "yahoo.com##.yschspns",
+      "yahoo.com##.ysmcm",
+      "yahoo.com##div[id^=\"y708-ad-\"]",
+      "yahoo.com##div[id^=\"y708-advertorial-\"]",
+      "yahoo.com##div[id^=\"y708-promo-\"]",
+      "yatsoba.com##.sponsors",
+      "yauba.com##a[onclick^=\"on_moo(\"][onclick*=\".ask.com/r?\"]",
+      "yorkshireeveningpost.co.uk###banner01",
+      "yorkshirepost.co.uk###banner01",
+      "yourtomtom.com##div[style^=\"border\"][style*=\"rgb(180, 195, 154)\"][style*=\"background: rgb(249, 252, 241)\"]",
+      "youtube.com###chrome-promo",
+      "youtube.com###feedmodule-PRO",
+      "youtube.com###homepage-chrome-side-promo",
+      "youtube.com###search-pva",
+      "youtube.com###watch-buy-urls",
+      "youtube.com##.searchView.list-view",
+      "zam.com##a[href^=\"http://ad.doubleclick.net/clk\"]",
+      "zam.com##a[id^=\"skinlink\"]",
+      "zdnet.com###pplayLinks",
+      "zdnet.com##.hotspot",
+      "zdnet.com##.promoBox",
+      "zeenews.com###NewBanner",
+      "zeenews.com##.ban-720-container",
+      "zeenews.com##div[style=\"height: 40px; width: 690px; float: right; text-align: left; margin-right: 10px; margin-bottom: 5px; position: relative;\"]",
+      "zomganime.com##div[style*=\"background-color: rgb(153, 153, 153);\"][style*=\"width: 300px;\"][style*=\"height: 250px;\"]",
+      "zomganime.com##div[style*=\"overflow: hidden;\"][style*=\"background-color: rgb(239, 239, 239);\"][style*=\"width: 728px;\"][style*=\"height: 90px;\"]",
+      "zomganime.com##marquee[width=\"160\"]",
+      "zone.msn.com##.SuperBannerTVMain",
+      "zuploads.com##.hispeed",
+      "!---------------------------------Exception rules to fix problems----------------------------------!",
+      "! *** easylist_whitelist.txt ***",
+      "@@||2mdn.net/*_ecw_$image,domain=wwe.com",
+      "@@||2mdn.net/crossdomain.xml$object_subrequest,domain=imdb.com",
+      "@@||2mdn.net/viewad/817-grey.gif$object_subrequest,domain=imdb.com",
+      "@@||a.giantrealm.com/assets/vau/grplayer*.swf$object",
+      "@@||ad.gogopin.com^$~document",
+      "@@||ad3.liverail.com^$object_subrequest,domain=seesaw.com",
+      "@@||adap.tv/redir/client/adplayer.swf?$object_subrequest,domain=egreetings.com|ehow.com|xxlmag.com",
+      "@@||addictinggames.com/jsource/ad_functions.js$script",
+      "@@||adjuggler.com^$script,domain=videodetective.com",
+      "@@||adm.fwmrm.net^$object_subrequest",
+      "@@||ads.adap.tv/control?$object_subrequest,domain=xxlmag.com",
+      "@@||ads.adap.tv/crossdomain.xml$object_subrequest,domain=xxlmag.com",
+      "@@||ads.adultswim.com/js.ng/site=toonswim&toonswim_pos=600x400_ctr&toonswim_rollup=games$script",
+      "@@||ads.ahds.ac.uk^$~document",
+      "@@||ads.cnn.com/js.ng/*&cnn_intl_subsection=download$script",
+      "@@||ads.forbes.com/realmedia/ads/*@videopreroll$script",
+      "@@||ads.fox.com/fox/black_2sec_600.flv$object_subrequest",
+      "@@||ads.hulu.com^*.flv$object_subrequest",
+      "@@||ads.hulu.com^*.swf$object_subrequest",
+      "@@||ads.imeem.com^$object_subrequest",
+      "@@||ads.morningstar.com/realmedia/ads/adstream_lx.ads/www.morningstar.com/video/$object_subrequest",
+      "@@||ads.yimg.com^*/any/yahoologo$image",
+      "@@||ads.yimg.com^*/search/b/syc_logo_2.gif$image",
+      "@@||ads.yimg.com^*videoadmodule*.swf$object_subrequest",
+      "@@||ads1.msn.com/library/dap.js$script,domain=msnbc.msn.com|wowarmory.com",
+      "@@||adsatt.abc.starwave.com^$object_subrequest",
+      "@@||adserver.adtech.de/crossdomain.xml$object_subrequest,domain=deluxetelevision.com",
+      "@@||adserver.bigwigmedia.com/ingamead3.swf$object_subrequest",
+      "@@||adserver.yahoo.com/a?*&l=head&$script,domain=yahoo.com",
+      "@@||adserver.yahoo.com/a?*=headr$script,domain=mail.yahoo.com",
+      "@@||adtech.de/crossdomain.xml$object_subrequest,domain=gigwise.com|nelonen.fi",
+      "@@||affiliates.jlist.com/ads/img_$image,domain=jlist.com",
+      "@@||affiliates.quintura.com^*.php?$object_subrequest,script,xmlhttprequest",
+      "@@||apple.com^*/adswap.js$script",
+      "@@||ar.atwola.com/file/adswrapper.js$script,domain=gasprices.mapquest.com",
+      "@@||as.webmd.com/html.ng/transactionid=$object_subrequest",
+      "@@||assets.idiomag.com/flash/adverts/yume_$object_subrequest",
+      "@@||autotrader.co.nz/data/adverts/$image",
+      "@@||belointeractive.com^*/ads/*@*?|$script",
+      "@@||bitgravity.com/revision3/swf/player/admanager.swf?$object_subrequest,domain=area5.tv",
+      "@@||brothersoft.com/gads/coop_show_download.php?soft_id=$script",
+      "@@||chloe.videogamer.com/data/*/videos/adverts/$object_subrequest",
+      "@@||cinshare.com/js/isalive.js?$script",
+      "@@||cnet.com/ads/common/adclient/*.swf$object_subrequest",
+      "@@||cpalead.com/mygateway.php?pub=$script,domain=superfastfile.com|videodownloadx.com",
+      "@@||cubeecraft.com/images/home/features/300x250/$image",
+      "@@||d1.openx.org/ajs.php?zoneid=25815&$script,domain=rottentomatoes.com",
+      "@@||dart.clearchannel.com/html.ng/$object_subrequest,domain=radio1045.com",
+      "@@||deviantart.com/global/difi/?$subdocument",
+      "@@||direct.fairfax.com.au/hserver/*/site=vid.*/adtype=embedded/$script",
+      "@@||doubleclick.net/ad/*smartclip$script,domain=last.fm",
+      "@@||doubleclick.net/adj/*smartclip$script,domain=last.fm",
+      "@@||doubleclick.net/adj/imdb2.consumer.video/*;sz=320x240,$script",
+      "@@||doubleclick.net/adj/nbcu.nbc/videoplayer-$script",
+      "@@||doubleclick.net/adj/pong.all/*;dcopt=ist;$script",
+      "@@||doubleclick.net/pfadx/channel.video.crn/;*;cue=pre;$object_subrequest",
+      "@@||doubleclick.net/pfadx/umg.*;sz=10x$script",
+      "@@||doubleclick.net^*/adj/wwe.shows/ecw_ecwreplay;*;sz=624x325;$script",
+      "@@||doubleclick.net^*/listen/*;sz=$script,domain=last.fm",
+      "@@||dyncdn.buzznet.com/catfiles/?f=dojo/*.googleadservices.$script",
+      "@@||ebayrtm.com/rtm?rtmcmd&a=json&cb=parent.$script",
+      "@@||edgar.pro-g.co.uk/data/*/videos/adverts/$object_subrequest",
+      "@@||empireonline.com/images/image_index/300x250/$background,image",
+      "@@||espn.go.com^*/espn360/banner?$subdocument",
+      "@@||eyewonder.com^$object,script,domain=last.fm",
+      "@@||facepunch.com/ad/$script",
+      "@@||facepunch.com/ads/$image,stylesheet",
+      "@@||fdimages.fairfax.com.au^*/ffxutils.js$domain=thevine.com.au",
+      "@@||feeds.videogamer.com^*/videoad.xml?$object_subrequest",
+      "@@||flyordie.com^*&affiliate$subdocument",
+      "@@||freeonlinegames.com/advertising/google-loader.swf?$object",
+      "@@||gannett.gcion.com/addyn/3.0/*/adtech;alias=pluck_signin$script",
+      "@@||garrysmod.org/ads/$background,image,script,stylesheet",
+      "@@||gr.burstnet.com/crossdomain.xml$object_subrequest,domain=filefront.com",
+      "@@||guim.co.uk^*/styles/wide/google-ads.css$stylesheet",
+      "@@||gws.ign.com/ws/search?*&google_adpage=$script",
+      "@@||i.cdn.turner.com^*/adserviceadapter.swf$object",
+      "@@||i.real.com/ads/*.swf?clicktag=$object_subrequest,domain=rollingstone.com",
+      "@@||ign.com/js.ng/size=headermainad&site=teamxbox$script,domain=teamxbox.com",
+      "@@||ikea.com/ms/img/ads/services/$image",
+      "@@||im.mstar.com/ads/*.flv$object_subrequest",
+      "@@||imdb.com/images/*/js/ads.js$script",
+      "@@||img.thedailywtf.com/images/ads/$image",
+      "@@||img.weather.weatherbug.com^*/stickers/$background,image,stylesheet",
+      "@@||jobs.wa.gov.au/images/advertimages/$background,image",
+      "@@||last.fm/ads.php?zone=*listen$subdocument",
+      "@@||lightningcast.net/servlets/getplaylist?*&responsetype=asx&$object",
+      "@@||liverail.com/crossdomain.xml$object_subrequest",
+      "@@||liverail.com/swf/*/plugins/flowplayer/$object_subrequest",
+      "@@||m1.2mdn.net^*/dartshell8_9.swf$object_subrequest,domain=vladtv.com",
+      "@@||mads.cbs.com/mac-ad?$object_subrequest",
+      "@@||mads.com.com/ads/common/faith/*.xml$object_subrequest",
+      "@@||media-imdb.com/images/*/js/ads.js$script,domain=imdb.com",
+      "@@||media.salemwebnetwork.com/js/admanager/swfobject.js$script,domain=christianity.com",
+      "@@||media.washingtonpost.com/wp-srv/ad/ad_v2.js$script",
+      "@@||media.washingtonpost.com/wp-srv/ad/tiffany_manager.js$script",
+      "@@||motherjones.com/files/resized/files/*300x250$image",
+      "@@||mozilla.com/img/tignish/plugincheck/*/728_90/loading.png$image,domain=mozilla.com",
+      "@@||newgrounds.com/ads/ad_medals.gif$image",
+      "@@||newsarama.com/common/js/advertisements.js$script",
+      "@@||newsweek.com/ads/adscripts/prod/*_$script",
+      "@@||nick.com/js/ads.jsp$script",
+      "@@||o.aolcdn.com/ads/adswrapper.js$script,domain=photos.tmz.com",
+      "@@||oas.absoluteradio.co.uk/realmedia/ads/$object_subrequest",
+      "@@||oas.bigflix.com/realmedia/ads/$object_subrequest",
+      "@@||oas.five.tv/realmedia/ads/adstream_sx.ads/demand.five.tv/$object_subrequest",
+      "@@||oascentral.feedroom.com/realmedia/ads/adstream_sx.ads/$script,domain=businessweek.com|economist.com|feedroom.com|stanford.edu",
+      "@@||oascentral.upi.com^$object_subrequest",
+      "@@||objects.tremormedia.com/embed/js/$script,domain=deluxetelevision.com",
+      "@@||objects.tremormedia.com/embed/swf/acudeoplayer.swf$object,domain=deluxetelevision.com",
+      "@@||objects.tremormedia.com/embed/swf/admanager*.swf$object_subrequest",
+      "@@||objects.tremormedia.com/embed/xml/*.xml?r=$object_subrequest,domain=mydamnchannel.com",
+      "@@||omnikool.discovery.com/realmedia/ads/adstream_mjx.ads/dsc.discovery.com/$script",
+      "@@||pagead2.googlesyndication.com/pagead/expansion_embed.js$script,domain=myspace.com",
+      "@@||pagead2.googlesyndication.com/pagead/scache/show_invideo_ads.js$script,domain=sciencedaily.com",
+      "@@||pagead2.googlesyndication.com/pagead/show_ads.js$script,domain=myspace.com",
+      "@@||pagead2.googlesyndication.com/pagead/static?format=in_video_ads&$subdocument,domain=sciencedaily.com",
+      "@@||quit.org.au/images/images/ad/$image",
+      "@@||redir.adap.tv/redir/client/adplayer.swf?$object_subrequest,domain=cracked.com|videosift.com",
+      "@@||rosauers.com/locations/ads.html$subdocument",
+      "@@||sankakucomplex.com/img/www/d/spcjs.php?id=$script",
+      "@@||sankakucomplex.com/wp-content/themes/*/sankaku.js?*&adname=*&spc=/spc.php?",
+      "@@||seavideo-ak.espn.go.com/ads/$object_subrequest",
+      "@@||seesaw.com/cp/c4/realmedia/ads/adstream_sx.ads/$xmlhttprequest",
+      "@@||serve.vdopia.com/adserver/ad*.php$object_subrequest,script,xmlhttprequest",
+      "@@||server.cpmstar.com/adviewas3.swf?contentspotid=$object_subrequest,domain=armorgames.com|freewebarcade.com",
+      "@@||server.cpmstar.com/view.aspx?poolid=$script,domain=newgrounds.com",
+      "@@||sfx-images.mozilla.org^$image,domain=spreadfirefox.com",
+      "@@||shockwave.com/js/ad_functions.js$script",
+      "@@||smartadserver.com/call/pubj/*/affiliate_id$script,domain=deezer.com",
+      "@@||smartadserver.com/def/def/showdef.asp$script,domain=deezer.com",
+      "@@||smartclip.net/delivery/tag?sid=$script,domain=last.fm",
+      "@@||sonicstate.com/video/hd/hdconfig-geo.cfm?*/www/delivery/$object_subrequest",
+      "@@||sp.ltassrv.com.s3.amazonaws.com^$object_subrequest,domain=animecrazy.net",
+      "@@||spike.com/consolidation/spike-functions.js?*/js/ads.js$script",
+      "@@||static.2mdn.net^*.xml$object_subrequest,domain=photoradar.com|youtube.com",
+      "@@||static.ak.fbcdn.net^*/ads/$script",
+      "@@||superfundo.org/advertisement.js$script",
+      "@@||telegraphcouk.skimlinks.com/api/telegraph.skimlinks.js$script",
+      "@@||thenewsroom.com^*/advertisement.xml$object_subrequest",
+      "@@||theonion.com/ads/video-ad/$object_subrequest",
+      "@@||thesmokinggun.com/includes2/de/video/sync.$object_subrequest",
+      "@@||thestreet.com/js/ads/adplacer.js$script",
+      "@@||timeinc.net/people/static/i/advertising/getpeopleeverywhere-news.gif$background,domain=people.com|peoplestylewatch.com",
+      "@@||timeinc.net^*/tii_ads.js$script,domain=ew.com",
+      "@@||trutv.com/includes/banners/de/video/sync.$object_subrequest",
+      "@@||tvgorge.com^*/adplayer.swf$object",
+      "@@||tvnz.co.nz/stylesheets/tvnz/lib/js/advertisement.js$script",
+      "@@||ultrabrown.com/images/adheader.jpg$image",
+      "@@||upload.wikimedia.org/wikipedia/commons/",
+      "@@||utarget.co.uk/crossdomain.xml$object_subrequest,domain=tvcatchup.com",
+      "@@||v.fwmrm.net/ad/p/1?$object_subrequest,domain=mlb.com",
+      "@@||v.fwmrm.net/crossdomain.xml$object_subrequest,domain=mlb.com",
+      "@@||video.nbcuni.com/ads/$object_subrequest",
+      "@@||vortex.accuweather.com/adc2004/pub/ads/js/ads-2006_vod.js$script",
+      "@@||vox-static.liverail.com/swf/*/admanager.swf$object_subrequest",
+      "@@||weather.com/common/a2/oasadframe.html?position=pagespon$subdocument",
+      "@@||weather.com/common/a2/oasadframe.html?position=pointspon$subdocument",
+      "@@||widget.slide.com^*/ads/*/preroll.swf$object_subrequest",
+      "@@||wrapper.teamxbox.com/a?size=headermainad&altlocdir=teamxbox$script",
+      "@@||yallwire.com/pl_ads.php?$object_subrequest",
+      "@@||yimg.com^*/java/promotions/js/ad_eo_1.1.js$script",
+      "@@||zedo.com/*.swf$object_subrequest,domain=rajshri.com",
+      "@@||zedo.com/*.xml$object_subrequest,domain=rajshri.com",
+      "@@||zedo.com//$object_subrequest,domain=rajshri.com",
+      "!Anti-Adblock",
+      "@@||arto.com/includes/js/adtech.de/script.axd/adframe.js?$script",
+      "@@||avforums.com/forums/adframe.js$script",
+      "@@||cinshare.com/js/*ad_type$script",
+      "@@||dailykos.com/ads/adblocker.blogads.css$stylesheet",
+      "@@||eq2flames.com/adframe.js$script",
+      "@@||gdataonline.com/exp/textad.js$script",
+      "@@||hackers.co.id/adframe/adframe.js$script",
+      "@@||macobserver.com/js/adframe.js$script",
+      "@@||megavideodownloader.com/adimages/|$subdocument",
+      "@@||novamov.com/ads.js?*&ad_url=/adbanner$script",
+      "@@||onlinevideoconverter.com/scripts/advertisement.js$script",
+      "@@||superfastfile.com/adsense.js$script",
+      "@@||superfastfile.com/advertisement.js$script",
+      "@@||theteacherscorner.net/adiframe/ad.js$script",
+      "@@||tpmrpg.net/adframe.js$script",
+      "@@||video2mp3.net/img/adframe.js$script",
+      "@@||zshare.net/ads.js?*&ad_url=/adbanner$script",
+      "!Non-English",
+      "@@||adser.localport.it/banman.asp?zoneid=71$subdocument",
+      "@@||adswizz.com/www/delivery/$object_subrequest,domain=video.belga.be",
+      "@@||adtech.de/?adrawdata/3.0/*;|$object_subrequest,domain=nelonen.fi|tv2.dk",
+      "@@||adtech.de/crossdomain.xml$object_subrequest,domain=nelonen.fi|tv2.dk",
+      "@@||adtech.panthercustomer.com^*.flv$object_subrequest,domain=tv3.ie",
+      "@@||aka-cdn-ns.adtech.de^*.flv$object_subrequest,domain=tv3.ie",
+      "@@||amarillas.cl/advertise.do?$xmlhttprequest",
+      "@@||amarillas.cl/js/advertise/$script",
+      "@@||banneradmin.rai.it/js.ng/sezione_rai=barramenu$script",
+      "@@||bnrs.ilm.ee/www/delivery/fl.js$script",
+      "@@||e-planning.net/eb/*?*fvp=2&$object_subrequest,domain=clarin.com|emol.com",
+      "@@||fotojorgen.no/images/*/webadverts/$image",
+      "@@||openx.zomoto.nl/live/www/delivery/fl.js$script",
+      "@@||openx.zomoto.nl/live/www/delivery/spcjs.php?id=$script",
+      "@@||pagead2.googlesyndication.com/pagead/abglogo/abg-da-100c-000000.png$domain=janno.dk|nielco.dk",
+      "@@||ring.bg/adserver/adall.php?*&video_on_page=1$script"
+    ];
+
+    function runTest()
+    {
+      for each (let text in filters)
+        Filter.fromText(text);
+    }
+
+    function cleanup()
+    {
+      // Clear cache
+      Filter.knownFilters = {__proto__: null};
+    }
+
+    runTests(runTest, cleanup);
+  </script>
+</body>
+</html>

=== added file 'chrome/content/mochitest/tests/performance/matcher_init.html'
--- chrome/content/mochitest/tests/performance/matcher_init.html	1970-01-01 00:00:00 +0000
+++ chrome/content/mochitest/tests/performance/matcher_init.html	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2560 @@
+<!DOCTYPE HTML>
+<html>
+<head>
+  <title>Matcher initialization performance measurements</title>
+  <script type="application/x-javascript;version=1.7" src="common.js"></script>
+  <script type="application/x-javascript;version=1.7" src="../common.js"></script>
+  <script type="application/x-javascript;version=1.7" src="chrome://adblockplus/content/filterClasses.js"></script>
+  <script type="application/x-javascript;version=1.7" src="chrome://adblockplus/content/matcher.js"></script>
+</head>
+<body>
+  <p id="progress">Please wait while performance measurement is in progress... <span id="current"></span></p>
+
+  <pre id="result"></pre>
+
+  <script type="application/x-javascript;version=1.7">
+    let filters = [
+      "&ad_type_id=",
+      "-ad.html",
+      "-banner-ads/",
+      ".aspx?zoneid=*&task=",
+      ".au/_ads/",
+      ".au/ads/",
+      ".ca/ads/",
+      ".com/ad-",
+      ".com/ad/",
+      ".com/ads/",
+      ".com/ads?",
+      ".com/adv/",
+      ".com/advt/",
+      ".com/gad/",
+      ".com/gads/",
+      ".com/ss/ad/",
+      ".html?ad=",
+      ".net/_ads/",
+      ".net/ad/$~object_subrequest",
+      ".net/ads/",
+      ".net/adv/",
+      ".nz/ads/",
+      ".org/ads/",
+      ".org/gads/",
+      ".php?bannerid=",
+      ".php?zoneid=*&loc=",
+      ".swf?clicktag=",
+      ".tv/ads/",
+      ".uk/ads/",
+      ".us/ads/",
+      ".za/ads/",
+      "/*;cue=pre;$object_subrequest",
+      "/.adserv/*",
+      "/468xads.",
+      "/_adv.gif?",
+      "/_media/ads/*",
+      "/a8-ads/*",
+      "/aamsz=*/acc_random=",
+      "/aamsz=*/pageid=",
+      "/aamsz=*/position=",
+      "/abm.asp?z=",
+      "/abmw.asp?z=",
+      "/abmw.aspx",
+      "/acc_random=*/aamsz=",
+      "/ad-1.5.",
+      "/ad-amz.",
+      "/ad-box-single.",
+      "/ad-cdn.",
+      "/ad-frame.",
+      "/ad-iframe-wrapper.",
+      "/ad-inject/*",
+      "/ad-leaderboard.",
+      "/ad-loader-frame.",
+      "/ad-server/*",
+      "/ad-top-fr.",
+      "/ad-topbanner-single.",
+      "/ad-vertical-single.",
+      "/ad.asp?",
+      "/ad.aspx",
+      "/ad.cgi?",
+      "/ad.html",
+      "/ad.jsp?",
+      "/ad.mason?",
+      "/ad.php?",
+      "/ad.pl?z",
+      "/ad/?id=",
+      "/ad/adtech",
+      "/ad/banner",
+      "/ad/code",
+      "/ad/common",
+      "/ad/frame",
+      "/ad/google",
+      "/ad/header",
+      "/ad/iframe/*",
+      "/ad/img/*",
+      "/ad/inad",
+      "/ad/init",
+      "/ad/lrec",
+      "/ad/mercury",
+      "/ad/mrec",
+      "/ad/script/*",
+      "/ad/serve",
+      "/ad/side_",
+      "/ad/skyscraper",
+      "/ad/sponsor",
+      "/ad/text",
+      "/ad/view",
+      "/ad/wr.php",
+      "/ad160.php",
+      "/ad1x1home.",
+      "/ad2.aspx",
+      "/ad2.html",
+      "/ad350.html",
+      "/ad728.php",
+      "/ad728x15.",
+      "/ad?count=",
+      "/ad_banner_left/*",
+      "/ad_banner_right/*",
+      "/ad_configuration.",
+      "/ad_creatives.",
+      "/ad_engine?",
+      "/ad_feed.js?",
+      "/ad_forum_",
+      "/ad_frame.",
+      "/ad_functions.",
+      "/ad_google.",
+      "/ad_holder/*",
+      "/ad_iframe.",
+      "/ad_iframe_",
+      "/ad_insert.",
+      "/ad_js.php",
+      "/ad_label_",
+      "/ad_left.",
+      "/ad_legend_",
+      "/ad_manager.",
+      "/ad_notice.",
+      "/ad_page_frame.",
+      "/ad_rectangle_",
+      "/ad_refresher.",
+      "/ad_reloader_",
+      "/ad_right.",
+      "/ad_serv.",
+      "/ad_serve.",
+      "/ad_server.",
+      "/ad_server/*",
+      "/ad_sizes=",
+      "/ad_sky.",
+      "/ad_space.",
+      "/ad_square.",
+      "/ad_supertile/*",
+      "/ad_tag_",
+      "/ad_tile/*",
+      "/ad_top.",
+      "/ad_vert.",
+      "/ad_view_",
+      "/adbanner.",
+      "/adbanner/*",
+      "/adbanners/*",
+      "/adbot_promos/*",
+      "/adbox.gif",
+      "/adbrite.",
+      "/adbureau.",
+      "/adchannel_",
+      "/adclick.",
+      "/adclient.",
+      "/adclient/*",
+      "/adcode.",
+      "/adcodes/*",
+      "/adconfig.js",
+      "/adconfig.xml?",
+      "/adconfig/*",
+      "/adcontent.$~object_subrequest",
+      "/adcreative.",
+      "/adcycle.",
+      "/adcycle/*",
+      "/addelivery/*",
+      "/addyn/3.0/*",
+      "/addyn|*|adtech;",
+      "/adengage1.",
+      "/adengage_",
+      "/adengine/*",
+      "/adexclude/*",
+      "/adf.cgi?",
+      "/adfarm.",
+      "/adfetch?",
+      "/adfetcher?",
+      "/adfooter.",
+      "/adframe.",
+      "/adframe/*",
+      "/adframe?",
+      "/adframe_",
+      "/adfshow?",
+      "/adfunction.",
+      "/adfunctions.",
+      "/adgraphics/*",
+      "/adguru.",
+      "/adhandler/*",
+      "/adheader.",
+      "/adhomepage.jsp",
+      "/adhtml/*",
+      "/adiframe.",
+      "/adiframe/*",
+      "/adimage.aspx",
+      "/adimage.php?",
+      "/adimages.",
+      "/adimages/*",
+      "/adindex/*",
+      "/adinjector.",
+      "/adinsert.",
+      "/adinterax.",
+      "/adjs.php?",
+      "/adjsmp.php?",
+      "/adlabel.",
+      "/adlabel_",
+      "/adlayer.php?",
+      "/adlayer/*",
+      "/adleader.",
+      "/adlink.",
+      "/adlink_",
+      "/adlinks.",
+      "/adm/ad/*",
+      "/adman.js",
+      "/adman/image/*",
+      "/adman/www/*",
+      "/admanagement/*",
+      "/admanagementadvanced.",
+      "/admanager.$~object_subrequest",
+      "/admanager/*$~object_subrequest",
+      "/admanager3.",
+      "/admanagerstatus/*",
+      "/admaster.",
+      "/admaster?",
+      "/admedia.",
+      "/admentor/*",
+      "/admin/ad_",
+      "/adnetwork.",
+      "/adng.html",
+      "/adonline.",
+      "/adpage.",
+      "/adpage/*",
+      "/adpeeps.",
+      "/adpeeps/*",
+      "/adplayer.",
+      "/adplayer/*",
+      "/adplugin.",
+      "/adpoint.",
+      "/adpopup.",
+      "/adproducts/*",
+      "/adproxy.",
+      "/adproxy/*",
+      "/adrelated.",
+      "/adreload?",
+      "/adremote.",
+      "/adrevenue/*",
+      "/adrevolver/*",
+      "/adrolays.",
+      "/adroot/*",
+      "/adrot.js",
+      "/adruptive.",
+      "/ads-1.js",
+      "/ads-2.js",
+      "/ads-banner.",
+      "/ads-leader|",
+      "/ads-rec|",
+      "/ads-service.",
+      "/ads-sky|",
+      "/ads.asp?",
+      "/ads.dll/*",
+      "/ads.htm",
+      "/ads.php?",
+      "/ads/acctid",
+      "/ads/ad-",
+      "/ads/common/*",
+      "/ads/frame",
+      "/ads/freewheel/*",
+      "/ads/house/*",
+      "/ads/html",
+      "/ads/i_ads.",
+      "/ads/interstitial/*",
+      "/ads/java",
+      "/ads/labels/*",
+      "/ads/layer.",
+      "/ads/pa/*",
+      "/ads/paid",
+      "/ads/right",
+      "/ads/text",
+      "/ads/top",
+      "/ads/www",
+      "/ads2.php",
+      "/ads2_2.",
+      "/ads_iframe.",
+      "/ads_php/*",
+      "/ads_reporting/*",
+      "/ads_v2.",
+      "/ads_yahoo.",
+      "/adsadclient31.",
+      "/adsadview.",
+      "/adsatt.",
+      "/adsbanner.",
+      "/adscluster.",
+      "/adscontent.",
+      "/adscontent2.",
+      "/adscript.",
+      "/adscripts/*",
+      "/adsearch.",
+      "/adsense.",
+      "/adsense/*",
+      "/adsense23.",
+      "/adsense24.",
+      "/adsense_",
+      "/adserve/*",
+      "/adserver.",
+      "/adserver/*",
+      "/adserver2.",
+      "/adserver2/*",
+      "/adserver?",
+      "/adserver_",
+      "/adserversolutions/*",
+      "/adservice|",
+      "/adserving.",
+      "/adsfac.",
+      "/adsfetch.",
+      "/adsfolder/*",
+      "/adshandler.",
+      "/adsheader.",
+      "/adshow?",
+      "/adsiframe/*",
+      "/adsign.",
+      "/adsimage/*",
+      "/adsinclude.",
+      "/adsinsert.",
+      "/adsky.php",
+      "/adslots.",
+      "/adslug_",
+      "/adsmanagement/*",
+      "/adsmanager/*",
+      "/adsnew.",
+      "/adsonar.",
+      "/adspace.",
+      "/adsponsor.",
+      "/adspro/*",
+      "/adsremote.",
+      "/adsreporting/*",
+      "/adssrv.",
+      "/adstorage.",
+      "/adstracking.",
+      "/adstream.",
+      "/adstream_nx.",
+      "/adswap.",
+      "/adswap/*",
+      "/adsync/*",
+      "/adsyndication.",
+      "/adsystem/*",
+      "/adtago.",
+      "/adtags.",
+      "/adtags/*",
+      "/adtagtranslator.",
+      "/adtech.",
+      "/adtech/*",
+      "/adtech;",
+      "/adtech_",
+      "/adtext.",
+      "/adtext_",
+      "/adtology.",
+      "/adtop.js",
+      "/adtrack/*",
+      "/adtraff.",
+      "/adtype.php?",
+      "/adunit.",
+      "/adunits/*",
+      "/adv-title.",
+      "/adv.asp?",
+      "/advert.",
+      "/advert/*",
+      "/advert?",
+      "/advert_",
+      "/advertise.",
+      "/advertise/*",
+      "/advertisement-",
+      "/advertisement.",
+      "/advertisement_",
+      "/advertisements/*",
+      "/advertisementview/*",
+      "/advertising.",
+      "/advertising/*",
+      "/advertising_js/*",
+      "/advertisingmanual.",
+      "/advertisment.",
+      "/advertize_on_",
+      "/advertorials/*",
+      "/advertpro/*",
+      "/adverts.",
+      "/adverts/*",
+      "/adverts_",
+      "/adview.",
+      "/adviewer.",
+      "/advision.",
+      "/advpartnerinit.",
+      "/advt.gif",
+      "/adworks.",
+      "/adworks/*",
+      "/adwrapper/*",
+      "/adwrapperiframe.",
+      "/aff_frame.",
+      "/affad?q=",
+      "/affads/*",
+      "/affilatebanner.",
+      "/affiliate*.php?",
+      "/affiliate/banners/*",
+      "/affiliate_banners/*",
+      "/affiliatebanners/*",
+      "/affiliates.*.aspx?",
+      "/affiliates/banner",
+      "/affiliatewiz/*",
+      "/affiliationcash.",
+      "/afimages.",
+      "/afr.php?",
+      "/ajax/ads/*",
+      "/ajrotator/*",
+      "/ajs.php?",
+      "/ak/ads/*",
+      "/annonser/*",
+      "/api/ads/*",
+      "/app/ads.js",
+      "/article_ad.",
+      "/aseadnshow.",
+      "/audioads/*",
+      "/auto_ad_change.",
+      "/ban_m.php?",
+      "/banimpress.",
+      "/banman.asp?",
+      "/banman/*",
+      "/banner/affiliate/*",
+      "/banner_ad.",
+      "/banner_ad_",
+      "/banner_ads.",
+      "/banner_ads_",
+      "/banner_control.php?",
+      "/banner_db.php?",
+      "/banner_file.php?",
+      "/banner_js.*?",
+      "/banner_management/*",
+      "/banner_skyscraper.",
+      "/bannerad.",
+      "/bannerads-",
+      "/bannerads/*",
+      "/banneradviva.",
+      "/bannercode.php",
+      "/bannerfarm/*",
+      "/bannerframe.*?",
+      "/bannermanager/*",
+      "/bannermedia/*",
+      "/bannerrotation.",
+      "/banners.*&iframe=",
+      "/banners/affiliate/*",
+      "/banners_rotation.",
+      "/bannerscript/*",
+      "/bannerserver/*",
+      "/bannersyndication.",
+      "/bannerview.*?",
+      "/bannery/*?banner=",
+      "/baselinead.",
+      "/behaviorads/*",
+      "/bg_ads_",
+      "/bigboxad.",
+      "/bkgrndads/*",
+      "/blogad_",
+      "/blogads.",
+      "/blogads3/*",
+      "/bmndoubleclickad.",
+      "/bnrsrv.*?",
+      "/boomad.",
+      "/bottomad/*",
+      "/br_ad_courier.",
+      "/butler.php?type=",
+      "/buttonads.",
+      "/buyclicks/*",
+      "/bw_adsys.",
+      "/bytemark_ad.",
+      "/cashad.",
+      "/cashad2.",
+      "/central/ads/*",
+      "/cgi-bin/ads/*",
+      "/chitika-ad?",
+      "/circads.",
+      "/cnnslads.",
+      "/cnwk.1d/ads/*",
+      "/commercial_horizontal.",
+      "/commercial_top.",
+      "/commercials/*",
+      "/common/ad/*",
+      "/common/ads/*",
+      "/contentad|",
+      "/contextad.",
+      "/controller/ads/*",
+      "/corner_ads/*",
+      "/country_ad.",
+      "/cpxads.",
+      "/ctamlive160x160.",
+      "/customad.",
+      "/cvs/ads/*",
+      "/dart_ads/*",
+      "/dartads.",
+      "/dc_ads.",
+      "/dcloadads/*",
+      "/deliver.nmi?",
+      "/deliverad/*",
+      "/deliverjs.nmi?",
+      "/delivery/ag.php",
+      "/descpopup.js",
+      "/direct_ads.",
+      "/directads.",
+      "/displayad.",
+      "/displayads/*",
+      "/dj_ad.js",
+      "/dne_ad.",
+      "/dnsads.html?",
+      "/doors/ads/*",
+      "/doubleclick.phpi?",
+      "/doubleclick/iframe.",
+      "/doubleclickcontainer.",
+      "/doubleclicktag.",
+      "/drawad.php?",
+      "/dsg/bnn/*",
+      "/dt.cms.ad.page.",
+      "/dyn_banner.",
+      "/dyn_banners_",
+      "/dynamicad?",
+      "/dynamiccsad?",
+      "/dynbanner/flash/*",
+      "/ebay_ads/*",
+      "/emailads/*",
+      "/external/ad.js",
+      "/eyewondermanagement.",
+      "/fatads.",
+      "/featuredadshome.",
+      "/files/ads/*",
+      "/fimserve.",
+      "/flash/ads/*",
+      "/flashads.",
+      "/flashads/*",
+      "/footad-",
+      "/footer_ad_include.",
+      "/fuseads/*",
+      "/gamersad.",
+      "/genericrichmediabannerad/*",
+      "/get-ad.php?",
+      "/get_player_ads_",
+      "/getad.php?",
+      "/getad.php|",
+      "/getad?n=",
+      "/getadframe.",
+      "/getadvertimageservlet?",
+      "/getarticleadvertimageservlet?",
+      "/getbanner.cfm?",
+      "/getsponslinks.",
+      "/getsponslinksauto.",
+      "/getvideoad.",
+      "/gfx/ads/*",
+      "/glam_ads.",
+      "/google-ad?",
+      "/google-ads.",
+      "/google-adsense-",
+      "/google-adsense.",
+      "/google_ad_",
+      "/google_ads.",
+      "/google_ads/*",
+      "/google_adsense.",
+      "/google_adsense_",
+      "/google_afc.",
+      "/googlead-",
+      "/googlead.",
+      "/googleadhtml/*",
+      "/googleads-",
+      "/googleads.html",
+      "/googleads.js",
+      "/googleads2.",
+      "/googleads_",
+      "/googleadsense.",
+      "/gt6skyadtop.",
+      "/hat_ad_label.",
+      "/homepage_ads/*",
+      "/housead/*",
+      "/houseads/*",
+      "/houseads?",
+      "/html.ng/*",
+      "/htmlads/*",
+      "/httpads/*",
+      "/icon_ad.",
+      "/iframe-ads/*",
+      "/iframe/ad/*",
+      "/iframe_ad.",
+      "/iframe_ads/*",
+      "/iframe_ads?",
+      "/iframe_chitika_",
+      "/iframead.",
+      "/im-ad/im-",
+      "/images/ad-",
+      "/images/ad/*",
+      "/images/ad_",
+      "/images/ads-",
+      "/images/ads/*",
+      "/img/ad_",
+      "/img/ads/*",
+      "/in/adv/*",
+      "/inc/ads/*",
+      "/include/ads/*",
+      "/includes/ad_",
+      "/includes/ads/*",
+      "/inline_ad.",
+      "/instreamad/*",
+      "/intextads.",
+      "/invideoad.",
+      "/ireel/ad*.jpg",
+      "/iwadsense.",
+      "/j/ads.js",
+      "/ji_advertise.",
+      "/jivoxadplayer.",
+      "/jlist-affiliates/*",
+      "/js.ng/c",
+      "/js.ng/s",
+      "/js/ad_eo_",
+      "/js/ads.js",
+      "/js/ads/*",
+      "/jsfiles/ads/*",
+      "/kredit-ad.",
+      "/layer-ad.",
+      "/layer-ads.",
+      "/layerads_",
+      "/layout/ads/*",
+      "/lbl_ad.",
+      "/leader_ad.",
+      "/links_sponsored_",
+      "/linkshare/*",
+      "/loadad.aspx?",
+      "/m4_advertorials/*",
+      "/m=advert/*",
+      "/mac-ad?",
+      "/magic-ads/*",
+      "/main/ad_",
+      "/mainad.",
+      "/mbn_ad.",
+      "/media/ads/*",
+      "/megaad.",
+      "/metaadserver/*",
+      "/miva_ads.",
+      "/mnetorfad.js",
+      "/mod_ad/*",
+      "/modules/ads/*",
+      "/mpumessage.",
+      "/mstextad?",
+      "/mtvi_ads_",
+      "/mylayer-ad/*",
+      "/neoads.",
+      "/new/ad/*",
+      "/newrightcolad.",
+      "/news_ad.",
+      "/newtopmsgad.",
+      "/nextad/*",
+      "/oasadframe.",
+      "/oascentral.$~object_subrequest",
+      "/oasdefault/*",
+      "/oasisi-*.php?",
+      "/oasisi.php?",
+      "/oiopub-direct/*",
+      "/openads-",
+      "/openads.",
+      "/openads/*",
+      "/openads2/*",
+      "/openx/www/*",
+      "/openx_fl.",
+      "/other/ads/*",
+      "/overlay_ad_",
+      "/ovt_show.asp?",
+      "/p2/ads/*",
+      "/page-ads.",
+      "/pagead/ads?*_fetch=",
+      "/pagead/ads?*_start_delay=1",
+      "/pageadimg/*",
+      "/pageads/*",
+      "/pageear.",
+      "/pageear/*",
+      "/pagepeel-",
+      "/pagepeel.",
+      "/pagepeel/*",
+      "/pagepeelads.",
+      "/paidlisting/*",
+      "/partnerbanner.",
+      "/partnerbanner/*",
+      "/peel.js",
+      "/peel1.js",
+      "/peelad/*",
+      "/peeljs.php",
+      "/perfads.",
+      "/performancingads/*",
+      "/phpads.",
+      "/phpads/*",
+      "/phpads2/*",
+      "/phpadserver/*",
+      "/phpadsnew/*",
+      "/pictures/ads/*",
+      "/pilot_ad.",
+      "/pitattoad.",
+      "/pix/ad/*",
+      "/play/ad/*",
+      "/popads.",
+      "/popunder.",
+      "/position=*/aamsz=",
+      "/premium_ad.",
+      "/printad.",
+      "/printads/*",
+      "/processads.",
+      "/promobuttonad.",
+      "/promotions/ads?",
+      "/protection/ad/*",
+      "/pub/ad/*",
+      "/pub/ads/*",
+      "/public/ad/*",
+      "/public/ad?",
+      "/publicidad.$~object_subrequest",
+      "/publicidad/*",
+      "/pyv_watch_request_ad.",
+      "/questions/ads/*",
+      "/radopenx?",
+      "/railads.",
+      "/random=*/aamsz=",
+      "/realmedia/ads/*",
+      "/rec_ad1.",
+      "/reclame/*",
+      "/reklam.",
+      "/reklama.",
+      "/relatedads.",
+      "/requestadvertisement.",
+      "/requestmyspacead.",
+      "/rightad.",
+      "/rotateads.",
+      "/rotatingpeels.js",
+      "/rsads/c",
+      "/rsads/r",
+      "/scripts/ad-",
+      "/scripts/ad.",
+      "/scripts/ads/*",
+      "/scripts/clickjs.php",
+      "/search/ads?",
+      "/searchads/*",
+      "/services/ads/*",
+      "/sevenl_ad.",
+      "/share/ads/*",
+      "/shared/ads/*",
+      "/show_ad.",
+      "/show_ad_",
+      "/show_ads.js?",
+      "/show_ads_",
+      "/show_afs_ads.",
+      "/showad.",
+      "/showad/*",
+      "/showads.",
+      "/showflashad.",
+      "/showlayer.",
+      "/sideads/*",
+      "/sideads|",
+      "/sidebarad/*",
+      "/sidecol_ad.",
+      "/silver/ads/*",
+      "/siteads.",
+      "/siteafs.txt?",
+      "/sites/ad_",
+      "/skyad.php",
+      "/skyadjs/*",
+      "/slideinad.",
+      "/small_ad.",
+      "/smartad.",
+      "/socialads.",
+      "/socialads/*",
+      "/spc.php?",
+      "/spcjs.php?",
+      "/special-ads/*",
+      "/special_ads/*",
+      "/spo_show.asp?",
+      "/sponsimages/*",
+      "/sponslink_",
+      "/sponsor-ad|",
+      "/sponsorad.",
+      "/sponsoradds/*",
+      "/sponsorads/*",
+      "/sponsored_links_",
+      "/sponsored_text.",
+      "/sponsoredlinks.",
+      "/sponsoredlinks/*",
+      "/square-ads/*",
+      "/squaread.",
+      "/srv/ad/*",
+      "/static/ad_",
+      "/static/ads/*",
+      "/stickyad.",
+      "/storage/ads/*",
+      "/swf/ad-",
+      "/synad2.",
+      "/system/ad/*",
+      "/systemad.",
+      "/systemad_",
+      "/testingad.",
+      "/textad.",
+      "/textad?",
+      "/textads/*",
+      "/textads_",
+      "/thirdparty/ad/*",
+      "/tii_ads.",
+      "/tikilink?",
+      "/tmo/ads/*",
+      "/toigoogleads.",
+      "/toolkitads.",
+      "/top_ad.",
+      "/top_ads/*",
+      "/trackads/*",
+      "/tracked_ad.",
+      "/tradead_",
+      "/tribalad.",
+      "/ttz_ad.",
+      "/tx_macinabanners/*",
+      "/update_ads/*",
+      "/upload/ads/*",
+      "/uploads/ads/*",
+      "/valueclick.",
+      "/vclkads.",
+      "/video/ads/*",
+      "/video_ad.",
+      "/video_ad_right.",
+      "/videoad.",
+      "/videoads.",
+      "/videoads/*",
+      "/videowall-ad.",
+      "/view/banner/*/zone?zid=",
+      "/vr-ad.png",
+      "/vtextads.",
+      "/webad?a",
+      "/webadimg/*",
+      "/webads.",
+      "/webads_",
+      "/webadverts/*",
+      "/wipeads/*",
+      "/wp-content/ads/*",
+      "/wp-srv/ad/*",
+      "/wpads/iframe.",
+      "/writelayerad.",
+      "/www/delivery/*",
+      "/xmladparser.",
+      "/your-ad.",
+      "/ysmads.",
+      "/zanox/banner/*",
+      "/zanox_ad/*",
+      "8080/ads/",
+      ";iframeid=ad_",
+      "?*&ad_keyword=",
+      "?*&adname=",
+      "?*&adspace=",
+      "?*&clientype=*&adid=",
+      "?*&google_adpage=",
+      "?*&googleadword=",
+      "?ad_ids=*&referer=",
+      "?ad_type=",
+      "?ad_width=",
+      "?adarea=",
+      "?adclass=",
+      "?adpage=",
+      "?adtype=",
+      "?advertising=",
+      "?advtile=",
+      "?file=ads&",
+      "?getad=&$~object_subrequest",
+      "_ad.aspx",
+      "_ad.php?",
+      "_ad_big.",
+      "_ad_code.",
+      "_ads.php?",
+      "_ads_reporting.",
+      "_adserve/",
+      "_adspaces.",
+      "_adtitle.",
+      "_advert.",
+      "_advert1.",
+      "_blogads.",
+      "_box_ads/",
+      "_buttonad.",
+      "_companionad.",
+      "_custom_ad.",
+      "_custom_ad_sets.",
+      "_dynamicads/",
+      "_fd_adbg1a.",
+      "_fd_adbg2.",
+      "_fd_adbg2a.",
+      "_fd_adtop.",
+      "_overlay_ad.",
+      "_topad.php",
+      "_videoad.",
+      "a/adx.js",
+      "d/adx.js",
+      "e/adx.js",
+      "e/js.ng/",
+      "e/js_ng/",
+      "k/ads.pl",
+      "m/adbox/",
+      "m/ads.pl",
+      "m/adx.js",
+      "m/js.ng/",
+      "m/topads|",
+      "n/adx.js",
+      "r/ad.htm",
+      "s/adx.js",
+      "t/adx.js",
+      "u/adx.js",
+      "z/adx.js",
+      "|http://a.ads.",
+      "|http://ad-uk.",
+      "|http://ad.$~object_subrequest,domain=~europa.eu|~sjsu.edu|~uitm.edu.my|~uni-freiburg.de",
+      "|http://ad0.",
+      "|http://ad1.",
+      "|http://ad2.",
+      "|http://ad3.",
+      "|http://ad4.",
+      "|http://ad5.",
+      "|http://ad6.",
+      "|http://ad7.",
+      "|http://adimg.",
+      "|http://adnet.",
+      "|http://ads.",
+      "|http://ads0.",
+      "|http://ads1.",
+      "|http://ads2.",
+      "|http://ads3.",
+      "|http://ads4.",
+      "|http://ads5.",
+      "|http://adsrv.",
+      "|http://adsvr.",
+      "|http://adsys.",
+      "|http://adv.",
+      "|http://adver.",
+      "|http://bwp.*/search",
+      "|http://feeds.*/~a/",
+      "|http://getad.",
+      "|http://jazad.",
+      "|http://openx.",
+      "|http://rss.*/~a/",
+      "|http://synad.",
+      "|http://wrapper.*/a?",
+      "*-120x600*",
+      "*-160x600*",
+      "*-300x250*",
+      "*-336x280*",
+      "*-360x110.*",
+      "*-468_60.*",
+      "*-468x60-*",
+      "*-468x60.*",
+      "*-468x60/*",
+      "*-468x60_*",
+      "*-468x80-*",
+      "*-468x80.*",
+      "*-468x80/*",
+      "*-468x80_*",
+      "*-480x60-*",
+      "*-480x60.*",
+      "*-480x60/*",
+      "*-480x60_*",
+      "*-728x90-*",
+      "*-728x90.*",
+      "*-728x90/*",
+      "*-728x90_*",
+      "*.120x600*",
+      "*.160x600*",
+      "*.300x250*",
+      "*.336x280*",
+      "*.468x60-*",
+      "*.468x60.*",
+      "*.468x60/*",
+      "*.468x60_*",
+      "*.468x80-*",
+      "*.468x80.*",
+      "*.468x80/*",
+      "*.468x80_*",
+      "*.480x60-*",
+      "*.480x60.*",
+      "*.480x60/*",
+      "*.480x60_*",
+      "*.728x90-*",
+      "*.728x90.*",
+      "*.728x90/*",
+      "*.728x90_*",
+      "*/120x600*",
+      "*/160x600*",
+      "*/300x250*",
+      "*/336x280*",
+      "*/468by60*",
+      "*/468x60-*",
+      "*/468x60.*",
+      "*/468x60/*",
+      "*/468x60_*",
+      "*/468x80-*",
+      "*/468x80.*",
+      "*/468x80/*",
+      "*/468x80_*",
+      "*/480x60-*",
+      "*/480x60.*",
+      "*/480x60/*",
+      "*/480x60_*",
+      "*/728_90/*",
+      "*/728x90-*",
+      "*/728x90.*",
+      "*/728x90/*",
+      "*/728x90_*",
+      "*300x250.*",
+      "*468x60.g*",
+      "*468x60.j*",
+      "*468x60ba*",
+      "*728banne*",
+      "*728x90.g*",
+      "*728x90.h*",
+      "*728x90.j*",
+      "*728x90.p*",
+      "*728x90.s*",
+      "*_120_600*",
+      "*_120x60.*",
+      "*_120x600*",
+      "*_120x60_*",
+      "*_160x290*",
+      "*_160x600*",
+      "*_300x250*",
+      "*_336x280*",
+      "*_460x60.*",
+      "*_468-60.*",
+      "*_468.gif*",
+      "*_468.htm*",
+      "*_468_60.*",
+      "*_468_60_*",
+      "*_468x60-*",
+      "*_468x60.*",
+      "*_468x60/*",
+      "*_468x60_*",
+      "*_468x80-*",
+      "*_468x80.*",
+      "*_468x80/*",
+      "*_468x80_*",
+      "*_468x90.*",
+      "*_480x60-*",
+      "*_480x60.*",
+      "*_480x60/*",
+      "*_480x60_*",
+      "*_580x100*",
+      "*_720x90.*",
+      "*_728_90.*",
+      "*_728_90_*",
+      "*_728by90*",
+      "*_728x90-*",
+      "*_728x90.*",
+      "*_728x90/*",
+      "*_728x90_*",
+      "*_768x90_*",
+      "*e120x600*",
+      "*n728x90_*",
+      "||1100i.com^$third-party",
+      "||188server.com^$third-party",
+      "||247realmedia.com^$third-party",
+      "||2mdn.net^$third-party",
+      "||360ads.com^$third-party",
+      "||3rdads.com^$third-party",
+      "||43plc.com^$third-party",
+      "||600z.com^$third-party",
+      "||777seo.com^$third-party",
+      "||7search.com^$third-party",
+      "||aa.voice2page.com^$third-party",
+      "||accuserveadsystem.com^$third-party",
+      "||acf-webmaster.net^$third-party",
+      "||acronym.com^$third-party",
+      "||ad-flow.com^$third-party",
+      "||ad20.net^$third-party",
+      "||ad2games.com^$third-party",
+      "||ad4game.com^$third-party",
+      "||adaction.se^$third-party",
+      "||adaos-ads.net^$third-party",
+      "||adbard.net^$third-party",
+      "||adblade.com^$third-party",
+      "||adbrite.com^$third-party",
+      "||adbureau.net^$third-party",
+      "||adbutler.com^$third-party",
+      "||adcde.com^$third-party",
+      "||adcentriconline.com^$third-party",
+      "||adchap.com^$third-party",
+      "||adclickmedia.com^$third-party",
+      "||adcru.com^$third-party",
+      "||addynamo.com^$third-party",
+      "||adecn.com^$third-party",
+      "||adengage.com^$third-party",
+      "||adf01.net^$third-party",
+      "||adfactory88.com^$third-party",
+      "||adfrontiers.com^$third-party",
+      "||adfusion.com^$third-party",
+      "||adgardener.com^$third-party",
+      "||adgent007.com^$third-party",
+      "||adgine.net^$third-party",
+      "||adgroups.com^$third-party",
+      "||adhese.be^$third-party",
+      "||adhese.net^$third-party",
+      "||adicate.com^$third-party",
+      "||adinterax.com^$third-party",
+      "||adireland.com^$third-party",
+      "||adisfy.com^$third-party",
+      "||adisn.com^$third-party",
+      "||adition.com^$third-party",
+      "||adjal.com^$third-party",
+      "||adjug.com^$third-party",
+      "||adjuggler.com^$third-party",
+      "||adjuggler.net^$third-party",
+      "||adlink.net^$third-party",
+      "||admarketplace.net^$third-party",
+      "||admeld.com^$third-party",
+      "||admeta.com^$third-party",
+      "||admpads.com^$third-party",
+      "||adnet.biz^$third-party",
+      "||adnet.com^$third-party",
+      "||adnet.ru^$third-party",
+      "||adocean.pl^$third-party",
+      "||adoperator.com^$third-party",
+      "||adotube.com^$third-party",
+      "||adparlor.com^$third-party",
+      "||adperium.com^$third-party",
+      "||adpinion.com^$third-party",
+      "||adpionier.de^$third-party",
+      "||adpremo.com^$third-party",
+      "||adroll.com^$third-party",
+      "||ads-stats.com^$third-party",
+      "||ads4cheap.com^$third-party",
+      "||adsdk.com^$third-party",
+      "||adsensecamp.com^$third-party",
+      "||adserver.yahoo.com^$third-party",
+      "||adservinginternational.com^$third-party",
+      "||adsfactor.net^$third-party",
+      "||adsfast.com^$third-party",
+      "||adsforindians.com^$third-party",
+      "||adshopping.com^$third-party",
+      "||adshuffle.com^$third-party",
+      "||adsmarket.com^$third-party",
+      "||adsonar.com^$third-party",
+      "||adspeed.com^$third-party",
+      "||adsrevenue.net^$third-party",
+      "||adtaily.eu^$third-party",
+      "||adtech.de^$third-party",
+      "||adtechus.com^$third-party",
+      "||adtoll.com^$third-party",
+      "||adtology1.com^$third-party",
+      "||adtology2.com^$third-party",
+      "||adtology3.com^$third-party",
+      "||adtoma.com^$third-party",
+      "||adtrgt.com^$third-party",
+      "||adtrix.com^$third-party",
+      "||adult-adv.com^$third-party",
+      "||adultadworld.com^$third-party",
+      "||adversalservers.com^$third-party",
+      "||adverserve.net^$third-party",
+      "||advertarium.com.ua^$third-party",
+      "||adverticum.net^$third-party",
+      "||advertise.com^$third-party",
+      "||advertiseyourgame.com^$third-party",
+      "||advertising-department.com^$third-party",
+      "||advertising.com^$third-party",
+      "||advertlets.com^$third-party",
+      "||advertserve.com^$third-party",
+      "||advertstatic.com^$third-party",
+      "||advg.jp/$third-party",
+      "||adviva.net^$third-party",
+      "||advpoints.com^$third-party",
+      "||adxpower.com^$third-party",
+      "||adyoz.com^$third-party",
+      "||afcyhf.com^$third-party",
+      "||affiliate.com^$third-party",
+      "||affiliatefuel.com^$third-party",
+      "||affiliatefuture.com^$third-party",
+      "||affiliatesensor.com^$third-party",
+      "||affiliproducts.com^$third-party",
+      "||affinity.com^$third-party",
+      "||afy11.net^$third-party",
+      "||agentcenters.com^$third-party",
+      "||aggregateknowledge.com^$third-party",
+      "||aim4media.com^$third-party",
+      "||alimama.cn^$third-party",
+      "||alphagodaddy.com^$third-party",
+      "||amgdgt.com^$third-party",
+      "||anrdoezrs.net^$third-party",
+      "||apmebf.com^$third-party",
+      "||arcadebannerexchange.net^$third-party",
+      "||arcadebanners.com^$third-party",
+      "||arcadebe.com^$third-party",
+      "||arti-mediagroup.com^$third-party",
+      "||as5000.com^$third-party",
+      "||asklots.com^$third-party",
+      "||assoc-amazon.co.uk^$third-party",
+      "||assoc-amazon.com^$third-party",
+      "||atdmt.com^$third-party",
+      "||atwola.com^$third-party",
+      "||audienceprofiler.com^$third-party",
+      "||auditude.com^$third-party",
+      "||auspipe.com^$third-party",
+      "||avads.co.uk^$third-party",
+      "||avantlink.com^$third-party",
+      "||awaps.net^$third-party",
+      "||awin1.com^$third-party",
+      "||awltovhc.com^$third-party",
+      "||axill.com^$third-party",
+      "||azads.com^$third-party",
+      "||azjmp.com^$third-party",
+      "||azoogleads.com^$third-party",
+      "||backbeatmedia.com^$third-party",
+      "||bannerbank.ru^$third-party",
+      "||bannerconnect.com^$third-party",
+      "||bannerconnect.net^$third-party",
+      "||bannerlot.com^$third-party",
+      "||bannersmania.com^$third-party",
+      "||bbelements.com^$third-party",
+      "||begun.ru^$third-party",
+      "||belointeractive.com^$third-party",
+      "||bestofferdirect.com^$third-party",
+      "||bfast.com^$third-party",
+      "||bidvertiser.com^$third-party",
+      "||biemedia.com^$third-party",
+      "||bin-layer.de^$third-party",
+      "||bin-layer.ru^$third-party",
+      "||binlayer.de^$third-party",
+      "||bittads.com^$third-party",
+      "||blogad.com.tw^$third-party",
+      "||blogads.com^$third-party",
+      "||bloggerads.net^$third-party",
+      "||bluestreak.com^$third-party",
+      "||bmanpn.com^$third-party",
+      "||bnetworx.com^$third-party",
+      "||bnr.sys.lv^$third-party",
+      "||boo-box.com^$third-party",
+      "||boylesportsreklame.com^$third-party",
+      "||branchr.com^$third-party",
+      "||bravenetmedianetwork.com^$third-party",
+      "||bridgetrack.com^$third-party",
+      "||btrll.com^$third-party",
+      "||bu520.com^$third-party",
+      "||buildtrafficx.com^$third-party",
+      "||burstnet.com^$third-party",
+      "||buysellads.com^$third-party",
+      "||buzzparadise.com^$third-party",
+      "||c-on-text.com^$third-party",
+      "||c8.net.ua^$third-party",
+      "||captainad.com^$third-party",
+      "||casalemedia.com^$third-party",
+      "||cc-dt.com^$third-party",
+      "||cdna.tremormedia.com^$third-party",
+      "||cgecwm.org^$third-party",
+      "||checkm8.com^$third-party",
+      "||checkmystats.com.au^$third-party",
+      "||checkoutfree.com^$third-party",
+      "||chitika.net^$third-party",
+      "||cjt1.net^$third-party",
+      "||clash-media.com^$third-party",
+      "||claxonmedia.com^$third-party",
+      "||clickad.pl^$third-party",
+      "||clickbooth.com^$third-party",
+      "||clickexa.com^$third-party",
+      "||clickexperts.net^$third-party",
+      "||clickfuse.com^$third-party",
+      "||clickintext.net^$third-party",
+      "||clickthrucash.com^$third-party",
+      "||clixgalore.com^$third-party",
+      "||cogsdigital.com^$third-party",
+      "||collective-media.net^$third-party",
+      "||commission-junction.com^$third-party",
+      "||commissionmonster.com^$third-party",
+      "||conduit-banners.com^$third-party",
+      "||connectedads.net^$third-party",
+      "||connextra.com^$third-party",
+      "||contenture.com^$third-party",
+      "||contextuads.com^$third-party",
+      "||contextweb.com^$third-party",
+      "||cpaclicks.com^$third-party",
+      "||cpalead.com^$third-party",
+      "||cpays.com^$third-party",
+      "||cpmstar.com^$third-party",
+      "||cpuim.com^$third-party",
+      "||cpxinteractive.com^$third-party",
+      "||crispads.com^$third-party",
+      "||crowdgravity.com^$third-party",
+      "||ctrhub.com^$third-party",
+      "||cubics.com^$third-party",
+      "||d.m3.net^$third-party",
+      "||da.feedsportal.com^$third-party",
+      "||dbbsrv.com^$third-party",
+      "||decisionmark.com^$third-party",
+      "||decisionnews.com^$third-party",
+      "||deepmetrix.com^$third-party",
+      "||destinationurl.com^$third-party",
+      "||dexplatform.com^$third-party",
+      "||dgmaustralia.com^$third-party",
+      "||digitrevenue.com^$third-party",
+      "||dinclinx.com^$third-party",
+      "||directorym.com^$third-party",
+      "||directtrack.com^$third-party",
+      "||dl-rms.com^$third-party",
+      "||domainsponsor.com^$third-party",
+      "||doubleclick.net/pfadx/*.mtvi$object_subrequest,third-party",
+      "||doubleclick.net/pfadx/*adcat=$object_subrequest,third-party",
+      "||doubleclick.net^$object_subrequest,third-party,domain=addictinggames.com|atom.com|break.com|businessweek.com|cbs4denver.com|darkhorizons.com|eonline.com|fandango.com|foxbusiness.com|foxnews.com|g4tv.com|gametrailers.com|joblo.com|mtv.co.uk|myfoxphoenix.com|newsweek.com|nick.com|nytimes.com|play.it|ps3news.com|sbsun.com|shockwave.com|space.com|spike.com|thedailygreen.com|thedailyshow.com|thewire.com|washingtonpost.com|wired.com|wsj.com|wwe.com|youtube.com|zoomin.tv",
+      "||doubleclick.net^$~object_subrequest,third-party",
+      "||doubleclick.net^*;sz=$object_subrequest,third-party,domain=1up.com|breitbart.tv|digitaltrends.com|gamesradar.com|heavy.com|myspace.com|nbc.com|nfl.com",
+      "||dpbolvw.net^$third-party",
+      "||dt00.net^$third-party,domain=~marketgid.com",
+      "||e-planning.net^$third-party",
+      "||ebannertraffic.com^$third-party",
+      "||ebayobjects.com.au^$third-party",
+      "||ebayobjects.com^$third-party",
+      "||edge-dl.andomedia.com^$third-party",
+      "||egamingonline.com^$third-party",
+      "||ekmas.com^$third-party",
+      "||emediate.eu^$third-party",
+      "||emediate.se^$third-party",
+      "||ero-advertising.com^$third-party",
+      "||etology.com^$third-party",
+      "||euroclick.com^$third-party",
+      "||euros4click.de^$third-party",
+      "||exelator.com^$third-party",
+      "||exitexplosion.com^$third-party",
+      "||exitjunction.com^$third-party",
+      "||exponential.com^$third-party",
+      "||eyereturn.com^$third-party",
+      "||eyewonder.com^$third-party",
+      "||fairadsnetwork.com^$third-party",
+      "||fairfax.com.au^$~stylesheet,third-party",
+      "||falkag.net^$third-party",
+      "||fastclick.net^$third-party",
+      "||fimserve.com^$third-party",
+      "||firstadsolution.com^$third-party",
+      "||firstlightera.com^$third-party",
+      "||fixionmedia.com^$third-party",
+      "||flashtalking.com^$third-party",
+      "||fluxads.com^$third-party",
+      "||fmpub.net^$third-party",
+      "||footerslideupad.com^$third-party",
+      "||forms.aweber.com^$third-party",
+      "||forrestersurveys.com^$third-party",
+      "||friendlyduck.com^$third-party",
+      "||ftjcfx.com^$third-party",
+      "||funklicks.com^$third-party",
+      "||fusionads.net^$third-party",
+      "||fwmrm.net^$third-party",
+      "||g.doubleclick.net^$third-party",
+      "||game-advertising-online.com^$third-party",
+      "||gameads.com^$third-party",
+      "||gamecetera.com^$third-party",
+      "||gamersbanner.com^$third-party",
+      "||gannett.gcion.com^$third-party",
+      "||geo-idm.fr^$third-party",
+      "||geopromos.com^$third-party",
+      "||gestionpub.com^$third-party",
+      "||gimiclub.com^$third-party",
+      "||gklmedia.com^$third-party",
+      "||globaladsales.com^$third-party",
+      "||globaladv.net^$third-party",
+      "||go2media.org^$third-party",
+      "||googleadservices.com^$third-party",
+      "||grabmyads.com^$third-party",
+      "||gratisnetwork.com^$third-party",
+      "||gumgum.com^$third-party",
+      "||halogennetwork.com^$third-party",
+      "||havamedia.net^$third-party",
+      "||hb-247.com^$third-party",
+      "||hit-now.com^$third-party",
+      "||hopfeed.com^$third-party",
+      "||hosticanaffiliate.com^$third-party",
+      "||httpool.com^$third-party",
+      "||hypemakers.net^$third-party",
+      "||hypervre.com^$third-party",
+      "||ic-live.com^$third-party",
+      "||icdirect.com^$third-party",
+      "||imagesatlantic.com^$third-party",
+      "||imedia.co.il^$third-party",
+      "||imglt.com^$third-party",
+      "||imho.ru/$third-party",
+      "||imiclk.com^$third-party",
+      "||impact-ad.jp^$third-party",
+      "||impresionesweb.com^$third-party",
+      "||indiads.com^$third-party",
+      "||industrybrains.com^$third-party",
+      "||inetinteractive.com^$third-party",
+      "||infinite-ads.com^$third-party",
+      "||infolinks.com^$third-party",
+      "||innity.com^$third-party",
+      "||insightexpressai.com^$third-party",
+      "||inskinad.com^$third-party",
+      "||intellitxt.com^$third-party",
+      "||interclick.com^$third-party",
+      "||interpolls.com^$third-party",
+      "||investingchannel.com^$third-party",
+      "||ipromote.com^$third-party",
+      "||jangonetwork.com^$third-party",
+      "||jdoqocy.com^$third-party",
+      "||jumboaffiliates.com^$third-party",
+      "||justrelevant.com^$third-party",
+      "||kanoodle.com^$third-party",
+      "||kerg.net^$third-party",
+      "||ketoo.com^$third-party",
+      "||kitnmedia.com^$third-party",
+      "||klipmart.com^$third-party",
+      "||kontera.com^$third-party",
+      "||kqzyfj.com^$third-party",
+      "||lakequincy.com^$third-party",
+      "||lduhtrp.net^$third-party",
+      "||leadacceptor.com^$third-party",
+      "||ligatus.com^$third-party",
+      "||lightningcast.net^$~object_subrequest,third-party",
+      "||lingospot.com^$third-party",
+      "||linkbucks.com^$third-party",
+      "||linkexchange.com^$third-party",
+      "||linkshowoff.com^$third-party",
+      "||linkstorm.net^$third-party",
+      "||linksynergy.com^$third-party",
+      "||linkworth.com^$third-party",
+      "||linkz.net^$third-party",
+      "||liverail.com^$third-party",
+      "||liveuniversenetwork.com^$third-party",
+      "||ltassrv.com.s3.amazonaws.com^$third-party",
+      "||ltassrv.com^$third-party",
+      "||lzjl.com^$third-party",
+      "||madisonlogic.com^$third-party",
+      "||marketingsolutions.yahoo.com^$third-party",
+      "||maxserving.com^$third-party",
+      "||mb01.com^$third-party",
+      "||mbn.com.ua^$third-party",
+      "||media6degrees.com^$third-party",
+      "||mediag4.com^$third-party",
+      "||mediagridwork.com^$third-party",
+      "||medialand.ru^$third-party",
+      "||mediaonenetwork.net^$third-party",
+      "||mediaplex.com^$third-party",
+      "||mediatarget.com^$third-party",
+      "||medleyads.com^$third-party",
+      "||medrx.sensis.com.au^$third-party",
+      "||megaclick.com^$third-party",
+      "||mercuras.com^$third-party",
+      "||metaffiliation.com^$third-party",
+      "||mezimedia.com^$third-party",
+      "||microsoftaffiliates.net^$third-party",
+      "||milabra.com^$third-party",
+      "||mirago.com^$third-party",
+      "||miva.com^$third-party",
+      "||mktseek.com^$third-party",
+      "||mochiads.com/srv/",
+      "||money4ads.com^$third-party",
+      "||mootermedia.com^$third-party",
+      "||moregamers.com^$third-party",
+      "||moreplayerz.com^$third-party",
+      "||mpression.net^$third-party",
+      "||nabbr.com^$third-party",
+      "||nbjmp.com^$third-party",
+      "||neodatagroup.com^$third-party",
+      "||neoffic.com^$third-party",
+      "||net3media.com^$third-party",
+      "||netavenir.com^$third-party",
+      "||netseer.com^$third-party",
+      "||networldmedia.net^$third-party",
+      "||newsadstream.com^$third-party",
+      "||newtention.net^$third-party",
+      "||nexac.com^$third-party",
+      "||nicheads.com^$third-party",
+      "||northmay.com^$third-party",
+      "||nvero.net^$third-party",
+      "||nyadmcncserve-05y06a.com^$third-party",
+      "||obeus.com^$third-party",
+      "||obibanners.com^$third-party",
+      "||objects.tremormedia.com^$~object_subrequest,third-party",
+      "||objectservers.com^$third-party",
+      "||oclus.com^$third-party",
+      "||omg2.com^$third-party",
+      "||omguk.com^$third-party",
+      "||onads.com^$third-party",
+      "||onenetworkdirect.net^$third-party",
+      "||openx.net^$third-party",
+      "||openx.org^$third-party",
+      "||othersonline.com^$third-party",
+      "||overture.com^$third-party",
+      "||oxado.com^$third-party",
+      "||p-advg.com^$third-party",
+      "||pagead2.googlesyndication.com^$~object_subrequest,third-party",
+      "||paperg.com^$third-party",
+      "||partner.video.syndication.msn.com^$~object_subrequest,third-party",
+      "||partypartners.com^$third-party",
+      "||payperpost.com^$third-party",
+      "||pc-ads.com^$third-party",
+      "||peer39.net^$third-party",
+      "||pepperjamnetwork.com^$third-party",
+      "||perfb.com^$third-party",
+      "||performancingads.com^$third-party",
+      "||pgmediaserve.com^$third-party",
+      "||pgpartner.com^$third-party",
+      "||pheedo.com^$third-party",
+      "||picadmedia.com^$third-party",
+      "||pinballpublishernetwork.com^$third-party",
+      "||platinumadvertisement.com^$third-party",
+      "||playertraffic.com^$third-party",
+      "||pntra.com^$third-party",
+      "||pntrac.com^$third-party",
+      "||pntrs.com^$third-party",
+      "||pointroll.com^$third-party",
+      "||precisionclick.com^$third-party",
+      "||predictad.com^$third-party",
+      "||primaryads.com^$third-party",
+      "||pro-advertising.com^$third-party",
+      "||pro-market.net^$third-party",
+      "||probannerswap.com^$third-party",
+      "||prod.untd.com^$third-party",
+      "||profitpeelers.com^$third-party",
+      "||projectwonderful.com^$third-party",
+      "||proximic.com^$third-party",
+      "||psclicks.com^$third-party",
+      "||ptp.lolco.net^$third-party",
+      "||pubmatic.com^$third-party",
+      "||pulse360.com^$third-party",
+      "||qksrv.net^$third-party",
+      "||qksz.net^$third-party",
+      "||questionmarket.com^$third-party",
+      "||questus.com^$third-party",
+      "||quisma.com^$third-party",
+      "||radiusmarketing.com^$third-party",
+      "||rapt.com^$third-party",
+      "||rbcdn.com^$third-party",
+      "||realmedia.com^$third-party",
+      "||reelcentric.com^$third-party",
+      "||reklamz.com^$third-party",
+      "||resultlinks.com^$third-party",
+      "||revfusion.net^$third-party",
+      "||revresda.com^$third-party",
+      "||ricead.com^$third-party",
+      "||ringtonematcher.com^$third-party",
+      "||rmxads.com^$third-party",
+      "||roirocket.com^$third-party",
+      "||rotatingad.com^$third-party",
+      "||rover.ebay.com^*&adtype=$third-party",
+      "||rovion.com^$third-party",
+      "||ru4.com/$third-party",
+      "||rubiconproject.com^$third-party",
+      "||rwpads.com^$third-party",
+      "||sa.entireweb.com^$third-party",
+      "||safelistextreme.com^$third-party",
+      "||salvador24.com^$third-party",
+      "||sbaffiliates.com^$third-party",
+      "||scanscout.com^$third-party",
+      "||sendptp.com^$third-party",
+      "||sev4ifmxa.com^$third-party",
+      "||shareasale.com^$third-party",
+      "||shareresults.com^$third-party",
+      "||shinobi.jp^$third-party",
+      "||simply.com^$third-party",
+      "||skimlinks.com^$third-party",
+      "||smart.allocine.fr^$third-party",
+      "||smartadserver.com^$third-party",
+      "||smarttargetting.co.uk^$third-party",
+      "||smarttargetting.com^$third-party",
+      "||smarttargetting.net^$third-party",
+      "||smpgfx.com^$third-party",
+      "||snap.com^$third-party",
+      "||sochr.com^$third-party",
+      "||sociallypublish.com^$third-party",
+      "||socialmedia.com^$third-party",
+      "||socialspark.com^$third-party",
+      "||socialvibe.com^$third-party",
+      "||sonnerie.net^$third-party",
+      "||sparkstudios.com^$third-party",
+      "||specificclick.net^$third-party",
+      "||specificmedia.com^$third-party",
+      "||speedsuccess.net^$third-party",
+      "||spinbox.freedom.com^$third-party",
+      "||sponsorads.de^$third-party",
+      "||sponsoredtweets.com^$third-party",
+      "||sponsorpalace.com^$third-party",
+      "||sportsyndicator.com^$third-party",
+      "||spottt.com^$third-party",
+      "||spotxchange.com^$third-party,domain=~supernovatube.com",
+      "||srtk.net^$third-party",
+      "||sta-ads.com^$third-party",
+      "||stocker.bonnint.net^$third-party",
+      "||sublimemedia.net^$third-party",
+      "||survey-poll.com^$third-party",
+      "||tacoda.net^$third-party",
+      "||tailsweep.com^$third-party",
+      "||targetnet.com^$third-party",
+      "||targetpoint.com^$third-party",
+      "||targetspot.com^$third-party",
+      "||teracent.net^$third-party",
+      "||testnet.nl^$third-party",
+      "||text-link-ads.com^$third-party",
+      "||thewebgemnetwork.com^$third-party",
+      "||tiser.com^$third-party",
+      "||tkqlhce.com^$third-party",
+      "||total-media.net^$third-party",
+      "||tqlkg.com^$third-party",
+      "||tradedoubler.com^$third-party",
+      "||tradepub.com^$third-party",
+      "||trafficjunky.net^$third-party",
+      "||trafficmasterz.net^$third-party",
+      "||traveladvertising.com^$third-party",
+      "||travelscream.com^$third-party",
+      "||travidia.com^$third-party",
+      "||triadmedianetwork.com^$third-party",
+      "||tribalfusion.com^$third-party",
+      "||trigami.com^$third-party",
+      "||trker.com^$third-party",
+      "||twinplan.com^$third-party",
+      "||twittad.com^$third-party",
+      "||tyroo.com^$third-party",
+      "||udmserve.net^$third-party",
+      "||uimserv.net^$third-party",
+      "||unanimis.co.uk^$third-party",
+      "||unicast.com^$third-party",
+      "||unrulymedia.com^$third-party",
+      "||usemax.de^$third-party",
+      "||usercash.com^$third-party",
+      "||utarget.co.uk^$third-party",
+      "||v.movad.de^*/ad.xml$third-party",
+      "||valuead.com^$third-party",
+      "||valueclick.com^$third-party",
+      "||vcmedia.com^$third-party",
+      "||velmedia.net^$third-party",
+      "||verticalacuity.com^$third-party",
+      "||vibrantmedia.com^$third-party",
+      "||videoegg.com^$third-party",
+      "||videostrip.com^$~object_subrequest,third-party",
+      "||videostrip.com^*/admatcherclient.$object_subrequest,third-party",
+      "||vidpay.com^$third-party",
+      "||viglink.com^$third-party",
+      "||vipquesting.com^$third-party",
+      "||visitdetails.com^$third-party",
+      "||vpico.com^$third-party",
+      "||vs20060817.com^$third-party",
+      "||vsservers.net^$third-party",
+      "||webads.co.nz^$third-party",
+      "||webgains.com^$third-party",
+      "||webmasterplan.com^$third-party",
+      "||webtraffic.ttinet.com^$third-party",
+      "||wgreatdream.com^$third-party",
+      "||widgetbucks.com^$third-party",
+      "||widgets.fccinteractive.com^$third-party",
+      "||worlddatinghere.com^$third-party",
+      "||worthathousandwords.com^$third-party",
+      "||x4300tiz.com^$third-party",
+      "||xcelltech.com^$third-party",
+      "||xcelsiusadserver.com^$third-party",
+      "||xchangebanners.com^$third-party",
+      "||xgraph.net^$third-party",
+      "||yceml.net^$third-party",
+      "||yieldbuild.com^$third-party",
+      "||yieldmanager.com^$third-party",
+      "||yieldmanager.net^$third-party",
+      "||yottacash.com^$third-party",
+      "||yumenetworks.com^$third-party",
+      "||zangocash.com^$third-party",
+      "||zanox.com^$third-party",
+      "||zeads.com^$third-party",
+      "||zedo.com^$third-party",
+      "||zoomdirect.com.au^$third-party",
+      "||zxxds.net^$third-party",
+      "||ablacrack.com/popup-pvd.js$third-party",
+      "||adultfriendfinder.com/banners/$third-party",
+      "||advanced-intelligence.com/banner$third-party",
+      "||affil.mupromo.com^$third-party",
+      "||affiliate.astraweb.com^$third-party",
+      "||affiliates.a2hosting.com^$third-party",
+      "||affiliates.generatorsoftware.com^$third-party",
+      "||affiliates.jlist.com^$third-party",
+      "||affiliates.supergreenhosting.com^$third-party",
+      "||apple.com/itunesaffiliates/$third-party",
+      "||aweber.com/banners/$third-party",
+      "||b.sell.com^$third-party",
+      "||banner.1and1.com^$third-party",
+      "||banner.3ddownloads.com^$third-party",
+      "||banner.telefragged.com^$third-party",
+      "||banners.adultfriendfinder.com^$third-party",
+      "||banners.friendfinder.com^$third-party",
+      "||banners.getiton.com^$third-party",
+      "||banners.ixitools.com^$third-party",
+      "||bc.coupons.com^$third-party",
+      "||beta.down2crazy.com^$third-party",
+      "||box.anchorfree.net^$third-party",
+      "||buy.com^*/affiliate/$third-party",
+      "||cas.clickability.com^$third-party",
+      "||cashmakingpowersites.com^*/banners/$third-party",
+      "||cbanners.virtuagirlhd.com^$third-party",
+      "||cbclickbank.com/affiliate/$third-party",
+      "||connect.summit.co.uk^$third-party",
+      "||creatives.summitconnect.co.uk^$third-party",
+      "||datakl.com/banner/$third-party",
+      "||dianomioffers.co.uk/smartlinks.epl?$third-party",
+      "||dynw.com/banner$third-party",
+      "||enticelabs.com/el/$third-party",
+      "||eplreplays.com/wl/$third-party",
+      "||feedburner.com/~a/$third-party",
+      "||frontsight.com^*/banners/$third-party",
+      "||fugger.netfirms.com/moa.swf$third-party",
+      "||gfxa.sheetmusicplus.com^$third-party",
+      "||googlesyndication.com^*/domainpark.cgi?$third-party",
+      "||grammar.coursekey.com/inter/$third-party",
+      "||gsniper.com/images/$third-party",
+      "||hostingcatalog.com/banner.php?$third-party",
+      "||iselectmedia.com^*/banners/$third-party",
+      "||jlist.com/feed.php?affid=$third-party",
+      "||kallout.com^*.php?id=$third-party",
+      "||l.yimg.com^*&partner=*&url=$subdocument,third-party",
+      "||lastlocation.com/images/banner$third-party",
+      "||lightningcast.net^*/getplaylist?$object_subrequest,third-party",
+      "||liutilities.com/partners/affiliate/$third-party",
+      "||livejasmin.com/?t_id=*&psid=$third-party",
+      "||longtailvideo.com/adtonomy.swf$third-party",
+      "||longtailvideo.com/ltas.swf$third-party",
+      "||match.com^*/prm/$third-party",
+      "||mazda.com.au/banners/$third-party",
+      "||meta4-group.com^*/promotioncorner.js?$third-party",
+      "||metaboli.fr^*/adgude_$third-party",
+      "||mfeed.newzfind.com^$third-party",
+      "||missnowmrs.com/images/banners/$third-party",
+      "||my-dirty-hobby.com/getmdhlink.$third-party",
+      "||mydirtyhobby.com/?sub=$third-party",
+      "||mydirtyhobby.com/getmdhlink.$third-party",
+      "||mydirtyhobby.com/gpromo/$third-party",
+      "||mydirtyhobby.com^*/gpromo/$third-party",
+      "||myhpf.co.uk/banners/$third-party",
+      "||mytrafficstrategy.com/images/$third-party",
+      "||nzpages.co.nz^*/banners/$third-party",
+      "||nzphoenix.com/nzgamer/$third-party",
+      "||onegameplace.com/iframe.php$third-party",
+      "||play-asia.com/paos-$third-party",
+      "||plugins.longtailvideo.com/adtvideo.swf$third-party",
+      "||ppc-coach.com/jamaffiliates/$third-party",
+      "||pricegrabber.com/cb_table.php$third-party",
+      "||promos.fling.com^$third-party",
+      "||promote.pair.com^$third-party",
+      "||pub.betclick.com^$third-party",
+      "||pubs.hiddennetwork.com^$third-party",
+      "||r.kelkoo.com^$third-party",
+      "||rapidjazz.com/banner_rotation/$third-party",
+      "||rcm*.amazon.$third-party",
+      "||robofish.com/cgi-bin/banner.cgi?$third-party",
+      "||searchportal.information.com/?$third-party",
+      "||servali.net^$third-party",
+      "||smartclip.net/delivery/tag?$third-party",
+      "||thebigchair.com.au^$subdocument,third-party",
+      "||themis-media.com^*/sponsorships/$third-party",
+      "||ticketmaster.com/promotionalcontent/$third-party",
+      "||top5result.com/promo/$third-party",
+      "||toptenreviews.com/widgets/af_widget.js$third-party",
+      "||torrentfreebie.com/index.asp?pid=$third-party",
+      "||tosol.co.uk/international.php?$third-party",
+      "||unsereuni.at/resources/img/$third-party",
+      "||veospot.com^*.html$third-party",
+      "||vianadserver.com/xmlservice/overlaycampaigninfo.aspx?$third-party",
+      "||visit.homepagle.com^$third-party",
+      "||ws.amazon.*/widgets/q?$third-party",
+      "||xgaming.com/rotate*.php?$third-party",
+      "||1up.com^*/promos/",
+      "||216.151.186.5^*/serve.php?$domain=sendspace.com",
+      "||2cpu.com/2cpu/*side*.html",
+      "||4chan.org/support/gf_$image",
+      "||77.247.178.36/layer/$domain=movie2k.com",
+      "||a.giantrealm.com^",
+      "||a.thefreedictionary.com^",
+      "||about.com/0g/$subdocument",
+      "||ac2.msn.com^",
+      "||activewin.com^*/blaze_static2.",
+      "||ads.netlog.com^",
+      "||adserver.yahoo.com^",
+      "||adshare.freedocast.com^",
+      "||adultswim.com^*/admanager.swf?",
+      "||advt.manoramaonline.com^",
+      "||akipress.com/_ban/",
+      "||akipress.org/ban/",
+      "||akipress.org/bimages/",
+      "||allthelyrics.com^*/popup.js",
+      "||analytics.mmosite.com^",
+      "||animekuro.com/layout/google$subdocument",
+      "||animenewsnetwork.com^*.aframe?",
+      "||anonib.com/zimages/",
+      "||armorgames.com^*/banners/",
+      "||armorgames.com^*/site-skins/",
+      "||armorgames.com^*/siteskin.css",
+      "||athena-ads.wikia.com^",
+      "||azlyrics.com^*_az.js",
+      "||banner.atomicgamer.com^",
+      "||banners.expressindia.com^",
+      "||banners.sys-con.com^",
+      "||bbc.co.uk^*/bbccom.js?",
+      "||beingpc.com^*/banners/",
+      "||bit-tech.net/style/skin/$stylesheet",
+      "||blackberryforums.net/banners/",
+      "||blinkx.com/adhocnetwork/",
+      "||blinkx.com/f2/overlays/adhoc",
+      "||bloomberg.com^*/banner.js",
+      "||bnrs.ilm.ee^",
+      "||boyplz.com^*/layer.js",
+      "||break.com^*/sponsors/",
+      "||burnsoftware.info*/!",
+      "||c21media.net/uploads/flash/*.swf",
+      "||cdmediaworld.com*/!",
+      "||centos.org/donors/",
+      "||ciao.co.uk/load_file.php?",
+      "||click.livedoor.com^",
+      "||clk.about.com^",
+      "||cms.myspacecdn.com^*/splash_assets/",
+      "||codeasily.com^*/codeasily.js",
+      "||codeproject.com^*/adm/",
+      "||complexmedianetwork.com^*/takeovers/",
+      "||computerworld.com^*/jobroll/",
+      "||consumerreports.org^*/sx.js",
+      "||countrychannel.tv/telvos_banners/",
+      "||covertarget.com^*_*.php$subdocument",
+      "||crazymotion.net/video_*.php?key=",
+      "||crushorflush.com/html/promoframe.html",
+      "||da.feedsportal.com^*/a2.img$image",
+      "||dailymail.co.uk^*/promoboxes/",
+      "||dailymotion.com^*masscast/",
+      "||dcad.watersoul.com^",
+      "||demonoid.com/cached/ab_",
+      "||demonoid.com/cached/bnr_",
+      "||dig.abclocal.go.com/preroll/",
+      "||digdug.divxnetworks.com^",
+      "||dimshare.com/empire.",
+      "||distrowatch.com/images/czmor",
+      "||divxstage.net/images/download.png",
+      "||dl4all.com/data4.files/dpopupwindow.",
+      "||earthlink.net^*/promos/",
+      "||ebayrtm.com/rtm?",
+      "||ebuddy.com/banners/",
+      "||ebuddy.com/textlink.php?",
+      "||ebuddy.com/web_banners/",
+      "||ecommerce-journal.com/specdata.php?",
+      "||el33tonline.com^*/el33t_bg_",
+      "||episodic.com^*/logos/player-",
+      "||espn.vad.go.com^$domain=youtube.com",
+      "||eva.ucas.com^",
+      "||eweek.com/images/stories/marketing/",
+      "||excite.com/gca_iframe.html?",
+      "||expertreviews.co.uk/images/skins/",
+      "||ffiles.com/counters.js",
+      "||filefront.com/linkto/",
+      "||filetarget.com*/!",
+      "||filetarget.com^*_*.php$subdocument",
+      "||flyordie.com/games/free/b/*--?p=",
+      "||foxbusiness.com/html/google_homepage_promo",
+      "||freeworldgroup.com/banner",
+      "||fudzilla.com^*/banners/",
+      "||gamecopyworld.com*/!",
+      "||gametrailers.com^*/gt6_siteskin_$stylesheet",
+      "||geocities.com/js_source/",
+      "||geocities.yahoo.*/js/sq.",
+      "||getprice.com.au/searchwidget.aspx?$subdocument",
+      "||glam.com^*/affiliate/",
+      "||goauto.com.au/mellor/mellor.nsf/toy$subdocument",
+      "||grapevine.is/media/flash/*.swf",
+      "||gumtree.com^*/dart_wrapper_",
+      "||gwinnettdailypost.com/1.iframe.asp?",
+      "||hostsearch.com/creative/",
+      "||hotfrog.com/adblock.ashx?",
+      "||hummy.org.uk^*/brotator/",
+      "||i.com.com^*/vendor_bg_",
+      "||i.neoseeker.com/d/$subdocument",
+      "||i4u.com/_banner/",
+      "||ibanners.empoweredcomms.com.au^",
+      "||idg.com.au/images/*_promo$image",
+      "||idg.com.au^*_skin.jpg",
+      "||illimitux.net/js/abp.js",
+      "||images-amazon.com^*/marqueepushdown/",
+      "||imageshack.us/ym.php?$subdocument",
+      "||independent.co.uk/multimedia/archive/$subdocument",
+      "||infoseek.co.jp/isweb/clip.html",
+      "||interfacelift.com/inc_new/$subdocument",
+      "||internet.ziffdavis.com^",
+      "||iptools.com/sky.php",
+      "||itpro.co.uk/images/skins/",
+      "||jame-world.com^*/adv/",
+      "||jarkey.net^*/for_jarkey.",
+      "||jpost.com/images/*/promos/",
+      "||kermit.macnn.com^",
+      "||kestrel.ospreymedialp.com^",
+      "||kewlshare.com/reward.",
+      "||kitz.co.uk/files/jump2/",
+      "||labtimes.org/banner/",
+      "||linuxtopia.org/includes/$subdocument",
+      "||loaded.it^*/iframe_vid.",
+      "||loaded.it^*/my_banner",
+      "||lookbook.nu/sponsors_box.",
+      "||macobserver.com^*/deal_brothers/",
+      "||macworld.co.uk^*/textdeals/",
+      "||majorgeeks.com^*/banners/",
+      "||medhelp.org/hserver/",
+      "||mediafire.com^*/linkto/default-$subdocument",
+      "||mediafire.com^*/remove_ads.gif",
+      "||mediamgr.ugo.com^",
+      "||meetic.com/js/*/site_under_",
+      "||merriam-webster.com^*/accipiter.js",
+      "||mgnetwork.com/dealtaker/",
+      "||mirror.co.uk^*/gutters/",
+      "||mirror.co.uk^*/m4_gutters/",
+      "||mirror.co.uk^*/m4_partners/",
+      "||mmorpg.com/images/skins/",
+      "||mp3mediaworld.com*/!",
+      "||msn.com/?adunitid",
+      "||musictarget.com*/!",
+      "||myspace.com^*.adtooltip&",
+      "||myway.com/gca_iframe.html",
+      "||nearlygood.com^*/_aff.php?",
+      "||news.com.au/news/vodafone/$object",
+      "||news.com.au^*-promo$image",
+      "||news.com.au^*/promos/",
+      "||nirsoft.net/banners/",
+      "||ntdtv.com^*/adv/",
+      "||nymag.com^*/metrony_",
+      "||nytimes.com/adx/",
+      "||ocforums.com/adj/",
+      "||ocp.com.com/ad.js",
+      "||payplay.fm^*/mastercs.js",
+      "||pbsrc.com/sponsor/",
+      "||pbsrc.com^*/sponsor/",
+      "||pcauthority.com.au^*/skins/",
+      "||pcpro.co.uk/images/*_siteskin",
+      "||pcpro.co.uk/images/skins/",
+      "||pcpro.co.uk^*/pcprositeskin",
+      "||pcpro.co.uk^*skin_wide.",
+      "||photosupload.net/photosupload.js",
+      "||pinknews.co.uk/newweb/",
+      "||prisonplanet.com^*advert.",
+      "||prisonplanet.com^*banner",
+      "||prisonplanet.com^*sky.",
+      "||project-for-sell.com/_google.php",
+      "||proxy.org/af.html",
+      "||proxy.org/ah.html",
+      "||ps3news.com/banner/",
+      "||ps3news.com^*.swf",
+      "||qrz.com/pix/*.gif",
+      "||retrevo.com^*/pcwframe.jsp?",
+      "||richmedia.yimg.com^",
+      "||sciencedaily.com^*/google-story2-rb.js",
+      "||sendspace.com^*?zone=",
+      "||shop.com/cc.class/dfp?",
+      "||shops.tgdaily.com^*&widget=",
+      "||showstreet.com/banner.",
+      "||snopes.com^*/*ad$subdocument",
+      "||softcab.com/google.php?",
+      "||softonic.com/specials_leaderboard/",
+      "||soundtracklyrics.net^*_az.js",
+      "||space.com/promo/",
+      "||stlyrics.com^*_az.js",
+      "||stuff.tv/client/skinning/",
+      "||techpowerup.com/images/bnnrs/",
+      "||techsupportforum.com^*/banners/",
+      "||techtree.com^*/jquery.catfish.js",
+      "||telegraphindia.com^*/banners/",
+      "||telegraphindia.com^*/hoabanner.",
+      "||tentonhammer.com^*/takeovers/",
+      "||thehighstreetweb.com^*/banners/",
+      "||themis-media.com/media/global/images/cskins/",
+      "||themis.yahoo.com^",
+      "||thewb.com/thewb/swf/tmz-adblock/",
+      "||timeslive.co.za^*/adtonomy.",
+      "||tripadvisor.com/adp/",
+      "||tripadvisor.com^*/skyscraper.jpg",
+      "||turbobit.net/js/popunder2.js",
+      "||typepad.com/sponsors/",
+      "||ua.badongo.com^",
+      "||uimserv.net^",
+      "||unicast.msn.com^",
+      "||universalhub.com/bban/",
+      "||videogamer.com^*/css/skins/$stylesheet",
+      "||videos.mediaite.com/decor/live/white_alpha_60.",
+      "||videosift.com/bnr.php?",
+      "||w3schools.com/banners/",
+      "||wareseeker.com/banners/",
+      "||webhostingtalk.com/js/hail.js",
+      "||whispersinthecorridors.com/banner2009/",
+      "||wikia.com/__varnish_",
+      "||windowsitpro.com^*/doubleclick/",
+      "||windowsitpro.com^*/googleafc",
+      "||windowsitpro.com^*/roadblock.js",
+      "||www2.sys-con.com^*.cfm",
+      "||xbitlabs.com^*/xbanner.php?",
+      "||yahoo.*/serv?s=",
+      "||yahoo.com/darla/",
+      "||yahoo.com/ysmload.html?",
+      "||yahoo.com^*.ads.darla.",
+      "||yahoo.com^*/eyc-themis?",
+      "||yfrog.com/ym.php?",
+      "||yimg.com/a/1-$~stylesheet",
+      "||yimg.com^*/fairfax/$image",
+      "||yourmovies.com.au^*/side_panels_",
+      "||zam.com/i/promos/*-skin.",
+      "||zattoo.com/static/images/sponsors/",
+      "||zophar.net/files/tf_",
+      "@@||2mdn.net/*_ecw_$image,domain=wwe.com",
+      "@@||2mdn.net/crossdomain.xml$object_subrequest,domain=imdb.com",
+      "@@||2mdn.net/viewad/817-grey.gif$object_subrequest,domain=imdb.com",
+      "@@||a.giantrealm.com/assets/vau/grplayer*.swf$object",
+      "@@||ad.gogopin.com^$~document",
+      "@@||ad3.liverail.com^$object_subrequest,domain=seesaw.com",
+      "@@||adap.tv/redir/client/adplayer.swf?$object_subrequest,domain=egreetings.com|ehow.com|xxlmag.com",
+      "@@||addictinggames.com/jsource/ad_functions.js$script",
+      "@@||adjuggler.com^$script,domain=videodetective.com",
+      "@@||adm.fwmrm.net^$object_subrequest",
+      "@@||ads.adap.tv/control?$object_subrequest,domain=ky3.com|xxlmag.com",
+      "@@||ads.adap.tv/crossdomain.xml$object_subrequest,domain=ky3.com|xxlmag.com",
+      "@@||ads.adultswim.com/js.ng/site=toonswim&toonswim_pos=600x400_ctr&toonswim_rollup=games$script",
+      "@@||ads.ahds.ac.uk^$~document",
+      "@@||ads.cnn.com/js.ng/*&cnn_intl_subsection=download$script",
+      "@@||ads.forbes.com/realmedia/ads/*@videopreroll$script",
+      "@@||ads.fox.com/fox/black_2sec_600.flv$object_subrequest",
+      "@@||ads.hulu.com^*.flv$object_subrequest",
+      "@@||ads.hulu.com^*.swf$object_subrequest",
+      "@@||ads.imeem.com^$object_subrequest",
+      "@@||ads.morningstar.com/realmedia/ads/adstream_lx.ads/www.morningstar.com/video/$object_subrequest",
+      "@@||ads.yimg.com^*/any/yahoologo$image",
+      "@@||ads.yimg.com^*/search/b/syc_logo_2.gif$image",
+      "@@||ads.yimg.com^*videoadmodule*.swf$object_subrequest",
+      "@@||ads1.msn.com/library/dap.js$script,domain=msnbc.msn.com|wowarmory.com",
+      "@@||adsatt.abc.starwave.com^$object_subrequest",
+      "@@||adserver.adtech.de/crossdomain.xml$object_subrequest,domain=deluxetelevision.com",
+      "@@||adserver.bigwigmedia.com/ingamead3.swf$object_subrequest",
+      "@@||adserver.yahoo.com/a?*&l=head&$script,domain=yahoo.com",
+      "@@||adserver.yahoo.com/a?*=headr$script,domain=mail.yahoo.com",
+      "@@||adtech.de/crossdomain.xml$object_subrequest,domain=gigwise.com|nelonen.fi",
+      "@@||affiliates.jlist.com/ads/img_$image,domain=jlist.com",
+      "@@||affiliates.quintura.com^*.php?$object_subrequest,script,xmlhttprequest",
+      "@@||apple.com^*/adswap.js$script",
+      "@@||ar.atwola.com/file/adswrapper.js$script,domain=gasprices.mapquest.com",
+      "@@||as.webmd.com/html.ng/transactionid=$object_subrequest",
+      "@@||assets.idiomag.com/flash/adverts/yume_$object_subrequest",
+      "@@||autotrader.co.nz/data/adverts/$image",
+      "@@||belointeractive.com^*/ads/*@*?|$script",
+      "@@||bitgravity.com/revision3/swf/player/admanager.swf?$object_subrequest,domain=area5.tv",
+      "@@||brothersoft.com/gads/coop_show_download.php?soft_id=$script",
+      "@@||chloe.videogamer.com/data/*/videos/adverts/$object_subrequest",
+      "@@||cinshare.com/js/isalive.js?$script",
+      "@@||cnet.com/ads/common/adclient/*.swf$object_subrequest",
+      "@@||cpalead.com/mygateway.php?pub=$script,domain=superfastfile.com|videodownloadx.com",
+      "@@||cubeecraft.com/images/home/features/300x250/$image",
+      "@@||d1.openx.org/ajs.php?zoneid=25815&$script,domain=rottentomatoes.com",
+      "@@||dart.clearchannel.com/html.ng/$object_subrequest,domain=radio1045.com",
+      "@@||deviantart.com/global/difi/?$subdocument",
+      "@@||direct.fairfax.com.au/hserver/*/site=vid.*/adtype=embedded/$script",
+      "@@||doubleclick.net/ad/*smartclip$script,domain=last.fm",
+      "@@||doubleclick.net/adj/*smartclip$script,domain=last.fm",
+      "@@||doubleclick.net/adj/imdb2.consumer.video/*;sz=320x240,$script",
+      "@@||doubleclick.net/adj/nbcu.nbc/videoplayer-$script",
+      "@@||doubleclick.net/adj/pong.all/*;dcopt=ist;$script",
+      "@@||doubleclick.net/pfadx/channel.video.crn/;*;cue=pre;$object_subrequest",
+      "@@||doubleclick.net/pfadx/umg.*;sz=10x$script",
+      "@@||doubleclick.net^*/adj/wwe.shows/ecw_ecwreplay;*;sz=624x325;$script",
+      "@@||doubleclick.net^*/listen/*;sz=$script,domain=last.fm",
+      "@@||dyncdn.buzznet.com/catfiles/?f=dojo/*.googleadservices.$script",
+      "@@||ebayrtm.com/rtm?rtmcmd&a=json&cb=parent.$script",
+      "@@||edgar.pro-g.co.uk/data/*/videos/adverts/$object_subrequest",
+      "@@||empireonline.com/images/image_index/300x250/$background,image",
+      "@@||espn.go.com^*/espn360/banner?$subdocument",
+      "@@||eyewonder.com^$object,script,domain=last.fm",
+      "@@||facepunch.com/ad/$script",
+      "@@||facepunch.com/ads/$image,stylesheet",
+      "@@||fdimages.fairfax.com.au^*/ffxutils.js$domain=thevine.com.au",
+      "@@||feeds.videogamer.com^*/videoad.xml?$object_subrequest",
+      "@@||flyordie.com^*&affiliate$subdocument",
+      "@@||freeonlinegames.com/advertising/google-loader.swf?$object",
+      "@@||gannett.gcion.com/addyn/3.0/*/adtech;alias=pluck_signin$script",
+      "@@||garrysmod.org/ads/$background,image,script,stylesheet",
+      "@@||gr.burstnet.com/crossdomain.xml$object_subrequest,domain=filefront.com",
+      "@@||guim.co.uk^*/styles/wide/google-ads.css$stylesheet",
+      "@@||gws.ign.com/ws/search?*&google_adpage=$script",
+      "@@||i.cdn.turner.com^*/adserviceadapter.swf$object",
+      "@@||i.real.com/ads/*.swf?clicktag=$object_subrequest,domain=rollingstone.com",
+      "@@||ign.com/js.ng/size=headermainad&site=teamxbox$script,domain=teamxbox.com",
+      "@@||ikea.com/ms/img/ads/services/$image",
+      "@@||im.mstar.com/ads/*.flv$object_subrequest",
+      "@@||imdb.com/images/*/js/ads.js$script",
+      "@@||img.thedailywtf.com/images/ads/$image",
+      "@@||img.weather.weatherbug.com^*/stickers/$background,image,stylesheet",
+      "@@||jobs.wa.gov.au/images/advertimages/$background,image",
+      "@@||last.fm/ads.php?zone=*listen$subdocument",
+      "@@||lightningcast.net/servlets/getplaylist?*&responsetype=asx&$object",
+      "@@||liverail.com/crossdomain.xml$object_subrequest",
+      "@@||liverail.com/swf/*/plugins/flowplayer/$object_subrequest",
+      "@@||m1.2mdn.net^*/dartshell8_9.swf$object_subrequest,domain=vladtv.com",
+      "@@||mads.cbs.com/mac-ad?$object_subrequest",
+      "@@||mads.com.com/ads/common/faith/*.xml$object_subrequest",
+      "@@||media-imdb.com/images/*/js/ads.js$script,domain=imdb.com",
+      "@@||media.salemwebnetwork.com/js/admanager/swfobject.js$script,domain=christianity.com",
+      "@@||media.washingtonpost.com/wp-srv/ad/ad_v2.js$script",
+      "@@||media.washingtonpost.com/wp-srv/ad/tiffany_manager.js$script",
+      "@@||motherjones.com/files/resized/files/*300x250$image",
+      "@@||mozilla.com/img/tignish/plugincheck/*/728_90/loading.png$image,domain=mozilla.com",
+      "@@||newgrounds.com/ads/ad_medals.gif$image",
+      "@@||newsarama.com/common/js/advertisements.js$script",
+      "@@||newsweek.com/ads/adscripts/prod/*_$script",
+      "@@||nick.com/js/ads.jsp$script",
+      "@@||o.aolcdn.com/ads/adswrapper.js$script,domain=photos.tmz.com",
+      "@@||oas.absoluteradio.co.uk/realmedia/ads/$object_subrequest",
+      "@@||oas.bigflix.com/realmedia/ads/$object_subrequest",
+      "@@||oas.five.tv/realmedia/ads/adstream_sx.ads/demand.five.tv/$object_subrequest",
+      "@@||oascentral.feedroom.com/realmedia/ads/adstream_sx.ads/$script,domain=businessweek.com|economist.com|feedroom.com|stanford.edu",
+      "@@||oascentral.upi.com^$object_subrequest",
+      "@@||objects.tremormedia.com/embed/js/$script,domain=deluxetelevision.com",
+      "@@||objects.tremormedia.com/embed/swf/acudeoplayer.swf$object,domain=deluxetelevision.com",
+      "@@||objects.tremormedia.com/embed/swf/admanager*.swf$object_subrequest",
+      "@@||objects.tremormedia.com/embed/xml/*.xml?r=$object_subrequest,domain=mydamnchannel.com",
+      "@@||omnikool.discovery.com/realmedia/ads/adstream_mjx.ads/dsc.discovery.com/$script",
+      "@@||pagead2.googlesyndication.com/pagead/expansion_embed.js$script,domain=myspace.com",
+      "@@||pagead2.googlesyndication.com/pagead/scache/show_invideo_ads.js$script,domain=sciencedaily.com",
+      "@@||pagead2.googlesyndication.com/pagead/show_ads.js$script,domain=myspace.com",
+      "@@||pagead2.googlesyndication.com/pagead/static?format=in_video_ads&$subdocument,domain=sciencedaily.com",
+      "@@||quit.org.au/images/images/ad/$image",
+      "@@||redir.adap.tv/redir/client/adplayer.swf?$object_subrequest,domain=cracked.com|videosift.com",
+      "@@||rosauers.com/locations/ads.html$subdocument",
+      "@@||sankakucomplex.com/img/www/d/spcjs.php?id=$script",
+      "@@||sankakucomplex.com/wp-content/themes/*/sankaku.js?*&adname=*&spc=/spc.php?",
+      "@@||seavideo-ak.espn.go.com/ads/$object_subrequest",
+      "@@||seesaw.com/cp/c4/realmedia/ads/adstream_sx.ads/$xmlhttprequest",
+      "@@||serve.vdopia.com/adserver/ad*.php$object_subrequest,script,xmlhttprequest",
+      "@@||server.cpmstar.com/adviewas3.swf?contentspotid=$object_subrequest,domain=armorgames.com|freewebarcade.com",
+      "@@||server.cpmstar.com/view.aspx?poolid=$script,domain=newgrounds.com",
+      "@@||sfx-images.mozilla.org^$image,domain=spreadfirefox.com",
+      "@@||shockwave.com/js/ad_functions.js$script",
+      "@@||smartadserver.com/call/pubj/*/affiliate_id$script,domain=deezer.com",
+      "@@||smartadserver.com/def/def/showdef.asp$script,domain=deezer.com",
+      "@@||smartclip.net/delivery/tag?sid=$script,domain=last.fm",
+      "@@||sonicstate.com/video/hd/hdconfig-geo.cfm?*/www/delivery/$object_subrequest",
+      "@@||sp.ltassrv.com.s3.amazonaws.com^$object_subrequest,domain=animecrazy.net",
+      "@@||spike.com/consolidation/spike-functions.js?*/js/ads.js$script",
+      "@@||static.2mdn.net^*.xml$object_subrequest,domain=photoradar.com|youtube.com",
+      "@@||static.ak.fbcdn.net^*/ads/$script",
+      "@@||superfundo.org/advertisement.js$script",
+      "@@||telegraphcouk.skimlinks.com/api/telegraph.skimlinks.js$script",
+      "@@||thenewsroom.com^*/advertisement.xml$object_subrequest",
+      "@@||theonion.com/ads/video-ad/$object_subrequest",
+      "@@||thesmokinggun.com/includes2/de/video/sync.$object_subrequest",
+      "@@||thestreet.com/js/ads/adplacer.js$script",
+      "@@||timeinc.net/people/static/i/advertising/getpeopleeverywhere-news.gif$background,domain=people.com|peoplestylewatch.com",
+      "@@||timeinc.net^*/tii_ads.js$script,domain=ew.com",
+      "@@||trutv.com/includes/banners/de/video/sync.$object_subrequest",
+      "@@||tvgorge.com^*/adplayer.swf$object",
+      "@@||tvnz.co.nz/stylesheets/tvnz/lib/js/advertisement.js$script",
+      "@@||ultrabrown.com/images/adheader.jpg$image",
+      "@@||upload.wikimedia.org/wikipedia/commons/",
+      "@@||utarget.co.uk/crossdomain.xml$object_subrequest,domain=tvcatchup.com",
+      "@@||v.fwmrm.net/ad/p/1?$object_subrequest,domain=mlb.com",
+      "@@||v.fwmrm.net/crossdomain.xml$object_subrequest,domain=mlb.com",
+      "@@||video.nbcuni.com/ads/$object_subrequest",
+      "@@||vortex.accuweather.com/adc2004/pub/ads/js/ads-2006_vod.js$script",
+      "@@||vox-static.liverail.com/swf/*/admanager.swf$object_subrequest",
+      "@@||weather.com/common/a2/oasadframe.html?position=pagespon$subdocument",
+      "@@||weather.com/common/a2/oasadframe.html?position=pointspon$subdocument",
+      "@@||widget.slide.com^*/ads/*/preroll.swf$object_subrequest",
+      "@@||wrapper.teamxbox.com/a?size=headermainad&altlocdir=teamxbox$script",
+      "@@||yallwire.com/pl_ads.php?$object_subrequest",
+      "@@||yimg.com^*/java/promotions/js/ad_eo_1.1.js$script",
+      "@@||zedo.com/*.swf$object_subrequest,domain=rajshri.com",
+      "@@||zedo.com/*.xml$object_subrequest,domain=rajshri.com",
+      "@@||zedo.com//$object_subrequest,domain=rajshri.com",
+      "@@||arto.com/includes/js/adtech.de/script.axd/adframe.js?$script",
+      "@@||avforums.com/forums/adframe.js$script",
+      "@@||cinshare.com/js/*ad_type$script",
+      "@@||dailykos.com/ads/adblocker.blogads.css$stylesheet",
+      "@@||eq2flames.com/adframe.js$script",
+      "@@||gdataonline.com/exp/textad.js$script",
+      "@@||hackers.co.id/adframe/adframe.js$script",
+      "@@||macobserver.com/js/adframe.js$script",
+      "@@||megavideodownloader.com/adimages/|$subdocument",
+      "@@||novamov.com/ads.js?*&ad_url=/adbanner$script",
+      "@@||onlinevideoconverter.com/scripts/advertisement.js$script",
+      "@@||superfastfile.com/adsense.js$script",
+      "@@||superfastfile.com/advertisement.js$script",
+      "@@||theteacherscorner.net/adiframe/ad.js$script",
+      "@@||tpmrpg.net/adframe.js$script",
+      "@@||video2mp3.net/img/adframe.js$script",
+      "@@||zshare.net/ads.js?*&ad_url=/adbanner$script",
+      "@@||adser.localport.it/banman.asp?zoneid=71$subdocument",
+      "@@||adswizz.com/www/delivery/$object_subrequest,domain=video.belga.be",
+      "@@||adtech.de/?adrawdata/3.0/*;|$object_subrequest,domain=nelonen.fi|tv2.dk",
+      "@@||adtech.de/crossdomain.xml$object_subrequest,domain=nelonen.fi|tv2.dk",
+      "@@||adtech.panthercustomer.com^*.flv$object_subrequest,domain=tv3.ie",
+      "@@||aka-cdn-ns.adtech.de^*.flv$object_subrequest,domain=tv3.ie",
+      "@@||amarillas.cl/advertise.do?$xmlhttprequest",
+      "@@||amarillas.cl/js/advertise/$script",
+      "@@||banneradmin.rai.it/js.ng/sezione_rai=barramenu$script",
+      "@@||bnrs.ilm.ee/www/delivery/fl.js$script",
+      "@@||e-planning.net/eb/*?*fvp=2&$object_subrequest,domain=clarin.com|emol.com",
+      "@@||fotojorgen.no/images/*/webadverts/$image",
+      "@@||openx.zomoto.nl/live/www/delivery/fl.js$script",
+      "@@||openx.zomoto.nl/live/www/delivery/spcjs.php?id=$script",
+      "@@||pagead2.googlesyndication.com/pagead/abglogo/abg-da-100c-000000.png$domain=janno.dk|nielco.dk",
+      "@@||ring.bg/adserver/adall.php?*&video_on_page=1$script"
+    ].map(function(text) Filter.fromText(text));
+
+    let addresses = [
+      "http://a.analytics.yahoo.com/p.pl?a=1000116666777&sid=3788ead&j=1366x768&flv=WIN+10%2C0%2C45",
+      "http://ad-emea.doubleclick.net/ad/N4137.yahoo.de/B4316546.2;sz=1x1;ai=609911305;si=102;ord=1269329333?",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedes300x250.jpg",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedes300x2501.swf",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedes400x60.gif",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedes400x60.swf",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedesexpand.swf",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedeswallpaperwide2.jpg",
+      "http://ads.yimg.com/ev/de/hp/mercedes/yadbg4.js",
+      "http://ads.yimg.com/ev/eu/any/pixel4.gif",
+      "http://ads.yimg.com/ev/eu/any/yad20100215min.js",
+      "http://cdn1.eyewonder.com/200125/762024/1248338/ewtrack.gif?ewbust=1269329333",
+      "http://d.yimg.com/a/i/ww/met/gsprite_20100208.png",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/ans_22_041609.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/brig_22_080609.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/facebook_22_063009.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/flickr_22_041609.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/heiseonline_22_072709.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/horoscopes_22_041609.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/kelkoo_22_061809.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/personals_22_041609.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/stern_22_092809.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/tb_22_042009.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/travel_22_063009.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/uk_pa_sprite_063009.png",
+      "http://d.yimg.com/a/i/ww/met/sprite_pg_20100125.png",
+      "http://d.yimg.com/a/i/ww/met/sprite_pg_nontheme_20100125.png",
+      "http://d.yimg.com/a/i/ww/met/sprite_videoicon_20100201.png",
+      "http://d.yimg.com/a/i/ww/met/th/slate/gsprite_pg_slate_20100129.gif",
+      "http://d.yimg.com/a/i/ww/met/th/slate/sprite_masthead_slate_srchbt2_07242009.png",
+      "http://d.yimg.com/a/i/ww/met/th/slate/sprite_pg_slate_20100126.png",
+      "http://l.yimg.com/a/a/1-/flash/promotions/de/intl/100225/50x50mpl.gif",
+      "http://l.yimg.com/a/combo?arc/yui/reset_2.6.5.css&arc/yui/fonts_2.6.4.css&metro/uiplugins/generic_0.1.9.css&metro/error/error_0.1.12.css&metro/fp/fp_zindex_0.0.24.css&metro/fp/fp_0.1.85.css&metro/navbar/navbar_0.1.83.css&metro/navbar/navbar_pageoptions_0.0.21.css&metro/marketindices/marketindices_0.1.33.css&metro/miniad/promoads_0.1.6.css&metro/uiplugins/tablist_service_0.1.6.css&metro/uiplugins/iframeshim_service_0.0.4.css&metro/uiplugins/ulm_service_0.1.8.css&metro/uiplugins/ulm_default_0.1.16.css&metro/uiplugins/tablist_news_0.0.14.css&metro/news/news_0.1.73.css&metro/specialevents/specialevents_0.0.21.css&metro/sda/sda_0.1.22.css&metro/subfooter/subfooter_0.0.6.css&metro/breakingnews/breakingnews_0.0.13.css&metro/uiplugins/carousel_service_0.1.6.css&metro/fptoday/fptoday_0.1.121.css&metro/uiplugins/carousel_default_0.1.11.css&metro/tuc/tuc_common_0.0.24.css&metro/tuc/tuc_embedded_0.0.15.css&metro/masthead/masthead_0.2.63.css&metro/contentcarousel/contentcarousel_0.1.81.css&metro/contentcarousel/contentcarousel_topten_0.1.69.css&metro/contentcarousel/pulse_0.1.60.css&metro/contentcarousel/slideshow1_0.1.24.css&metro/contentcarousel/shopping_0.1.19.css&metro/contentcarousel/contentcarousel_4_0.1.8.css&metro/footer/footer_0.1.53.css&metro/pa/pa_flash_0.1.2.css&metro/pa/pa_0.1.163.css&metro/pa/pa_detached_0.1.69.css&metro/uiplugins/tooltip_default_0.1.14.css&metro/pa/pa_edit_service_0.1.29.css&metro/contentcarousel/contentcarousel_3_0.1.9.css&metro/uiplugins/windowshade_service_0.0.13.css&metro/ipredirect/ipredirect_0.0.6.css",
+      "http://l.yimg.com/a/combo?arc/yui/substitute_0.1.9.js&arc/yui/oop_0.1.10.js&arc/yui/event-custom_0.1.5.js&arc/yui/io-base_0.1.10.js&arc/yui/dom_0.1.10.js&arc/yui/event-base_0.1.4.js&arc/yui/attribute_0.1.11.js&arc/yui/base-base_0.1.10.js&arc/yui/pluginhost_0.1.4.js&arc/yui/node_0.1.25.js&arc/yui/json_0.1.13.js&arc/yui/anim-base_0.1.9.js&arc/yui/anim-easing_0.1.9.js&arc/yui/anim-node-plugin_0.1.8.js&arc/yui/cookie_0.1.9.js&arc/yui/yuidef_0.1.9.js&arc/framework/module_platform_0.1.50.js&arc/framework/resourcemgr_0.1.14.js&metro2/dali/dali_transport_1.1.26.js&arc/framework/module_api_0.1.12.js&metro2/dali/metro_dali_1.0.18.js&metro/uiplugins/userinfo_service_0.1.7.js&metro/uiplugins/metro_viewtype_0.1.14.js&metro/uiplugins/default_viewtype_0.1.50.js&metro/uiplugins/edit_viewtype_0.1.31.js&metro/uiplugins/pa_viewtype_0.1.5.js&arc/util/ylc_1.8.17.js&metro/uiplugins/instrumentation_service_0.1.11.js&metro/uiplugins/metrologger_service_0.1.10.js&metro/sda/sda_bridge_service_0.0.5.js&metro/fp/fp_0.1.60.js&metro/uiplugins/metrics_service_0.1.5.js&metro/uiplugins/metro_performance_0.1.7.js&arc/framework/yui_service_0.1.11.js&metro/uiplugins/autohide_service_0.1.9.js&metro/uiplugins/statemgr_service_0.1.11.js&metro/navbar/navbar_0.1.75.js&metro/marketindices/marketindices_0.1.17.js&metro/uiplugins/aria_service_0.1.12.js&metro/uiplugins/tablist_service_0.1.29.js&metro/uiplugins/iframeshim_service_0.0.12.js&metro/uiplugins/ulm_service_0.1.31.js&metro/news/news_0.1.40.js&metro/sda/sda_deferred_service_0.0.13.js&metro/sda/sda_transport_0.0.9.js&metro/sda/sda_0.1.36.js&metro/uiplugins/carousel_service_0.1.37.js&metro/fptoday/fptoday_hover_0.1.53.js&metro/tuc/tuc_0.0.24.js&metro/masthead/masthead_0.2.114.js&metro/contentcarousel/contentcarousel_0.1.38.js&metro/contentcarousel/contentcarouselslideshow1_0.1.13.js&metro/uiplugins/toolbar_bridge_service_0.1.17.js&metro/uiplugins/tooltip_service_0.1.32.js&metro/pa/pa_0.1.187.js&metro/uiplugins/windowshade_service_0.0.12.js&metro/ipredirect/ipredirect_0.0.8.js",
+      "http://l.yimg.com/a/combo?arc/yui/yui_0.2.4.js",
+      "http://l.yimg.com/a/i/ww/met/mod/ybang_22_111908.png",
+      "http://l.yimg.com/a/i/ww/met/sprite_ip_redirect_052109.gif",
+      "http://l.yimg.com/a/i/ww/met/yahoo_logo_de_061509.png",
+      "http://l.yimg.com/a/lib/metro/apppromo/apppromo_0.0.12.css",
+      "http://l.yimg.com/a/lib/metro/autoapp/autoapp_0.0.36.css",
+      "http://l.yimg.com/a/lib/metro/autoapp/autoapp_0.0.42.js",
+      "http://l.yimg.com/a/lib/metro/ebay/ebay_0.1.25.css",
+      "http://l.yimg.com/a/lib/metro/ebay/ebay_0.1.31.js",
+      "http://l.yimg.com/a/lib/metro/facebook/facebook_0.0.59.js",
+      "http://l.yimg.com/a/lib/metro/facebook/facebook_0.0.63.css",
+      "http://l.yimg.com/a/lib/metro/feed/feed_0.0.10.js",
+      "http://l.yimg.com/a/lib/metro/feed/feed_0.1.4.css",
+      "http://l.yimg.com/a/lib/metro/finance/finance_0.1.62.css",
+      "http://l.yimg.com/a/lib/metro/finance/finance_0.1.77.js",
+      "http://l.yimg.com/a/lib/metro/fpflickr/fpflickr_0.1.38.css",
+      "http://l.yimg.com/a/lib/metro/fpflickr/fpflickr_0.1.43.js",
+      "http://l.yimg.com/a/lib/metro/horoscope/horoscope_0.1.29.js",
+      "http://l.yimg.com/a/lib/metro/horoscope/horoscope_0.1.42.css",
+      "http://l.yimg.com/a/lib/metro/mail/mail_0.0.11.js",
+      "http://l.yimg.com/a/lib/metro/mail/mail_0.0.20.css",
+      "http://l.yimg.com/a/lib/metro/messenger/messenger_0.0.31.css",
+      "http://l.yimg.com/a/lib/metro/messenger/messenger_0.0.40.js",
+      "http://l.yimg.com/a/lib/metro/pacontainer/pacontainer_0.0.31.css",
+      "http://l.yimg.com/a/lib/metro/pacontainer/pacontainer_0.0.41.js",
+      "http://l.yimg.com/a/lib/metro/scoreboard/scoreboard_0.1.53.js",
+      "http://l.yimg.com/a/lib/metro/scoreboard/scoreboard_0.1.62.css",
+      "http://l.yimg.com/a/lib/metro/uiplugins/menu_default_0.1.3.css",
+      "http://l.yimg.com/a/lib/metro/uiplugins/menu_service_0.1.3.css",
+      "http://l.yimg.com/a/lib/metro/uiplugins/tablist_default_0.1.5.css",
+      "http://l.yimg.com/a/lib/metro/weather/weather_0.1.72.css",
+      "http://l.yimg.com/a/lib/metro/weather/weather_0.1.78.js",
+      "http://l.yimg.com/a/lib/metro/yservices/yservices_0.1.25.js",
+      "http://l.yimg.com/a/lib/metro/yservices/yservices_0.1.95.css",
+      "http://l.yimg.com/cv/ae/de/__testing_only__/100320/50x50mpl.jpg",
+      "http://l.yimg.com/d/lib/bc/bcr_2.0.4.js",
+      "http://l.yimg.com/i/i/de/metro/032213.jpg",
+      "http://l.yimg.com/i/i/de/metro/david1.jpg",
+      "http://l.yimg.com/i/i/de/metro/depp5.jpg",
+      "http://l.yimg.com/i/i/de/metro/grins.jpg",
+      "http://l.yimg.com/i/i/de/metro/grins1.jpg",
+      "http://l.yimg.com/i/i/de/metro/klum9.jpg",
+      "http://l.yimg.com/i/i/de/metro/love5.jpg",
+      "http://l.yimg.com/i/i/de/metro/meyer.jpg",
+      "http://l.yimg.com/i/i/de/metro/patti.jpg",
+      "http://pil-de.sensic.net/view.php?id=609&ai=609911305&si=102&z=5169750",
+      "http://row.bc.yahoo.com/b?P=rOH7hlf4enaIjFzES6hqcAVfXMxrqkuobbUABTvY&T=13r3kd8oe%2fX%3d1269329333%2fE%3d2142153770%2fR%3ddehmpg%2fK%3d5%2fV%3d1.1%2fW%3dJR%2fY%3dDE%2fF%3d1627961479%2fS%3d1%2fJ%3d16A1EE4D&U=13odcn28u%2fN%3d3OW.LFf4eEc-%2fC%3d200077449.201936240.203227539.201427407%2fD%3dHDRM%2fB%3d201083721%2fV%3d1&U=12cltcst2%2fN%3d3.W.LFf4eEc-%2fC%3d-1%2fD%3dSTCK%2fB%3d-1%2fV%3d0&U=13oq99igf%2fN%3d3eW.LFf4eEc-%2fC%3d200121811.201962178.203251406.201366517%2fD%3dFPAD%2fB%3d201104189%2fV%3d1&U=13penir9s%2fN%3d4eW.LFf4eEc-%2fC%3d200122020.201964521.203249955.201421270%2fD%3dPROM1%2fB%3d201103196%2fV%3d1&U=13p21m4bp%2fN%3d4OW.LFf4eEc-%2fC%3d200121612.201961030.203250241.201441191%2fD%3dPROM2%2fB%3d201100611%2fV%3d1&U=12ber046v%2fN%3d5OW.LFf4eEc-%2fC%3d-1%2fD%3dSIP%2fB%3d-1%2fV%3d0&U=12dkuuk1c%2fN%3d5uW.LFf4eEc-%2fC%3d-1%2fD%3dYMBCN%2fB%3d-1%2fV%3d0&U=12b7orl19%2fN%3d4uW.LFf4eEc-%2fC%3d-2%2fD%3dRTG%2fB%3d-2%2fV%3d0&U=12cn27umu%2fN%3d4.W.LFf4eEc-%2fC%3d-1%2fD%3dRTG1%2fB%3d-1%2fV%3d0&U=13mgnvhf0%2fN%3d3uW.LFf4eEc-%2fC%3d200066141.201917714.203207718.201419751%2fD%3dRS%2fB%3d201075250%2fV%3d1&Q=0&O=0.2453797040205341",
+      "http://uk.ard.yahoo.com/SIG=15vmnkeq1/M=200121811.201962178.203251406.201366517/D=dehmpg/S=2142153770:FPAD/_ylt=AjU3QcOjT40Ps4X4Pt1qRHkqrK5_/Y=DE/EXP=1269336533/L=rOH7hlf4enaIjFzES6hqcAVfXMxrqkuobbUABTvY/B=3eW.LFf4eEc-/J=1269329333422048/K=c.k.Qwg3F0uysaPXI..55Q/A=201104189/N=-201/id=nu_ad_play/0.26024979463138365/*http://ads.yimg.com/ev/eu/any/pixel4.gif",
+      "http://uk.ard.yahoo.com/SIG=15vmnkeq1/M=200121811.201962178.203251406.201366517/D=dehmpg/S=2142153770:FPAD/_ylt=AjU3QcOjT40Ps4X4Pt1qRHkqrK5_/Y=DE/EXP=1269336533/L=rOH7hlf4enaIjFzES6hqcAVfXMxrqkuobbUABTvY/B=3eW.LFf4eEc-/J=1269329333422048/K=c.k.Qwg3F0uysaPXI..55Q/A=201104189/N=-247/id=nu_bg_on/0.4486526274433831/*http://ads.yimg.com/ev/eu/any/pixel4.gif",
+      "http://yahoo.ivwbox.de/blank.gif",
+      "http://yahoo.ivwbox.de/cgi-bin/ivw/CP/2142153770?r=&d=63214.11222648449",
+      "http://a.ligatus.com/?ids=12384&t=js",
+      "http://ad-emea.doubleclick.net/ad/N4137.heise.de/B4321259.12;sz=1x1;ord=906619961?",
+      "http://ad-emea.doubleclick.net/adj/N5295.111569.7876282795621/B4272309;sz=728x90;click0=http://oas.heise.de/RealMedia/ads/click_lx.ads/www.heise.de/Homepage/842927577/Top/OasDefault/google02_11ros_10/google02_11ros_10_redirect_mod.html/35393338313861373438353862653830?;ord=842927577?",
+      "http://heise.ivwbox.de/2004/01/survey.js",
+      "http://heise.ivwbox.de/blank.gif",
+      "http://heise.ivwbox.de/cgi-bin/ivw/CP/homepage;/?r=&d=75349.14130693086",
+      "http://i.ligatus.com/com_ads/9796_138x115.jpg",
+      "http://i.ligatus.com/com_global_img/logo-ligatus_frei_58x15.gif",
+      "http://just4business.de/images/Asus_Eee_PC_1201N_75x50.jpg",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/137x200/prakti_tr_sales.gif",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/3in1sky_sw/div_close_id_swvz_ad.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/3in1sky_sw/div_open_id_swvz_ad.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/bitdefender13_11sbox_10/bitdefenderav.jpg",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/cyberlink54674_44sbox_09/cyber.jpg",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/default/empty.gif",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/microsoft06_05nbox_10b/logo_sqlserver.jpg",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/microsoft33221_44sbox_09/msoffice.jpg",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/miwibox_hp/div_close.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/miwibox_hp/div_open_id_heise_bottom_4in1_banner.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/mjx/mjx.2009-11-17.0.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/textlinkbox_hp/div_close.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/textlinkbox_hp/div_open_class_teaser_adliste.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/textlinkbox_hp/ul_close.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/textlinkbox_hp/ul_open_class_linkliste.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/textlinkbox_hp/ul_open_class_microsites.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/wp06_EMC_51nbox_09/EMC_logo_75_50645575645667.jpg",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/3in1_sw/1406791973/x48/OasDefault/microsoft33221_44sbox_09/microsoft33221_44sbox_09.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/3in1_sw/284216804/x47/OasDefault/bitdefender13_11sbox_10/bitdefender13_44sbox_09.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/3in1_sw/962035171/x49/OasDefault/cyberlink54674_44sbox_09/cyberlink54674_44sbox_09.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/4in1_middle3hp/1292230445/x42/OasDefault/wp06_EMC_51nbox_09/ccp_textads_vorlage645575645667.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/4in1_middle3hp/262322103/x41/OasDefault/microsoft06_05nbox_10b/microsoft06_05nbox_10b_textad_new.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/4in1_middle3hp/814474394/x43/OasDefault/miwieigen06_miwibox/Asus_Eee_PC_1201N_75x50.script.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/1066903666/Middle3/OasDefault/miwibox_hp/miwibox_hp_rahmen.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/12677327/Bottom/OasDefault/default/empty.gif/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/1477879216/Middle/OasDefault/zz_hp/zz_autos_img.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/184013871/Left2/OasDefault/137x200/prakti_tr_sales.gif/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/262818978/Left1/OasDefault/3in1sky_sw/3in1sky_sw_rahmen.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/308630109/Right1/OasDefault/default/empty.gif/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/542677179/Left/OasDefault/ligatus03_ros/google02_nfanwendungen_script.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/60976329/Right2/OasDefault/textlinkbox_hp/textlinkbox_hp.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/842927577/Top/OasDefault/google02_11ros_10/google02_11ros_10_redirect_mod.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/911738277/Middle2/OasDefault/zz_free_contentad/zz_autos_img.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1124251766/x51/OasDefault/wc09_checkpoint_08hpnews_10/wc09_checkpoint_08hpnews_10.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1288004340/x54/OasDefault/ms09_05hpnews_10/ms09_05hpnews_10_textlink.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1372532510/x53/OasDefault/ibm09_04hpnews_10/ibm09_04hpnews_10_text.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1392564978/x55/OasDefault/1blu09_04hpnews_10/1blu09_04hpnews_10_textlink.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1415958888/x50/OasDefault/pz_hp09_51hp_09/pz_hp09_51hp_09_textlink.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1506484795/x52/OasDefault/whitepaper09_24hpnews_09/whitepaper_textlink.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/906619961/x60/OasDefault/strato10_09hp_10/strato10_09hp_10_webhosting.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_mjx.ads/www.heise.de/Homepage/1434665888@Bottom,Left,Left1,Left2,Middle,Middle2,Middle3,Right1,Right2,Top,Top1?",
+      "http://qs.ivwbox.de/?heise//CP//homepage",
+      "http://rl.heise.de/images/pic.gif?r=;tp=1073741824%7C1073827193;m=Heise;tid=1073838799;random=25442.718985329073;con=1;json=1;tc=1073741824%7C1073827193%7C1073838799;c=20;b=16;sep=%7C;tce=1;tn=News;tpn=heise%20online%7CRedaktioneller%20Content%7CNews;url=http%3A%2F%2Fwww.heise.de%2F;tit=Startseite;tpu=1;sz=1366x768x24;con=1;cs=1",
+      "http://s0.2mdn.net/viewad/2635444/ROI2_DE_728x90.gif",
+      "http://umw-de.sensic.net/view.php?id=693&ai=7&si=12345&ps0=Heise&ps1=ROS&ps2=TextAd_75x50&ps3=ProdSQLM2&z=262322103",
+      "http://view.atdmt.com/DEM/view/211257741/direct/01/",
+      "http://www.heise.de/RealMedia/ads/adstream_jx.ads/www.heise.de/3in1_sw/1693169649@x47,x48,x49?",
+      "http://www.heise.de/RealMedia/ads/adstream_jx.ads/www.heise.de/4in1_middle3hp/1540744443@x41,x42,x43,x44?",
+      "http://www.heise.de/RealMedia/ads/adstream_jx.ads/www.heise.de/textlinks_hp/1035057110@x50,x51,x52,x53,x54,x55,x56,x57,x58,x59?",
+      "http://www.heise.de/RealMedia/ads/adstream_jx.ads/www.heise.de/textlinks_hp/1035057110@x60,x61,x62,x63,x64,x65,x66,x67,x68,x69?",
+      "http://www.heise.de/defeckerellyinesteetshygolingshetrica/",
+      "http://www.heise.de/favicon.ico",
+      "http://www.heise.de/icons/ho/00on.gif",
+      "http://www.heise.de/icons/ho/background_mitte_40zu60.gif",
+      "http://www.heise.de/icons/ho/background_mitte_links.gif",
+      "http://www.heise.de/icons/ho/background_navi_top.gif",
+      "http://www.heise.de/icons/ho/background_navigation.gif",
+      "http://www.heise.de/icons/ho/background_onlinemarkt.gif",
+      "http://www.heise.de/icons/ho/background_teaser_ecke.png",
+      "http://www.heise.de/icons/ho/background_weitere.gif",
+      "http://www.heise.de/icons/ho/dpunktfoto.gif",
+      "http://www.heise.de/icons/ho/emedia.gif",
+      "http://www.heise.de/icons/ho/heise_online_logo.gif",
+      "http://www.heise.de/icons/ho/low_link.gif",
+      "http://www.heise.de/icons/ho/midot.gif",
+      "http://www.heise.de/icons/ho/mittelstandswiki.gif",
+      "http://www.heise.de/imgs/02/3/9/8/2/3/9/00.jpg-c8df87c7325bb251.jpeg",
+      "http://www.heise.de/imgs/02/3/9/9/5/4/2/ct0510Thinkpad_64746-jow-jg_PR-137-96bc3ad582573fb2.gif",
+      "http://www.heise.de/imgs/02/4/0/2/9/2/7/kde4-gnome-80x80-42caec49ea223795.png",
+      "http://www.heise.de/imgs/02/4/2/6/5/1/1/ir_engine-2.jpg-4d3fb8309d2c3808.jpeg",
+      "http://www.heise.de/imgs/02/4/3/9/0/0/1/Breitband.jpg-ed3b76a2f37c3bbd.jpeg",
+      "http://www.heise.de/imgs/02/4/5/2/8/6/9/update-check-teaser-grau-eb2471c6cbfe8a9e.gif",
+      "http://www.heise.de/imgs/02/4/7/8/8/3/7/tpspecial0110-d01129faf4ab9c46.gif",
+      "http://www.heise.de/imgs/02/4/9/8/7/5/1/Google2-c52f2c091ee665ca.png",
+      "http://www.heise.de/imgs/18/4/9/7/4/9/5/Platine1-7a44dd182f22c0ac.png",
+      "http://www.heise.de/imgs/18/4/9/8/4/3/7/TN_19349274_79671348f6-c162feefc49e954c.png",
+      "http://www.heise.de/imgs/18/4/9/8/5/9/0/nt-mi.jpg-3ef5aa6f33f02d9d.jpeg",
+      "http://www.heise.de/imgs/18/4/9/8/6/1/0/aufmacher_ajax.jpg-5bbbcea175e4cbcc.jpeg",
+      "http://www.heise.de/imgs/18/4/9/8/6/6/4/nt-brown.jpg-4bdb775e5337ed24.jpeg",
+      "http://www.heise.de/imgs/18/4/9/8/6/8/9/kernel-log-75x100-teaser.jpg-9ad4c881273c6e97.jpeg",
+      "http://www.heise.de/imgs/18/4/9/8/6/9/7/Iran2-97230727a4d76307.png",
+      "http://www.heise.de/imgs/18/4/9/8/7/3/1/TV5_StockXChng-MJimanges-3419995169601f3a.png",
+      "http://www.heise.de/imgs/18/4/9/8/7/6/4/TV1-65ed120a09b6758c.png",
+      "http://www.heise.de/imgs/18/4/9/8/8/2/8/Datenschutz_EU-Datenschutzbeauftragter_PeterHustinx2-d0f55c7009e75827.png",
+      "http://www.heise.de/ivw-bin/ivw/CP/",
+      "http://www.heise.de/software/specials/top_downloads_2009.jpeg",
+      "http://www.heise.de/stil/drucken.css",
+      "http://www.heise.de/stil/ho/standard2008.css",
+      "http://www.heise.de/stil/navi_top2008.css",
+      "http://www.heise.de/stil/standard2008.css",
+      "http://www.heise.de/support/lib/external.js",
+      "http://www.heise.de/support/lib/jquery-1.4.1.min.js",
+      "http://www.heise.de/support/lib/jquery/jquery.ui-1.8.ho-teaserbundle.min.js",
+      "http://www.heise.de/support/lib/login_ho.js",
+      "http://www.heise.de/support/lib/mclient/mclient-1.0.js",
+      "http://www.heise.de/support/sales/software/swvz_skyscraper/swvz_ad_verlauf.jpg",
+      "http://www.heise.de/support/sales/software/swvz_skyscraper/swvz_logo.png",
+      "http://www.strato.de/asis/pilot.de.asis?5121844",
+      "http://www.strato.de/asis/pilot.de.asis?906619961",
+      "http://x.ligatus.de/blank.gif",
+      "http://x.ligatus.de/cgi-bin/ivw/CP/33548454",
+      "http://ad.doubleclick.net/ad/N1727.cnn.com/B4080371.3;sz=1x1;ord=coaKddo,bfAqIpmbIqy?",
+      "http://ad.doubleclick.net/ad/N5364.CNN.com/B4366287;sz=300x250;ord=cNeKdzI,bfAqIpmbIut?",
+      "http://ad.doubleclick.net/adj/N3880.SD146.3880/B4087837.11;dcove=o;mtfIFPath=/.element/ssi/ads.iframes/doubleclick/;sz=120x90;click=http://ads.cnn.com/event.ng/Type=click&FlightID=285106&AdID=388426&TargetID=77947&Values=1588&Redirect=;ord=bpxeKwy,bfAqIpmbKhI?",
+      "http://ads.cnn.com/DartRichMedia_1_03.js",
+      "http://ads.cnn.com/DartRichMedia_1_03.js",
+      "http://ads.cnn.com/DartRichMedia_1_03.js",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=352666&FlightID=257771&TargetID=75867&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,16113,17173,17251,18517,18982,20139,23491,31271,31323,32004,32594,32859,33776,33852,34282,34895,35523,36041,36376&Targets=1515,75806,75867&Values=46,60,82,100,1266,1588,2677,2746,4432,52897,56058,57005,57006,58702,59988,60001,61089&RawValues=TIELID%2C9348839239621&random=cvcuzjc,bfAqIpmbIuu",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=388426&FlightID=285106&TargetID=77947&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,4875,6041,9129,9496,9779,9781,9853,10381,16113,17173,17251,18517,18982,20139,23491,30995,31071,32004,32594,32828,32859,33776,33852,34282,34485,34895,35523,36041,36105,36376&Targets=77048,73788,77741,75201,1515,77947,76343,84488,87917&Values=46,60,82,100,1266,1588,2677,2746,4432,48137,52897,56058,57005,57006,58702,59988,61089&RawValues=TIELID%2C9348839239621&random=bpxeKwy,bfAqIpmbKhI",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=390833&FlightID=285031&TargetID=34606&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,12853,16113,17173,17251,18517,18982,19974,20139,23491,32004,32594,32859,33776,33852,34282,34895,35523,36041,36376&Targets=34606,1515,46824&Values=46,60,82,100,1266,1588,2677,2746,4432,52786,52897,56058,57005,57006,58702,59988,61089&RawValues=TIELID%2C9348839239621&random=coaKddo,bfAqIpmbIqy",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=396796&FlightID=272450&TargetID=85456&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,16113,17173,17251,18517,18982,20139,23491,30357,30363,31448,32004,32594,32827,32859,33776,33852,34282,34895,35523,35605,36041,36257,36376&Targets=73787,73789,1515,82547,82806,85456,79630&Values=46,60,82,100,1266,1588,2677,2746,4432,52897,56058,57005,57006,58702,59473,59988,61089&RawValues=TIELID%2C9348839239622&random=ckvbliA,bfAqIpmbKhw",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=396796&FlightID=272450&TargetID=85456&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,16113,17173,17251,18517,18982,20139,23491,30363,30708,31448,32004,32594,32859,33776,33852,34282,34895,35523,35605,36041,36260,36376&Targets=73789,1515,82806,82549,85456&Values=46,60,82,100,1266,1588,2677,2746,4432,52897,56058,57005,57006,58702,59474,59988,61089&RawValues=TIELID%2C9348839239622&random=bKxwbjs,bfAqIpmbKhy",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=396796&FlightID=272450&TargetID=85456&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,16113,17173,17251,18517,18982,20139,23491,30363,30709,31448,32004,32594,32859,33776,33852,34282,34895,35523,35605,36041,36261,36376&Targets=73789,1515,82806,82548,85456&Values=46,60,82,100,1266,1588,2677,2746,4432,52897,56058,57005,57006,58702,59475,59988,61089&RawValues=TIELID%2C9348839239622&random=biqiovA,bfAqIpmbIqI",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=397003&FlightID=292368&TargetID=72775&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,13086,13087,13088,13090,13091,13303,16113,16337,17173,17251,18517,18887,18901,18904,18982,20139,23491,23793,25535,25538,25544,25547,25550,29699,29776,30401,31073,32004,32594,32736,32825,32859,33776,33852,34253,34282,34895,35523,35895,36040,36041,36310,36376&Targets=73881,72775,72645,1515,70690,88526,86748,86245,86257,85450,76350,79628,82457,85144,85146,86622,88640,86090,87669,87671,82751,85139,82663,84902,86352,88869,82775,84903,82659,84555,84559,84564,87626,87918&Values=46,60,82,100,1266,1588,2677,2746,4432,52897,56058,57005,57006,58702,59477,59988,61089&RawValues=TIELID%2C9348839239621&random=cNeKdzI,bfAqIpmbIut",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=120x90_bot1&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=653357",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=126x31_spon3&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=223595",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=126x31_spon8&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=101386",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=126x31_spon9&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=308194",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=1x1_bot&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=728136",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=230x250_adlinks&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=709129",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=300x100_bot1&cnn_rollup=homepage&page.allowcompete=no&params.styles=fs&tile=9348839239622&domId=274828",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=300x100_bot2&cnn_rollup=homepage&page.allowcompete=no&params.styles=fs&tile=9348839239622&domId=790397",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=300x100_bot3&cnn_rollup=homepage&page.allowcompete=no&params.styles=fs&tile=9348839239622&domId=709102",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=300x250_rgt&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=985003",
+      "http://b.scorecardresearch.com/r2?c2=6035748&d.c=gif&d.o=cnn3global&d.x=253275916&d.t=page&d.u=http%3A%2F%2Fwww.cnn.com%2F",
+      "http://b.scorecardresearch.com/r?c2=6035748&d.c=gif&d.o=cnn3global&d.x=253275916&d.t=page&d.u=http%3A%2F%2Fwww.cnn.com%2F",
+      "http://cnn.dyn.cnn.com/cookie.crumb",
+      "http://content.dl-rms.com/rms/mother/5721/nodetag.js",
+      "http://es.optimost.com/es/203/c/3/u/cnn_live.js",
+      "http://gdyn.cnn.com/1.1/1.gif?1269329388870",
+      "http://googleads.g.doubleclick.net/pagead/ads?client=ca-cnn-home_js&output=js&num_ads=3&channel=homepage&ad_type=text&adtest=off&ea=0&oe=utf8&flash=10.0.45&hl=en&url=http%3A%2F%2Fwww.cnn.com%2F&adsafe=high&dt=1269329389465&correlator=1269329389472&frm=1&ga_vid=1045930262.1269329390&ga_sid=1269329390&ga_hid=558562656&ga_fc=0&u_tz=60&u_his=3&u_java=0&u_h=768&u_w=1366&u_ah=768&u_aw=1366&u_cd=24&u_nplug=2&u_nmime=3&biw=1349&bih=390&ifk=806819358&loc=http%3A%2F%2Fwww.cnn.com%2F&fu=4&ifi=1&dtd=210",
+      "http://googleads.g.doubleclick.net/pagead/test_domain.js",
+      "http://i.cdn.turner.com/cnn/.element/css/3.0/common.css",
+      "http://i.cdn.turner.com/cnn/.element/css/3.0/common.css",
+      "http://i.cdn.turner.com/cnn/.element/css/3.0/connect/overlay.css",
+      "http://i.cdn.turner.com/cnn/.element/css/3.0/main.css",
+      "http://i.cdn.turner.com/cnn/.element/css/3.0/personalization.css",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/1px.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/buttons/Sprite_BT_master.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/buttons/sprite_tabbed.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/arabic.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/footer_cnn_logo.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/footer_google.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/japanese.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/korean.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/turkish.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/bg-nav.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/hat/arrow_black.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/hat/bg_hat_black_lg.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/hdr-close.jpg",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/hdr-main.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/hdr-search-google.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/nav-arrow.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/nav-beta.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/icons/red.carrot.jpg",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/icons/video_icon.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/Numbers_Sprite.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/advertisement.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/filter.line.100px.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/loading.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/red_bull.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/BL_shadow_7x6.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/BR_shadow_1000x6.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/Left_shadow.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/Right_shadow.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/TL_shadow_7x6.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/TR_shadow_1000x6.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/cnn_shdcamtt1.990px.bg.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/cnn_shdcamtt1.990px.header.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/cnn_shdsectbin.990px.bg.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/sprite_shades.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/35x35_generic_avatar.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/Green_market_status.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/Module_gradient.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/arrow_down.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/arrow_up.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/hp_market_sprite.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/popular_bar.jpg",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/search/bg_ftrsearchfield.lrg.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/search/btn_search_hp_text.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/search/search_btn_footer.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/video/thumbnail_play.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/weather/03/33.png",
+      "http://i.cdn.turner.com/cnn/.element/js/2.0/ad_head0.js",
+      "http://i.cdn.turner.com/cnn/.element/js/2.0/frame.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/StorageManager.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/connect/connect-lite.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/csiManager.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/edition.vars.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/hpsectiontracking.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/local.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/main.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/protoaculous.1.8.2.min.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/s_code.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/swfobject-2.2.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/video/cvp.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/video/cvp_suppl.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/weather.footer.js",
+      "http://i.cdn.turner.com/cnn/2009/images/11/16/210x80_cnn_Challenge.jpg",
+      "http://i.cdn.turner.com/cnn/2010/HEALTH/03/22/united.nations.water.report/c1main.india.river.afp.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/LIVING/03/22/margaret.moth.tributes/tzvids.margaret.moth.courtesy.jpg",
+      "http://i.cdn.turner.com/cnn/2010/LIVING/03/22/real.men.eat.salad/tzvids.salad.cnn.jpg",
+      "http://i.cdn.turner.com/cnn/2010/LIVING/03/22/vegan.food.activists/tzvids.veg.activists.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/LIVING/worklife/03/22/cb.job.search.mistakes/tzvids.js.mistakes.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/LIVING/worklife/03/22/rs.secrets.working.mother/tzvids.unflappable.mom.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/POLITICS/03/16/health.care.immediate/tzvids.benefits.c2.jpg",
+      "http://i.cdn.turner.com/cnn/2010/SHOWBIZ/TV/03/22/rosie.odonnell.show.ppl/tzvids.rosie.odonnell.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/SPORT/tennis/03/18/tennis.film.nadal.amritraj.mcenroe/tzvids.rafa.jpg",
+      "http://i.cdn.turner.com/cnn/2010/TRAVEL/03/22/flying.now.then/tzvids.flying.then.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/WORLD/africa/03/22/africa.elephants.ivory.trade/tzvids.elephant.poaching.jpg",
+      "http://i.cdn.turner.com/cnn/2010/WORLD/europe/03/22/germany.hitler.letter.cordial/tzvids.hitler.letter.jpg",
+      "http://i.cdn.turner.com/cnn/2010/images/03/22/tzvids.health.effects.irpt.jpg",
+      "http://i.cdn.turner.com/cnn/2010/images/03/22/tzvids.ncaa.upset.gi.jpg",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2008/9/17/2855151x1.gif",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2008/9/17/2855151x1.gif",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2008/9/17/2855151x1.gif",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2009/11/9/56101520090708_DB_IP_DBLEPLUSA_24_300_100.swf",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2009/11/9/56101520090708_DB_IP_DBLEPLUSA_24_300_100.swf",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2009/11/9/56101520090708_DB_IP_DBLEPLUSA_24_300_100.swf",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2009/6/3/4436122_equifax.143x31.jpg",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/cnn_adspaces.js",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif?csiTestMatch=true",
+      "http://i.cdn.turner.com/cnn/video/us/2010/03/22/dnt.cows.drink.more.beer.kval.120x68.jpg",
+      "http://i.cdn.turner.com/xslo/cvp/ads/freewheel/js/fwjslib_1.1.js?version=1.1",
+      "http://i.cnn.net/cnn/.element/js/2.0/csi_include.js",
+      "http://i2.cdn.turner.com/cnn/2009/images/10/27/lking120x68.copy.jpg",
+      "http://i2.cdn.turner.com/cnn/2009/images/10/29/roberts-chetry120x68.copy.jpg",
+      "http://i2.cdn.turner.com/cnn/2010/POLITICS/03/22/health.care.main/t1main.obama.cnn.jpg",
+      "http://i2.cdn.turner.com/cnn/2010/images/03/15/jk_usa_plain_120x68.jpg",
+      "http://i2.cdn.turner.com/cnn/2010/images/03/22/tzvids.kennedy.offcenter.cnn.jpg?hpt=C2",
+      "http://js.revsci.net/gateway/gw.js?csid=A09801",
+      "http://metrics.cnn.com/b/ss/cnn3global/1/H.20.3/s0429878539768?AQB=1&ndh=1&t=23/2/2010%208%3A29%3A48%202%20-60&ns=cnn&pageName=CNN%20Home%20Page&g=http%3A//www.cnn.com/&ch=CNN%20Home%20Page&v1=CNN%20Home%20Page&v2=CNN%20Home%20Page&c5=Homepage&v5=Homepage&c9=03%3A15&c10=Tue&c18=10&c20=03&s=1366x768&c=24&j=1.7&v=N&k=Y&bw=1366&bh=390&p=Mozilla%20Default%20Plug-in%3BShockwave%20Flash%3B&AQE=1",
+      "http://metrics.cnn.com/b/ss/cnn3global/1/H.20.3/s0429878539768?AQB=1&pccr=true&vidn=25D436F5051D16A6-40000105C00092FC&&ndh=1&t=23/2/2010%208%3A29%3A48%202%20-60&ns=cnn&pageName=CNN%20Home%20Page&g=http%3A//www.cnn.com/&ch=CNN%20Home%20Page&v1=CNN%20Home%20Page&v2=CNN%20Home%20Page&c5=Homepage&v5=Homepage&c9=03%3A15&c10=Tue&c18=10&c20=03&s=1366x768&c=24&j=1.7&v=N&k=Y&bw=1366&bh=390&p=Mozilla%20Default%20Plug-in%3BShockwave%20Flash%3B&AQE=1",
+      "http://pagead2.googlesyndication.com/pagead/show_ads.js",
+      "http://pix04.revsci.net/A09801/b3/0/3/0902121/429848602.js?D=DM_LOC%3Dhttp%253A%252F%252Fwww.cnn.com%252F%253Fundefined%253Dundefined%26DM_CAT%3Dcnn%2520%253E%2520homepage%26DM_EOM%3D1&C=A09801",
+      "http://s0.2mdn.net/viewad/1873234/CR7USDS_001_300x250.gif",
+      "http://s0.2mdn.net/viewad/2584085/120x90_Ally_Logo.gif",
+      "http://s0.2mdn.net/viewad/617966/84-1x1.gif",
+      "http://svcs.cnn.com/weather/getForecast?time=59&mode=json_html&zipCode=74446&locCode=MUSX&celcius=false&csiID=csi3",
+      "http://view.atdmt.com/NYC/view/184916056/direct;wi.1;hi.1/01/bKxwbjs,bfAqIpmbKhy",
+      "http://view.atdmt.com/NYC/view/184916056/direct;wi.1;hi.1/01/biqiovA,bfAqIpmbIqI",
+      "http://view.atdmt.com/NYC/view/184916056/direct;wi.1;hi.1/01/ckvbliA,bfAqIpmbKhw",
+      "http://www.cnn.com/",
+      "http://www.cnn.com/.element/ssi/misc/3.0/editionvars.html?csiID=csi2",
+      "http://www.cnn.com/.element/ssi/www/breaking_news/3.0/banner.html?csiID=csi1",
+      "http://www.cnn.com/cnn_adspaces/3.0/homepage/main/bot1.120x90.ad"
+    ];
+
+    function runTest()
+    {
+      // Add everything to the same matcher, don't bother separating whitelist and blacklist
+      let matcher = new Matcher();
+      for each (let filter in filters)
+        matcher.add(filter);
+    }
+
+    function cleanup()
+    {
+      // Delete shortcuts added by the matcher
+      for each (let filter in filters)
+        delete filter.shortcut;
+    }
+
+    runTests(runTest, cleanup);
+  </script>
+</body>
+</html>

=== added file 'chrome/content/mochitest/tests/performance/matching.html'
--- chrome/content/mochitest/tests/performance/matching.html	1970-01-01 00:00:00 +0000
+++ chrome/content/mochitest/tests/performance/matching.html	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2565 @@
+<!DOCTYPE HTML>
+<html>
+<head>
+  <title>Filter matching performance measurements</title>
+  <script type="application/x-javascript;version=1.7" src="common.js"></script>
+  <script type="application/x-javascript;version=1.7" src="../common.js"></script>
+  <script type="application/x-javascript;version=1.7" src="chrome://adblockplus/content/filterClasses.js"></script>
+  <script type="application/x-javascript;version=1.7" src="chrome://adblockplus/content/matcher.js"></script>
+</head>
+<body>
+  <p id="progress">Please wait while performance measurement is in progress... <span id="current"></span></p>
+
+  <pre id="result"></pre>
+
+  <script type="application/x-javascript;version=1.7">
+    let filters = [
+      "&ad_type_id=",
+      "-ad.html",
+      "-banner-ads/",
+      ".aspx?zoneid=*&task=",
+      ".au/_ads/",
+      ".au/ads/",
+      ".ca/ads/",
+      ".com/ad-",
+      ".com/ad/",
+      ".com/ads/",
+      ".com/ads?",
+      ".com/adv/",
+      ".com/advt/",
+      ".com/gad/",
+      ".com/gads/",
+      ".com/ss/ad/",
+      ".html?ad=",
+      ".net/_ads/",
+      ".net/ad/$~object_subrequest",
+      ".net/ads/",
+      ".net/adv/",
+      ".nz/ads/",
+      ".org/ads/",
+      ".org/gads/",
+      ".php?bannerid=",
+      ".php?zoneid=*&loc=",
+      ".swf?clicktag=",
+      ".tv/ads/",
+      ".uk/ads/",
+      ".us/ads/",
+      ".za/ads/",
+      "/*;cue=pre;$object_subrequest",
+      "/.adserv/*",
+      "/468xads.",
+      "/_adv.gif?",
+      "/_media/ads/*",
+      "/a8-ads/*",
+      "/aamsz=*/acc_random=",
+      "/aamsz=*/pageid=",
+      "/aamsz=*/position=",
+      "/abm.asp?z=",
+      "/abmw.asp?z=",
+      "/abmw.aspx",
+      "/acc_random=*/aamsz=",
+      "/ad-1.5.",
+      "/ad-amz.",
+      "/ad-box-single.",
+      "/ad-cdn.",
+      "/ad-frame.",
+      "/ad-iframe-wrapper.",
+      "/ad-inject/*",
+      "/ad-leaderboard.",
+      "/ad-loader-frame.",
+      "/ad-server/*",
+      "/ad-top-fr.",
+      "/ad-topbanner-single.",
+      "/ad-vertical-single.",
+      "/ad.asp?",
+      "/ad.aspx",
+      "/ad.cgi?",
+      "/ad.html",
+      "/ad.jsp?",
+      "/ad.mason?",
+      "/ad.php?",
+      "/ad.pl?z",
+      "/ad/?id=",
+      "/ad/adtech",
+      "/ad/banner",
+      "/ad/code",
+      "/ad/common",
+      "/ad/frame",
+      "/ad/google",
+      "/ad/header",
+      "/ad/iframe/*",
+      "/ad/img/*",
+      "/ad/inad",
+      "/ad/init",
+      "/ad/lrec",
+      "/ad/mercury",
+      "/ad/mrec",
+      "/ad/script/*",
+      "/ad/serve",
+      "/ad/side_",
+      "/ad/skyscraper",
+      "/ad/sponsor",
+      "/ad/text",
+      "/ad/view",
+      "/ad/wr.php",
+      "/ad160.php",
+      "/ad1x1home.",
+      "/ad2.aspx",
+      "/ad2.html",
+      "/ad350.html",
+      "/ad728.php",
+      "/ad728x15.",
+      "/ad?count=",
+      "/ad_banner_left/*",
+      "/ad_banner_right/*",
+      "/ad_configuration.",
+      "/ad_creatives.",
+      "/ad_engine?",
+      "/ad_feed.js?",
+      "/ad_forum_",
+      "/ad_frame.",
+      "/ad_functions.",
+      "/ad_google.",
+      "/ad_holder/*",
+      "/ad_iframe.",
+      "/ad_iframe_",
+      "/ad_insert.",
+      "/ad_js.php",
+      "/ad_label_",
+      "/ad_left.",
+      "/ad_legend_",
+      "/ad_manager.",
+      "/ad_notice.",
+      "/ad_page_frame.",
+      "/ad_rectangle_",
+      "/ad_refresher.",
+      "/ad_reloader_",
+      "/ad_right.",
+      "/ad_serv.",
+      "/ad_serve.",
+      "/ad_server.",
+      "/ad_server/*",
+      "/ad_sizes=",
+      "/ad_sky.",
+      "/ad_space.",
+      "/ad_square.",
+      "/ad_supertile/*",
+      "/ad_tag_",
+      "/ad_tile/*",
+      "/ad_top.",
+      "/ad_vert.",
+      "/ad_view_",
+      "/adbanner.",
+      "/adbanner/*",
+      "/adbanners/*",
+      "/adbot_promos/*",
+      "/adbox.gif",
+      "/adbrite.",
+      "/adbureau.",
+      "/adchannel_",
+      "/adclick.",
+      "/adclient.",
+      "/adclient/*",
+      "/adcode.",
+      "/adcodes/*",
+      "/adconfig.js",
+      "/adconfig.xml?",
+      "/adconfig/*",
+      "/adcontent.$~object_subrequest",
+      "/adcreative.",
+      "/adcycle.",
+      "/adcycle/*",
+      "/addelivery/*",
+      "/addyn/3.0/*",
+      "/addyn|*|adtech;",
+      "/adengage1.",
+      "/adengage_",
+      "/adengine/*",
+      "/adexclude/*",
+      "/adf.cgi?",
+      "/adfarm.",
+      "/adfetch?",
+      "/adfetcher?",
+      "/adfooter.",
+      "/adframe.",
+      "/adframe/*",
+      "/adframe?",
+      "/adframe_",
+      "/adfshow?",
+      "/adfunction.",
+      "/adfunctions.",
+      "/adgraphics/*",
+      "/adguru.",
+      "/adhandler/*",
+      "/adheader.",
+      "/adhomepage.jsp",
+      "/adhtml/*",
+      "/adiframe.",
+      "/adiframe/*",
+      "/adimage.aspx",
+      "/adimage.php?",
+      "/adimages.",
+      "/adimages/*",
+      "/adindex/*",
+      "/adinjector.",
+      "/adinsert.",
+      "/adinterax.",
+      "/adjs.php?",
+      "/adjsmp.php?",
+      "/adlabel.",
+      "/adlabel_",
+      "/adlayer.php?",
+      "/adlayer/*",
+      "/adleader.",
+      "/adlink.",
+      "/adlink_",
+      "/adlinks.",
+      "/adm/ad/*",
+      "/adman.js",
+      "/adman/image/*",
+      "/adman/www/*",
+      "/admanagement/*",
+      "/admanagementadvanced.",
+      "/admanager.$~object_subrequest",
+      "/admanager/*$~object_subrequest",
+      "/admanager3.",
+      "/admanagerstatus/*",
+      "/admaster.",
+      "/admaster?",
+      "/admedia.",
+      "/admentor/*",
+      "/admin/ad_",
+      "/adnetwork.",
+      "/adng.html",
+      "/adonline.",
+      "/adpage.",
+      "/adpage/*",
+      "/adpeeps.",
+      "/adpeeps/*",
+      "/adplayer.",
+      "/adplayer/*",
+      "/adplugin.",
+      "/adpoint.",
+      "/adpopup.",
+      "/adproducts/*",
+      "/adproxy.",
+      "/adproxy/*",
+      "/adrelated.",
+      "/adreload?",
+      "/adremote.",
+      "/adrevenue/*",
+      "/adrevolver/*",
+      "/adrolays.",
+      "/adroot/*",
+      "/adrot.js",
+      "/adruptive.",
+      "/ads-1.js",
+      "/ads-2.js",
+      "/ads-banner.",
+      "/ads-leader|",
+      "/ads-rec|",
+      "/ads-service.",
+      "/ads-sky|",
+      "/ads.asp?",
+      "/ads.dll/*",
+      "/ads.htm",
+      "/ads.php?",
+      "/ads/acctid",
+      "/ads/ad-",
+      "/ads/common/*",
+      "/ads/frame",
+      "/ads/freewheel/*",
+      "/ads/house/*",
+      "/ads/html",
+      "/ads/i_ads.",
+      "/ads/interstitial/*",
+      "/ads/java",
+      "/ads/labels/*",
+      "/ads/layer.",
+      "/ads/pa/*",
+      "/ads/paid",
+      "/ads/right",
+      "/ads/text",
+      "/ads/top",
+      "/ads/www",
+      "/ads2.php",
+      "/ads2_2.",
+      "/ads_iframe.",
+      "/ads_php/*",
+      "/ads_reporting/*",
+      "/ads_v2.",
+      "/ads_yahoo.",
+      "/adsadclient31.",
+      "/adsadview.",
+      "/adsatt.",
+      "/adsbanner.",
+      "/adscluster.",
+      "/adscontent.",
+      "/adscontent2.",
+      "/adscript.",
+      "/adscripts/*",
+      "/adsearch.",
+      "/adsense.",
+      "/adsense/*",
+      "/adsense23.",
+      "/adsense24.",
+      "/adsense_",
+      "/adserve/*",
+      "/adserver.",
+      "/adserver/*",
+      "/adserver2.",
+      "/adserver2/*",
+      "/adserver?",
+      "/adserver_",
+      "/adserversolutions/*",
+      "/adservice|",
+      "/adserving.",
+      "/adsfac.",
+      "/adsfetch.",
+      "/adsfolder/*",
+      "/adshandler.",
+      "/adsheader.",
+      "/adshow?",
+      "/adsiframe/*",
+      "/adsign.",
+      "/adsimage/*",
+      "/adsinclude.",
+      "/adsinsert.",
+      "/adsky.php",
+      "/adslots.",
+      "/adslug_",
+      "/adsmanagement/*",
+      "/adsmanager/*",
+      "/adsnew.",
+      "/adsonar.",
+      "/adspace.",
+      "/adsponsor.",
+      "/adspro/*",
+      "/adsremote.",
+      "/adsreporting/*",
+      "/adssrv.",
+      "/adstorage.",
+      "/adstracking.",
+      "/adstream.",
+      "/adstream_nx.",
+      "/adswap.",
+      "/adswap/*",
+      "/adsync/*",
+      "/adsyndication.",
+      "/adsystem/*",
+      "/adtago.",
+      "/adtags.",
+      "/adtags/*",
+      "/adtagtranslator.",
+      "/adtech.",
+      "/adtech/*",
+      "/adtech;",
+      "/adtech_",
+      "/adtext.",
+      "/adtext_",
+      "/adtology.",
+      "/adtop.js",
+      "/adtrack/*",
+      "/adtraff.",
+      "/adtype.php?",
+      "/adunit.",
+      "/adunits/*",
+      "/adv-title.",
+      "/adv.asp?",
+      "/advert.",
+      "/advert/*",
+      "/advert?",
+      "/advert_",
+      "/advertise.",
+      "/advertise/*",
+      "/advertisement-",
+      "/advertisement.",
+      "/advertisement_",
+      "/advertisements/*",
+      "/advertisementview/*",
+      "/advertising.",
+      "/advertising/*",
+      "/advertising_js/*",
+      "/advertisingmanual.",
+      "/advertisment.",
+      "/advertize_on_",
+      "/advertorials/*",
+      "/advertpro/*",
+      "/adverts.",
+      "/adverts/*",
+      "/adverts_",
+      "/adview.",
+      "/adviewer.",
+      "/advision.",
+      "/advpartnerinit.",
+      "/advt.gif",
+      "/adworks.",
+      "/adworks/*",
+      "/adwrapper/*",
+      "/adwrapperiframe.",
+      "/aff_frame.",
+      "/affad?q=",
+      "/affads/*",
+      "/affilatebanner.",
+      "/affiliate*.php?",
+      "/affiliate/banners/*",
+      "/affiliate_banners/*",
+      "/affiliatebanners/*",
+      "/affiliates.*.aspx?",
+      "/affiliates/banner",
+      "/affiliatewiz/*",
+      "/affiliationcash.",
+      "/afimages.",
+      "/afr.php?",
+      "/ajax/ads/*",
+      "/ajrotator/*",
+      "/ajs.php?",
+      "/ak/ads/*",
+      "/annonser/*",
+      "/api/ads/*",
+      "/app/ads.js",
+      "/article_ad.",
+      "/aseadnshow.",
+      "/audioads/*",
+      "/auto_ad_change.",
+      "/ban_m.php?",
+      "/banimpress.",
+      "/banman.asp?",
+      "/banman/*",
+      "/banner/affiliate/*",
+      "/banner_ad.",
+      "/banner_ad_",
+      "/banner_ads.",
+      "/banner_ads_",
+      "/banner_control.php?",
+      "/banner_db.php?",
+      "/banner_file.php?",
+      "/banner_js.*?",
+      "/banner_management/*",
+      "/banner_skyscraper.",
+      "/bannerad.",
+      "/bannerads-",
+      "/bannerads/*",
+      "/banneradviva.",
+      "/bannercode.php",
+      "/bannerfarm/*",
+      "/bannerframe.*?",
+      "/bannermanager/*",
+      "/bannermedia/*",
+      "/bannerrotation.",
+      "/banners.*&iframe=",
+      "/banners/affiliate/*",
+      "/banners_rotation.",
+      "/bannerscript/*",
+      "/bannerserver/*",
+      "/bannersyndication.",
+      "/bannerview.*?",
+      "/bannery/*?banner=",
+      "/baselinead.",
+      "/behaviorads/*",
+      "/bg_ads_",
+      "/bigboxad.",
+      "/bkgrndads/*",
+      "/blogad_",
+      "/blogads.",
+      "/blogads3/*",
+      "/bmndoubleclickad.",
+      "/bnrsrv.*?",
+      "/boomad.",
+      "/bottomad/*",
+      "/br_ad_courier.",
+      "/butler.php?type=",
+      "/buttonads.",
+      "/buyclicks/*",
+      "/bw_adsys.",
+      "/bytemark_ad.",
+      "/cashad.",
+      "/cashad2.",
+      "/central/ads/*",
+      "/cgi-bin/ads/*",
+      "/chitika-ad?",
+      "/circads.",
+      "/cnnslads.",
+      "/cnwk.1d/ads/*",
+      "/commercial_horizontal.",
+      "/commercial_top.",
+      "/commercials/*",
+      "/common/ad/*",
+      "/common/ads/*",
+      "/contentad|",
+      "/contextad.",
+      "/controller/ads/*",
+      "/corner_ads/*",
+      "/country_ad.",
+      "/cpxads.",
+      "/ctamlive160x160.",
+      "/customad.",
+      "/cvs/ads/*",
+      "/dart_ads/*",
+      "/dartads.",
+      "/dc_ads.",
+      "/dcloadads/*",
+      "/deliver.nmi?",
+      "/deliverad/*",
+      "/deliverjs.nmi?",
+      "/delivery/ag.php",
+      "/descpopup.js",
+      "/direct_ads.",
+      "/directads.",
+      "/displayad.",
+      "/displayads/*",
+      "/dj_ad.js",
+      "/dne_ad.",
+      "/dnsads.html?",
+      "/doors/ads/*",
+      "/doubleclick.phpi?",
+      "/doubleclick/iframe.",
+      "/doubleclickcontainer.",
+      "/doubleclicktag.",
+      "/drawad.php?",
+      "/dsg/bnn/*",
+      "/dt.cms.ad.page.",
+      "/dyn_banner.",
+      "/dyn_banners_",
+      "/dynamicad?",
+      "/dynamiccsad?",
+      "/dynbanner/flash/*",
+      "/ebay_ads/*",
+      "/emailads/*",
+      "/external/ad.js",
+      "/eyewondermanagement.",
+      "/fatads.",
+      "/featuredadshome.",
+      "/files/ads/*",
+      "/fimserve.",
+      "/flash/ads/*",
+      "/flashads.",
+      "/flashads/*",
+      "/footad-",
+      "/footer_ad_include.",
+      "/fuseads/*",
+      "/gamersad.",
+      "/genericrichmediabannerad/*",
+      "/get-ad.php?",
+      "/get_player_ads_",
+      "/getad.php?",
+      "/getad.php|",
+      "/getad?n=",
+      "/getadframe.",
+      "/getadvertimageservlet?",
+      "/getarticleadvertimageservlet?",
+      "/getbanner.cfm?",
+      "/getsponslinks.",
+      "/getsponslinksauto.",
+      "/getvideoad.",
+      "/gfx/ads/*",
+      "/glam_ads.",
+      "/google-ad?",
+      "/google-ads.",
+      "/google-adsense-",
+      "/google-adsense.",
+      "/google_ad_",
+      "/google_ads.",
+      "/google_ads/*",
+      "/google_adsense.",
+      "/google_adsense_",
+      "/google_afc.",
+      "/googlead-",
+      "/googlead.",
+      "/googleadhtml/*",
+      "/googleads-",
+      "/googleads.html",
+      "/googleads.js",
+      "/googleads2.",
+      "/googleads_",
+      "/googleadsense.",
+      "/gt6skyadtop.",
+      "/hat_ad_label.",
+      "/homepage_ads/*",
+      "/housead/*",
+      "/houseads/*",
+      "/houseads?",
+      "/html.ng/*",
+      "/htmlads/*",
+      "/httpads/*",
+      "/icon_ad.",
+      "/iframe-ads/*",
+      "/iframe/ad/*",
+      "/iframe_ad.",
+      "/iframe_ads/*",
+      "/iframe_ads?",
+      "/iframe_chitika_",
+      "/iframead.",
+      "/im-ad/im-",
+      "/images/ad-",
+      "/images/ad/*",
+      "/images/ad_",
+      "/images/ads-",
+      "/images/ads/*",
+      "/img/ad_",
+      "/img/ads/*",
+      "/in/adv/*",
+      "/inc/ads/*",
+      "/include/ads/*",
+      "/includes/ad_",
+      "/includes/ads/*",
+      "/inline_ad.",
+      "/instreamad/*",
+      "/intextads.",
+      "/invideoad.",
+      "/ireel/ad*.jpg",
+      "/iwadsense.",
+      "/j/ads.js",
+      "/ji_advertise.",
+      "/jivoxadplayer.",
+      "/jlist-affiliates/*",
+      "/js.ng/c",
+      "/js.ng/s",
+      "/js/ad_eo_",
+      "/js/ads.js",
+      "/js/ads/*",
+      "/jsfiles/ads/*",
+      "/kredit-ad.",
+      "/layer-ad.",
+      "/layer-ads.",
+      "/layerads_",
+      "/layout/ads/*",
+      "/lbl_ad.",
+      "/leader_ad.",
+      "/links_sponsored_",
+      "/linkshare/*",
+      "/loadad.aspx?",
+      "/m4_advertorials/*",
+      "/m=advert/*",
+      "/mac-ad?",
+      "/magic-ads/*",
+      "/main/ad_",
+      "/mainad.",
+      "/mbn_ad.",
+      "/media/ads/*",
+      "/megaad.",
+      "/metaadserver/*",
+      "/miva_ads.",
+      "/mnetorfad.js",
+      "/mod_ad/*",
+      "/modules/ads/*",
+      "/mpumessage.",
+      "/mstextad?",
+      "/mtvi_ads_",
+      "/mylayer-ad/*",
+      "/neoads.",
+      "/new/ad/*",
+      "/newrightcolad.",
+      "/news_ad.",
+      "/newtopmsgad.",
+      "/nextad/*",
+      "/oasadframe.",
+      "/oascentral.$~object_subrequest",
+      "/oasdefault/*",
+      "/oasisi-*.php?",
+      "/oasisi.php?",
+      "/oiopub-direct/*",
+      "/openads-",
+      "/openads.",
+      "/openads/*",
+      "/openads2/*",
+      "/openx/www/*",
+      "/openx_fl.",
+      "/other/ads/*",
+      "/overlay_ad_",
+      "/ovt_show.asp?",
+      "/p2/ads/*",
+      "/page-ads.",
+      "/pagead/ads?*_fetch=",
+      "/pagead/ads?*_start_delay=1",
+      "/pageadimg/*",
+      "/pageads/*",
+      "/pageear.",
+      "/pageear/*",
+      "/pagepeel-",
+      "/pagepeel.",
+      "/pagepeel/*",
+      "/pagepeelads.",
+      "/paidlisting/*",
+      "/partnerbanner.",
+      "/partnerbanner/*",
+      "/peel.js",
+      "/peel1.js",
+      "/peelad/*",
+      "/peeljs.php",
+      "/perfads.",
+      "/performancingads/*",
+      "/phpads.",
+      "/phpads/*",
+      "/phpads2/*",
+      "/phpadserver/*",
+      "/phpadsnew/*",
+      "/pictures/ads/*",
+      "/pilot_ad.",
+      "/pitattoad.",
+      "/pix/ad/*",
+      "/play/ad/*",
+      "/popads.",
+      "/popunder.",
+      "/position=*/aamsz=",
+      "/premium_ad.",
+      "/printad.",
+      "/printads/*",
+      "/processads.",
+      "/promobuttonad.",
+      "/promotions/ads?",
+      "/protection/ad/*",
+      "/pub/ad/*",
+      "/pub/ads/*",
+      "/public/ad/*",
+      "/public/ad?",
+      "/publicidad.$~object_subrequest",
+      "/publicidad/*",
+      "/pyv_watch_request_ad.",
+      "/questions/ads/*",
+      "/radopenx?",
+      "/railads.",
+      "/random=*/aamsz=",
+      "/realmedia/ads/*",
+      "/rec_ad1.",
+      "/reclame/*",
+      "/reklam.",
+      "/reklama.",
+      "/relatedads.",
+      "/requestadvertisement.",
+      "/requestmyspacead.",
+      "/rightad.",
+      "/rotateads.",
+      "/rotatingpeels.js",
+      "/rsads/c",
+      "/rsads/r",
+      "/scripts/ad-",
+      "/scripts/ad.",
+      "/scripts/ads/*",
+      "/scripts/clickjs.php",
+      "/search/ads?",
+      "/searchads/*",
+      "/services/ads/*",
+      "/sevenl_ad.",
+      "/share/ads/*",
+      "/shared/ads/*",
+      "/show_ad.",
+      "/show_ad_",
+      "/show_ads.js?",
+      "/show_ads_",
+      "/show_afs_ads.",
+      "/showad.",
+      "/showad/*",
+      "/showads.",
+      "/showflashad.",
+      "/showlayer.",
+      "/sideads/*",
+      "/sideads|",
+      "/sidebarad/*",
+      "/sidecol_ad.",
+      "/silver/ads/*",
+      "/siteads.",
+      "/siteafs.txt?",
+      "/sites/ad_",
+      "/skyad.php",
+      "/skyadjs/*",
+      "/slideinad.",
+      "/small_ad.",
+      "/smartad.",
+      "/socialads.",
+      "/socialads/*",
+      "/spc.php?",
+      "/spcjs.php?",
+      "/special-ads/*",
+      "/special_ads/*",
+      "/spo_show.asp?",
+      "/sponsimages/*",
+      "/sponslink_",
+      "/sponsor-ad|",
+      "/sponsorad.",
+      "/sponsoradds/*",
+      "/sponsorads/*",
+      "/sponsored_links_",
+      "/sponsored_text.",
+      "/sponsoredlinks.",
+      "/sponsoredlinks/*",
+      "/square-ads/*",
+      "/squaread.",
+      "/srv/ad/*",
+      "/static/ad_",
+      "/static/ads/*",
+      "/stickyad.",
+      "/storage/ads/*",
+      "/swf/ad-",
+      "/synad2.",
+      "/system/ad/*",
+      "/systemad.",
+      "/systemad_",
+      "/testingad.",
+      "/textad.",
+      "/textad?",
+      "/textads/*",
+      "/textads_",
+      "/thirdparty/ad/*",
+      "/tii_ads.",
+      "/tikilink?",
+      "/tmo/ads/*",
+      "/toigoogleads.",
+      "/toolkitads.",
+      "/top_ad.",
+      "/top_ads/*",
+      "/trackads/*",
+      "/tracked_ad.",
+      "/tradead_",
+      "/tribalad.",
+      "/ttz_ad.",
+      "/tx_macinabanners/*",
+      "/update_ads/*",
+      "/upload/ads/*",
+      "/uploads/ads/*",
+      "/valueclick.",
+      "/vclkads.",
+      "/video/ads/*",
+      "/video_ad.",
+      "/video_ad_right.",
+      "/videoad.",
+      "/videoads.",
+      "/videoads/*",
+      "/videowall-ad.",
+      "/view/banner/*/zone?zid=",
+      "/vr-ad.png",
+      "/vtextads.",
+      "/webad?a",
+      "/webadimg/*",
+      "/webads.",
+      "/webads_",
+      "/webadverts/*",
+      "/wipeads/*",
+      "/wp-content/ads/*",
+      "/wp-srv/ad/*",
+      "/wpads/iframe.",
+      "/writelayerad.",
+      "/www/delivery/*",
+      "/xmladparser.",
+      "/your-ad.",
+      "/ysmads.",
+      "/zanox/banner/*",
+      "/zanox_ad/*",
+      "8080/ads/",
+      ";iframeid=ad_",
+      "?*&ad_keyword=",
+      "?*&adname=",
+      "?*&adspace=",
+      "?*&clientype=*&adid=",
+      "?*&google_adpage=",
+      "?*&googleadword=",
+      "?ad_ids=*&referer=",
+      "?ad_type=",
+      "?ad_width=",
+      "?adarea=",
+      "?adclass=",
+      "?adpage=",
+      "?adtype=",
+      "?advertising=",
+      "?advtile=",
+      "?file=ads&",
+      "?getad=&$~object_subrequest",
+      "_ad.aspx",
+      "_ad.php?",
+      "_ad_big.",
+      "_ad_code.",
+      "_ads.php?",
+      "_ads_reporting.",
+      "_adserve/",
+      "_adspaces.",
+      "_adtitle.",
+      "_advert.",
+      "_advert1.",
+      "_blogads.",
+      "_box_ads/",
+      "_buttonad.",
+      "_companionad.",
+      "_custom_ad.",
+      "_custom_ad_sets.",
+      "_dynamicads/",
+      "_fd_adbg1a.",
+      "_fd_adbg2.",
+      "_fd_adbg2a.",
+      "_fd_adtop.",
+      "_overlay_ad.",
+      "_topad.php",
+      "_videoad.",
+      "a/adx.js",
+      "d/adx.js",
+      "e/adx.js",
+      "e/js.ng/",
+      "e/js_ng/",
+      "k/ads.pl",
+      "m/adbox/",
+      "m/ads.pl",
+      "m/adx.js",
+      "m/js.ng/",
+      "m/topads|",
+      "n/adx.js",
+      "r/ad.htm",
+      "s/adx.js",
+      "t/adx.js",
+      "u/adx.js",
+      "z/adx.js",
+      "|http://a.ads.",
+      "|http://ad-uk.",
+      "|http://ad.$~object_subrequest,domain=~europa.eu|~sjsu.edu|~uitm.edu.my|~uni-freiburg.de",
+      "|http://ad0.",
+      "|http://ad1.",
+      "|http://ad2.",
+      "|http://ad3.",
+      "|http://ad4.",
+      "|http://ad5.",
+      "|http://ad6.",
+      "|http://ad7.",
+      "|http://adimg.",
+      "|http://adnet.",
+      "|http://ads.",
+      "|http://ads0.",
+      "|http://ads1.",
+      "|http://ads2.",
+      "|http://ads3.",
+      "|http://ads4.",
+      "|http://ads5.",
+      "|http://adsrv.",
+      "|http://adsvr.",
+      "|http://adsys.",
+      "|http://adv.",
+      "|http://adver.",
+      "|http://bwp.*/search",
+      "|http://feeds.*/~a/",
+      "|http://getad.",
+      "|http://jazad.",
+      "|http://openx.",
+      "|http://rss.*/~a/",
+      "|http://synad.",
+      "|http://wrapper.*/a?",
+      "*-120x600*",
+      "*-160x600*",
+      "*-300x250*",
+      "*-336x280*",
+      "*-360x110.*",
+      "*-468_60.*",
+      "*-468x60-*",
+      "*-468x60.*",
+      "*-468x60/*",
+      "*-468x60_*",
+      "*-468x80-*",
+      "*-468x80.*",
+      "*-468x80/*",
+      "*-468x80_*",
+      "*-480x60-*",
+      "*-480x60.*",
+      "*-480x60/*",
+      "*-480x60_*",
+      "*-728x90-*",
+      "*-728x90.*",
+      "*-728x90/*",
+      "*-728x90_*",
+      "*.120x600*",
+      "*.160x600*",
+      "*.300x250*",
+      "*.336x280*",
+      "*.468x60-*",
+      "*.468x60.*",
+      "*.468x60/*",
+      "*.468x60_*",
+      "*.468x80-*",
+      "*.468x80.*",
+      "*.468x80/*",
+      "*.468x80_*",
+      "*.480x60-*",
+      "*.480x60.*",
+      "*.480x60/*",
+      "*.480x60_*",
+      "*.728x90-*",
+      "*.728x90.*",
+      "*.728x90/*",
+      "*.728x90_*",
+      "*/120x600*",
+      "*/160x600*",
+      "*/300x250*",
+      "*/336x280*",
+      "*/468by60*",
+      "*/468x60-*",
+      "*/468x60.*",
+      "*/468x60/*",
+      "*/468x60_*",
+      "*/468x80-*",
+      "*/468x80.*",
+      "*/468x80/*",
+      "*/468x80_*",
+      "*/480x60-*",
+      "*/480x60.*",
+      "*/480x60/*",
+      "*/480x60_*",
+      "*/728_90/*",
+      "*/728x90-*",
+      "*/728x90.*",
+      "*/728x90/*",
+      "*/728x90_*",
+      "*300x250.*",
+      "*468x60.g*",
+      "*468x60.j*",
+      "*468x60ba*",
+      "*728banne*",
+      "*728x90.g*",
+      "*728x90.h*",
+      "*728x90.j*",
+      "*728x90.p*",
+      "*728x90.s*",
+      "*_120_600*",
+      "*_120x60.*",
+      "*_120x600*",
+      "*_120x60_*",
+      "*_160x290*",
+      "*_160x600*",
+      "*_300x250*",
+      "*_336x280*",
+      "*_460x60.*",
+      "*_468-60.*",
+      "*_468.gif*",
+      "*_468.htm*",
+      "*_468_60.*",
+      "*_468_60_*",
+      "*_468x60-*",
+      "*_468x60.*",
+      "*_468x60/*",
+      "*_468x60_*",
+      "*_468x80-*",
+      "*_468x80.*",
+      "*_468x80/*",
+      "*_468x80_*",
+      "*_468x90.*",
+      "*_480x60-*",
+      "*_480x60.*",
+      "*_480x60/*",
+      "*_480x60_*",
+      "*_580x100*",
+      "*_720x90.*",
+      "*_728_90.*",
+      "*_728_90_*",
+      "*_728by90*",
+      "*_728x90-*",
+      "*_728x90.*",
+      "*_728x90/*",
+      "*_728x90_*",
+      "*_768x90_*",
+      "*e120x600*",
+      "*n728x90_*",
+      "||1100i.com^$third-party",
+      "||188server.com^$third-party",
+      "||247realmedia.com^$third-party",
+      "||2mdn.net^$third-party",
+      "||360ads.com^$third-party",
+      "||3rdads.com^$third-party",
+      "||43plc.com^$third-party",
+      "||600z.com^$third-party",
+      "||777seo.com^$third-party",
+      "||7search.com^$third-party",
+      "||aa.voice2page.com^$third-party",
+      "||accuserveadsystem.com^$third-party",
+      "||acf-webmaster.net^$third-party",
+      "||acronym.com^$third-party",
+      "||ad-flow.com^$third-party",
+      "||ad20.net^$third-party",
+      "||ad2games.com^$third-party",
+      "||ad4game.com^$third-party",
+      "||adaction.se^$third-party",
+      "||adaos-ads.net^$third-party",
+      "||adbard.net^$third-party",
+      "||adblade.com^$third-party",
+      "||adbrite.com^$third-party",
+      "||adbureau.net^$third-party",
+      "||adbutler.com^$third-party",
+      "||adcde.com^$third-party",
+      "||adcentriconline.com^$third-party",
+      "||adchap.com^$third-party",
+      "||adclickmedia.com^$third-party",
+      "||adcru.com^$third-party",
+      "||addynamo.com^$third-party",
+      "||adecn.com^$third-party",
+      "||adengage.com^$third-party",
+      "||adf01.net^$third-party",
+      "||adfactory88.com^$third-party",
+      "||adfrontiers.com^$third-party",
+      "||adfusion.com^$third-party",
+      "||adgardener.com^$third-party",
+      "||adgent007.com^$third-party",
+      "||adgine.net^$third-party",
+      "||adgroups.com^$third-party",
+      "||adhese.be^$third-party",
+      "||adhese.net^$third-party",
+      "||adicate.com^$third-party",
+      "||adinterax.com^$third-party",
+      "||adireland.com^$third-party",
+      "||adisfy.com^$third-party",
+      "||adisn.com^$third-party",
+      "||adition.com^$third-party",
+      "||adjal.com^$third-party",
+      "||adjug.com^$third-party",
+      "||adjuggler.com^$third-party",
+      "||adjuggler.net^$third-party",
+      "||adlink.net^$third-party",
+      "||admarketplace.net^$third-party",
+      "||admeld.com^$third-party",
+      "||admeta.com^$third-party",
+      "||admpads.com^$third-party",
+      "||adnet.biz^$third-party",
+      "||adnet.com^$third-party",
+      "||adnet.ru^$third-party",
+      "||adocean.pl^$third-party",
+      "||adoperator.com^$third-party",
+      "||adotube.com^$third-party",
+      "||adparlor.com^$third-party",
+      "||adperium.com^$third-party",
+      "||adpinion.com^$third-party",
+      "||adpionier.de^$third-party",
+      "||adpremo.com^$third-party",
+      "||adroll.com^$third-party",
+      "||ads-stats.com^$third-party",
+      "||ads4cheap.com^$third-party",
+      "||adsdk.com^$third-party",
+      "||adsensecamp.com^$third-party",
+      "||adserver.yahoo.com^$third-party",
+      "||adservinginternational.com^$third-party",
+      "||adsfactor.net^$third-party",
+      "||adsfast.com^$third-party",
+      "||adsforindians.com^$third-party",
+      "||adshopping.com^$third-party",
+      "||adshuffle.com^$third-party",
+      "||adsmarket.com^$third-party",
+      "||adsonar.com^$third-party",
+      "||adspeed.com^$third-party",
+      "||adsrevenue.net^$third-party",
+      "||adtaily.eu^$third-party",
+      "||adtech.de^$third-party",
+      "||adtechus.com^$third-party",
+      "||adtoll.com^$third-party",
+      "||adtology1.com^$third-party",
+      "||adtology2.com^$third-party",
+      "||adtology3.com^$third-party",
+      "||adtoma.com^$third-party",
+      "||adtrgt.com^$third-party",
+      "||adtrix.com^$third-party",
+      "||adult-adv.com^$third-party",
+      "||adultadworld.com^$third-party",
+      "||adversalservers.com^$third-party",
+      "||adverserve.net^$third-party",
+      "||advertarium.com.ua^$third-party",
+      "||adverticum.net^$third-party",
+      "||advertise.com^$third-party",
+      "||advertiseyourgame.com^$third-party",
+      "||advertising-department.com^$third-party",
+      "||advertising.com^$third-party",
+      "||advertlets.com^$third-party",
+      "||advertserve.com^$third-party",
+      "||advertstatic.com^$third-party",
+      "||advg.jp/$third-party",
+      "||adviva.net^$third-party",
+      "||advpoints.com^$third-party",
+      "||adxpower.com^$third-party",
+      "||adyoz.com^$third-party",
+      "||afcyhf.com^$third-party",
+      "||affiliate.com^$third-party",
+      "||affiliatefuel.com^$third-party",
+      "||affiliatefuture.com^$third-party",
+      "||affiliatesensor.com^$third-party",
+      "||affiliproducts.com^$third-party",
+      "||affinity.com^$third-party",
+      "||afy11.net^$third-party",
+      "||agentcenters.com^$third-party",
+      "||aggregateknowledge.com^$third-party",
+      "||aim4media.com^$third-party",
+      "||alimama.cn^$third-party",
+      "||alphagodaddy.com^$third-party",
+      "||amgdgt.com^$third-party",
+      "||anrdoezrs.net^$third-party",
+      "||apmebf.com^$third-party",
+      "||arcadebannerexchange.net^$third-party",
+      "||arcadebanners.com^$third-party",
+      "||arcadebe.com^$third-party",
+      "||arti-mediagroup.com^$third-party",
+      "||as5000.com^$third-party",
+      "||asklots.com^$third-party",
+      "||assoc-amazon.co.uk^$third-party",
+      "||assoc-amazon.com^$third-party",
+      "||atdmt.com^$third-party",
+      "||atwola.com^$third-party",
+      "||audienceprofiler.com^$third-party",
+      "||auditude.com^$third-party",
+      "||auspipe.com^$third-party",
+      "||avads.co.uk^$third-party",
+      "||avantlink.com^$third-party",
+      "||awaps.net^$third-party",
+      "||awin1.com^$third-party",
+      "||awltovhc.com^$third-party",
+      "||axill.com^$third-party",
+      "||azads.com^$third-party",
+      "||azjmp.com^$third-party",
+      "||azoogleads.com^$third-party",
+      "||backbeatmedia.com^$third-party",
+      "||bannerbank.ru^$third-party",
+      "||bannerconnect.com^$third-party",
+      "||bannerconnect.net^$third-party",
+      "||bannerlot.com^$third-party",
+      "||bannersmania.com^$third-party",
+      "||bbelements.com^$third-party",
+      "||begun.ru^$third-party",
+      "||belointeractive.com^$third-party",
+      "||bestofferdirect.com^$third-party",
+      "||bfast.com^$third-party",
+      "||bidvertiser.com^$third-party",
+      "||biemedia.com^$third-party",
+      "||bin-layer.de^$third-party",
+      "||bin-layer.ru^$third-party",
+      "||binlayer.de^$third-party",
+      "||bittads.com^$third-party",
+      "||blogad.com.tw^$third-party",
+      "||blogads.com^$third-party",
+      "||bloggerads.net^$third-party",
+      "||bluestreak.com^$third-party",
+      "||bmanpn.com^$third-party",
+      "||bnetworx.com^$third-party",
+      "||bnr.sys.lv^$third-party",
+      "||boo-box.com^$third-party",
+      "||boylesportsreklame.com^$third-party",
+      "||branchr.com^$third-party",
+      "||bravenetmedianetwork.com^$third-party",
+      "||bridgetrack.com^$third-party",
+      "||btrll.com^$third-party",
+      "||bu520.com^$third-party",
+      "||buildtrafficx.com^$third-party",
+      "||burstnet.com^$third-party",
+      "||buysellads.com^$third-party",
+      "||buzzparadise.com^$third-party",
+      "||c-on-text.com^$third-party",
+      "||c8.net.ua^$third-party",
+      "||captainad.com^$third-party",
+      "||casalemedia.com^$third-party",
+      "||cc-dt.com^$third-party",
+      "||cdna.tremormedia.com^$third-party",
+      "||cgecwm.org^$third-party",
+      "||checkm8.com^$third-party",
+      "||checkmystats.com.au^$third-party",
+      "||checkoutfree.com^$third-party",
+      "||chitika.net^$third-party",
+      "||cjt1.net^$third-party",
+      "||clash-media.com^$third-party",
+      "||claxonmedia.com^$third-party",
+      "||clickad.pl^$third-party",
+      "||clickbooth.com^$third-party",
+      "||clickexa.com^$third-party",
+      "||clickexperts.net^$third-party",
+      "||clickfuse.com^$third-party",
+      "||clickintext.net^$third-party",
+      "||clickthrucash.com^$third-party",
+      "||clixgalore.com^$third-party",
+      "||cogsdigital.com^$third-party",
+      "||collective-media.net^$third-party",
+      "||commission-junction.com^$third-party",
+      "||commissionmonster.com^$third-party",
+      "||conduit-banners.com^$third-party",
+      "||connectedads.net^$third-party",
+      "||connextra.com^$third-party",
+      "||contenture.com^$third-party",
+      "||contextuads.com^$third-party",
+      "||contextweb.com^$third-party",
+      "||cpaclicks.com^$third-party",
+      "||cpalead.com^$third-party",
+      "||cpays.com^$third-party",
+      "||cpmstar.com^$third-party",
+      "||cpuim.com^$third-party",
+      "||cpxinteractive.com^$third-party",
+      "||crispads.com^$third-party",
+      "||crowdgravity.com^$third-party",
+      "||ctrhub.com^$third-party",
+      "||cubics.com^$third-party",
+      "||d.m3.net^$third-party",
+      "||da.feedsportal.com^$third-party",
+      "||dbbsrv.com^$third-party",
+      "||decisionmark.com^$third-party",
+      "||decisionnews.com^$third-party",
+      "||deepmetrix.com^$third-party",
+      "||destinationurl.com^$third-party",
+      "||dexplatform.com^$third-party",
+      "||dgmaustralia.com^$third-party",
+      "||digitrevenue.com^$third-party",
+      "||dinclinx.com^$third-party",
+      "||directorym.com^$third-party",
+      "||directtrack.com^$third-party",
+      "||dl-rms.com^$third-party",
+      "||domainsponsor.com^$third-party",
+      "||doubleclick.net/pfadx/*.mtvi$object_subrequest,third-party",
+      "||doubleclick.net/pfadx/*adcat=$object_subrequest,third-party",
+      "||doubleclick.net^$object_subrequest,third-party,domain=addictinggames.com|atom.com|break.com|businessweek.com|cbs4denver.com|darkhorizons.com|eonline.com|fandango.com|foxbusiness.com|foxnews.com|g4tv.com|gametrailers.com|joblo.com|mtv.co.uk|myfoxphoenix.com|newsweek.com|nick.com|nytimes.com|play.it|ps3news.com|sbsun.com|shockwave.com|space.com|spike.com|thedailygreen.com|thedailyshow.com|thewire.com|washingtonpost.com|wired.com|wsj.com|wwe.com|youtube.com|zoomin.tv",
+      "||doubleclick.net^$~object_subrequest,third-party",
+      "||doubleclick.net^*;sz=$object_subrequest,third-party,domain=1up.com|breitbart.tv|digitaltrends.com|gamesradar.com|heavy.com|myspace.com|nbc.com|nfl.com",
+      "||dpbolvw.net^$third-party",
+      "||dt00.net^$third-party,domain=~marketgid.com",
+      "||e-planning.net^$third-party",
+      "||ebannertraffic.com^$third-party",
+      "||ebayobjects.com.au^$third-party",
+      "||ebayobjects.com^$third-party",
+      "||edge-dl.andomedia.com^$third-party",
+      "||egamingonline.com^$third-party",
+      "||ekmas.com^$third-party",
+      "||emediate.eu^$third-party",
+      "||emediate.se^$third-party",
+      "||ero-advertising.com^$third-party",
+      "||etology.com^$third-party",
+      "||euroclick.com^$third-party",
+      "||euros4click.de^$third-party",
+      "||exelator.com^$third-party",
+      "||exitexplosion.com^$third-party",
+      "||exitjunction.com^$third-party",
+      "||exponential.com^$third-party",
+      "||eyereturn.com^$third-party",
+      "||eyewonder.com^$third-party",
+      "||fairadsnetwork.com^$third-party",
+      "||fairfax.com.au^$~stylesheet,third-party",
+      "||falkag.net^$third-party",
+      "||fastclick.net^$third-party",
+      "||fimserve.com^$third-party",
+      "||firstadsolution.com^$third-party",
+      "||firstlightera.com^$third-party",
+      "||fixionmedia.com^$third-party",
+      "||flashtalking.com^$third-party",
+      "||fluxads.com^$third-party",
+      "||fmpub.net^$third-party",
+      "||footerslideupad.com^$third-party",
+      "||forms.aweber.com^$third-party",
+      "||forrestersurveys.com^$third-party",
+      "||friendlyduck.com^$third-party",
+      "||ftjcfx.com^$third-party",
+      "||funklicks.com^$third-party",
+      "||fusionads.net^$third-party",
+      "||fwmrm.net^$third-party",
+      "||g.doubleclick.net^$third-party",
+      "||game-advertising-online.com^$third-party",
+      "||gameads.com^$third-party",
+      "||gamecetera.com^$third-party",
+      "||gamersbanner.com^$third-party",
+      "||gannett.gcion.com^$third-party",
+      "||geo-idm.fr^$third-party",
+      "||geopromos.com^$third-party",
+      "||gestionpub.com^$third-party",
+      "||gimiclub.com^$third-party",
+      "||gklmedia.com^$third-party",
+      "||globaladsales.com^$third-party",
+      "||globaladv.net^$third-party",
+      "||go2media.org^$third-party",
+      "||googleadservices.com^$third-party",
+      "||grabmyads.com^$third-party",
+      "||gratisnetwork.com^$third-party",
+      "||gumgum.com^$third-party",
+      "||halogennetwork.com^$third-party",
+      "||havamedia.net^$third-party",
+      "||hb-247.com^$third-party",
+      "||hit-now.com^$third-party",
+      "||hopfeed.com^$third-party",
+      "||hosticanaffiliate.com^$third-party",
+      "||httpool.com^$third-party",
+      "||hypemakers.net^$third-party",
+      "||hypervre.com^$third-party",
+      "||ic-live.com^$third-party",
+      "||icdirect.com^$third-party",
+      "||imagesatlantic.com^$third-party",
+      "||imedia.co.il^$third-party",
+      "||imglt.com^$third-party",
+      "||imho.ru/$third-party",
+      "||imiclk.com^$third-party",
+      "||impact-ad.jp^$third-party",
+      "||impresionesweb.com^$third-party",
+      "||indiads.com^$third-party",
+      "||industrybrains.com^$third-party",
+      "||inetinteractive.com^$third-party",
+      "||infinite-ads.com^$third-party",
+      "||infolinks.com^$third-party",
+      "||innity.com^$third-party",
+      "||insightexpressai.com^$third-party",
+      "||inskinad.com^$third-party",
+      "||intellitxt.com^$third-party",
+      "||interclick.com^$third-party",
+      "||interpolls.com^$third-party",
+      "||investingchannel.com^$third-party",
+      "||ipromote.com^$third-party",
+      "||jangonetwork.com^$third-party",
+      "||jdoqocy.com^$third-party",
+      "||jumboaffiliates.com^$third-party",
+      "||justrelevant.com^$third-party",
+      "||kanoodle.com^$third-party",
+      "||kerg.net^$third-party",
+      "||ketoo.com^$third-party",
+      "||kitnmedia.com^$third-party",
+      "||klipmart.com^$third-party",
+      "||kontera.com^$third-party",
+      "||kqzyfj.com^$third-party",
+      "||lakequincy.com^$third-party",
+      "||lduhtrp.net^$third-party",
+      "||leadacceptor.com^$third-party",
+      "||ligatus.com^$third-party",
+      "||lightningcast.net^$~object_subrequest,third-party",
+      "||lingospot.com^$third-party",
+      "||linkbucks.com^$third-party",
+      "||linkexchange.com^$third-party",
+      "||linkshowoff.com^$third-party",
+      "||linkstorm.net^$third-party",
+      "||linksynergy.com^$third-party",
+      "||linkworth.com^$third-party",
+      "||linkz.net^$third-party",
+      "||liverail.com^$third-party",
+      "||liveuniversenetwork.com^$third-party",
+      "||ltassrv.com.s3.amazonaws.com^$third-party",
+      "||ltassrv.com^$third-party",
+      "||lzjl.com^$third-party",
+      "||madisonlogic.com^$third-party",
+      "||marketingsolutions.yahoo.com^$third-party",
+      "||maxserving.com^$third-party",
+      "||mb01.com^$third-party",
+      "||mbn.com.ua^$third-party",
+      "||media6degrees.com^$third-party",
+      "||mediag4.com^$third-party",
+      "||mediagridwork.com^$third-party",
+      "||medialand.ru^$third-party",
+      "||mediaonenetwork.net^$third-party",
+      "||mediaplex.com^$third-party",
+      "||mediatarget.com^$third-party",
+      "||medleyads.com^$third-party",
+      "||medrx.sensis.com.au^$third-party",
+      "||megaclick.com^$third-party",
+      "||mercuras.com^$third-party",
+      "||metaffiliation.com^$third-party",
+      "||mezimedia.com^$third-party",
+      "||microsoftaffiliates.net^$third-party",
+      "||milabra.com^$third-party",
+      "||mirago.com^$third-party",
+      "||miva.com^$third-party",
+      "||mktseek.com^$third-party",
+      "||mochiads.com/srv/",
+      "||money4ads.com^$third-party",
+      "||mootermedia.com^$third-party",
+      "||moregamers.com^$third-party",
+      "||moreplayerz.com^$third-party",
+      "||mpression.net^$third-party",
+      "||nabbr.com^$third-party",
+      "||nbjmp.com^$third-party",
+      "||neodatagroup.com^$third-party",
+      "||neoffic.com^$third-party",
+      "||net3media.com^$third-party",
+      "||netavenir.com^$third-party",
+      "||netseer.com^$third-party",
+      "||networldmedia.net^$third-party",
+      "||newsadstream.com^$third-party",
+      "||newtention.net^$third-party",
+      "||nexac.com^$third-party",
+      "||nicheads.com^$third-party",
+      "||northmay.com^$third-party",
+      "||nvero.net^$third-party",
+      "||nyadmcncserve-05y06a.com^$third-party",
+      "||obeus.com^$third-party",
+      "||obibanners.com^$third-party",
+      "||objects.tremormedia.com^$~object_subrequest,third-party",
+      "||objectservers.com^$third-party",
+      "||oclus.com^$third-party",
+      "||omg2.com^$third-party",
+      "||omguk.com^$third-party",
+      "||onads.com^$third-party",
+      "||onenetworkdirect.net^$third-party",
+      "||openx.net^$third-party",
+      "||openx.org^$third-party",
+      "||othersonline.com^$third-party",
+      "||overture.com^$third-party",
+      "||oxado.com^$third-party",
+      "||p-advg.com^$third-party",
+      "||pagead2.googlesyndication.com^$~object_subrequest,third-party",
+      "||paperg.com^$third-party",
+      "||partner.video.syndication.msn.com^$~object_subrequest,third-party",
+      "||partypartners.com^$third-party",
+      "||payperpost.com^$third-party",
+      "||pc-ads.com^$third-party",
+      "||peer39.net^$third-party",
+      "||pepperjamnetwork.com^$third-party",
+      "||perfb.com^$third-party",
+      "||performancingads.com^$third-party",
+      "||pgmediaserve.com^$third-party",
+      "||pgpartner.com^$third-party",
+      "||pheedo.com^$third-party",
+      "||picadmedia.com^$third-party",
+      "||pinballpublishernetwork.com^$third-party",
+      "||platinumadvertisement.com^$third-party",
+      "||playertraffic.com^$third-party",
+      "||pntra.com^$third-party",
+      "||pntrac.com^$third-party",
+      "||pntrs.com^$third-party",
+      "||pointroll.com^$third-party",
+      "||precisionclick.com^$third-party",
+      "||predictad.com^$third-party",
+      "||primaryads.com^$third-party",
+      "||pro-advertising.com^$third-party",
+      "||pro-market.net^$third-party",
+      "||probannerswap.com^$third-party",
+      "||prod.untd.com^$third-party",
+      "||profitpeelers.com^$third-party",
+      "||projectwonderful.com^$third-party",
+      "||proximic.com^$third-party",
+      "||psclicks.com^$third-party",
+      "||ptp.lolco.net^$third-party",
+      "||pubmatic.com^$third-party",
+      "||pulse360.com^$third-party",
+      "||qksrv.net^$third-party",
+      "||qksz.net^$third-party",
+      "||questionmarket.com^$third-party",
+      "||questus.com^$third-party",
+      "||quisma.com^$third-party",
+      "||radiusmarketing.com^$third-party",
+      "||rapt.com^$third-party",
+      "||rbcdn.com^$third-party",
+      "||realmedia.com^$third-party",
+      "||reelcentric.com^$third-party",
+      "||reklamz.com^$third-party",
+      "||resultlinks.com^$third-party",
+      "||revfusion.net^$third-party",
+      "||revresda.com^$third-party",
+      "||ricead.com^$third-party",
+      "||ringtonematcher.com^$third-party",
+      "||rmxads.com^$third-party",
+      "||roirocket.com^$third-party",
+      "||rotatingad.com^$third-party",
+      "||rover.ebay.com^*&adtype=$third-party",
+      "||rovion.com^$third-party",
+      "||ru4.com/$third-party",
+      "||rubiconproject.com^$third-party",
+      "||rwpads.com^$third-party",
+      "||sa.entireweb.com^$third-party",
+      "||safelistextreme.com^$third-party",
+      "||salvador24.com^$third-party",
+      "||sbaffiliates.com^$third-party",
+      "||scanscout.com^$third-party",
+      "||sendptp.com^$third-party",
+      "||sev4ifmxa.com^$third-party",
+      "||shareasale.com^$third-party",
+      "||shareresults.com^$third-party",
+      "||shinobi.jp^$third-party",
+      "||simply.com^$third-party",
+      "||skimlinks.com^$third-party",
+      "||smart.allocine.fr^$third-party",
+      "||smartadserver.com^$third-party",
+      "||smarttargetting.co.uk^$third-party",
+      "||smarttargetting.com^$third-party",
+      "||smarttargetting.net^$third-party",
+      "||smpgfx.com^$third-party",
+      "||snap.com^$third-party",
+      "||sochr.com^$third-party",
+      "||sociallypublish.com^$third-party",
+      "||socialmedia.com^$third-party",
+      "||socialspark.com^$third-party",
+      "||socialvibe.com^$third-party",
+      "||sonnerie.net^$third-party",
+      "||sparkstudios.com^$third-party",
+      "||specificclick.net^$third-party",
+      "||specificmedia.com^$third-party",
+      "||speedsuccess.net^$third-party",
+      "||spinbox.freedom.com^$third-party",
+      "||sponsorads.de^$third-party",
+      "||sponsoredtweets.com^$third-party",
+      "||sponsorpalace.com^$third-party",
+      "||sportsyndicator.com^$third-party",
+      "||spottt.com^$third-party",
+      "||spotxchange.com^$third-party,domain=~supernovatube.com",
+      "||srtk.net^$third-party",
+      "||sta-ads.com^$third-party",
+      "||stocker.bonnint.net^$third-party",
+      "||sublimemedia.net^$third-party",
+      "||survey-poll.com^$third-party",
+      "||tacoda.net^$third-party",
+      "||tailsweep.com^$third-party",
+      "||targetnet.com^$third-party",
+      "||targetpoint.com^$third-party",
+      "||targetspot.com^$third-party",
+      "||teracent.net^$third-party",
+      "||testnet.nl^$third-party",
+      "||text-link-ads.com^$third-party",
+      "||thewebgemnetwork.com^$third-party",
+      "||tiser.com^$third-party",
+      "||tkqlhce.com^$third-party",
+      "||total-media.net^$third-party",
+      "||tqlkg.com^$third-party",
+      "||tradedoubler.com^$third-party",
+      "||tradepub.com^$third-party",
+      "||trafficjunky.net^$third-party",
+      "||trafficmasterz.net^$third-party",
+      "||traveladvertising.com^$third-party",
+      "||travelscream.com^$third-party",
+      "||travidia.com^$third-party",
+      "||triadmedianetwork.com^$third-party",
+      "||tribalfusion.com^$third-party",
+      "||trigami.com^$third-party",
+      "||trker.com^$third-party",
+      "||twinplan.com^$third-party",
+      "||twittad.com^$third-party",
+      "||tyroo.com^$third-party",
+      "||udmserve.net^$third-party",
+      "||uimserv.net^$third-party",
+      "||unanimis.co.uk^$third-party",
+      "||unicast.com^$third-party",
+      "||unrulymedia.com^$third-party",
+      "||usemax.de^$third-party",
+      "||usercash.com^$third-party",
+      "||utarget.co.uk^$third-party",
+      "||v.movad.de^*/ad.xml$third-party",
+      "||valuead.com^$third-party",
+      "||valueclick.com^$third-party",
+      "||vcmedia.com^$third-party",
+      "||velmedia.net^$third-party",
+      "||verticalacuity.com^$third-party",
+      "||vibrantmedia.com^$third-party",
+      "||videoegg.com^$third-party",
+      "||videostrip.com^$~object_subrequest,third-party",
+      "||videostrip.com^*/admatcherclient.$object_subrequest,third-party",
+      "||vidpay.com^$third-party",
+      "||viglink.com^$third-party",
+      "||vipquesting.com^$third-party",
+      "||visitdetails.com^$third-party",
+      "||vpico.com^$third-party",
+      "||vs20060817.com^$third-party",
+      "||vsservers.net^$third-party",
+      "||webads.co.nz^$third-party",
+      "||webgains.com^$third-party",
+      "||webmasterplan.com^$third-party",
+      "||webtraffic.ttinet.com^$third-party",
+      "||wgreatdream.com^$third-party",
+      "||widgetbucks.com^$third-party",
+      "||widgets.fccinteractive.com^$third-party",
+      "||worlddatinghere.com^$third-party",
+      "||worthathousandwords.com^$third-party",
+      "||x4300tiz.com^$third-party",
+      "||xcelltech.com^$third-party",
+      "||xcelsiusadserver.com^$third-party",
+      "||xchangebanners.com^$third-party",
+      "||xgraph.net^$third-party",
+      "||yceml.net^$third-party",
+      "||yieldbuild.com^$third-party",
+      "||yieldmanager.com^$third-party",
+      "||yieldmanager.net^$third-party",
+      "||yottacash.com^$third-party",
+      "||yumenetworks.com^$third-party",
+      "||zangocash.com^$third-party",
+      "||zanox.com^$third-party",
+      "||zeads.com^$third-party",
+      "||zedo.com^$third-party",
+      "||zoomdirect.com.au^$third-party",
+      "||zxxds.net^$third-party",
+      "||ablacrack.com/popup-pvd.js$third-party",
+      "||adultfriendfinder.com/banners/$third-party",
+      "||advanced-intelligence.com/banner$third-party",
+      "||affil.mupromo.com^$third-party",
+      "||affiliate.astraweb.com^$third-party",
+      "||affiliates.a2hosting.com^$third-party",
+      "||affiliates.generatorsoftware.com^$third-party",
+      "||affiliates.jlist.com^$third-party",
+      "||affiliates.supergreenhosting.com^$third-party",
+      "||apple.com/itunesaffiliates/$third-party",
+      "||aweber.com/banners/$third-party",
+      "||b.sell.com^$third-party",
+      "||banner.1and1.com^$third-party",
+      "||banner.3ddownloads.com^$third-party",
+      "||banner.telefragged.com^$third-party",
+      "||banners.adultfriendfinder.com^$third-party",
+      "||banners.friendfinder.com^$third-party",
+      "||banners.getiton.com^$third-party",
+      "||banners.ixitools.com^$third-party",
+      "||bc.coupons.com^$third-party",
+      "||beta.down2crazy.com^$third-party",
+      "||box.anchorfree.net^$third-party",
+      "||buy.com^*/affiliate/$third-party",
+      "||cas.clickability.com^$third-party",
+      "||cashmakingpowersites.com^*/banners/$third-party",
+      "||cbanners.virtuagirlhd.com^$third-party",
+      "||cbclickbank.com/affiliate/$third-party",
+      "||connect.summit.co.uk^$third-party",
+      "||creatives.summitconnect.co.uk^$third-party",
+      "||datakl.com/banner/$third-party",
+      "||dianomioffers.co.uk/smartlinks.epl?$third-party",
+      "||dynw.com/banner$third-party",
+      "||enticelabs.com/el/$third-party",
+      "||eplreplays.com/wl/$third-party",
+      "||feedburner.com/~a/$third-party",
+      "||frontsight.com^*/banners/$third-party",
+      "||fugger.netfirms.com/moa.swf$third-party",
+      "||gfxa.sheetmusicplus.com^$third-party",
+      "||googlesyndication.com^*/domainpark.cgi?$third-party",
+      "||grammar.coursekey.com/inter/$third-party",
+      "||gsniper.com/images/$third-party",
+      "||hostingcatalog.com/banner.php?$third-party",
+      "||iselectmedia.com^*/banners/$third-party",
+      "||jlist.com/feed.php?affid=$third-party",
+      "||kallout.com^*.php?id=$third-party",
+      "||l.yimg.com^*&partner=*&url=$subdocument,third-party",
+      "||lastlocation.com/images/banner$third-party",
+      "||lightningcast.net^*/getplaylist?$object_subrequest,third-party",
+      "||liutilities.com/partners/affiliate/$third-party",
+      "||livejasmin.com/?t_id=*&psid=$third-party",
+      "||longtailvideo.com/adtonomy.swf$third-party",
+      "||longtailvideo.com/ltas.swf$third-party",
+      "||match.com^*/prm/$third-party",
+      "||mazda.com.au/banners/$third-party",
+      "||meta4-group.com^*/promotioncorner.js?$third-party",
+      "||metaboli.fr^*/adgude_$third-party",
+      "||mfeed.newzfind.com^$third-party",
+      "||missnowmrs.com/images/banners/$third-party",
+      "||my-dirty-hobby.com/getmdhlink.$third-party",
+      "||mydirtyhobby.com/?sub=$third-party",
+      "||mydirtyhobby.com/getmdhlink.$third-party",
+      "||mydirtyhobby.com/gpromo/$third-party",
+      "||mydirtyhobby.com^*/gpromo/$third-party",
+      "||myhpf.co.uk/banners/$third-party",
+      "||mytrafficstrategy.com/images/$third-party",
+      "||nzpages.co.nz^*/banners/$third-party",
+      "||nzphoenix.com/nzgamer/$third-party",
+      "||onegameplace.com/iframe.php$third-party",
+      "||play-asia.com/paos-$third-party",
+      "||plugins.longtailvideo.com/adtvideo.swf$third-party",
+      "||ppc-coach.com/jamaffiliates/$third-party",
+      "||pricegrabber.com/cb_table.php$third-party",
+      "||promos.fling.com^$third-party",
+      "||promote.pair.com^$third-party",
+      "||pub.betclick.com^$third-party",
+      "||pubs.hiddennetwork.com^$third-party",
+      "||r.kelkoo.com^$third-party",
+      "||rapidjazz.com/banner_rotation/$third-party",
+      "||rcm*.amazon.$third-party",
+      "||robofish.com/cgi-bin/banner.cgi?$third-party",
+      "||searchportal.information.com/?$third-party",
+      "||servali.net^$third-party",
+      "||smartclip.net/delivery/tag?$third-party",
+      "||thebigchair.com.au^$subdocument,third-party",
+      "||themis-media.com^*/sponsorships/$third-party",
+      "||ticketmaster.com/promotionalcontent/$third-party",
+      "||top5result.com/promo/$third-party",
+      "||toptenreviews.com/widgets/af_widget.js$third-party",
+      "||torrentfreebie.com/index.asp?pid=$third-party",
+      "||tosol.co.uk/international.php?$third-party",
+      "||unsereuni.at/resources/img/$third-party",
+      "||veospot.com^*.html$third-party",
+      "||vianadserver.com/xmlservice/overlaycampaigninfo.aspx?$third-party",
+      "||visit.homepagle.com^$third-party",
+      "||ws.amazon.*/widgets/q?$third-party",
+      "||xgaming.com/rotate*.php?$third-party",
+      "||1up.com^*/promos/",
+      "||216.151.186.5^*/serve.php?$domain=sendspace.com",
+      "||2cpu.com/2cpu/*side*.html",
+      "||4chan.org/support/gf_$image",
+      "||77.247.178.36/layer/$domain=movie2k.com",
+      "||a.giantrealm.com^",
+      "||a.thefreedictionary.com^",
+      "||about.com/0g/$subdocument",
+      "||ac2.msn.com^",
+      "||activewin.com^*/blaze_static2.",
+      "||ads.netlog.com^",
+      "||adserver.yahoo.com^",
+      "||adshare.freedocast.com^",
+      "||adultswim.com^*/admanager.swf?",
+      "||advt.manoramaonline.com^",
+      "||akipress.com/_ban/",
+      "||akipress.org/ban/",
+      "||akipress.org/bimages/",
+      "||allthelyrics.com^*/popup.js",
+      "||analytics.mmosite.com^",
+      "||animekuro.com/layout/google$subdocument",
+      "||animenewsnetwork.com^*.aframe?",
+      "||anonib.com/zimages/",
+      "||armorgames.com^*/banners/",
+      "||armorgames.com^*/site-skins/",
+      "||armorgames.com^*/siteskin.css",
+      "||athena-ads.wikia.com^",
+      "||azlyrics.com^*_az.js",
+      "||banner.atomicgamer.com^",
+      "||banners.expressindia.com^",
+      "||banners.sys-con.com^",
+      "||bbc.co.uk^*/bbccom.js?",
+      "||beingpc.com^*/banners/",
+      "||bit-tech.net/style/skin/$stylesheet",
+      "||blackberryforums.net/banners/",
+      "||blinkx.com/adhocnetwork/",
+      "||blinkx.com/f2/overlays/adhoc",
+      "||bloomberg.com^*/banner.js",
+      "||bnrs.ilm.ee^",
+      "||boyplz.com^*/layer.js",
+      "||break.com^*/sponsors/",
+      "||burnsoftware.info*/!",
+      "||c21media.net/uploads/flash/*.swf",
+      "||cdmediaworld.com*/!",
+      "||centos.org/donors/",
+      "||ciao.co.uk/load_file.php?",
+      "||click.livedoor.com^",
+      "||clk.about.com^",
+      "||cms.myspacecdn.com^*/splash_assets/",
+      "||codeasily.com^*/codeasily.js",
+      "||codeproject.com^*/adm/",
+      "||complexmedianetwork.com^*/takeovers/",
+      "||computerworld.com^*/jobroll/",
+      "||consumerreports.org^*/sx.js",
+      "||countrychannel.tv/telvos_banners/",
+      "||covertarget.com^*_*.php$subdocument",
+      "||crazymotion.net/video_*.php?key=",
+      "||crushorflush.com/html/promoframe.html",
+      "||da.feedsportal.com^*/a2.img$image",
+      "||dailymail.co.uk^*/promoboxes/",
+      "||dailymotion.com^*masscast/",
+      "||dcad.watersoul.com^",
+      "||demonoid.com/cached/ab_",
+      "||demonoid.com/cached/bnr_",
+      "||dig.abclocal.go.com/preroll/",
+      "||digdug.divxnetworks.com^",
+      "||dimshare.com/empire.",
+      "||distrowatch.com/images/czmor",
+      "||divxstage.net/images/download.png",
+      "||dl4all.com/data4.files/dpopupwindow.",
+      "||earthlink.net^*/promos/",
+      "||ebayrtm.com/rtm?",
+      "||ebuddy.com/banners/",
+      "||ebuddy.com/textlink.php?",
+      "||ebuddy.com/web_banners/",
+      "||ecommerce-journal.com/specdata.php?",
+      "||el33tonline.com^*/el33t_bg_",
+      "||episodic.com^*/logos/player-",
+      "||espn.vad.go.com^$domain=youtube.com",
+      "||eva.ucas.com^",
+      "||eweek.com/images/stories/marketing/",
+      "||excite.com/gca_iframe.html?",
+      "||expertreviews.co.uk/images/skins/",
+      "||ffiles.com/counters.js",
+      "||filefront.com/linkto/",
+      "||filetarget.com*/!",
+      "||filetarget.com^*_*.php$subdocument",
+      "||flyordie.com/games/free/b/*--?p=",
+      "||foxbusiness.com/html/google_homepage_promo",
+      "||freeworldgroup.com/banner",
+      "||fudzilla.com^*/banners/",
+      "||gamecopyworld.com*/!",
+      "||gametrailers.com^*/gt6_siteskin_$stylesheet",
+      "||geocities.com/js_source/",
+      "||geocities.yahoo.*/js/sq.",
+      "||getprice.com.au/searchwidget.aspx?$subdocument",
+      "||glam.com^*/affiliate/",
+      "||goauto.com.au/mellor/mellor.nsf/toy$subdocument",
+      "||grapevine.is/media/flash/*.swf",
+      "||gumtree.com^*/dart_wrapper_",
+      "||gwinnettdailypost.com/1.iframe.asp?",
+      "||hostsearch.com/creative/",
+      "||hotfrog.com/adblock.ashx?",
+      "||hummy.org.uk^*/brotator/",
+      "||i.com.com^*/vendor_bg_",
+      "||i.neoseeker.com/d/$subdocument",
+      "||i4u.com/_banner/",
+      "||ibanners.empoweredcomms.com.au^",
+      "||idg.com.au/images/*_promo$image",
+      "||idg.com.au^*_skin.jpg",
+      "||illimitux.net/js/abp.js",
+      "||images-amazon.com^*/marqueepushdown/",
+      "||imageshack.us/ym.php?$subdocument",
+      "||independent.co.uk/multimedia/archive/$subdocument",
+      "||infoseek.co.jp/isweb/clip.html",
+      "||interfacelift.com/inc_new/$subdocument",
+      "||internet.ziffdavis.com^",
+      "||iptools.com/sky.php",
+      "||itpro.co.uk/images/skins/",
+      "||jame-world.com^*/adv/",
+      "||jarkey.net^*/for_jarkey.",
+      "||jpost.com/images/*/promos/",
+      "||kermit.macnn.com^",
+      "||kestrel.ospreymedialp.com^",
+      "||kewlshare.com/reward.",
+      "||kitz.co.uk/files/jump2/",
+      "||labtimes.org/banner/",
+      "||linuxtopia.org/includes/$subdocument",
+      "||loaded.it^*/iframe_vid.",
+      "||loaded.it^*/my_banner",
+      "||lookbook.nu/sponsors_box.",
+      "||macobserver.com^*/deal_brothers/",
+      "||macworld.co.uk^*/textdeals/",
+      "||majorgeeks.com^*/banners/",
+      "||medhelp.org/hserver/",
+      "||mediafire.com^*/linkto/default-$subdocument",
+      "||mediafire.com^*/remove_ads.gif",
+      "||mediamgr.ugo.com^",
+      "||meetic.com/js/*/site_under_",
+      "||merriam-webster.com^*/accipiter.js",
+      "||mgnetwork.com/dealtaker/",
+      "||mirror.co.uk^*/gutters/",
+      "||mirror.co.uk^*/m4_gutters/",
+      "||mirror.co.uk^*/m4_partners/",
+      "||mmorpg.com/images/skins/",
+      "||mp3mediaworld.com*/!",
+      "||msn.com/?adunitid",
+      "||musictarget.com*/!",
+      "||myspace.com^*.adtooltip&",
+      "||myway.com/gca_iframe.html",
+      "||nearlygood.com^*/_aff.php?",
+      "||news.com.au/news/vodafone/$object",
+      "||news.com.au^*-promo$image",
+      "||news.com.au^*/promos/",
+      "||nirsoft.net/banners/",
+      "||ntdtv.com^*/adv/",
+      "||nymag.com^*/metrony_",
+      "||nytimes.com/adx/",
+      "||ocforums.com/adj/",
+      "||ocp.com.com/ad.js",
+      "||payplay.fm^*/mastercs.js",
+      "||pbsrc.com/sponsor/",
+      "||pbsrc.com^*/sponsor/",
+      "||pcauthority.com.au^*/skins/",
+      "||pcpro.co.uk/images/*_siteskin",
+      "||pcpro.co.uk/images/skins/",
+      "||pcpro.co.uk^*/pcprositeskin",
+      "||pcpro.co.uk^*skin_wide.",
+      "||photosupload.net/photosupload.js",
+      "||pinknews.co.uk/newweb/",
+      "||prisonplanet.com^*advert.",
+      "||prisonplanet.com^*banner",
+      "||prisonplanet.com^*sky.",
+      "||project-for-sell.com/_google.php",
+      "||proxy.org/af.html",
+      "||proxy.org/ah.html",
+      "||ps3news.com/banner/",
+      "||ps3news.com^*.swf",
+      "||qrz.com/pix/*.gif",
+      "||retrevo.com^*/pcwframe.jsp?",
+      "||richmedia.yimg.com^",
+      "||sciencedaily.com^*/google-story2-rb.js",
+      "||sendspace.com^*?zone=",
+      "||shop.com/cc.class/dfp?",
+      "||shops.tgdaily.com^*&widget=",
+      "||showstreet.com/banner.",
+      "||snopes.com^*/*ad$subdocument",
+      "||softcab.com/google.php?",
+      "||softonic.com/specials_leaderboard/",
+      "||soundtracklyrics.net^*_az.js",
+      "||space.com/promo/",
+      "||stlyrics.com^*_az.js",
+      "||stuff.tv/client/skinning/",
+      "||techpowerup.com/images/bnnrs/",
+      "||techsupportforum.com^*/banners/",
+      "||techtree.com^*/jquery.catfish.js",
+      "||telegraphindia.com^*/banners/",
+      "||telegraphindia.com^*/hoabanner.",
+      "||tentonhammer.com^*/takeovers/",
+      "||thehighstreetweb.com^*/banners/",
+      "||themis-media.com/media/global/images/cskins/",
+      "||themis.yahoo.com^",
+      "||thewb.com/thewb/swf/tmz-adblock/",
+      "||timeslive.co.za^*/adtonomy.",
+      "||tripadvisor.com/adp/",
+      "||tripadvisor.com^*/skyscraper.jpg",
+      "||turbobit.net/js/popunder2.js",
+      "||typepad.com/sponsors/",
+      "||ua.badongo.com^",
+      "||uimserv.net^",
+      "||unicast.msn.com^",
+      "||universalhub.com/bban/",
+      "||videogamer.com^*/css/skins/$stylesheet",
+      "||videos.mediaite.com/decor/live/white_alpha_60.",
+      "||videosift.com/bnr.php?",
+      "||w3schools.com/banners/",
+      "||wareseeker.com/banners/",
+      "||webhostingtalk.com/js/hail.js",
+      "||whispersinthecorridors.com/banner2009/",
+      "||wikia.com/__varnish_",
+      "||windowsitpro.com^*/doubleclick/",
+      "||windowsitpro.com^*/googleafc",
+      "||windowsitpro.com^*/roadblock.js",
+      "||www2.sys-con.com^*.cfm",
+      "||xbitlabs.com^*/xbanner.php?",
+      "||yahoo.*/serv?s=",
+      "||yahoo.com/darla/",
+      "||yahoo.com/ysmload.html?",
+      "||yahoo.com^*.ads.darla.",
+      "||yahoo.com^*/eyc-themis?",
+      "||yfrog.com/ym.php?",
+      "||yimg.com/a/1-$~stylesheet",
+      "||yimg.com^*/fairfax/$image",
+      "||yourmovies.com.au^*/side_panels_",
+      "||zam.com/i/promos/*-skin.",
+      "||zattoo.com/static/images/sponsors/",
+      "||zophar.net/files/tf_",
+      "@@||2mdn.net/*_ecw_$image,domain=wwe.com",
+      "@@||2mdn.net/crossdomain.xml$object_subrequest,domain=imdb.com",
+      "@@||2mdn.net/viewad/817-grey.gif$object_subrequest,domain=imdb.com",
+      "@@||a.giantrealm.com/assets/vau/grplayer*.swf$object",
+      "@@||ad.gogopin.com^$~document",
+      "@@||ad3.liverail.com^$object_subrequest,domain=seesaw.com",
+      "@@||adap.tv/redir/client/adplayer.swf?$object_subrequest,domain=egreetings.com|ehow.com|xxlmag.com",
+      "@@||addictinggames.com/jsource/ad_functions.js$script",
+      "@@||adjuggler.com^$script,domain=videodetective.com",
+      "@@||adm.fwmrm.net^$object_subrequest",
+      "@@||ads.adap.tv/control?$object_subrequest,domain=ky3.com|xxlmag.com",
+      "@@||ads.adap.tv/crossdomain.xml$object_subrequest,domain=ky3.com|xxlmag.com",
+      "@@||ads.adultswim.com/js.ng/site=toonswim&toonswim_pos=600x400_ctr&toonswim_rollup=games$script",
+      "@@||ads.ahds.ac.uk^$~document",
+      "@@||ads.cnn.com/js.ng/*&cnn_intl_subsection=download$script",
+      "@@||ads.forbes.com/realmedia/ads/*@videopreroll$script",
+      "@@||ads.fox.com/fox/black_2sec_600.flv$object_subrequest",
+      "@@||ads.hulu.com^*.flv$object_subrequest",
+      "@@||ads.hulu.com^*.swf$object_subrequest",
+      "@@||ads.imeem.com^$object_subrequest",
+      "@@||ads.morningstar.com/realmedia/ads/adstream_lx.ads/www.morningstar.com/video/$object_subrequest",
+      "@@||ads.yimg.com^*/any/yahoologo$image",
+      "@@||ads.yimg.com^*/search/b/syc_logo_2.gif$image",
+      "@@||ads.yimg.com^*videoadmodule*.swf$object_subrequest",
+      "@@||ads1.msn.com/library/dap.js$script,domain=msnbc.msn.com|wowarmory.com",
+      "@@||adsatt.abc.starwave.com^$object_subrequest",
+      "@@||adserver.adtech.de/crossdomain.xml$object_subrequest,domain=deluxetelevision.com",
+      "@@||adserver.bigwigmedia.com/ingamead3.swf$object_subrequest",
+      "@@||adserver.yahoo.com/a?*&l=head&$script,domain=yahoo.com",
+      "@@||adserver.yahoo.com/a?*=headr$script,domain=mail.yahoo.com",
+      "@@||adtech.de/crossdomain.xml$object_subrequest,domain=gigwise.com|nelonen.fi",
+      "@@||affiliates.jlist.com/ads/img_$image,domain=jlist.com",
+      "@@||affiliates.quintura.com^*.php?$object_subrequest,script,xmlhttprequest",
+      "@@||apple.com^*/adswap.js$script",
+      "@@||ar.atwola.com/file/adswrapper.js$script,domain=gasprices.mapquest.com",
+      "@@||as.webmd.com/html.ng/transactionid=$object_subrequest",
+      "@@||assets.idiomag.com/flash/adverts/yume_$object_subrequest",
+      "@@||autotrader.co.nz/data/adverts/$image",
+      "@@||belointeractive.com^*/ads/*@*?|$script",
+      "@@||bitgravity.com/revision3/swf/player/admanager.swf?$object_subrequest,domain=area5.tv",
+      "@@||brothersoft.com/gads/coop_show_download.php?soft_id=$script",
+      "@@||chloe.videogamer.com/data/*/videos/adverts/$object_subrequest",
+      "@@||cinshare.com/js/isalive.js?$script",
+      "@@||cnet.com/ads/common/adclient/*.swf$object_subrequest",
+      "@@||cpalead.com/mygateway.php?pub=$script,domain=superfastfile.com|videodownloadx.com",
+      "@@||cubeecraft.com/images/home/features/300x250/$image",
+      "@@||d1.openx.org/ajs.php?zoneid=25815&$script,domain=rottentomatoes.com",
+      "@@||dart.clearchannel.com/html.ng/$object_subrequest,domain=radio1045.com",
+      "@@||deviantart.com/global/difi/?$subdocument",
+      "@@||direct.fairfax.com.au/hserver/*/site=vid.*/adtype=embedded/$script",
+      "@@||doubleclick.net/ad/*smartclip$script,domain=last.fm",
+      "@@||doubleclick.net/adj/*smartclip$script,domain=last.fm",
+      "@@||doubleclick.net/adj/imdb2.consumer.video/*;sz=320x240,$script",
+      "@@||doubleclick.net/adj/nbcu.nbc/videoplayer-$script",
+      "@@||doubleclick.net/adj/pong.all/*;dcopt=ist;$script",
+      "@@||doubleclick.net/pfadx/channel.video.crn/;*;cue=pre;$object_subrequest",
+      "@@||doubleclick.net/pfadx/umg.*;sz=10x$script",
+      "@@||doubleclick.net^*/adj/wwe.shows/ecw_ecwreplay;*;sz=624x325;$script",
+      "@@||doubleclick.net^*/listen/*;sz=$script,domain=last.fm",
+      "@@||dyncdn.buzznet.com/catfiles/?f=dojo/*.googleadservices.$script",
+      "@@||ebayrtm.com/rtm?rtmcmd&a=json&cb=parent.$script",
+      "@@||edgar.pro-g.co.uk/data/*/videos/adverts/$object_subrequest",
+      "@@||empireonline.com/images/image_index/300x250/$background,image",
+      "@@||espn.go.com^*/espn360/banner?$subdocument",
+      "@@||eyewonder.com^$object,script,domain=last.fm",
+      "@@||facepunch.com/ad/$script",
+      "@@||facepunch.com/ads/$image,stylesheet",
+      "@@||fdimages.fairfax.com.au^*/ffxutils.js$domain=thevine.com.au",
+      "@@||feeds.videogamer.com^*/videoad.xml?$object_subrequest",
+      "@@||flyordie.com^*&affiliate$subdocument",
+      "@@||freeonlinegames.com/advertising/google-loader.swf?$object",
+      "@@||gannett.gcion.com/addyn/3.0/*/adtech;alias=pluck_signin$script",
+      "@@||garrysmod.org/ads/$background,image,script,stylesheet",
+      "@@||gr.burstnet.com/crossdomain.xml$object_subrequest,domain=filefront.com",
+      "@@||guim.co.uk^*/styles/wide/google-ads.css$stylesheet",
+      "@@||gws.ign.com/ws/search?*&google_adpage=$script",
+      "@@||i.cdn.turner.com^*/adserviceadapter.swf$object",
+      "@@||i.real.com/ads/*.swf?clicktag=$object_subrequest,domain=rollingstone.com",
+      "@@||ign.com/js.ng/size=headermainad&site=teamxbox$script,domain=teamxbox.com",
+      "@@||ikea.com/ms/img/ads/services/$image",
+      "@@||im.mstar.com/ads/*.flv$object_subrequest",
+      "@@||imdb.com/images/*/js/ads.js$script",
+      "@@||img.thedailywtf.com/images/ads/$image",
+      "@@||img.weather.weatherbug.com^*/stickers/$background,image,stylesheet",
+      "@@||jobs.wa.gov.au/images/advertimages/$background,image",
+      "@@||last.fm/ads.php?zone=*listen$subdocument",
+      "@@||lightningcast.net/servlets/getplaylist?*&responsetype=asx&$object",
+      "@@||liverail.com/crossdomain.xml$object_subrequest",
+      "@@||liverail.com/swf/*/plugins/flowplayer/$object_subrequest",
+      "@@||m1.2mdn.net^*/dartshell8_9.swf$object_subrequest,domain=vladtv.com",
+      "@@||mads.cbs.com/mac-ad?$object_subrequest",
+      "@@||mads.com.com/ads/common/faith/*.xml$object_subrequest",
+      "@@||media-imdb.com/images/*/js/ads.js$script,domain=imdb.com",
+      "@@||media.salemwebnetwork.com/js/admanager/swfobject.js$script,domain=christianity.com",
+      "@@||media.washingtonpost.com/wp-srv/ad/ad_v2.js$script",
+      "@@||media.washingtonpost.com/wp-srv/ad/tiffany_manager.js$script",
+      "@@||motherjones.com/files/resized/files/*300x250$image",
+      "@@||mozilla.com/img/tignish/plugincheck/*/728_90/loading.png$image,domain=mozilla.com",
+      "@@||newgrounds.com/ads/ad_medals.gif$image",
+      "@@||newsarama.com/common/js/advertisements.js$script",
+      "@@||newsweek.com/ads/adscripts/prod/*_$script",
+      "@@||nick.com/js/ads.jsp$script",
+      "@@||o.aolcdn.com/ads/adswrapper.js$script,domain=photos.tmz.com",
+      "@@||oas.absoluteradio.co.uk/realmedia/ads/$object_subrequest",
+      "@@||oas.bigflix.com/realmedia/ads/$object_subrequest",
+      "@@||oas.five.tv/realmedia/ads/adstream_sx.ads/demand.five.tv/$object_subrequest",
+      "@@||oascentral.feedroom.com/realmedia/ads/adstream_sx.ads/$script,domain=businessweek.com|economist.com|feedroom.com|stanford.edu",
+      "@@||oascentral.upi.com^$object_subrequest",
+      "@@||objects.tremormedia.com/embed/js/$script,domain=deluxetelevision.com",
+      "@@||objects.tremormedia.com/embed/swf/acudeoplayer.swf$object,domain=deluxetelevision.com",
+      "@@||objects.tremormedia.com/embed/swf/admanager*.swf$object_subrequest",
+      "@@||objects.tremormedia.com/embed/xml/*.xml?r=$object_subrequest,domain=mydamnchannel.com",
+      "@@||omnikool.discovery.com/realmedia/ads/adstream_mjx.ads/dsc.discovery.com/$script",
+      "@@||pagead2.googlesyndication.com/pagead/expansion_embed.js$script,domain=myspace.com",
+      "@@||pagead2.googlesyndication.com/pagead/scache/show_invideo_ads.js$script,domain=sciencedaily.com",
+      "@@||pagead2.googlesyndication.com/pagead/show_ads.js$script,domain=myspace.com",
+      "@@||pagead2.googlesyndication.com/pagead/static?format=in_video_ads&$subdocument,domain=sciencedaily.com",
+      "@@||quit.org.au/images/images/ad/$image",
+      "@@||redir.adap.tv/redir/client/adplayer.swf?$object_subrequest,domain=cracked.com|videosift.com",
+      "@@||rosauers.com/locations/ads.html$subdocument",
+      "@@||sankakucomplex.com/img/www/d/spcjs.php?id=$script",
+      "@@||sankakucomplex.com/wp-content/themes/*/sankaku.js?*&adname=*&spc=/spc.php?",
+      "@@||seavideo-ak.espn.go.com/ads/$object_subrequest",
+      "@@||seesaw.com/cp/c4/realmedia/ads/adstream_sx.ads/$xmlhttprequest",
+      "@@||serve.vdopia.com/adserver/ad*.php$object_subrequest,script,xmlhttprequest",
+      "@@||server.cpmstar.com/adviewas3.swf?contentspotid=$object_subrequest,domain=armorgames.com|freewebarcade.com",
+      "@@||server.cpmstar.com/view.aspx?poolid=$script,domain=newgrounds.com",
+      "@@||sfx-images.mozilla.org^$image,domain=spreadfirefox.com",
+      "@@||shockwave.com/js/ad_functions.js$script",
+      "@@||smartadserver.com/call/pubj/*/affiliate_id$script,domain=deezer.com",
+      "@@||smartadserver.com/def/def/showdef.asp$script,domain=deezer.com",
+      "@@||smartclip.net/delivery/tag?sid=$script,domain=last.fm",
+      "@@||sonicstate.com/video/hd/hdconfig-geo.cfm?*/www/delivery/$object_subrequest",
+      "@@||sp.ltassrv.com.s3.amazonaws.com^$object_subrequest,domain=animecrazy.net",
+      "@@||spike.com/consolidation/spike-functions.js?*/js/ads.js$script",
+      "@@||static.2mdn.net^*.xml$object_subrequest,domain=photoradar.com|youtube.com",
+      "@@||static.ak.fbcdn.net^*/ads/$script",
+      "@@||superfundo.org/advertisement.js$script",
+      "@@||telegraphcouk.skimlinks.com/api/telegraph.skimlinks.js$script",
+      "@@||thenewsroom.com^*/advertisement.xml$object_subrequest",
+      "@@||theonion.com/ads/video-ad/$object_subrequest",
+      "@@||thesmokinggun.com/includes2/de/video/sync.$object_subrequest",
+      "@@||thestreet.com/js/ads/adplacer.js$script",
+      "@@||timeinc.net/people/static/i/advertising/getpeopleeverywhere-news.gif$background,domain=people.com|peoplestylewatch.com",
+      "@@||timeinc.net^*/tii_ads.js$script,domain=ew.com",
+      "@@||trutv.com/includes/banners/de/video/sync.$object_subrequest",
+      "@@||tvgorge.com^*/adplayer.swf$object",
+      "@@||tvnz.co.nz/stylesheets/tvnz/lib/js/advertisement.js$script",
+      "@@||ultrabrown.com/images/adheader.jpg$image",
+      "@@||upload.wikimedia.org/wikipedia/commons/",
+      "@@||utarget.co.uk/crossdomain.xml$object_subrequest,domain=tvcatchup.com",
+      "@@||v.fwmrm.net/ad/p/1?$object_subrequest,domain=mlb.com",
+      "@@||v.fwmrm.net/crossdomain.xml$object_subrequest,domain=mlb.com",
+      "@@||video.nbcuni.com/ads/$object_subrequest",
+      "@@||vortex.accuweather.com/adc2004/pub/ads/js/ads-2006_vod.js$script",
+      "@@||vox-static.liverail.com/swf/*/admanager.swf$object_subrequest",
+      "@@||weather.com/common/a2/oasadframe.html?position=pagespon$subdocument",
+      "@@||weather.com/common/a2/oasadframe.html?position=pointspon$subdocument",
+      "@@||widget.slide.com^*/ads/*/preroll.swf$object_subrequest",
+      "@@||wrapper.teamxbox.com/a?size=headermainad&altlocdir=teamxbox$script",
+      "@@||yallwire.com/pl_ads.php?$object_subrequest",
+      "@@||yimg.com^*/java/promotions/js/ad_eo_1.1.js$script",
+      "@@||zedo.com/*.swf$object_subrequest,domain=rajshri.com",
+      "@@||zedo.com/*.xml$object_subrequest,domain=rajshri.com",
+      "@@||zedo.com//$object_subrequest,domain=rajshri.com",
+      "@@||arto.com/includes/js/adtech.de/script.axd/adframe.js?$script",
+      "@@||avforums.com/forums/adframe.js$script",
+      "@@||cinshare.com/js/*ad_type$script",
+      "@@||dailykos.com/ads/adblocker.blogads.css$stylesheet",
+      "@@||eq2flames.com/adframe.js$script",
+      "@@||gdataonline.com/exp/textad.js$script",
+      "@@||hackers.co.id/adframe/adframe.js$script",
+      "@@||macobserver.com/js/adframe.js$script",
+      "@@||megavideodownloader.com/adimages/|$subdocument",
+      "@@||novamov.com/ads.js?*&ad_url=/adbanner$script",
+      "@@||onlinevideoconverter.com/scripts/advertisement.js$script",
+      "@@||superfastfile.com/adsense.js$script",
+      "@@||superfastfile.com/advertisement.js$script",
+      "@@||theteacherscorner.net/adiframe/ad.js$script",
+      "@@||tpmrpg.net/adframe.js$script",
+      "@@||video2mp3.net/img/adframe.js$script",
+      "@@||zshare.net/ads.js?*&ad_url=/adbanner$script",
+      "@@||adser.localport.it/banman.asp?zoneid=71$subdocument",
+      "@@||adswizz.com/www/delivery/$object_subrequest,domain=video.belga.be",
+      "@@||adtech.de/?adrawdata/3.0/*;|$object_subrequest,domain=nelonen.fi|tv2.dk",
+      "@@||adtech.de/crossdomain.xml$object_subrequest,domain=nelonen.fi|tv2.dk",
+      "@@||adtech.panthercustomer.com^*.flv$object_subrequest,domain=tv3.ie",
+      "@@||aka-cdn-ns.adtech.de^*.flv$object_subrequest,domain=tv3.ie",
+      "@@||amarillas.cl/advertise.do?$xmlhttprequest",
+      "@@||amarillas.cl/js/advertise/$script",
+      "@@||banneradmin.rai.it/js.ng/sezione_rai=barramenu$script",
+      "@@||bnrs.ilm.ee/www/delivery/fl.js$script",
+      "@@||e-planning.net/eb/*?*fvp=2&$object_subrequest,domain=clarin.com|emol.com",
+      "@@||fotojorgen.no/images/*/webadverts/$image",
+      "@@||openx.zomoto.nl/live/www/delivery/fl.js$script",
+      "@@||openx.zomoto.nl/live/www/delivery/spcjs.php?id=$script",
+      "@@||pagead2.googlesyndication.com/pagead/abglogo/abg-da-100c-000000.png$domain=janno.dk|nielco.dk",
+      "@@||ring.bg/adserver/adall.php?*&video_on_page=1$script"
+    ].map(function(text) Filter.fromText(text));
+
+    let addresses = [
+      "http://a.analytics.yahoo.com/p.pl?a=1000116666777&sid=3788ead&j=1366x768&flv=WIN+10%2C0%2C45",
+      "http://ad-emea.doubleclick.net/ad/N4137.yahoo.de/B4316546.2;sz=1x1;ai=609911305;si=102;ord=1269329333?",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedes300x250.jpg",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedes300x2501.swf",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedes400x60.gif",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedes400x60.swf",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedesexpand.swf",
+      "http://ads.yimg.com/ev/de/hp/mercedes/20100323mercedeswallpaperwide2.jpg",
+      "http://ads.yimg.com/ev/de/hp/mercedes/yadbg4.js",
+      "http://ads.yimg.com/ev/eu/any/pixel4.gif",
+      "http://ads.yimg.com/ev/eu/any/yad20100215min.js",
+      "http://cdn1.eyewonder.com/200125/762024/1248338/ewtrack.gif?ewbust=1269329333",
+      "http://d.yimg.com/a/i/ww/met/gsprite_20100208.png",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/ans_22_041609.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/brig_22_080609.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/facebook_22_063009.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/flickr_22_041609.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/heiseonline_22_072709.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/horoscopes_22_041609.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/kelkoo_22_061809.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/personals_22_041609.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/stern_22_092809.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/tb_22_042009.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/travel_22_063009.gif",
+      "http://d.yimg.com/a/i/ww/met/pa_icons/uk_pa_sprite_063009.png",
+      "http://d.yimg.com/a/i/ww/met/sprite_pg_20100125.png",
+      "http://d.yimg.com/a/i/ww/met/sprite_pg_nontheme_20100125.png",
+      "http://d.yimg.com/a/i/ww/met/sprite_videoicon_20100201.png",
+      "http://d.yimg.com/a/i/ww/met/th/slate/gsprite_pg_slate_20100129.gif",
+      "http://d.yimg.com/a/i/ww/met/th/slate/sprite_masthead_slate_srchbt2_07242009.png",
+      "http://d.yimg.com/a/i/ww/met/th/slate/sprite_pg_slate_20100126.png",
+      "http://l.yimg.com/a/a/1-/flash/promotions/de/intl/100225/50x50mpl.gif",
+      "http://l.yimg.com/a/combo?arc/yui/reset_2.6.5.css&arc/yui/fonts_2.6.4.css&metro/uiplugins/generic_0.1.9.css&metro/error/error_0.1.12.css&metro/fp/fp_zindex_0.0.24.css&metro/fp/fp_0.1.85.css&metro/navbar/navbar_0.1.83.css&metro/navbar/navbar_pageoptions_0.0.21.css&metro/marketindices/marketindices_0.1.33.css&metro/miniad/promoads_0.1.6.css&metro/uiplugins/tablist_service_0.1.6.css&metro/uiplugins/iframeshim_service_0.0.4.css&metro/uiplugins/ulm_service_0.1.8.css&metro/uiplugins/ulm_default_0.1.16.css&metro/uiplugins/tablist_news_0.0.14.css&metro/news/news_0.1.73.css&metro/specialevents/specialevents_0.0.21.css&metro/sda/sda_0.1.22.css&metro/subfooter/subfooter_0.0.6.css&metro/breakingnews/breakingnews_0.0.13.css&metro/uiplugins/carousel_service_0.1.6.css&metro/fptoday/fptoday_0.1.121.css&metro/uiplugins/carousel_default_0.1.11.css&metro/tuc/tuc_common_0.0.24.css&metro/tuc/tuc_embedded_0.0.15.css&metro/masthead/masthead_0.2.63.css&metro/contentcarousel/contentcarousel_0.1.81.css&metro/contentcarousel/contentcarousel_topten_0.1.69.css&metro/contentcarousel/pulse_0.1.60.css&metro/contentcarousel/slideshow1_0.1.24.css&metro/contentcarousel/shopping_0.1.19.css&metro/contentcarousel/contentcarousel_4_0.1.8.css&metro/footer/footer_0.1.53.css&metro/pa/pa_flash_0.1.2.css&metro/pa/pa_0.1.163.css&metro/pa/pa_detached_0.1.69.css&metro/uiplugins/tooltip_default_0.1.14.css&metro/pa/pa_edit_service_0.1.29.css&metro/contentcarousel/contentcarousel_3_0.1.9.css&metro/uiplugins/windowshade_service_0.0.13.css&metro/ipredirect/ipredirect_0.0.6.css",
+      "http://l.yimg.com/a/combo?arc/yui/substitute_0.1.9.js&arc/yui/oop_0.1.10.js&arc/yui/event-custom_0.1.5.js&arc/yui/io-base_0.1.10.js&arc/yui/dom_0.1.10.js&arc/yui/event-base_0.1.4.js&arc/yui/attribute_0.1.11.js&arc/yui/base-base_0.1.10.js&arc/yui/pluginhost_0.1.4.js&arc/yui/node_0.1.25.js&arc/yui/json_0.1.13.js&arc/yui/anim-base_0.1.9.js&arc/yui/anim-easing_0.1.9.js&arc/yui/anim-node-plugin_0.1.8.js&arc/yui/cookie_0.1.9.js&arc/yui/yuidef_0.1.9.js&arc/framework/module_platform_0.1.50.js&arc/framework/resourcemgr_0.1.14.js&metro2/dali/dali_transport_1.1.26.js&arc/framework/module_api_0.1.12.js&metro2/dali/metro_dali_1.0.18.js&metro/uiplugins/userinfo_service_0.1.7.js&metro/uiplugins/metro_viewtype_0.1.14.js&metro/uiplugins/default_viewtype_0.1.50.js&metro/uiplugins/edit_viewtype_0.1.31.js&metro/uiplugins/pa_viewtype_0.1.5.js&arc/util/ylc_1.8.17.js&metro/uiplugins/instrumentation_service_0.1.11.js&metro/uiplugins/metrologger_service_0.1.10.js&metro/sda/sda_bridge_service_0.0.5.js&metro/fp/fp_0.1.60.js&metro/uiplugins/metrics_service_0.1.5.js&metro/uiplugins/metro_performance_0.1.7.js&arc/framework/yui_service_0.1.11.js&metro/uiplugins/autohide_service_0.1.9.js&metro/uiplugins/statemgr_service_0.1.11.js&metro/navbar/navbar_0.1.75.js&metro/marketindices/marketindices_0.1.17.js&metro/uiplugins/aria_service_0.1.12.js&metro/uiplugins/tablist_service_0.1.29.js&metro/uiplugins/iframeshim_service_0.0.12.js&metro/uiplugins/ulm_service_0.1.31.js&metro/news/news_0.1.40.js&metro/sda/sda_deferred_service_0.0.13.js&metro/sda/sda_transport_0.0.9.js&metro/sda/sda_0.1.36.js&metro/uiplugins/carousel_service_0.1.37.js&metro/fptoday/fptoday_hover_0.1.53.js&metro/tuc/tuc_0.0.24.js&metro/masthead/masthead_0.2.114.js&metro/contentcarousel/contentcarousel_0.1.38.js&metro/contentcarousel/contentcarouselslideshow1_0.1.13.js&metro/uiplugins/toolbar_bridge_service_0.1.17.js&metro/uiplugins/tooltip_service_0.1.32.js&metro/pa/pa_0.1.187.js&metro/uiplugins/windowshade_service_0.0.12.js&metro/ipredirect/ipredirect_0.0.8.js",
+      "http://l.yimg.com/a/combo?arc/yui/yui_0.2.4.js",
+      "http://l.yimg.com/a/i/ww/met/mod/ybang_22_111908.png",
+      "http://l.yimg.com/a/i/ww/met/sprite_ip_redirect_052109.gif",
+      "http://l.yimg.com/a/i/ww/met/yahoo_logo_de_061509.png",
+      "http://l.yimg.com/a/lib/metro/apppromo/apppromo_0.0.12.css",
+      "http://l.yimg.com/a/lib/metro/autoapp/autoapp_0.0.36.css",
+      "http://l.yimg.com/a/lib/metro/autoapp/autoapp_0.0.42.js",
+      "http://l.yimg.com/a/lib/metro/ebay/ebay_0.1.25.css",
+      "http://l.yimg.com/a/lib/metro/ebay/ebay_0.1.31.js",
+      "http://l.yimg.com/a/lib/metro/facebook/facebook_0.0.59.js",
+      "http://l.yimg.com/a/lib/metro/facebook/facebook_0.0.63.css",
+      "http://l.yimg.com/a/lib/metro/feed/feed_0.0.10.js",
+      "http://l.yimg.com/a/lib/metro/feed/feed_0.1.4.css",
+      "http://l.yimg.com/a/lib/metro/finance/finance_0.1.62.css",
+      "http://l.yimg.com/a/lib/metro/finance/finance_0.1.77.js",
+      "http://l.yimg.com/a/lib/metro/fpflickr/fpflickr_0.1.38.css",
+      "http://l.yimg.com/a/lib/metro/fpflickr/fpflickr_0.1.43.js",
+      "http://l.yimg.com/a/lib/metro/horoscope/horoscope_0.1.29.js",
+      "http://l.yimg.com/a/lib/metro/horoscope/horoscope_0.1.42.css",
+      "http://l.yimg.com/a/lib/metro/mail/mail_0.0.11.js",
+      "http://l.yimg.com/a/lib/metro/mail/mail_0.0.20.css",
+      "http://l.yimg.com/a/lib/metro/messenger/messenger_0.0.31.css",
+      "http://l.yimg.com/a/lib/metro/messenger/messenger_0.0.40.js",
+      "http://l.yimg.com/a/lib/metro/pacontainer/pacontainer_0.0.31.css",
+      "http://l.yimg.com/a/lib/metro/pacontainer/pacontainer_0.0.41.js",
+      "http://l.yimg.com/a/lib/metro/scoreboard/scoreboard_0.1.53.js",
+      "http://l.yimg.com/a/lib/metro/scoreboard/scoreboard_0.1.62.css",
+      "http://l.yimg.com/a/lib/metro/uiplugins/menu_default_0.1.3.css",
+      "http://l.yimg.com/a/lib/metro/uiplugins/menu_service_0.1.3.css",
+      "http://l.yimg.com/a/lib/metro/uiplugins/tablist_default_0.1.5.css",
+      "http://l.yimg.com/a/lib/metro/weather/weather_0.1.72.css",
+      "http://l.yimg.com/a/lib/metro/weather/weather_0.1.78.js",
+      "http://l.yimg.com/a/lib/metro/yservices/yservices_0.1.25.js",
+      "http://l.yimg.com/a/lib/metro/yservices/yservices_0.1.95.css",
+      "http://l.yimg.com/cv/ae/de/__testing_only__/100320/50x50mpl.jpg",
+      "http://l.yimg.com/d/lib/bc/bcr_2.0.4.js",
+      "http://l.yimg.com/i/i/de/metro/032213.jpg",
+      "http://l.yimg.com/i/i/de/metro/david1.jpg",
+      "http://l.yimg.com/i/i/de/metro/depp5.jpg",
+      "http://l.yimg.com/i/i/de/metro/grins.jpg",
+      "http://l.yimg.com/i/i/de/metro/grins1.jpg",
+      "http://l.yimg.com/i/i/de/metro/klum9.jpg",
+      "http://l.yimg.com/i/i/de/metro/love5.jpg",
+      "http://l.yimg.com/i/i/de/metro/meyer.jpg",
+      "http://l.yimg.com/i/i/de/metro/patti.jpg",
+      "http://pil-de.sensic.net/view.php?id=609&ai=609911305&si=102&z=5169750",
+      "http://row.bc.yahoo.com/b?P=rOH7hlf4enaIjFzES6hqcAVfXMxrqkuobbUABTvY&T=13r3kd8oe%2fX%3d1269329333%2fE%3d2142153770%2fR%3ddehmpg%2fK%3d5%2fV%3d1.1%2fW%3dJR%2fY%3dDE%2fF%3d1627961479%2fS%3d1%2fJ%3d16A1EE4D&U=13odcn28u%2fN%3d3OW.LFf4eEc-%2fC%3d200077449.201936240.203227539.201427407%2fD%3dHDRM%2fB%3d201083721%2fV%3d1&U=12cltcst2%2fN%3d3.W.LFf4eEc-%2fC%3d-1%2fD%3dSTCK%2fB%3d-1%2fV%3d0&U=13oq99igf%2fN%3d3eW.LFf4eEc-%2fC%3d200121811.201962178.203251406.201366517%2fD%3dFPAD%2fB%3d201104189%2fV%3d1&U=13penir9s%2fN%3d4eW.LFf4eEc-%2fC%3d200122020.201964521.203249955.201421270%2fD%3dPROM1%2fB%3d201103196%2fV%3d1&U=13p21m4bp%2fN%3d4OW.LFf4eEc-%2fC%3d200121612.201961030.203250241.201441191%2fD%3dPROM2%2fB%3d201100611%2fV%3d1&U=12ber046v%2fN%3d5OW.LFf4eEc-%2fC%3d-1%2fD%3dSIP%2fB%3d-1%2fV%3d0&U=12dkuuk1c%2fN%3d5uW.LFf4eEc-%2fC%3d-1%2fD%3dYMBCN%2fB%3d-1%2fV%3d0&U=12b7orl19%2fN%3d4uW.LFf4eEc-%2fC%3d-2%2fD%3dRTG%2fB%3d-2%2fV%3d0&U=12cn27umu%2fN%3d4.W.LFf4eEc-%2fC%3d-1%2fD%3dRTG1%2fB%3d-1%2fV%3d0&U=13mgnvhf0%2fN%3d3uW.LFf4eEc-%2fC%3d200066141.201917714.203207718.201419751%2fD%3dRS%2fB%3d201075250%2fV%3d1&Q=0&O=0.2453797040205341",
+      "http://uk.ard.yahoo.com/SIG=15vmnkeq1/M=200121811.201962178.203251406.201366517/D=dehmpg/S=2142153770:FPAD/_ylt=AjU3QcOjT40Ps4X4Pt1qRHkqrK5_/Y=DE/EXP=1269336533/L=rOH7hlf4enaIjFzES6hqcAVfXMxrqkuobbUABTvY/B=3eW.LFf4eEc-/J=1269329333422048/K=c.k.Qwg3F0uysaPXI..55Q/A=201104189/N=-201/id=nu_ad_play/0.26024979463138365/*http://ads.yimg.com/ev/eu/any/pixel4.gif",
+      "http://uk.ard.yahoo.com/SIG=15vmnkeq1/M=200121811.201962178.203251406.201366517/D=dehmpg/S=2142153770:FPAD/_ylt=AjU3QcOjT40Ps4X4Pt1qRHkqrK5_/Y=DE/EXP=1269336533/L=rOH7hlf4enaIjFzES6hqcAVfXMxrqkuobbUABTvY/B=3eW.LFf4eEc-/J=1269329333422048/K=c.k.Qwg3F0uysaPXI..55Q/A=201104189/N=-247/id=nu_bg_on/0.4486526274433831/*http://ads.yimg.com/ev/eu/any/pixel4.gif",
+      "http://yahoo.ivwbox.de/blank.gif",
+      "http://yahoo.ivwbox.de/cgi-bin/ivw/CP/2142153770?r=&d=63214.11222648449",
+      "http://a.ligatus.com/?ids=12384&t=js",
+      "http://ad-emea.doubleclick.net/ad/N4137.heise.de/B4321259.12;sz=1x1;ord=906619961?",
+      "http://ad-emea.doubleclick.net/adj/N5295.111569.7876282795621/B4272309;sz=728x90;click0=http://oas.heise.de/RealMedia/ads/click_lx.ads/www.heise.de/Homepage/842927577/Top/OasDefault/google02_11ros_10/google02_11ros_10_redirect_mod.html/35393338313861373438353862653830?;ord=842927577?",
+      "http://heise.ivwbox.de/2004/01/survey.js",
+      "http://heise.ivwbox.de/blank.gif",
+      "http://heise.ivwbox.de/cgi-bin/ivw/CP/homepage;/?r=&d=75349.14130693086",
+      "http://i.ligatus.com/com_ads/9796_138x115.jpg",
+      "http://i.ligatus.com/com_global_img/logo-ligatus_frei_58x15.gif",
+      "http://just4business.de/images/Asus_Eee_PC_1201N_75x50.jpg",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/137x200/prakti_tr_sales.gif",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/3in1sky_sw/div_close_id_swvz_ad.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/3in1sky_sw/div_open_id_swvz_ad.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/bitdefender13_11sbox_10/bitdefenderav.jpg",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/cyberlink54674_44sbox_09/cyber.jpg",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/default/empty.gif",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/microsoft06_05nbox_10b/logo_sqlserver.jpg",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/microsoft33221_44sbox_09/msoffice.jpg",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/miwibox_hp/div_close.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/miwibox_hp/div_open_id_heise_bottom_4in1_banner.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/mjx/mjx.2009-11-17.0.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/textlinkbox_hp/div_close.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/textlinkbox_hp/div_open_class_teaser_adliste.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/textlinkbox_hp/ul_close.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/textlinkbox_hp/ul_open_class_linkliste.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/textlinkbox_hp/ul_open_class_microsites.js",
+      "http://oas.heise.de/RealMedia/ads/Creatives/OasDefault/wp06_EMC_51nbox_09/EMC_logo_75_50645575645667.jpg",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/3in1_sw/1406791973/x48/OasDefault/microsoft33221_44sbox_09/microsoft33221_44sbox_09.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/3in1_sw/284216804/x47/OasDefault/bitdefender13_11sbox_10/bitdefender13_44sbox_09.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/3in1_sw/962035171/x49/OasDefault/cyberlink54674_44sbox_09/cyberlink54674_44sbox_09.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/4in1_middle3hp/1292230445/x42/OasDefault/wp06_EMC_51nbox_09/ccp_textads_vorlage645575645667.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/4in1_middle3hp/262322103/x41/OasDefault/microsoft06_05nbox_10b/microsoft06_05nbox_10b_textad_new.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/4in1_middle3hp/814474394/x43/OasDefault/miwieigen06_miwibox/Asus_Eee_PC_1201N_75x50.script.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/1066903666/Middle3/OasDefault/miwibox_hp/miwibox_hp_rahmen.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/12677327/Bottom/OasDefault/default/empty.gif/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/1477879216/Middle/OasDefault/zz_hp/zz_autos_img.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/184013871/Left2/OasDefault/137x200/prakti_tr_sales.gif/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/262818978/Left1/OasDefault/3in1sky_sw/3in1sky_sw_rahmen.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/308630109/Right1/OasDefault/default/empty.gif/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/542677179/Left/OasDefault/ligatus03_ros/google02_nfanwendungen_script.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/60976329/Right2/OasDefault/textlinkbox_hp/textlinkbox_hp.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/842927577/Top/OasDefault/google02_11ros_10/google02_11ros_10_redirect_mod.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/Homepage/911738277/Middle2/OasDefault/zz_free_contentad/zz_autos_img.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1124251766/x51/OasDefault/wc09_checkpoint_08hpnews_10/wc09_checkpoint_08hpnews_10.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1288004340/x54/OasDefault/ms09_05hpnews_10/ms09_05hpnews_10_textlink.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1372532510/x53/OasDefault/ibm09_04hpnews_10/ibm09_04hpnews_10_text.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1392564978/x55/OasDefault/1blu09_04hpnews_10/1blu09_04hpnews_10_textlink.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1415958888/x50/OasDefault/pz_hp09_51hp_09/pz_hp09_51hp_09_textlink.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/1506484795/x52/OasDefault/whitepaper09_24hpnews_09/whitepaper_textlink.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_lx.ads/www.heise.de/textlinks_hp/906619961/x60/OasDefault/strato10_09hp_10/strato10_09hp_10_webhosting.html/35393338313861373438353862653830?_RM_EMPTY_",
+      "http://oas.heise.de/RealMedia/ads/adstream_mjx.ads/www.heise.de/Homepage/1434665888@Bottom,Left,Left1,Left2,Middle,Middle2,Middle3,Right1,Right2,Top,Top1?",
+      "http://qs.ivwbox.de/?heise//CP//homepage",
+      "http://rl.heise.de/images/pic.gif?r=;tp=1073741824%7C1073827193;m=Heise;tid=1073838799;random=25442.718985329073;con=1;json=1;tc=1073741824%7C1073827193%7C1073838799;c=20;b=16;sep=%7C;tce=1;tn=News;tpn=heise%20online%7CRedaktioneller%20Content%7CNews;url=http%3A%2F%2Fwww.heise.de%2F;tit=Startseite;tpu=1;sz=1366x768x24;con=1;cs=1",
+      "http://s0.2mdn.net/viewad/2635444/ROI2_DE_728x90.gif",
+      "http://umw-de.sensic.net/view.php?id=693&ai=7&si=12345&ps0=Heise&ps1=ROS&ps2=TextAd_75x50&ps3=ProdSQLM2&z=262322103",
+      "http://view.atdmt.com/DEM/view/211257741/direct/01/",
+      "http://www.heise.de/RealMedia/ads/adstream_jx.ads/www.heise.de/3in1_sw/1693169649@x47,x48,x49?",
+      "http://www.heise.de/RealMedia/ads/adstream_jx.ads/www.heise.de/4in1_middle3hp/1540744443@x41,x42,x43,x44?",
+      "http://www.heise.de/RealMedia/ads/adstream_jx.ads/www.heise.de/textlinks_hp/1035057110@x50,x51,x52,x53,x54,x55,x56,x57,x58,x59?",
+      "http://www.heise.de/RealMedia/ads/adstream_jx.ads/www.heise.de/textlinks_hp/1035057110@x60,x61,x62,x63,x64,x65,x66,x67,x68,x69?",
+      "http://www.heise.de/defeckerellyinesteetshygolingshetrica/",
+      "http://www.heise.de/favicon.ico",
+      "http://www.heise.de/icons/ho/00on.gif",
+      "http://www.heise.de/icons/ho/background_mitte_40zu60.gif",
+      "http://www.heise.de/icons/ho/background_mitte_links.gif",
+      "http://www.heise.de/icons/ho/background_navi_top.gif",
+      "http://www.heise.de/icons/ho/background_navigation.gif",
+      "http://www.heise.de/icons/ho/background_onlinemarkt.gif",
+      "http://www.heise.de/icons/ho/background_teaser_ecke.png",
+      "http://www.heise.de/icons/ho/background_weitere.gif",
+      "http://www.heise.de/icons/ho/dpunktfoto.gif",
+      "http://www.heise.de/icons/ho/emedia.gif",
+      "http://www.heise.de/icons/ho/heise_online_logo.gif",
+      "http://www.heise.de/icons/ho/low_link.gif",
+      "http://www.heise.de/icons/ho/midot.gif",
+      "http://www.heise.de/icons/ho/mittelstandswiki.gif",
+      "http://www.heise.de/imgs/02/3/9/8/2/3/9/00.jpg-c8df87c7325bb251.jpeg",
+      "http://www.heise.de/imgs/02/3/9/9/5/4/2/ct0510Thinkpad_64746-jow-jg_PR-137-96bc3ad582573fb2.gif",
+      "http://www.heise.de/imgs/02/4/0/2/9/2/7/kde4-gnome-80x80-42caec49ea223795.png",
+      "http://www.heise.de/imgs/02/4/2/6/5/1/1/ir_engine-2.jpg-4d3fb8309d2c3808.jpeg",
+      "http://www.heise.de/imgs/02/4/3/9/0/0/1/Breitband.jpg-ed3b76a2f37c3bbd.jpeg",
+      "http://www.heise.de/imgs/02/4/5/2/8/6/9/update-check-teaser-grau-eb2471c6cbfe8a9e.gif",
+      "http://www.heise.de/imgs/02/4/7/8/8/3/7/tpspecial0110-d01129faf4ab9c46.gif",
+      "http://www.heise.de/imgs/02/4/9/8/7/5/1/Google2-c52f2c091ee665ca.png",
+      "http://www.heise.de/imgs/18/4/9/7/4/9/5/Platine1-7a44dd182f22c0ac.png",
+      "http://www.heise.de/imgs/18/4/9/8/4/3/7/TN_19349274_79671348f6-c162feefc49e954c.png",
+      "http://www.heise.de/imgs/18/4/9/8/5/9/0/nt-mi.jpg-3ef5aa6f33f02d9d.jpeg",
+      "http://www.heise.de/imgs/18/4/9/8/6/1/0/aufmacher_ajax.jpg-5bbbcea175e4cbcc.jpeg",
+      "http://www.heise.de/imgs/18/4/9/8/6/6/4/nt-brown.jpg-4bdb775e5337ed24.jpeg",
+      "http://www.heise.de/imgs/18/4/9/8/6/8/9/kernel-log-75x100-teaser.jpg-9ad4c881273c6e97.jpeg",
+      "http://www.heise.de/imgs/18/4/9/8/6/9/7/Iran2-97230727a4d76307.png",
+      "http://www.heise.de/imgs/18/4/9/8/7/3/1/TV5_StockXChng-MJimanges-3419995169601f3a.png",
+      "http://www.heise.de/imgs/18/4/9/8/7/6/4/TV1-65ed120a09b6758c.png",
+      "http://www.heise.de/imgs/18/4/9/8/8/2/8/Datenschutz_EU-Datenschutzbeauftragter_PeterHustinx2-d0f55c7009e75827.png",
+      "http://www.heise.de/ivw-bin/ivw/CP/",
+      "http://www.heise.de/software/specials/top_downloads_2009.jpeg",
+      "http://www.heise.de/stil/drucken.css",
+      "http://www.heise.de/stil/ho/standard2008.css",
+      "http://www.heise.de/stil/navi_top2008.css",
+      "http://www.heise.de/stil/standard2008.css",
+      "http://www.heise.de/support/lib/external.js",
+      "http://www.heise.de/support/lib/jquery-1.4.1.min.js",
+      "http://www.heise.de/support/lib/jquery/jquery.ui-1.8.ho-teaserbundle.min.js",
+      "http://www.heise.de/support/lib/login_ho.js",
+      "http://www.heise.de/support/lib/mclient/mclient-1.0.js",
+      "http://www.heise.de/support/sales/software/swvz_skyscraper/swvz_ad_verlauf.jpg",
+      "http://www.heise.de/support/sales/software/swvz_skyscraper/swvz_logo.png",
+      "http://www.strato.de/asis/pilot.de.asis?5121844",
+      "http://www.strato.de/asis/pilot.de.asis?906619961",
+      "http://x.ligatus.de/blank.gif",
+      "http://x.ligatus.de/cgi-bin/ivw/CP/33548454",
+      "http://ad.doubleclick.net/ad/N1727.cnn.com/B4080371.3;sz=1x1;ord=coaKddo,bfAqIpmbIqy?",
+      "http://ad.doubleclick.net/ad/N5364.CNN.com/B4366287;sz=300x250;ord=cNeKdzI,bfAqIpmbIut?",
+      "http://ad.doubleclick.net/adj/N3880.SD146.3880/B4087837.11;dcove=o;mtfIFPath=/.element/ssi/ads.iframes/doubleclick/;sz=120x90;click=http://ads.cnn.com/event.ng/Type=click&FlightID=285106&AdID=388426&TargetID=77947&Values=1588&Redirect=;ord=bpxeKwy,bfAqIpmbKhI?",
+      "http://ads.cnn.com/DartRichMedia_1_03.js",
+      "http://ads.cnn.com/DartRichMedia_1_03.js",
+      "http://ads.cnn.com/DartRichMedia_1_03.js",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=352666&FlightID=257771&TargetID=75867&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,16113,17173,17251,18517,18982,20139,23491,31271,31323,32004,32594,32859,33776,33852,34282,34895,35523,36041,36376&Targets=1515,75806,75867&Values=46,60,82,100,1266,1588,2677,2746,4432,52897,56058,57005,57006,58702,59988,60001,61089&RawValues=TIELID%2C9348839239621&random=cvcuzjc,bfAqIpmbIuu",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=388426&FlightID=285106&TargetID=77947&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,4875,6041,9129,9496,9779,9781,9853,10381,16113,17173,17251,18517,18982,20139,23491,30995,31071,32004,32594,32828,32859,33776,33852,34282,34485,34895,35523,36041,36105,36376&Targets=77048,73788,77741,75201,1515,77947,76343,84488,87917&Values=46,60,82,100,1266,1588,2677,2746,4432,48137,52897,56058,57005,57006,58702,59988,61089&RawValues=TIELID%2C9348839239621&random=bpxeKwy,bfAqIpmbKhI",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=390833&FlightID=285031&TargetID=34606&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,12853,16113,17173,17251,18517,18982,19974,20139,23491,32004,32594,32859,33776,33852,34282,34895,35523,36041,36376&Targets=34606,1515,46824&Values=46,60,82,100,1266,1588,2677,2746,4432,52786,52897,56058,57005,57006,58702,59988,61089&RawValues=TIELID%2C9348839239621&random=coaKddo,bfAqIpmbIqy",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=396796&FlightID=272450&TargetID=85456&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,16113,17173,17251,18517,18982,20139,23491,30357,30363,31448,32004,32594,32827,32859,33776,33852,34282,34895,35523,35605,36041,36257,36376&Targets=73787,73789,1515,82547,82806,85456,79630&Values=46,60,82,100,1266,1588,2677,2746,4432,52897,56058,57005,57006,58702,59473,59988,61089&RawValues=TIELID%2C9348839239622&random=ckvbliA,bfAqIpmbKhw",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=396796&FlightID=272450&TargetID=85456&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,16113,17173,17251,18517,18982,20139,23491,30363,30708,31448,32004,32594,32859,33776,33852,34282,34895,35523,35605,36041,36260,36376&Targets=73789,1515,82806,82549,85456&Values=46,60,82,100,1266,1588,2677,2746,4432,52897,56058,57005,57006,58702,59474,59988,61089&RawValues=TIELID%2C9348839239622&random=bKxwbjs,bfAqIpmbKhy",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=396796&FlightID=272450&TargetID=85456&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,16113,17173,17251,18517,18982,20139,23491,30363,30709,31448,32004,32594,32859,33776,33852,34282,34895,35523,35605,36041,36261,36376&Targets=73789,1515,82806,82548,85456&Values=46,60,82,100,1266,1588,2677,2746,4432,52897,56058,57005,57006,58702,59475,59988,61089&RawValues=TIELID%2C9348839239622&random=biqiovA,bfAqIpmbIqI",
+      "http://ads.cnn.com/event.ng/Type=count&ClientType=2&ASeg=&AMod=&AdID=397003&FlightID=292368&TargetID=72775&SiteID=1588&EntityDefResetFlag=0&Segments=730,2247,2743,2823,3285,9496,9779,9781,9853,10381,13086,13087,13088,13090,13091,13303,16113,16337,17173,17251,18517,18887,18901,18904,18982,20139,23491,23793,25535,25538,25544,25547,25550,29699,29776,30401,31073,32004,32594,32736,32825,32859,33776,33852,34253,34282,34895,35523,35895,36040,36041,36310,36376&Targets=73881,72775,72645,1515,70690,88526,86748,86245,86257,85450,76350,79628,82457,85144,85146,86622,88640,86090,87669,87671,82751,85139,82663,84902,86352,88869,82775,84903,82659,84555,84559,84564,87626,87918&Values=46,60,82,100,1266,1588,2677,2746,4432,52897,56058,57005,57006,58702,59477,59988,61089&RawValues=TIELID%2C9348839239621&random=cNeKdzI,bfAqIpmbIut",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=120x90_bot1&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=653357",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=126x31_spon3&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=223595",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=126x31_spon8&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=101386",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=126x31_spon9&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=308194",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=1x1_bot&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=728136",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=230x250_adlinks&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=709129",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=300x100_bot1&cnn_rollup=homepage&page.allowcompete=no&params.styles=fs&tile=9348839239622&domId=274828",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=300x100_bot2&cnn_rollup=homepage&page.allowcompete=no&params.styles=fs&tile=9348839239622&domId=790397",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=300x100_bot3&cnn_rollup=homepage&page.allowcompete=no&params.styles=fs&tile=9348839239622&domId=709102",
+      "http://ads.cnn.com/html.ng/site=cnn&cnn_pagetype=main&cnn_position=300x250_rgt&cnn_rollup=homepage&page.allowcompete=yes&params.styles=fs&tile=9348839239621&domId=985003",
+      "http://b.scorecardresearch.com/r2?c2=6035748&d.c=gif&d.o=cnn3global&d.x=253275916&d.t=page&d.u=http%3A%2F%2Fwww.cnn.com%2F",
+      "http://b.scorecardresearch.com/r?c2=6035748&d.c=gif&d.o=cnn3global&d.x=253275916&d.t=page&d.u=http%3A%2F%2Fwww.cnn.com%2F",
+      "http://cnn.dyn.cnn.com/cookie.crumb",
+      "http://content.dl-rms.com/rms/mother/5721/nodetag.js",
+      "http://es.optimost.com/es/203/c/3/u/cnn_live.js",
+      "http://gdyn.cnn.com/1.1/1.gif?1269329388870",
+      "http://googleads.g.doubleclick.net/pagead/ads?client=ca-cnn-home_js&output=js&num_ads=3&channel=homepage&ad_type=text&adtest=off&ea=0&oe=utf8&flash=10.0.45&hl=en&url=http%3A%2F%2Fwww.cnn.com%2F&adsafe=high&dt=1269329389465&correlator=1269329389472&frm=1&ga_vid=1045930262.1269329390&ga_sid=1269329390&ga_hid=558562656&ga_fc=0&u_tz=60&u_his=3&u_java=0&u_h=768&u_w=1366&u_ah=768&u_aw=1366&u_cd=24&u_nplug=2&u_nmime=3&biw=1349&bih=390&ifk=806819358&loc=http%3A%2F%2Fwww.cnn.com%2F&fu=4&ifi=1&dtd=210",
+      "http://googleads.g.doubleclick.net/pagead/test_domain.js",
+      "http://i.cdn.turner.com/cnn/.element/css/3.0/common.css",
+      "http://i.cdn.turner.com/cnn/.element/css/3.0/common.css",
+      "http://i.cdn.turner.com/cnn/.element/css/3.0/connect/overlay.css",
+      "http://i.cdn.turner.com/cnn/.element/css/3.0/main.css",
+      "http://i.cdn.turner.com/cnn/.element/css/3.0/personalization.css",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/1px.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/buttons/Sprite_BT_master.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/buttons/sprite_tabbed.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/arabic.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/footer_cnn_logo.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/footer_google.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/japanese.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/korean.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/footer/pngs/turkish.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/bg-nav.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/hat/arrow_black.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/hat/bg_hat_black_lg.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/hdr-close.jpg",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/hdr-main.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/hdr-search-google.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/nav-arrow.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/header/nav-beta.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/icons/red.carrot.jpg",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/icons/video_icon.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/Numbers_Sprite.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/advertisement.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/filter.line.100px.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/loading.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/red_bull.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/BL_shadow_7x6.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/BR_shadow_1000x6.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/Left_shadow.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/Right_shadow.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/TL_shadow_7x6.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/TR_shadow_1000x6.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/cnn_shdcamtt1.990px.bg.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/cnn_shdcamtt1.990px.header.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/cnn_shdsectbin.990px.bg.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/global/shade/sprite_shades.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/35x35_generic_avatar.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/Green_market_status.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/Module_gradient.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/arrow_down.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/arrow_up.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/hp_market_sprite.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/personalization/popular_bar.jpg",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/search/bg_ftrsearchfield.lrg.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/search/btn_search_hp_text.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/search/search_btn_footer.gif",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/video/thumbnail_play.png",
+      "http://i.cdn.turner.com/cnn/.element/img/3.0/weather/03/33.png",
+      "http://i.cdn.turner.com/cnn/.element/js/2.0/ad_head0.js",
+      "http://i.cdn.turner.com/cnn/.element/js/2.0/frame.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/StorageManager.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/connect/connect-lite.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/csiManager.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/edition.vars.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/hpsectiontracking.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/local.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/main.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/protoaculous.1.8.2.min.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/s_code.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/swfobject-2.2.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/video/cvp.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/video/cvp_suppl.js",
+      "http://i.cdn.turner.com/cnn/.element/js/3.0/weather.footer.js",
+      "http://i.cdn.turner.com/cnn/2009/images/11/16/210x80_cnn_Challenge.jpg",
+      "http://i.cdn.turner.com/cnn/2010/HEALTH/03/22/united.nations.water.report/c1main.india.river.afp.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/LIVING/03/22/margaret.moth.tributes/tzvids.margaret.moth.courtesy.jpg",
+      "http://i.cdn.turner.com/cnn/2010/LIVING/03/22/real.men.eat.salad/tzvids.salad.cnn.jpg",
+      "http://i.cdn.turner.com/cnn/2010/LIVING/03/22/vegan.food.activists/tzvids.veg.activists.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/LIVING/worklife/03/22/cb.job.search.mistakes/tzvids.js.mistakes.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/LIVING/worklife/03/22/rs.secrets.working.mother/tzvids.unflappable.mom.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/POLITICS/03/16/health.care.immediate/tzvids.benefits.c2.jpg",
+      "http://i.cdn.turner.com/cnn/2010/SHOWBIZ/TV/03/22/rosie.odonnell.show.ppl/tzvids.rosie.odonnell.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/SPORT/tennis/03/18/tennis.film.nadal.amritraj.mcenroe/tzvids.rafa.jpg",
+      "http://i.cdn.turner.com/cnn/2010/TRAVEL/03/22/flying.now.then/tzvids.flying.then.gi.jpg",
+      "http://i.cdn.turner.com/cnn/2010/WORLD/africa/03/22/africa.elephants.ivory.trade/tzvids.elephant.poaching.jpg",
+      "http://i.cdn.turner.com/cnn/2010/WORLD/europe/03/22/germany.hitler.letter.cordial/tzvids.hitler.letter.jpg",
+      "http://i.cdn.turner.com/cnn/2010/images/03/22/tzvids.health.effects.irpt.jpg",
+      "http://i.cdn.turner.com/cnn/2010/images/03/22/tzvids.ncaa.upset.gi.jpg",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2008/9/17/2855151x1.gif",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2008/9/17/2855151x1.gif",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2008/9/17/2855151x1.gif",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2009/11/9/56101520090708_DB_IP_DBLEPLUSA_24_300_100.swf",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2009/11/9/56101520090708_DB_IP_DBLEPLUSA_24_300_100.swf",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2009/11/9/56101520090708_DB_IP_DBLEPLUSA_24_300_100.swf",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/2.0/creatives/2009/6/3/4436122_equifax.143x31.jpg",
+      "http://i.cdn.turner.com/cnn/cnn_adspaces/cnn_adspaces.js",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif",
+      "http://i.cdn.turner.com/cnn/images/1.gif?csiTestMatch=true",
+      "http://i.cdn.turner.com/cnn/video/us/2010/03/22/dnt.cows.drink.more.beer.kval.120x68.jpg",
+      "http://i.cdn.turner.com/xslo/cvp/ads/freewheel/js/fwjslib_1.1.js?version=1.1",
+      "http://i.cnn.net/cnn/.element/js/2.0/csi_include.js",
+      "http://i2.cdn.turner.com/cnn/2009/images/10/27/lking120x68.copy.jpg",
+      "http://i2.cdn.turner.com/cnn/2009/images/10/29/roberts-chetry120x68.copy.jpg",
+      "http://i2.cdn.turner.com/cnn/2010/POLITICS/03/22/health.care.main/t1main.obama.cnn.jpg",
+      "http://i2.cdn.turner.com/cnn/2010/images/03/15/jk_usa_plain_120x68.jpg",
+      "http://i2.cdn.turner.com/cnn/2010/images/03/22/tzvids.kennedy.offcenter.cnn.jpg?hpt=C2",
+      "http://js.revsci.net/gateway/gw.js?csid=A09801",
+      "http://metrics.cnn.com/b/ss/cnn3global/1/H.20.3/s0429878539768?AQB=1&ndh=1&t=23/2/2010%208%3A29%3A48%202%20-60&ns=cnn&pageName=CNN%20Home%20Page&g=http%3A//www.cnn.com/&ch=CNN%20Home%20Page&v1=CNN%20Home%20Page&v2=CNN%20Home%20Page&c5=Homepage&v5=Homepage&c9=03%3A15&c10=Tue&c18=10&c20=03&s=1366x768&c=24&j=1.7&v=N&k=Y&bw=1366&bh=390&p=Mozilla%20Default%20Plug-in%3BShockwave%20Flash%3B&AQE=1",
+      "http://metrics.cnn.com/b/ss/cnn3global/1/H.20.3/s0429878539768?AQB=1&pccr=true&vidn=25D436F5051D16A6-40000105C00092FC&&ndh=1&t=23/2/2010%208%3A29%3A48%202%20-60&ns=cnn&pageName=CNN%20Home%20Page&g=http%3A//www.cnn.com/&ch=CNN%20Home%20Page&v1=CNN%20Home%20Page&v2=CNN%20Home%20Page&c5=Homepage&v5=Homepage&c9=03%3A15&c10=Tue&c18=10&c20=03&s=1366x768&c=24&j=1.7&v=N&k=Y&bw=1366&bh=390&p=Mozilla%20Default%20Plug-in%3BShockwave%20Flash%3B&AQE=1",
+      "http://pagead2.googlesyndication.com/pagead/show_ads.js",
+      "http://pix04.revsci.net/A09801/b3/0/3/0902121/429848602.js?D=DM_LOC%3Dhttp%253A%252F%252Fwww.cnn.com%252F%253Fundefined%253Dundefined%26DM_CAT%3Dcnn%2520%253E%2520homepage%26DM_EOM%3D1&C=A09801",
+      "http://s0.2mdn.net/viewad/1873234/CR7USDS_001_300x250.gif",
+      "http://s0.2mdn.net/viewad/2584085/120x90_Ally_Logo.gif",
+      "http://s0.2mdn.net/viewad/617966/84-1x1.gif",
+      "http://svcs.cnn.com/weather/getForecast?time=59&mode=json_html&zipCode=74446&locCode=MUSX&celcius=false&csiID=csi3",
+      "http://view.atdmt.com/NYC/view/184916056/direct;wi.1;hi.1/01/bKxwbjs,bfAqIpmbKhy",
+      "http://view.atdmt.com/NYC/view/184916056/direct;wi.1;hi.1/01/biqiovA,bfAqIpmbIqI",
+      "http://view.atdmt.com/NYC/view/184916056/direct;wi.1;hi.1/01/ckvbliA,bfAqIpmbKhw",
+      "http://www.cnn.com/",
+      "http://www.cnn.com/.element/ssi/misc/3.0/editionvars.html?csiID=csi2",
+      "http://www.cnn.com/.element/ssi/www/breaking_news/3.0/banner.html?csiID=csi1",
+      "http://www.cnn.com/cnn_adspaces/3.0/homepage/main/bot1.120x90.ad"
+    ];
+
+    // Add everything to the same matcher, don't bother separating whitelist and blacklist
+    let matcher = new Matcher();
+    for each (let filter in filters)
+      matcher.add(filter);
+
+    function runTest()
+    {
+      for each (let address in addresses)
+        matcher.matchesAny(address, "IMAGE", null, false);
+      let endTime = Date.now();
+    }
+
+    function cleanup()
+    {
+      // Add and remove a dummy filter to clear matcher's cache
+      let dummy = Filter.fromText("foobar");
+      matcher.add(dummy);
+      matcher.remove(dummy);
+    }
+
+    runTests(runTest, cleanup);
+  </script>
+</body>
+</html>

=== modified file 'chrome/content/mochitest/tests/test_domainRestrictions.html'
--- chrome/content/mochitest/tests/test_domainRestrictions.html	2010-01-07 17:25:17 +0000
+++ chrome/content/mochitest/tests/test_domainRestrictions.html	2010-05-04 14:45:07 +0000
@@ -97,6 +97,18 @@
     testActive("example.com,~com#foo", "example.com", true, true);
     testActive("example.com,~com#foo", "foo.example.com", true, false);
     testActive("example.com,~com#foo", "mple.com", false, false);
+
+    testActive("foo$domain=nnnnnnn.nnn", null, false, false);
+    testActive("foo$domain=nnnnnnn.nnn", "com", false, false);
+    testActive("foo$domain=nnnnnnn.nnn", "example.com", false, false);
+    testActive("foo$domain=nnnnnnn.nnn", "foo.example.com", false, false);
+    testActive("foo$domain=nnnnnnn.nnn", "mple.com", false, false);
+
+    testActive("nnnnnnn.nnn#foo", null, false, false);
+    testActive("nnnnnnn.nnn#foo", "com", false, false);
+    testActive("nnnnnnn.nnn#foo", "example.com", false, false);
+    testActive("nnnnnnn.nnn#foo", "foo.example.com", false, false);
+    testActive("nnnnnnn.nnn#foo", "mple.com", false, false);
   </script>
   </pre>
 </body>

=== modified file 'chrome/content/mochitest/tests/test_elemhide.html'
--- chrome/content/mochitest/tests/test_elemhide.html	2010-01-07 17:25:17 +0000
+++ chrome/content/mochitest/tests/test_elemhide.html	2010-05-04 14:45:07 +0000
@@ -79,7 +79,7 @@
 
       if (currentTest >= tests.length - 1)
       {
-        if (++currentRun <= 3)
+        if (++currentRun <= 5)
         {
           currentTest = -1;
           runNextTest();
@@ -101,14 +101,19 @@
         abp.whitelistMatcher.add(abp.Filter.fromText("@@|chrome://mochikit/$document"));
       else if (currentRun == 3)
         abp.whitelistMatcher.add(abp.Filter.fromText("@@|chrome://mochikit/$~document"));
+      else if (currentRun == 4)
+        abp.whitelistMatcher.add(abp.Filter.fromText("@@|chrome://mochikit/$elemhide"));
+      else if (currentRun == 5)
+        abp.whitelistMatcher.add(abp.Filter.fromText("@@||localhost^$elemhide"));
 
       // Reset the loaded document
       let body = document.getElementById("frame").contentDocument.body;
       body.innerHTML = body.innerHTML;
 
-      if (currentRun == 2)
-        expected = "visible visible";   // Second run is whitelisted, nothing should be hidden
+      if (currentRun == 2 || currentRun == 5)
+        expected = "visible visible";   // Second and fifth runs are whitelisted, nothing should be hidden
 
+      body.offsetHeight;    // force reflow
       setTimeout(function()
       {
         let doc = document.getElementById("frame").contentDocument;

=== modified file 'chrome/content/mochitest/tests/test_filterClasses.html'
--- chrome/content/mochitest/tests/test_filterClasses.html	2010-01-07 17:25:17 +0000
+++ chrome/content/mochitest/tests/test_filterClasses.html	2010-05-04 14:45:07 +0000
@@ -112,7 +112,7 @@
       }
       if (type == "whitelist" || type == "filterlist")
       {
-        addProperty("contentType", 0x7FFFFFFF);
+        addProperty("contentType", 0x7FFFFFFF & ~RegExpFilter.typeMap.ELEMHIDE);
         addProperty("matchCase", "false");
         addProperty("thirdParty", "null");
         addProperty("domains", "");
@@ -198,26 +198,32 @@
       filter.lastHit = 20;
     });
 
+    let t = RegExpFilter.typeMap;
+    let allTypes = 0x7FFFFFFF;
+
     compareFilter("/ddd|f?a[s]d/", ["type=filterlist", "text=/ddd|f?a[s]d/", "regexp=ddd|f?a[s]d"]);
     compareFilter("*asdf*d**dd*", ["type=filterlist", "text=*asdf*d**dd*", "regexp=asdf.*d.*dd"]);
     compareFilter("|*asd|f*d**dd*|", ["type=filterlist", "text=|*asd|f*d**dd*|", "regexp=^.*asd\\|f.*d.*dd.*$"]);
     compareFilter("dd[]{}$%<>&()d", ["type=filterlist", "text=dd[]{}$%<>&()d", "regexp=dd\\[\\]\\{\\}\\$\\%\\<\\>\\&\\(\\)d"]);
 
-    compareFilter("@@/ddd|f?a[s]d/", ["type=whitelist", "text=@@/ddd|f?a[s]d/", "regexp=ddd|f?a[s]d", "contentType=2147483583"]);
-    compareFilter("@@*asdf*d**dd*", ["type=whitelist", "text=@@*asdf*d**dd*", "regexp=asdf.*d.*dd", "contentType=2147483583"]);
-    compareFilter("@@|*asd|f*d**dd*|", ["type=whitelist", "text=@@|*asd|f*d**dd*|", "regexp=^.*asd\\|f.*d.*dd.*$", "contentType=2147483583"]);
-    compareFilter("@@dd[]{}$%<>&()d", ["type=whitelist", "text=@@dd[]{}$%<>&()d", "regexp=dd\\[\\]\\{\\}\\$\\%\\<\\>\\&\\(\\)d", "contentType=2147483583"]);
-
-    compareFilter("bla$match-case,script,other,third-party,domain=foo.com", ["type=filterlist", "text=bla$match-case,script,other,third-party,domain=foo.com", "regexp=bla", "matchCase=true", "contentType=3", "thirdParty=true", "domains=FOO.COM"]);
-    compareFilter("bla$~match-case,~script,~other,~third-party,domain=~bar.com", ["type=filterlist", "text=bla$~match-case,~script,~other,~third-party,domain=~bar.com", "regexp=bla", "contentType=2147483644", "thirdParty=false", "domains=~BAR.COM"]);
-    compareFilter("@@bla$match-case,script,other,third-party,domain=foo.com|bar.com|~bar.foo.com|~foo.bar.com", ["type=whitelist", "text=@@bla$match-case,script,other,third-party,domain=foo.com|bar.com|~bar.foo.com|~foo.bar.com", "regexp=bla", "matchCase=true", "contentType=3", "thirdParty=true", "domains=BAR.COM|FOO.COM|~BAR.FOO.COM|~FOO.BAR.COM"]);
-
-    compareFilter("@@bla$~script,~other", ["type=whitelist", "text=@@bla$~script,~other", "regexp=bla", "contentType=2147483580"]);
-    compareFilter("@@http://bla$~script,~other", ["type=whitelist", "text=@@http://bla$~script,~other", "regexp=http\\:\\/\\/bla", "contentType=2147483644"]);
-    compareFilter("@@|ftp://bla$~script,~other", ["type=whitelist", "text=@@|ftp://bla$~script,~other", "regexp=^ftp\\:\\/\\/bla", "contentType=2147483644"]);
-    compareFilter("@@bla$~script,~other,document", ["type=whitelist", "text=@@bla$~script,~other,document", "regexp=bla", "contentType=2147483644"]);
-    compareFilter("@@bla$~script,~other,~document", ["type=whitelist", "text=@@bla$~script,~other,~document", "regexp=bla", "contentType=2147483580"]);
-    compareFilter("@@bla$document", ["type=whitelist", "text=@@bla$document", "regexp=bla", "contentType=64"]);
+    compareFilter("@@/ddd|f?a[s]d/", ["type=whitelist", "text=@@/ddd|f?a[s]d/", "regexp=ddd|f?a[s]d", "contentType=" + (allTypes & ~(t.ELEMHIDE | t.DOCUMENT))]);
+    compareFilter("@@*asdf*d**dd*", ["type=whitelist", "text=@@*asdf*d**dd*", "regexp=asdf.*d.*dd", "contentType=" + (allTypes & ~(t.ELEMHIDE | t.DOCUMENT))]);
+    compareFilter("@@|*asd|f*d**dd*|", ["type=whitelist", "text=@@|*asd|f*d**dd*|", "regexp=^.*asd\\|f.*d.*dd.*$", "contentType=" + (allTypes & ~(t.ELEMHIDE | t.DOCUMENT))]);
+    compareFilter("@@dd[]{}$%<>&()d", ["type=whitelist", "text=@@dd[]{}$%<>&()d", "regexp=dd\\[\\]\\{\\}\\$\\%\\<\\>\\&\\(\\)d", "contentType=" + (allTypes & ~(t.ELEMHIDE | t.DOCUMENT))]);
+
+    compareFilter("bla$match-case,script,other,third-party,domain=foo.com", ["type=filterlist", "text=bla$match-case,script,other,third-party,domain=foo.com", "regexp=bla", "matchCase=true", "contentType=" + (t.SCRIPT | t.OTHER), "thirdParty=true", "domains=FOO.COM"]);
+    compareFilter("bla$~match-case,~script,~other,~third-party,domain=~bar.com", ["type=filterlist", "text=bla$~match-case,~script,~other,~third-party,domain=~bar.com", "regexp=bla", "contentType=" + (allTypes & ~(t.ELEMHIDE | t.SCRIPT | t.OTHER)), "thirdParty=false", "domains=~BAR.COM"]);
+    compareFilter("@@bla$match-case,script,other,third-party,domain=foo.com|bar.com|~bar.foo.com|~foo.bar.com", ["type=whitelist", "text=@@bla$match-case,script,other,third-party,domain=foo.com|bar.com|~bar.foo.com|~foo.bar.com", "regexp=bla", "matchCase=true", "contentType=" + (t.SCRIPT | t.OTHER), "thirdParty=true", "domains=BAR.COM|FOO.COM|~BAR.FOO.COM|~FOO.BAR.COM"]);
+
+    compareFilter("@@bla$~script,~other", ["type=whitelist", "text=@@bla$~script,~other", "regexp=bla", "contentType=" + (allTypes & ~(t.ELEMHIDE | t.DOCUMENT | t.SCRIPT | t.OTHER))]);
+    compareFilter("@@http://bla$~script,~other", ["type=whitelist", "text=@@http://bla$~script,~other", "regexp=http\\:\\/\\/bla", "contentType=" + (allTypes & ~(t.ELEMHIDE | t.SCRIPT | t.OTHER))]);
+    compareFilter("@@|ftp://bla$~script,~other", ["type=whitelist", "text=@@|ftp://bla$~script,~other", "regexp=^ftp\\:\\/\\/bla", "contentType=" + (allTypes & ~(t.ELEMHIDE | t.SCRIPT | t.OTHER))]);
+    compareFilter("@@bla$~script,~other,document", ["type=whitelist", "text=@@bla$~script,~other,document", "regexp=bla", "contentType=" +  (allTypes & ~(t.ELEMHIDE | t.SCRIPT | t.OTHER))]);
+    compareFilter("@@bla$~script,~other,~document", ["type=whitelist", "text=@@bla$~script,~other,~document", "regexp=bla", "contentType=" + (allTypes & ~(t.ELEMHIDE | t.DOCUMENT | t.SCRIPT | t.OTHER))]);
+    compareFilter("@@bla$document", ["type=whitelist", "text=@@bla$document", "regexp=bla", "contentType=" + t.DOCUMENT]);
+    compareFilter("@@bla$~script,~other,elemhide", ["type=whitelist", "text=@@bla$~script,~other,elemhide", "regexp=bla", "contentType=" +  (allTypes & ~(t.DOCUMENT | t.SCRIPT | t.OTHER))]);
+    compareFilter("@@bla$~script,~other,~elemhide", ["type=whitelist", "text=@@bla$~script,~other,~elemhide", "regexp=bla", "contentType=" + (allTypes & ~(t.ELEMHIDE | t.DOCUMENT | t.SCRIPT | t.OTHER))]);
+    compareFilter("@@bla$elemhide", ["type=whitelist", "text=@@bla$elemhide", "regexp=bla", "contentType=" + t.ELEMHIDE]);
 
     compareFilter("#ddd", ["type=elemhide", "text=#ddd", "selector=ddd"]);
     compareFilter("#ddd(fff)", ["type=elemhide", "text=#ddd(fff)", "selector=ddd.fff,ddd#fff"]);
@@ -233,4 +239,4 @@
   </script>
   </pre>
 </body>
-</html>
\ No newline at end of file
+</html>

=== modified file 'chrome/content/mochitest/tests/test_filterStorage.html'
--- chrome/content/mochitest/tests/test_filterStorage.html	2010-01-07 17:25:17 +0000
+++ chrome/content/mochitest/tests/test_filterStorage.html	2010-05-04 14:45:07 +0000
@@ -65,6 +65,7 @@
     filterStorage.addSubscription(Subscription.fromURL("~eh~"));
 
     testFilters();
+    testDisabledSubscriptions();
 
     function testSubscriptions()
     {
@@ -296,7 +297,35 @@
       filterStorage.removeSubscription(subscription2);
       filterStorage.removeSubscription(subscription3);
     }
+
+    function testDisabledSubscriptions()
+    {
+      let subscription = Subscription.fromURL("~fl~");
+      filterStorage.updateSubscriptionFilters(subscription, []);
+      subscription.disabled = true;
+
+      let filter1 = Filter.fromText("filter1");
+      let filter2 = Filter.fromText("filter2");
+
+      filterStorage.addFilter(filter1);
+      is(subscription.disabled, true, "Subscription still disabled after adding one filter");
+      filterStorage.addFilter(filter2);
+      is(subscription.disabled, true, "Subscription still disabled after adding two filters");
+
+      filterStorage.removeFilter(filter1);
+      is(subscription.disabled, true, "Subscription still disabled after removing one filter");
+      filterStorage.removeFilter(filter2);
+      is(subscription.disabled, false, "Subscription no longer disabled after removing all filters");
+
+      subscription.disabled = true;
+      filterStorage.updateSubscriptionFilters(subscription, [filter1]);
+      is(subscription.disabled, true, "Subscription still disabled after replacing filters by one filter");
+      filterStorage.updateSubscriptionFilters(subscription, [filter1, filter2]);
+      is(subscription.disabled, true, "Subscription still disabled after replacing filters by two filters");
+      filterStorage.updateSubscriptionFilters(subscription, []);
+      is(subscription.disabled, false, "Subscription no longer disabled after replacing filters by an empty list");
+    }
   </script>
   </pre>
 </body>
-</html>
\ No newline at end of file
+</html>

=== modified file 'chrome/content/mochitest/tests/test_matcher.html'
--- chrome/content/mochitest/tests/test_matcher.html	2010-01-07 17:25:17 +0000
+++ chrome/content/mochitest/tests/test_matcher.html	2010-05-04 14:45:07 +0000
@@ -24,17 +24,19 @@
     {
       expected.push(null);
 
-      let filter = Filter.fromText(text);
-      let result = [];
-      for each (let shortcut in expected)
+      for each (let filter in [Filter.fromText(text), Filter.fromText("@@" + text)])
       {
-        result.push(matcher.findShortcut(filter.text));
-        if (shortcut)
-          matcher.add(Filter.fromText(shortcut));
+        let result = [];
+        for each (let shortcut in expected)
+        {
+          result.push(matcher.findShortcut(filter.text));
+          if (shortcut)
+            matcher.add(Filter.fromText(shortcut));
+        }
+  
+        is(result.join("\n"), expected.join("\n"), "Shortcut candidates for " + filter.text);
+        matcher.clear();
       }
-
-      is(result.join("\n"), expected.join("\n"), "Shortcut candidates for " + text);
-      matcher.clear();
     }
     function checkMatch(filters, location, contentType, docDomain, thirdParty, expected)
     {
@@ -175,4 +177,4 @@
   </script>
   </pre>
 </body>
-</html>
\ No newline at end of file
+</html>

=== modified file 'chrome/content/mochitest/tests/test_policy.html'
--- chrome/content/mochitest/tests/test_policy.html	2010-01-07 17:25:17 +0000
+++ chrome/content/mochitest/tests/test_policy.html	2010-05-04 14:45:07 +0000
@@ -158,6 +158,14 @@
       ]);
     }
 
+    if (compareGeckoVersion("1.9.1") >= 0)
+    {
+      tests.push([
+        '<script>var xmlDoc = document.implementation.createDocument(null, "root", null);xmlDoc.async = false;xmlDoc.load("test.xml")</' + 'script>',
+        "http://127.0.0.1:1234/test.xml", "xmlhttprequest", "127.0.0.1", false
+      ]);
+    }
+
     // TODO: '<' + 'script>new Worker("test.js");<' + '/script>'
     // Web workers need special treatment, no way to ensure that web worker loads before the page is loaded.
 
@@ -178,6 +186,15 @@
     {
       if (wnd != top || type != "add" || location.location == "http://127.0.0.1:1234/test")
         return;
+      if (policyHits.length > 0)
+      {
+        // Ignore duplicate policy calls (possible due to prefetching)
+        let [prevWnd, prevType, prevData, prevLocation] = policyHits[policyHits.length - 1];
+        if (prevType == "background") // Prefetched images are misinterpreted as background images
+          prevType = "image";
+        if (prevWnd == wnd && prevType == type && prevData == data && prevLocation == location)
+          policyHits.pop();
+      }
       policyHits.push([wnd, type, data, location]);
     }
 

=== modified file 'chrome/content/mochitest/tests/test_synchronizer.html'
--- chrome/content/mochitest/tests/test_synchronizer.html	2010-01-07 17:25:17 +0000
+++ chrome/content/mochitest/tests/test_synchronizer.html	2010-05-04 14:45:07 +0000
@@ -35,12 +35,7 @@
       return currentTime;
     }
 
-    let ourLoadGroup;
-    with (new XMLHttpRequest())
-    {
-        open("GET", "http://foo/bar");
-        ourLoadGroup = channel.loadGroup;
-    }
+    let outstandingRequests = 0;
 
     function runScheduledTasks(maxHours)
     {
@@ -67,7 +62,7 @@
                                .currentThread;
         let loopStartTime = oldNow();
 
-        while (ourLoadGroup.requests.hasMoreElements() || thread.hasPendingEvents())
+        while (outstandingRequests > 0 || thread.hasPendingEvents())
         {
           thread.processNextEvent(true);
 
@@ -112,21 +107,21 @@
     var oldXMLHttp = XMLHttpRequest;
     XMLHttpRequest = function()
     {
+      let inner = new oldXMLHttp();
+
       return {
-        __proto__: new oldXMLHttp(),
-        get channel()
+        __proto__: inner,
+        send: function()
         {
-          var result = {
-            get loadGroup()
-            {
-              return this.__proto__.loadGroup;
-            },
-            set loadGroup(val)
-            {
-            }
-          };
-          result.__proto__ = this.__proto__.channel;
-          return result;
+          outstandingRequests++;
+          function finished()
+          {
+            outstandingRequests--;
+          }
+          inner.addEventListener("load", finished, false);
+          inner.addEventListener("error", finished, false);
+
+          inner.send.apply(inner, arguments);
         }
       }
     }

=== removed file 'chrome/content/objecttab.xml'
--- chrome/content/objecttab.xml	2010-01-07 17:25:17 +0000
+++ chrome/content/objecttab.xml	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-<!DOCTYPE bindings SYSTEM "chrome://adblockplus/locale/overlay.dtd">
-
-<bindings id="objectTabBindings"
-    xmlns="http://www.mozilla.org/xbl"
-    xmlns:html="http://www.w3.org/1999/xhtml"
-    xmlns:xbl="http://www.mozilla.org/xbl">
-
-  <binding id="objectTab">
-    <content title="&objecttab.tooltip;">
-      &objecttab.title;
-      <html:img src="chrome://global/content/abp-dummy-image-request.png"/>
-    </content>
-  </binding>
-
-  <!-- Dummy binding to apply to invisible object tabs, without this the previous binding won't be unapplied -->
-  <binding id="dummy"/>
-</bindings>

=== modified file 'chrome/content/objtabs.css'
--- chrome/content/objtabs.css	2010-01-07 17:25:17 +0000
+++ chrome/content/objtabs.css	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -24,29 +24,17 @@
 
 @namespace url("http://www.w3.org/1999/xhtml");
 
-a.%%CLASSNAME%%
-{
-  display: none !important;
-  -moz-binding: url(chrome://adblockplus/content/objecttab.xml#dummy) !important;
-}
-
-object:hover + a.%%CLASSNAME%%,
-embed:hover + a.%%CLASSNAME%%,
-applet:hover + a.%%CLASSNAME%%,
-a.%%CLASSNAME%%:hover
-{
+.%%CLASSVISIBLETOP%%, .%%CLASSVISIBLEBOTTOM%%, .%%CLASSHIDDEN%%
+{
+  position: fixed !important;
   display: block !important;
-  -moz-binding: url(chrome://adblockplus/content/objecttab.xml#objectTab) !important;
 
-  position: absolute !important;
-  visibility: visible !important;
   width: auto !important;
   height: auto !important;
   z-index: 65535 !important;
-  opacity: 0.8 !important;
   float: left !important;
   border-color: black !important;
-  border-style: ridge !important;
+  border-style: solid !important;
   background: white !important;
   color: black !important;
   cursor: pointer !important;
@@ -64,33 +52,36 @@
   text-transform: none !important;
   direction: ltr !important;
   padding: 0px 5px !important;
-
-  border-width: 0px 2px 2px 2px !important;
+  -moz-binding: none !important;
+  -moz-user-focus: none !important;
+  -moz-user-input: none !important;
+  -moz-user-select: none !important;
+}
+
+.%%CLASSVISIBLETOP%%, .%%CLASSHIDDEN%%
+{
+  border-width: 1px 1px 0px 1px !important;
+  -moz-border-radius-topleft: 10px !important;
+  -moz-border-radius-topright: 10px !important;
+  -moz-border-radius-bottomleft: 0px !important;
+  -moz-border-radius-bottomright: 0px !important;
+}
+
+.%%CLASSVISIBLEBOTTOM%%
+{
+  border-width: 0px 1px 1px 1px !important;
   -moz-border-radius-topleft: 0px !important;
   -moz-border-radius-topright: 0px !important;
   -moz-border-radius-bottomleft: 10px !important;
   -moz-border-radius-bottomright: 10px !important;
 }
 
-object:hover + a.%%CLASSNAME%%.%%ONTOP%%,
-embed:hover + a.%%CLASSNAME%%.%%ONTOP%%,
-applet:hover + a.%%CLASSNAME%%.%%ONTOP%%,
-a.%%CLASSNAME%%.%%ONTOP%%:hover
-{
-  border-width: 2px 2px 0px 2px !important;
-  -moz-border-radius-topleft: 10px !important;
-  -moz-border-radius-topright: 10px !important;
-  -moz-border-radius-bottomleft: 0px !important;
-  -moz-border-radius-bottomright: 0px !important;
-}
-
-a.%%CLASSNAME%% > img
-{
-  /* Images still load even if invisible, unlikely to change */
-  display: none !important;
-}
-
-.%%COLLAPSED%%
-{
-  -moz-binding: url(chrome://global/content/bindings/general.xml#asdfzxcv) !important;
+.%%CLASSVISIBLETOP%%, .%%CLASSVISIBLEBOTTOM%%
+{
+  visibility: visible !important;
+}
+
+.%%CLASSHIDDEN%%
+{
+  visibility: hidden !important;
 }

=== added file 'chrome/content/objtabs.js'
--- chrome/content/objtabs.js	1970-01-01 00:00:00 +0000
+++ chrome/content/objtabs.js	2010-05-04 14:45:07 +0000
@@ -0,0 +1,484 @@
+/* ***** BEGIN LICENSE BLOCK *****
+ * Version: MPL 1.1
+ *
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
+ *
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ *
+ * The Original Code is Adblock Plus.
+ *
+ * The Initial Developer of the Original Code is
+ * Wladimir Palant.
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
+ * the Initial Developer. All Rights Reserved.
+ *
+ * Contributor(s):
+ *
+ * ***** END LICENSE BLOCK ***** */
+
+/**
+ * @fileOverview Code responsible for showing and hiding object tabs.
+ * This file is included from AdblockPlus.js.
+ */
+
+XPCOMUtils.defineLazyServiceGetter(this, "accessibleRetrieval", "@mozilla.org/accessibleRetrieval;1", "nsIAccessibleRetrieval");
+
+/**
+ * Class responsible for showing and hiding object tabs.
+ * @class
+ */
+var objTabs =
+{
+  /**
+   * Number of milliseconds to wait until hiding tab after the mouse moves away.
+   * @type Integer
+   */
+  HIDE_DELAY: 1000,
+
+  /**
+   * Flag used to trigger object tabs initialization first time object tabs are
+   * used.
+   * @type Boolean
+   */
+  initialized: false,
+
+  /**
+   * Will be set to true while initialization is in progress.
+   * @type Boolean
+   */
+  initializing: false,
+
+  /**
+   * Parameters for _showTab, to be called once initialization is complete.
+   */
+  delayedShowParams: null,
+
+  /**
+   * Randomly generated class to be used for visible object tabs on top of object.
+   * @type String
+   */
+  objTabClassVisibleTop: null,
+
+  /**
+   * Randomly generated class to be used for visible object tabs at the bottom of the object.
+   * @type String
+   */
+  objTabClassVisibleBottom: null,
+
+  /**
+   * Randomly generated class to be used for invisible object tabs.
+   * @type String
+   */
+  objTabClassHidden: null,
+
+  /**
+   * Document element the object tab is currently being displayed for.
+   * @type Element
+   */
+  currentElement: null,
+
+  /**
+   * Windows that the window event handler is currently registered for.
+   * @type Array of Window
+   */
+  windowListeners: null,
+
+  /**
+   * Panel element currently used as object tab.
+   * @type Element
+   */
+  objtabElement: null,
+
+  /**
+   * Time of previous position update.
+   * @type Integer
+   */
+  prevPositionUpdate: 0,
+
+  /**
+   * Timer used to update position of the object tab.
+   * @type nsITimer
+   */
+  positionTimer: null,
+
+  /**
+   * Timer used to delay hiding of the object tab.
+   * @type nsITimer
+   */
+  hideTimer: null,
+
+  /**
+   * Used when hideTimer is running, time when the tab should be hidden.
+   * @type Integer
+   */
+  hideTargetTime: 0,
+
+  /**
+   * Will be true for Gecko 1.9/1.9.1, objects occupy the entire element
+   * space there including border and padding.
+   * @type Boolean
+   */
+  get _objectOverlapsBorder()
+  {
+    let result = (abp.versionComparator.compare(
+                        Cc["@mozilla.org/xre/app-info;1"].getService(Ci.nsIXULAppInfo).platformVersion,
+                        "1.9.2") < 0);
+    this.__defineGetter__("_objectOverlapsBorder", function() result);
+    return result;
+  },
+
+  /**
+   * Initializes object tabs (generates random classes and registers stylesheet).
+   */
+  _initCSS: function()
+  {
+    this.delayedShowParams = arguments;
+
+    if (!this.initializing)
+    {
+      this.initializing = true;
+
+      function processCSSData(data)
+      {
+        let rnd = [];
+        let offset = "a".charCodeAt(0);
+        for (let i = 0; i < 60; i++)
+          rnd.push(offset + Math.random() * 26);
+
+        this.objTabClassVisibleTop = String.fromCharCode.apply(String, rnd.slice(0, 20));
+        this.objTabClassVisibleBottom = String.fromCharCode.apply(String, rnd.slice(20, 40));
+        this.objTabClassHidden = String.fromCharCode.apply(String, rnd.slice(40, 60));
+
+        let url = makeURL("data:text/css," + encodeURIComponent(data.replace(/%%CLASSVISIBLETOP%%/g, this.objTabClassVisibleTop)
+                                                                    .replace(/%%CLASSVISIBLEBOTTOM%%/g, this.objTabClassVisibleBottom)
+                                                                    .replace(/%%CLASSHIDDEN%%/g, this.objTabClassHidden)));
+        styleService.loadAndRegisterSheet(url, Ci.nsIStyleSheetService.USER_SHEET);
+
+        this.initializing = false;
+        this.initialized = true;
+
+        if (this.delayedShowParams)
+          this._showTab.apply(this, this.delayedShowParams);
+      }
+
+      // Load CSS asynchronously
+      try {
+        let request = new XMLHttpRequest();
+        request.open("GET", "chrome://adblockplus/content/objtabs.css");
+        request.overrideMimeType("text/plain");
+
+        let me = this;
+        request.onload = function()
+        {
+          processCSSData.call(me, request.responseText);
+        }
+        request.send(null);
+      }
+      catch (e)
+      {
+        Cu.reportError(e);
+        this.initializing = false;
+      }
+    }
+  },
+
+  /**
+   * Called to show object tab for an element.
+   */
+  showTabFor: function(/**Element*/ element)
+  {
+    if (!prefs.frameobjects)
+      return;
+
+    if (this.hideTimer)
+    {
+      this.hideTimer.cancel();
+      this.hideTimer = null;
+    }
+
+    if (this.objtabElement)
+      this.objtabElement.style.setProperty("opacity", "1", "important");
+
+    if (this.currentElement != element)
+    {
+      this._hideTab();
+
+      let data = RequestList.getDataForNode(element, true);
+      if (data)
+      {
+        let doc = element.ownerDocument.defaultView
+                         .QueryInterface(Ci.nsIInterfaceRequestor)
+                         .getInterface(Ci.nsIWebNavigation)
+                         .QueryInterface(Ci.nsIDocShellTreeItem)
+                         .rootTreeItem
+                         .QueryInterface(Ci.nsIInterfaceRequestor)
+                         .getInterface(Ci.nsIDOMWindow)
+                         .document;
+        let hooks = doc.getElementById("abp-hooks");
+        if (hooks && hooks.wrappedJSObject)
+          hooks = hooks.wrappedJSObject;
+
+        // Only open popup in focused window, will steal focus otherwise
+        if (hooks)
+        {
+          if (this.initialized)
+            this._showTab(hooks, element, data[1]);
+          else
+            this._initCSS(hooks, element, data[1]);
+        }
+      }
+    }
+  },
+
+  /**
+   * Called to hide object tab for an element (actual hiding happens delayed).
+   */
+  hideTabFor: function(/**Element*/ element)
+  {
+    if (element != this.currentElement)
+      return;
+
+    this.hideTargetTime = Date.now() + this.HIDE_DELAY;
+    this.hideTimer = Cc["@mozilla.org/timer;1"].createInstance(Ci.nsITimer);
+    this.hideTimer.init(this, 40, Ci.nsITimer.TYPE_REPEATING_SLACK);
+  },
+
+  /**
+   * Makes the tab element visible.
+   */
+  _showTab: function(/**Element*/ hooks, /**Element*/ element, /**RequestEntry*/ data)
+  {
+    let doc = element.ownerDocument.defaultView.top.document;
+
+    this.objtabElement = doc.createElementNS("http://www.w3.org/1999/xhtml", "a");
+    this.objtabElement.textContent = hooks.getAttribute("objtabtext");
+    this.objtabElement.setAttribute("title", hooks.getAttribute("objtabtooltip"));
+    this.objtabElement.setAttribute("href", data.location);
+    this.objtabElement.setAttribute("class", this.objTabClassHidden);
+    this.objtabElement.style.setProperty("opacity", "1", "important");
+    this.objtabElement.nodeData = data;
+    hooks.initObjTab(this.objtabElement);
+
+    this.currentElement = element;
+
+    // Register paint listeners for the relevant windows
+    this.windowListeners = [];
+    let wnd = element.ownerDocument.defaultView;
+    while (wnd)
+    {
+      wnd.addEventListener("MozAfterPaint", objectWindowEventHandler, false);
+      this.windowListeners.push(wnd);
+      wnd = (wnd.parent != wnd ? wnd.parent : null);
+    }
+
+    // Register mouse listeners on the object tab
+    this.objtabElement.addEventListener("mouseover", objectTabEventHander, false);
+    this.objtabElement.addEventListener("mouseout", objectTabEventHander, false);
+
+    // Insert the tab into the document and adjust its position
+    doc.documentElement.appendChild(this.objtabElement);
+    this._positionTab();
+
+    if (!this.positionTimer)
+    {
+      this.positionTimer = Cc["@mozilla.org/timer;1"].createInstance(Ci.nsITimer);
+      this.positionTimer.init(this, 200, Ci.nsITimer.TYPE_REPEATING_SLACK);
+    }
+  },
+
+  /**
+   * Hides the tab element.
+   */
+  _hideTab: function()
+  {
+    this.delayedShowParams = null;
+
+    if (this.objtabElement)
+    {
+      // Prevent recursive calls via popuphidden handler
+      let objtab = this.objtabElement;
+      this.objtabElement = null;
+      this.currentElement = null;
+
+      if (this.hideTimer)
+      {
+        this.hideTimer.cancel();
+        this.hideTimer = null;
+      }
+
+      if (this.positionTimer)
+      {
+        this.positionTimer.cancel();
+        this.positionTimer = null;
+      }
+
+      try {
+        objtab.parentNode.removeChild(objtab);
+      } catch (e) {}
+      objtab.removeEventListener("mouseover", objectTabEventHander, false);
+      objtab.removeEventListener("mouseout", objectTabEventHander, false);
+      objtab.nodeData = null;
+
+      for each (let wnd in this.windowListeners)
+        wnd.removeEventListener("MozAfterPaint", objectWindowEventHandler, false);
+      this.windowListeners = null;
+    }
+  },
+
+  /**
+   * Updates position of the tab element.
+   */
+  _positionTab: function()
+  {
+    // Test whether element is still in document
+    if (!this.currentElement.offsetWidth || !this.currentElement.offsetHeight)
+    {
+      this._hideTab();
+      return;
+    }
+
+    let objRect = this._getElementPosition(this.currentElement);
+
+    let className = this.objTabClassVisibleTop;
+    let left = objRect.right - this.objtabElement.offsetWidth;
+    let top = objRect.top - this.objtabElement.offsetHeight;
+    if (top < 0)
+    {
+      top = objRect.bottom;
+      className = this.objTabClassVisibleBottom;
+    }
+
+    if (this.objtabElement.style.left != left + "px")
+      this.objtabElement.style.setProperty("left", left + "px", "important");
+    if (this.objtabElement.style.top != top + "px")
+      this.objtabElement.style.setProperty("top", top + "px", "important");
+
+    if (this.objtabElement.getAttribute("class") != className)
+      this.objtabElement.setAttribute("class", className);
+
+    this.prevPositionUpdate = Date.now();
+  },
+
+  /**
+   * Calculates element's position relative to the top frame and considering
+   * clipping due to scrolling.
+   * @return {left: Number, top: Number, right: Number, bottom: Number}
+   */
+  _getElementPosition: function(/**Element*/ element)
+  {
+    // Restrict rectangle coordinates by the boundaries of a window's client area
+    function intersectRect(rect, wnd)
+    {
+      let doc = wnd.document;
+      let wndWidth = doc.documentElement.clientWidth;
+      let wndHeight = doc.documentElement.clientHeight;
+      if (doc.compatMode == "BackCompat") // clientHeight will be bogus in quirks mode
+        wndHeight = doc.documentElement.offsetHeight - wnd.scrollMaxY;
+  
+      rect.left = Math.max(rect.left, 0);
+      rect.top = Math.max(rect.top, 0);
+      rect.right = Math.min(rect.right, wndWidth);
+      rect.bottom = Math.min(rect.bottom, wndHeight);
+    }
+
+    let rect = element.getBoundingClientRect();
+    let wnd = element.ownerDocument.defaultView;
+
+    let offsets = [0, 0, 0, 0];
+    if (!this._objectOverlapsBorder)
+    {
+      let style = wnd.getComputedStyle(element, null);
+      offsets[0] = parseFloat(style.borderLeftWidth) + parseFloat(style.paddingLeft);
+      offsets[1] = parseFloat(style.borderTopWidth) + parseFloat(style.paddingTop);
+      offsets[2] = parseFloat(style.borderRightWidth) + parseFloat(style.paddingRight);
+      offsets[3] = parseFloat(style.borderBottomWidth) + parseFloat(style.paddingBottom);
+    }
+
+    rect = {left: rect.left + offsets[0], top: rect.top + offsets[1],
+            right: rect.right - offsets[2], bottom: rect.bottom - offsets[3]};
+    while (true)
+    {
+      intersectRect(rect, wnd);
+
+      if (!wnd.frameElement)
+        break;
+
+      // Recalculate coordinates to be relative to frame's parent window
+      let frameElement = wnd.frameElement;
+      wnd = frameElement.ownerDocument.defaultView;
+
+      let frameRect = frameElement.getBoundingClientRect();
+      let frameStyle = wnd.getComputedStyle(frameElement, null);
+      let relLeft = frameRect.left + parseFloat(frameStyle.borderLeftWidth) + parseFloat(frameStyle.paddingLeft);
+      let relTop = frameRect.top + parseFloat(frameStyle.borderTopWidth) + parseFloat(frameStyle.paddingTop);
+
+      rect.left += relLeft;
+      rect.right += relLeft;
+      rect.top += relTop;
+      rect.bottom += relTop;
+    }
+
+    return rect;
+  },
+
+  /**
+   * Called whenever a timer fires.
+   */
+  observe: function(/**nsISupport*/ subject, /**String*/ topic, /**String*/ data)
+  {
+    if (subject == this.positionTimer)
+    {
+      // Don't update position if it was already updated recently (via MozAfterPaint)
+      if (Date.now() - this.prevPositionUpdate > 100)
+        this._positionTab();
+    }
+    else if (subject == this.hideTimer)
+    {
+      let now = Date.now();
+      if (now >= this.hideTargetTime)
+        this._hideTab();
+      else if (this.hideTargetTime - now < this.HIDE_DELAY / 2)
+        this.objtabElement.style.setProperty("opacity", (this.hideTargetTime - now) * 2 / this.HIDE_DELAY, "important");
+    }
+  }
+};
+
+/**
+ * Function called whenever the mouse enters or leaves an object.
+ */
+function objectMouseEventHander(/**Event*/ event)
+{
+  if (event.type == "mouseover")
+    objTabs.showTabFor(event.target);
+  else if (event.type == "mouseout")
+    objTabs.hideTabFor(event.target);
+}
+
+/**
+ * Function called for paint events of the object tab window.
+ */
+function objectWindowEventHandler(/**Event*/ event)
+{
+  // Don't trigger update too often, avoid overusing CPU on frequent page updates
+  if (event.type == "MozAfterPaint" && Date.now() - objTabs.prevPositionUpdate > 20)
+    objTabs._positionTab();
+}
+
+/**
+ * Function called whenever the mouse enters or leaves an object tab.
+ */
+function objectTabEventHander(/**Event*/ event)
+{
+  if (event.type == "mouseover")
+    objTabs.showTabFor(objTabs.currentElement);
+  else if (event.type == "mouseout")
+    objTabs.hideTabFor(objTabs.currentElement);
+}
+
+abp.objTabs = objTabs;

=== modified file 'chrome/content/policy.js'
--- chrome/content/policy.js	2010-01-07 17:25:17 +0000
+++ chrome/content/policy.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -27,8 +27,8 @@
  * This file is included from AdblockPlus.js.
  */
 
-var effectiveTLD = Cc["@mozilla.org/network/effective-tld-service;1"].getService(Ci.nsIEffectiveTLDService);
-var netUtils = Cc["@mozilla.org/network/util;1"].getService(Ci.nsINetUtil);
+XPCOMUtils.defineLazyServiceGetter(this, "effectiveTLD", "@mozilla.org/network/effective-tld-service;1", "nsIEffectiveTLDService");
+XPCOMUtils.defineLazyServiceGetter(this, "netUtils", "@mozilla.org/network/util;1", "nsINetUtil");
 
 const ok = Ci.nsIContentPolicy.ACCEPT;
 const block = Ci.nsIContentPolicy.REJECT_REQUEST;
@@ -68,21 +68,6 @@
   whitelistSchemes: null,
 
   /**
-   * Randomly generated class for object tab nodes.
-   * @type String
-   */
-  objtabClass: null,
-  /**
-   * Randomly generated class for object tab nodes displayed on top of the object.
-   * @type String
-   */
-  objtabOnTopClass: null,
-  /**
-   * Randomly generated property name to be set for object tab nodes.
-   * @type String
-   */
-  objtabMarker: null,
-  /**
    * Randomly generated class for collapsed nodes.
    * @type String
    */
@@ -123,20 +108,16 @@
     for each (var scheme in prefs.whitelistschemes.toLowerCase().split(" "))
       this.whitelistSchemes[scheme] = true;
 
-    // Generate identifiers for object tabs
-    this.objtabClass = "";
-    this.objtabOnTopClass = "";
+    // Generate class identifier used to collapse node and register corresponding
+    // stylesheet.
     this.collapsedClass = "";
-    this.objtabMarker = "abpObjTab"
     for (let i = 0; i < 20; i++)
-    {
-      this.objtabClass += String.fromCharCode("a".charCodeAt(0) + Math.random() * 26);
-      this.objtabOnTopClass += String.fromCharCode("a".charCodeAt(0) + Math.random() * 26);
       this.collapsedClass +=  String.fromCharCode("a".charCodeAt(0) + Math.random() * 26);
-      this.objtabMarker += String.fromCharCode("a".charCodeAt(0) + Math.random() * 26);
-    }
 
-    this.initObjectTabCSS();
+    let collapseStyle = makeURL("data:text/css," +
+                                 encodeURIComponent("." + this.collapsedClass +
+                                 "{-moz-binding: url(chrome://global/content/bindings/general.xml#foobarbazdummy) !important;}"));
+    styleService.loadAndRegisterSheet(collapseStyle, Ci.nsIStyleSheetService.USER_SHEET);
   },
 
   /**
@@ -177,9 +158,21 @@
     if (contentType != this.type.OBJECT && (node instanceof Ci.nsIDOMHTMLObjectElement || node instanceof Ci.nsIDOMHTMLEmbedElement))
       contentType = this.type.OBJECT;
 
-    let docDomain = this.getHostname(this.getOriginWindow(wnd).location.href);
+    let originWindow = this.getOriginWindow(wnd);
+    let wndLocation = originWindow.location.href;
+    let docDomain = this.getHostname(wndLocation);
     if (!match && contentType == this.type.ELEMHIDE)
     {
+      match = whitelistMatcher.matchesAny(wndLocation, "ELEMHIDE", docDomain, false);
+      if (match)
+      {
+        filterStorage.increaseHitCount(match);
+
+        let data = RequestList.getDataForWindow(wnd);
+        data.addNode(wnd.document, contentType, docDomain, false, wndLocation, match);
+        return true;
+      }
+
       match = location;
       locationText = match.text.replace(/^.*?#/, '#');
       location = locationText;
@@ -190,7 +183,6 @@
 
     var data = RequestList.getDataForWindow(wnd);
 
-    var objTab = null;
     let thirdParty = (contentType == this.type.ELEMHIDE ? false : this.isThirdParty(location, docDomain));
 
     if (!match && prefs.enabled) {
@@ -205,25 +197,18 @@
           this.schedulePostProcess(node);
       }
 
-      // Add object tab
-      if (!match && prefs.frameobjects && contentType == this.type.OBJECT)
+      // Track mouse events for objects
+      if (!match && contentType == this.type.OBJECT)
       {
-        // Before adding object tabs always check whether one exist already
-        let hasObjectTab = (node.nextSibling && node.nextSibling.getUserData(this.objtabMarker));
-        if (!hasObjectTab)
-        {
-          objTab = node.ownerDocument.createElementNS("http://www.w3.org/1999/xhtml", "a");
-          objTab.setUserData(this.objtabMarker, true, null);
-        }
+        node.addEventListener("mouseover", objectMouseEventHander, true);
+        node.addEventListener("mouseout", objectMouseEventHander, true);
       }
     }
 
     // Store node data
-    var nodeData = data.addNode(node, contentType, docDomain, thirdParty, locationText, match, objTab);
+    var nodeData = data.addNode(node, contentType, docDomain, thirdParty, locationText, match);
     if (match)
       filterStorage.increaseHitCount(match);
-    if (objTab)
-      wnd.setTimeout(addObjectTab, 0, topWnd, node, nodeData, objTab);
 
     return !match || match instanceof WhitelistFilter;
   },
@@ -331,16 +316,17 @@
    * @param url {String}
    * @return {Boolean}
    */
-  isWhitelisted: function(url) {
+  isWhitelisted: function(url)
+  {
     return whitelistMatcher.matchesAny(url, "DOCUMENT", this.getHostname(url), false);
   },
 
   /**
-   * Checks whether the page loaded in a window is whitelisted.
+   * Retrieves the location of a window.
    * @param wnd {nsIDOMWindow}
-   * @return {Boolean}
+   * @return {String} window location or null on failure
    */
-  isWindowWhitelisted: function(wnd)
+  getWindowLocation: function(wnd)
   {
     if ("name" in wnd && wnd.name == "messagepane")
     {
@@ -362,25 +348,35 @@
   
         if ("currentHeaderData" in mailWnd && "content-base" in mailWnd.currentHeaderData)
         {
-          return this.isWhitelisted(mailWnd.currentHeaderData["content-base"].headerValue);
+          return mailWnd.currentHeaderData["content-base"].headerValue;
         }
         else if ("currentHeaderData" in mailWnd && "from" in mailWnd.currentHeaderData)
         {
           let emailAddress = headerParser.extractHeaderAddressMailboxes(mailWnd.currentHeaderData.from.headerValue);
           if (emailAddress)
-          {
-            emailAddress = 'mailto:' + emailAddress.replace(/^[\s"]+/, "").replace(/[\s"]+$/, "").replace(/\s/g, '%20');
-            return this.isWhitelisted(emailAddress);
-          }
+            return 'mailto:' + emailAddress.replace(/^[\s"]+/, "").replace(/[\s"]+$/, "").replace(/\s/g, '%20');
         }
       } catch(e) {}
     }
     else
     {
       // Firefox branch
-      return this.isWhitelisted(wnd.location.href);
+      return wnd.location.href;
     }
-    return null;
+  },
+
+  /**
+   * Checks whether the page loaded in a window is whitelisted.
+   * @param wnd {nsIDOMWindow}
+   * @return {Filter} matching exception rule or null if not whitelisted
+   */
+  isWindowWhitelisted: function(wnd)
+  {
+    let location = this.getWindowLocation(wnd);
+    if (!location)
+      return null;
+
+    return this.isWhitelisted(location);
   },
 
   /**
@@ -407,64 +403,6 @@
     }
   },
 
-  /**
-   * Updates position of an object tab to match the object
-   */
-  repositionObjectTab: function(/**Element*/ objTab)
-  {
-    let object = objTab.previousSibling;
-    if (!(object instanceof Ci.nsIDOMHTMLObjectElement || object instanceof Ci.nsIDOMHTMLEmbedElement || object instanceof Ci.nsIDOMHTMLAppletElement))
-    {
-      if (objTab.parentNode)
-        objTab.parentNode.removeChild(objTab);
-      return;
-    }
-
-    let doc = objTab.ownerDocument;
-
-    let objectRect = object.getBoundingClientRect();
-    let tabRect = objTab.getBoundingClientRect();
-
-    let onTop = (objectRect.top > tabRect.bottom - tabRect.top + 5);
-    let leftDiff = objectRect.right - tabRect.right;
-    let topDiff = (onTop ? objectRect.top - tabRect.bottom : objectRect.bottom - tabRect.top);
-
-    objTab.style.setProperty("left", ((parseInt(objTab.style.left) || 0) + leftDiff) + "px", "important");
-    objTab.style.setProperty("top", ((parseInt(objTab.style.top) || 0) + topDiff) + "px", "important");
-    objTab.className = (onTop ? this.objtabClass + " " + this.objtabOnTopClass : this.objtabClass);
-    objTab.style.removeProperty("visibility");
-  },
-
-  /**
-   * Loads objtabs.css on startup and registers it globally.
-   */
-  initObjectTabCSS: function()
-  {
-    // Load CSS asynchronously (synchronous loading at startup causes weird issues)
-    try {
-      let channel = ioService.newChannel("chrome://adblockplus/content/objtabs.css", null, null);
-      channel.asyncOpen({
-        data: "",
-        onDataAvailable: function(request, context, stream, offset, count)
-        {
-          let scriptableStream = Cc["@mozilla.org/scriptableinputstream;1"].createInstance(Ci.nsIScriptableInputStream);
-          scriptableStream.init(stream);
-          this.data += scriptableStream.read(count);
-        },
-        onStartRequest: function() {},
-        onStopRequest: function()
-        {
-          let data = this.data.replace(/%%CLASSNAME%%/g, policy.objtabClass).replace(/%%ONTOP%%/g, policy.objtabOnTopClass).replace(/%%COLLAPSED%%/g, policy.collapsedClass);
-          let objtabsCSS = makeURL("data:text/css," + encodeURIComponent(data));
-          Cc["@mozilla.org/content/style-sheet-service;1"].getService(Ci.nsIStyleSheetService)
-                                                          .loadAndRegisterSheet(objtabsCSS, styleService.USER_SHEET);
-          channel = null;
-        },
-        QueryInterface: XPCOMUtils.generateQI([Ci.nsIRequestObserver, Ci.nsIStreamListener])
-      }, null);
-    } catch (e) {}
-  },
-
   //
   // nsISupports interface implementation
   //
@@ -498,14 +436,6 @@
     if (!(contentType in this.typeDescr))
       contentType = this.type.OTHER;
 
-    if (contentType == this.type.IMAGE && location.spec == "chrome://global/content/abp-dummy-image-request.png")
-    {
-      let objTab = node.parentNode;
-      if (objTab && objTab.getUserData(this.objtabMarker))
-        runAsync(this.repositionObjectTab, this, objTab);
-      return block;
-    }
-
     // if it's not a blockable type or a whitelisted scheme, use the usual policy
     if (contentType == this.type.DOCUMENT || !this.isBlockableScheme(location))
       return ok;
@@ -590,14 +520,12 @@
         let nodes = data[i].clearNodes();
         for each (let node in nodes)
         {
-          if (node.getUserData(this.objtabMarker))
+          if (data[i].type == this.type.OBJECT)
           {
-            // Remove object tabs
-            if (node.parentNode)
-              node.parentNode.removeChild(node);
+            node.removeEventListener("mouseover", objectMouseEventHander, true);
+            node.removeEventListener("mouseout", objectMouseEventHander, true);
           }
-          else
-            this.processNode(wnd, node, data[i].type, makeURL(data[i].location), true);
+          this.processNode(wnd, node, data[i].type, makeURL(data[i].location), true);
         }
       }
     }

=== modified file 'chrome/content/prefs.js'
--- chrome/content/prefs.js	2010-01-07 17:25:17 +0000
+++ chrome/content/prefs.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -29,7 +29,7 @@
 
 const prefRoot = "extensions.adblockplus.";
 
-var prefService = Cc["@mozilla.org/preferences-service;1"].getService(Ci.nsIPrefService);
+XPCOMUtils.defineLazyServiceGetter(this, "prefService", "@mozilla.org/preferences-service;1", "nsIPrefService");
 
 /**
  * This object allows easy access to Adblock Plus preferences, all defined

=== modified file 'chrome/content/requests.js'
--- chrome/content/requests.js	2010-01-07 17:25:17 +0000
+++ chrome/content/requests.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -126,7 +126,7 @@
       listener(wnd, type, this, entry);
   },
 
-  addNode: function(node, contentType, docDomain, thirdParty, location, filter, objTab)
+  addNode: function(node, contentType, docDomain, thirdParty, location, filter)
   {
     // for images repeated on page store node for each repeated image
     let key = " " + contentType + " " + location;
@@ -142,8 +142,6 @@
       entry.filter = filter;
 
     entry.addNode(node);
-    if (objTab)
-      entry.addNode(objTab);
 
     if (isNew)
       this.topList.notifyListeners("add", this.entries[key]);
@@ -445,6 +443,14 @@
   },
 
   /**
+   * Associates a document element with a request without adding it to the list.
+   */
+  attachTo: function(/**Node*/ node)
+  {
+    node.setUserData(nodeDataProp, this.key, null);
+  },
+
+  /**
    * Resets the list of document elements associated with this entry.
    * @return {Array of Node} old list of elements
    */

=== modified file 'chrome/content/subscriptionClasses.js'
--- chrome/content/subscriptionClasses.js	2010-01-07 17:25:17 +0000
+++ chrome/content/subscriptionClasses.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):

=== modified file 'chrome/content/synchronizer.js'
--- chrome/content/synchronizer.js	2010-01-07 17:25:17 +0000
+++ chrome/content/synchronizer.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -77,7 +77,7 @@
       // Get the number of hours since last download
       let interval = (time - subscription.lastDownload) / 3600;
       if (interval >= prefs.synchronizationinterval)
-        synchronizer.execute(subscription);
+        synchronizer.execute(subscription, false);
     }
   },
 
@@ -155,54 +155,68 @@
    * @param {String} downloadURL the URL used for download
    * @param {String} error error ID in global.properties
    * @param {Boolean} isBaseLocation false if the subscription was downloaded from a location specified in X-Alternative-Locations header
+   * @param {Boolean} manual  true for a manually started download (should not trigger fallback requests)
    */
-  setError: function(subscription, error, channelStatus, responseStatus, downloadURL, isBaseLocation)
+  setError: function(subscription, error, channelStatus, responseStatus, downloadURL, isBaseLocation, manual)
   {
     // If download from an alternative location failed, reset the list of
     // alternative locations - have to get an updated list from base location.
     if (!isBaseLocation)
       subscription.alternativeLocations = null;
 
+    try {
+      Cu.reportError("Adblock Plus: Downloading filter subscription " + subscription.title + " failed (" + abp.getString(error) + ")\n" +
+                     "Download address: " + downloadURL + "\n" +
+                     "Channel status: " + channelStatus + "\n" +
+                     "Server response: " + responseStatus);
+    } catch(e) {}
+
     subscription.lastDownload = parseInt(Date.now() / 1000);
     subscription.downloadStatus = error;
-    if (error == "synchronize_checksum_mismatch")
-    {
-      // No fallback for successful download with checksum mismatch, reset error counter
-      subscription.errors = 0;
-    }
-    else
-      subscription.errors++;
-
-    if (subscription.errors >= prefs.subscriptions_fallbackerrors && /^https?:\/\//i.test(subscription.url))
-    {
-      subscription.errors = 0;
-
-      let fallbackURL = prefs.subscriptions_fallbackurl;
-      fallbackURL = fallbackURL.replace(/%SUBSCRIPTION%/g, encodeURIComponent(subscription.url));
-      fallbackURL = fallbackURL.replace(/%URL%/g, encodeURIComponent(downloadURL));
-      fallbackURL = fallbackURL.replace(/%ERROR%/g, encodeURIComponent(error));
-      fallbackURL = fallbackURL.replace(/%CHANNELSTATUS%/g, encodeURIComponent(channelStatus));
-      fallbackURL = fallbackURL.replace(/%RESPONSESTATUS%/g, encodeURIComponent(responseStatus));
-
-      let request = new XMLHttpRequest();
-      request.open("GET", fallbackURL);
-      request.overrideMimeType("text/plain");
-      request.channel.loadGroup = null;
-      request.channel.loadFlags = request.channel.loadFlags |
-                                  request.channel.INHIBIT_CACHING |
-                                  request.channel.VALIDATE_ALWAYS;
-      request.onload = function(ev)
-      {
-        if (/^301\s+(\S+)/.test(request.responseText))  // Moved permanently    
-          subscription.nextURL = RegExp.$1;
-        else if (/^410\b/.test(request.responseText))   // Gone
+
+    // Request fallback URL if necessary - for automatic updates only
+    if (!manual)
+    {
+      if (error == "synchronize_checksum_mismatch")
+      {
+        // No fallback for successful download with checksum mismatch, reset error counter
+        subscription.errors = 0;
+      }
+      else
+        subscription.errors++;
+  
+      if (subscription.errors >= prefs.subscriptions_fallbackerrors && /^https?:\/\//i.test(subscription.url))
+      {
+        subscription.errors = 0;
+  
+        let fallbackURL = prefs.subscriptions_fallbackurl;
+        fallbackURL = fallbackURL.replace(/%VERSION%/g, encodeURIComponent(abp.getInstalledVersion()));
+        fallbackURL = fallbackURL.replace(/%SUBSCRIPTION%/g, encodeURIComponent(subscription.url));
+        fallbackURL = fallbackURL.replace(/%URL%/g, encodeURIComponent(downloadURL));
+        fallbackURL = fallbackURL.replace(/%ERROR%/g, encodeURIComponent(error));
+        fallbackURL = fallbackURL.replace(/%CHANNELSTATUS%/g, encodeURIComponent(channelStatus));
+        fallbackURL = fallbackURL.replace(/%RESPONSESTATUS%/g, encodeURIComponent(responseStatus));
+  
+        let request = new XMLHttpRequest();
+        request.mozBackgroundRequest = true;
+        request.open("GET", fallbackURL);
+        request.overrideMimeType("text/plain");
+        request.channel.loadFlags = request.channel.loadFlags |
+                                    request.channel.INHIBIT_CACHING |
+                                    request.channel.VALIDATE_ALWAYS;
+        request.onload = function(ev)
         {
-          subscription.autoDownload = false;
-          filterStorage.triggerSubscriptionObservers("updateinfo", [subscription]);
+          if (/^301\s+(\S+)/.test(request.responseText))  // Moved permanently    
+            subscription.nextURL = RegExp.$1;
+          else if (/^410\b/.test(request.responseText))   // Gone
+          {
+            subscription.autoDownload = false;
+            filterStorage.triggerSubscriptionObservers("updateinfo", [subscription]);
+          }
+          filterStorage.saveToDisk();
         }
-        filterStorage.saveToDisk();
+        request.send(null);
       }
-      request.send(null);
     }
 
     filterStorage.triggerSubscriptionObservers("updateinfo", [subscription]);
@@ -212,9 +226,10 @@
   /**
    * Starts the download of a subscription.
    * @param {DownloadableSubscription} subscription  Subscription to be downloaded
+   * @param {Boolean} manual  true for a manually started download (should not trigger fallback requests)
    * @param {Boolean}  forceDownload  if true, the subscription will even be redownloaded if it didn't change on the server
    */
-  execute: function(subscription, forceDownload)
+  execute: function(subscription, manual, forceDownload)
   {
     let url = subscription.url;
     if (url in this.executing)
@@ -285,11 +300,12 @@
       try {
         responseStatus = request.channel.QueryInterface(Ci.nsIHttpChannel).responseStatus;
       } catch (e) {}
-      me.setError(subscription, error, channelStatus, responseStatus, loadFrom, isBaseLocation);
+      me.setError(subscription, error, channelStatus, responseStatus, loadFrom, isBaseLocation, manual);
     }
 
     try {
       request = new XMLHttpRequest();
+      request.mozBackgroundRequest = true;
       request.open("GET", loadFrom);
     }
     catch (e) {
@@ -299,7 +315,6 @@
 
     try {
       request.overrideMimeType("text/plain");
-      request.channel.loadGroup = null;
       request.channel.loadFlags = request.channel.loadFlags |
                                   request.channel.INHIBIT_CACHING |
                                   request.channel.VALIDATE_ALWAYS;
@@ -457,6 +472,7 @@
       request.send(null);
     }
     catch (e) {
+      delete me.executing[url];
       errorCallback("synchronize_connection_error");
       return;
     }

=== modified file 'chrome/content/ui/about.js'
--- chrome/content/ui/about.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/about.js	2010-05-04 14:45:07 +0000
@@ -15,17 +15,137 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
  *
  * ***** END LICENSE BLOCK ***** */
 
-function fillInVersion() {
-  var versionField = document.getElementById("version");
-  versionField.value = abp.getInstalledVersion();
-
-  // Work-around for bug 494901, change align attribute to ensure correct positioning
-  versionField.parentNode.setAttribute("align", "baseline");
+try
+{
+  Cu.import("resource://gre/modules/AddonManager.jsm");
+}
+catch (e) {}
+
+const addonID = "{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}";
+
+function init()
+{
+  E("version").value = abp.getInstalledVersion();
+
+  let ioService = Cc["@mozilla.org/network/io-service;1"].getService(Ci.nsIIOService);
+  if (typeof AddonManager != "undefined")
+  {
+    let addon = AddonManager.getAddonByID(addonID, function(addon)
+    {
+      loadInstallManifest(ioService.newURI(addon.getResourceURL("install.rdf"), null, null));
+    });
+  }
+  else
+  {
+    let extensionManager = Cc["@mozilla.org/extensions/manager;1"].getService(Ci.nsIExtensionManager);
+    let installLocation = extensionManager.getInstallLocation(addonID);
+    let installManifestFile = installLocation.getItemFile(addonID, "install.rdf");
+    loadInstallManifest(ioService.newFileURI(installManifestFile));
+  }
+}
+
+function loadInstallManifest(installManifestURI)
+{
+  let rdf = Cc["@mozilla.org/rdf/rdf-service;1"].getService(Ci.nsIRDFService);
+  let ds = rdf.GetDataSource(installManifestURI.spec);
+  let root = rdf.GetResource("urn:mozilla:install-manifest");
+
+  function emResource(prop)
+  {
+    return rdf.GetResource("http://www.mozilla.org/2004/em-rdf#" + prop);
+  }
+
+  function getTargets(prop)
+  {
+    let targets = ds.GetTargets(root, emResource(prop), true);
+    let result = [];
+    while (targets.hasMoreElements())
+      result.push(targets.getNext().QueryInterface(Ci.nsIRDFLiteral).Value);
+    return result;
+  }
+
+  function dataSourceLoaded()
+  {
+    setContributors(getTargets("contributor"), getTargets("translator"));
+  }
+
+  if (ds instanceof Ci.nsIRDFRemoteDataSource && ds.loaded)
+    dataSourceLoaded();
+  else
+  {
+    let sink = ds.QueryInterface(Ci.nsIRDFXMLSink);
+    sink.addXMLSinkObserver({
+      onBeginLoad: function() {},
+      onInterrupt: function() {},
+      onResume: function() {},
+      onEndLoad: function() {
+        sink.removeXMLSinkObserver(this);
+        dataSourceLoaded();
+      },
+      onError: function() {},
+    });
+  }
+}
+
+function cmpNoCase(a, b)
+{
+  let aLC = a.toLowerCase();
+  let bLC = b.toLowerCase();
+  if (aLC < bLC)
+    return -1;
+  else if (aLC > bLC)
+    return 1;
+  else
+    return 0;
+}
+
+function setContributors(contributors, translators)
+{
+  contributors.sort(cmpNoCase);
+  translators.sort(cmpNoCase);
+
+  E("developers").textContent = contributors.join(", ");
+  E("translators").textContent = translators.join(", ");
+
+  let request = new XMLHttpRequest();
+  request.open("GET", "chrome://adblockplus/content/ui/subscriptions.xml");
+  request.onload = setSubscriptionAuthors;
+  request.send(null);
+}
+
+function setSubscriptionAuthors()
+{
+  let doc = this.responseXML;
+  if (!doc || doc.documentElement.localName != "subscriptions")
+    return;
+
+  let authors = {__proto__: null};
+  for (let node = doc.documentElement.firstChild; node; node = node.nextSibling)
+  {
+    if (node.localName != "subscription" || !node.hasAttribute("author"))
+      continue;
+
+    for each (let author in node.getAttribute("author").split(","))
+    {
+      author = author.replace(/^\s+/, "").replace(/\s+$/, "");
+      if (author == "")
+        continue;
+
+      authors[author] = true;
+    }
+  }
+
+  let list = [];
+  for (let author in authors)
+    list.push(author);
+
+  list.sort(cmpNoCase)
+  E("subscriptionAuthors").textContent = list.join(", ");
 }

=== modified file 'chrome/content/ui/about.xul'
--- chrome/content/ui/about.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/about.xul	2010-05-04 14:45:07 +0000
@@ -17,7 +17,7 @@
    -
    - The Initial Developer of the Original Code is
    - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
@@ -34,113 +34,49 @@
   title="&dialog.title;"
   id="adblockAboutWindow"
   windowtype="abp:about"
-  onload="fillInVersion()"
+  onload="init()"
   buttons="accept">
 
 <script type="application/x-javascript;version=1.7" src="utils.js"/>
 <script type="application/x-javascript;version=1.7" src="about.js"/>
 
 <description id="title" value="&caption.title;"/>
-<hbox align="start">
+<hbox align="baseline">
   <label control="version" value="&version.title;"/>
   <textbox id="version" flex="1" class="plain" readonly="true" tabindex="-1"/>
 </hbox>
 
-<groupbox id="mainGroup">
+<groupbox id="mainGroup" flex="1">
   <description id="description">
     &description;
   </description>
 
   <description id="homepageTitle" value="&homepage.label;"/>
-  <description id="homepage" value="&homepage.url;" onclick="abp.loadInBrowser(this.getAttribute('value'))"/>
+  <description id="homepage" class="text-link" value="&homepage.url;" onclick="abp.loadInBrowser(this.getAttribute('value'))"/>
 
   <description id="authorTitle" value="&author.label;"/>
   <description id="author" value="Wladimir Palant"/>
 
   <description id="contributorsTitle" value="&contributors.label;"/>
-  <vbox id="contributorsBox">
-    <description value="Ahmad Zhafir - Malay translation"/>
-    <description value="Ahmet Serkan Tıratacı - Turkish translation"/>
-    <description value="Aigar Vals - Estonian translation"/>
-    <description value="Alexander Mihalkin - &quot;Morpeh Rus List&quot; filter subscription"/>
-    <description value="Antonio Urquia - Spanish translation of the Element Hiding Helper extension"/>
-    <description value="Ares2 - EasyList and &quot;Ares' ABP Liste&quot; filter subscriptions"/>
-    <description value="Bahram Maravandi - Persian translation"/>
-    <description value="Baurzhan Muftakhidinov - Kazakh translation"/>
-    <description value="Bayarsaikhan Enkhtaivan - Mongolian translation"/>
-    <description value="Besmir Godole - Albanian translation of the Element Hiding Helper extension"/>
-    <description value="Blackdire - Chinese Simplified translation"/>
-    <description value="Brian Yi - &quot;Corset&quot; filter subscription"/>
-    <description value="Cédric Menge - &quot;Cédrics Liste&quot; filter subscription and many suggestions"/>
-    <description value="Claude Lespagnol aka Efdur - icons"/>
-    <description value="Claudio Périco - Brazilian Portuguese translation"/>
-    <description value="Dagobert_78 - French translation"/>
-    <description value="edo248 - Armenian translation"/>
-    <description value="Fabrice Desré - Fennec support"/>
-    <description value="Finn Sørensen - Danish translation"/>
-    <description value="Gárdonyi László - Hungarian translation"/>
-    <description value="Gythialy - &quot;ChinaList&quot; filter subscription"/>
-    <description value="Hatul - Hebrew translation"/>
-    <description value="Hrvoje Majer - Croatian translation"/>
-    <description value="Humberto Sartini - Brazilian Portuguese translation of the Element Hiding Helper extension"/>
-    <description value="Jacen - Slovak translation"/>
-    <description value="Jakub Tománek - Czech translation"/>
-    <description value="Jari Huttunen - Finnish translation of the Element Hiding Helper extension"/>
-    <description value="Jesús Vidal Panalés - Spanish translation"/>
-    <description value="jojaba - French translation"/>
-    <description value="Jonas Slivka - Lithuanian translation"/>
-    <description value="Joni Heinonen aka Akilles - Finnish translation"/>
-    <description value="Jose Sun - Chinese Traditional translation"/>
-    <description value="kapetance - Serbian translation"/>
-    <description value="Kevin Keller - icons"/>
-    <description value="Kristján Bjarni Guðmundsson - Icelandic translation"/>
-    <description value="Leszek (teo) Życzkowski - Polish translation"/>
-    <description value="Luana Di Muzio - Italian translation"/>
-    <description value="Lukmanul Hakim - Indonesian translation"/>
-    <description value="Malte Kraus - &quot;Filter von Dr.Evil&quot; filter subscription"/>
-    <description value="Manuel Meixide - Galician translation"/>
-    <description value="Mark Heijl - Dutch translation of the Element Hiding Helper extension"/>
-    <description value="Mark Schlögel - German FAQ translation"/>
-    <description value="Mark Tyndall - British English translation"/>
-    <description value="Martin Srebotnjak - Slovenian translation"/>
-    <description value="matsuda1026 - Japanese translation"/>
-    <description value="MenetZ - &quot;ROList&quot; filter subscription"/>
-    <description value="Mikes Kaszmán István - Hungarian translation"/>
-    <description value="Moayad Mardini - Arabic translation"/>
-    <description value="MonztA - &quot;Filter von Dr.Evil&quot; filter subscription"/>
-    <description value="moZes - Frisian translation"/>
-    <description value="Navid Kashani - Persian translation"/>
-    <description value="NGUYỄN Mạnh Hùng - Vietnamese translation and &quot;Việt Nam List&quot; filter subscription"/>
-    <description value="Nickolay Ponomarev - start-up performance improvements"/>
-    <description value="Olexander Kasyanyuk - Ukrainian translation"/>
-    <description value="Paul Dicker - Dutch translation"/>
-    <description value="Piarres Beobide - Basque translation of the Element Hiding Helper extension"/>
-    <description value="pirlouy - French translation and &quot;Liste FR&quot; filter subscription"/>
-    <description value="Premier - Japanese translation"/>
-    <description value="Raryel Costa Souza - Brasilian Portuguese translation"/>
-    <description value="Rick752 - EasyList filter subscription and many suggestions"/>
-    <description value="Rob Brown - Aardvark code reused in the Element Hiding Helper extension"/>
-    <description value="Robbie Groenewoudt - dutchblock filter subscription"/>
-    <description value="SiiiE - Hebrew translation"/>
-    <description value="srxo1978 - Spanish translation"/>
-    <description value="Stefan Lewitas - Swedish translation"/>
-    <description value="Stian Domben Bårdsen - Norwegian translation"/>
-    <description value="Suphanat Thitiphattharakon - Thai translation"/>
-    <description value="sushizang - Korean translation"/>
-    <description value="Thanos - Greek translation"/>
-    <description value="Timothy Babych - Ukrainian translation"/>
-    <description value="Toni Barrera - Catalan translation"/>
-    <description value="Tony Nguyen - Vietnamese translation"/>
-    <description value="ultravioletu - Romanian translation"/>
-    <description value="Wang Congming - &quot;ChinaList&quot; filter subscription"/>
-    <description value="Владо Дакић - Serbian translation of the Element Hiding Helper extension"/>
-    <description value="znaya - Portuguese translation"/>
-    <spacer height="5"/>
-    <description value="Henrik Aasted Sorensen - original Adblock"/>
-    <description value="Michael McDonald - Adblock Plus 0.5"/>
-    <description value="rue - Adblock 0.4/0.5"/>
-    <description value="Ben Karel - Adblock 0.4/0.5"/>
-    <description value="Stefan Kinitz - Adblock 0.4/0.5"/>
+
+  <vbox id="developersBox" align="top">
+    <label control="developers" value="&developers.label;"/>
+    <description id="developers" flex="1"/>
+  </vbox>
+
+  <vbox id="designersBox" align="top">
+    <label control="designers" value="&designers.label;"/>
+    <description id="designers" flex="1">Claude Lespagnol aka Efdur, Kevin Keller</description>
+  </vbox>
+
+  <vbox id="subscriptionAuthorsBox" align="top">
+    <label control="subscriptionAuthors" value="&subscriptionAuthors.label;"/>
+    <description id="subscriptionAuthors" flex="1"/>
+  </vbox>
+
+  <vbox id="translatorsBox">
+    <label control="translators" value="&translators.label;"/>
+    <description id="translators" flex="1"/>
   </vbox>
 </groupbox>
 

=== modified file 'chrome/content/ui/browserWindow.js'
--- chrome/content/ui/browserWindow.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/browserWindow.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -49,6 +49,7 @@
   ["abp-toolbarbutton", "click", function(event) { if (event.eventPhase == event.AT_TARGET && event.button == 1) abpTogglePref("enabled"); }],
   ["abp-image-menuitem", "command", function() { abpNode(backgroundData || nodeData); }],
   ["abp-object-menuitem", "command", function() { abpNode(nodeData); }],
+  ["abp-media-menuitem", "command", function() { abpNode(nodeData); }],
   ["abp-frame-menuitem", "command", function() { abpNode(frameData); }],
   ["abp-removeWhitelist-menuitem", "command", function() { removeWhitelist(); }]
 ];
@@ -103,12 +104,24 @@
 
 function abpInit() {
   // Initialize app hooks
-  for each (let hook in ["init", "getBrowser", "addTab", "getContextMenu", "getToolbox", "getDefaultToolbar", "toolbarInsertBefore"])
+  for each (let hook in ["getBrowser", "addTab", "getContextMenu", "getToolbox", "getDefaultToolbar", "toolbarInsertBefore"])
   {
     let handler = abpHooks.getAttribute(hook);
     if (handler)
       abpHooks[hook] = new Function(handler);
   }
+  abpHooks.initObjTab = function(objTab)
+  {
+    objTab.addEventListener("click", function(event)
+    {
+      if (event.isTrusted && event.button == 0)
+      {
+        event.preventDefault();
+        event.stopPropagation();
+        abpNode(objTab.nodeData);
+      }
+    }, true);
+  };
 
   // Process preferences
   abpReloadPrefs();
@@ -206,6 +219,7 @@
     contextMenu.appendChild(E("abp-removeWhitelist-menuitem"));
     contextMenu.appendChild(E("abp-frame-menuitem"));
     contextMenu.appendChild(E("abp-object-menuitem"));
+    contextMenu.appendChild(E("abp-media-menuitem"));
     contextMenu.appendChild(E("abp-image-menuitem"));
   }
 
@@ -217,7 +231,31 @@
 
     // Show subscriptions dialog if the user doesn't have any subscriptions yet
     if (prefs.lastVersion != prefs.currentVersion)
-      abp.runAsync(showSubscriptions);
+    {
+      if ("nsISessionStore" in Ci)
+      {
+        // Have to wait for session to be restored
+        let observer = {
+          QueryInterface: XPCOMUtils.generateQI([Ci.nsIObserver]),
+          observe: function(subject, topic, data)
+          {
+            observerService.removeObserver(observer, "sessionstore-windows-restored");
+            timer.cancel();
+            timer = null;
+            showSubscriptions();
+          }
+        };
+
+        let observerService = Cc["@mozilla.org/observer-service;1"].getService(Ci.nsIObserverService);
+        observerService.addObserver(observer, "sessionstore-windows-restored", false);
+
+        // Just in case, don't wait more than a second
+        let timer = Cc['@mozilla.org/timer;1'].createInstance(Ci.nsITimer);
+        timer.init(observer, 1000, Ci.nsITimer.TYPE_ONE_SHOT);
+      }
+      else
+        abp.runAsync(showSubscriptions);
+    }
   }
 
   // Window-specific first run actions
@@ -246,8 +284,12 @@
     }
   }
 
-  if ("init" in abpHooks)
-    abpHooks.init();
+  // Some people actually switch off browser.frames.enabled and are surprised
+  // that things stop working...
+  window.QueryInterface(Ci.nsIInterfaceRequestor)
+        .getInterface(Ci.nsIWebNavigation)
+        .QueryInterface(Ci.nsIDocShell)
+        .allowSubframes = true;
 }
 
 function abpUnload()
@@ -260,7 +302,6 @@
 
 function abpReloadPrefs() {
   var state = (prefs.enabled ? "active" : "disabled");
-  var label = abp.getString("status_" + state + "_label");
 
   if (state == "active")
   {
@@ -277,12 +318,8 @@
     if (!element)
       return;
 
-    if (element.tagName == "statusbarpanel" || element.tagName == "vbox") {
+    if (element.tagName == "statusbarpanel")
       element.hidden = !prefs.showinstatusbar;
-
-      var labelElement = element.getElementsByTagName("label")[0];
-      labelElement.setAttribute("value", label);
-    }
     else
       element.hidden = !prefs.showintoolbar;
 
@@ -410,7 +447,7 @@
   while (link && !(link instanceof Ci.nsIDOMNSHTMLAnchorElement))
     link = link.parentNode;
 
-  if (!link || !/^abp:\/*subscribe\/*\?(.*)/i.test(link.href))
+  if (!link || !/^abp:\/*subscribe\/*\?(.*)/i.test(link.href))  /**/
     return;
 
   // This is our link - make sure the browser doesn't handle it
@@ -420,40 +457,73 @@
   // Decode URL parameters
   let title = null;
   let url = null;
+  let mainSubscriptionTitle = null;
+  let mainSubscriptionURL = null;
   for each (let param in RegExp.$1.split('&'))
   {
     let parts = param.split("=", 2);
-    if (parts.length == 2 && parts[0] == 'title')
-      title = decodeURIComponent(parts[1]);
-    if (parts.length == 2 && parts[0] == 'location')
-      url = decodeURIComponent(parts[1]);
+    if (parts.length != 2 || !/\S/.test(parts[1]))
+      continue;
+    switch (parts[0])
+    {
+      case "title":
+        title = decodeURIComponent(parts[1]);
+        break;
+      case "location":
+        url = decodeURIComponent(parts[1]);
+        break;
+      case "requiresTitle":
+        mainSubscriptionTitle = decodeURIComponent(parts[1]);
+        break;
+      case "requiresLocation":
+        mainSubscriptionURL = decodeURIComponent(parts[1]);
+        break;
+    }
   }
-  if (!url || !/\S/.test(url))
+  if (!url)
     return;
 
   // Default title to the URL
-  if (!title || !/\S/.test(title))
+  if (!title)
     title = url;
 
+  // Main subscription needs both title and URL
+  if (mainSubscriptionTitle && !mainSubscriptionURL)
+    mainSubscriptionTitle = null;
+  if (mainSubscriptionURL && !mainSubscriptionTitle)
+    mainSubscriptionURL = null;
+
   // Trim spaces in title and URL
   title = title.replace(/^\s+/, "").replace(/\s+$/, "");
   url = url.replace(/^\s+/, "").replace(/\s+$/, "");
+  if (mainSubscriptionURL)
+  {
+    mainSubscriptionTitle = mainSubscriptionTitle.replace(/^\s+/, "").replace(/\s+$/, "");
+    mainSubscriptionURL = mainSubscriptionURL.replace(/^\s+/, "").replace(/\s+$/, "");
+  }
 
   // Verify that the URL is valid
   url = abp.makeURL(url);
-  if (!url)
-    return;
-  if (url.scheme != "http" && url.scheme != "https" && url.scheme != "ftp")
+  if (!url || (url.scheme != "http" && url.scheme != "https" && url.scheme != "ftp"))
     return;
   url = url.spec;
 
+  if (mainSubscriptionURL)
+  {
+    mainSubscriptionURL = abp.makeURL(mainSubscriptionURL);
+    if (!mainSubscriptionURL || (mainSubscriptionURL.scheme != "http" && mainSubscriptionURL.scheme != "https" && mainSubscriptionURL.scheme != "ftp"))
+      mainSubscriptionURL = mainSubscriptionTitle = null;
+    else
+      mainSubscriptionURL = mainSubscriptionURL.spec;
+  }
+
   // Open dialog
-  let appInfo = Cc["@mozilla.org/xre/app-info;1"].getService(Ci.nsIXULAppInfo);
-  if (appInfo.ID != "{a23983c0-fd0e-11dc-95ff-0800200c9a66}")
+  if (!isFennec)
   {
-    var subscription = {url: url, title: title, disabled: false, external: false, autoDownload: true};
-    window.openDialog("chrome://adblockplus/content/ui/subscription.xul", "_blank",
-                     "chrome,centerscreen,modal", subscription);
+    var subscription = {url: url, title: title, disabled: false, external: false, autoDownload: true,
+                        mainSubscriptionTitle: mainSubscriptionTitle, mainSubscriptionURL: mainSubscriptionURL};
+    window.openDialog("chrome://adblockplus/content/ui/subscriptionSelection.xul", "_blank",
+                     "chrome,centerscreen,resizable,dialog=no", subscription, null);
   }
   else
   {
@@ -517,81 +587,116 @@
   if (hasFilters && abp.versionComparator.compare(prefs.lastVersion, "0.0") > 0)
     return;
 
-  if (!abpHooks.addTab || abpHooks.addTab("chrome://adblockplus/content/ui/tip_subscriptions.xul") === false)
-    window.openDialog("chrome://adblockplus/content/ui/tip_subscriptions.xul", "_blank", "chrome,centerscreen,resizable,dialog=no");
+  if (!abpHooks.addTab || abpHooks.addTab("chrome://adblockplus/content/ui/subscriptionSelection.xul") === false)
+    window.openDialog("chrome://adblockplus/content/ui/subscriptionSelection.xul", "_blank", "chrome,centerscreen,resizable,dialog=no");
 }
 
-function abpFillTooltip(event) {
+function abpFillTooltip(event)
+{
   if (!document.tooltipNode || !document.tooltipNode.hasAttribute("tooltip"))
   {
     event.preventDefault();
     return;
   }
 
-  var type = (document.tooltipNode && document.tooltipNode.id == "abp-toolbarbutton" ? "toolbar" : "statusbar");
-  var action = parseInt(prefs["default" + type + "action"]);
+  let type = (document.tooltipNode && document.tooltipNode.id == "abp-toolbarbutton" ? "toolbar" : "statusbar");
+  let action = parseInt(prefs["default" + type + "action"]);
   if (isNaN(action))
     action = -1;
 
-  var actionDescr = E("abp-tooltip-action");
+  let actionDescr = E("abp-tooltip-action");
   actionDescr.hidden = (action < 0 || action > 3);
   if (!actionDescr.hidden)
     actionDescr.setAttribute("value", abp.getString("action" + action + "_tooltip"));
 
-  var state = event.target.getAttribute("curstate");
-  var statusDescr = E("abp-tooltip-status");
-  statusDescr.setAttribute("value", abp.getString(state + "_tooltip"));
-
-  var activeFilters = [];
+  let state = event.target.getAttribute("curstate");
+  let statusDescr = E("abp-tooltip-status");
+  let statusStr = abp.getString(state + "_tooltip");
+  if (state == "active")
+  {
+    let [activeSubscriptions, activeFilters] = abp.filterStorage.subscriptions.reduce(function([subscriptions, filters], current)
+    {
+      if (current instanceof abp.SpecialSubscription)
+        return [subscriptions, filters + current.filters.length];
+      else
+        return [subscriptions + 1, filters];
+    }, [0, 0]);
+
+    statusStr = statusStr.replace(/\?1\?/, activeSubscriptions).replace(/\?2\?/, activeFilters);
+  }
+  statusDescr.setAttribute("value", statusStr);
+
+  let activeFilters = [];
   E("abp-tooltip-blocked-label").hidden = (state != "active");
   E("abp-tooltip-blocked").hidden = (state != "active");
-  if (state == "active") {
-    var data = RequestList.getDataForWindow(abpHooks.getBrowser().contentWindow);
-    var locations = data.getAllLocations();
-
-    var blocked = 0;
-    var filterCount = {__proto__: null};
-    for (i = 0; i < locations.length; i++) {
-      if (locations[i].filter && !(locations[i].filter instanceof abp.WhitelistFilter))
-        blocked++;
-      if (locations[i].filter) {
-        if (locations[i].filter.text in filterCount)
-          filterCount[locations[i].filter.text]++;
+  if (state == "active")
+  {
+    let data = RequestList.getDataForWindow(abpHooks.getBrowser().contentWindow);
+
+    let itemsCount = 0;
+    let blocked = 0;
+    let hidden = 0;
+    let whitelisted = 0;
+    let filterCount = {__proto__: null};
+    for each (let location in data.getAllLocations())
+    {
+      let filter = location.filter;
+      if (filter && filter instanceof abp.ElemHideFilter)
+        hidden++;
+      else
+        itemsCount++;
+
+      if (filter)
+      {
+        if (filter instanceof abp.BlockingFilter)
+          blocked++;
+        else if (filter instanceof abp.WhitelistFilter)
+          whitelisted++;
+
+        if (filter.text in filterCount)
+          filterCount[filter.text]++;
         else
-          filterCount[locations[i].filter.text] = 1;
+          filterCount[filter.text] = 1;
       }
     }
 
-    var blockedStr = abp.getString("blocked_count_tooltip");
-    blockedStr = blockedStr.replace(/--/, blocked).replace(/--/, locations.length);
+    let blockedStr = abp.getString("blocked_count_tooltip");
+    blockedStr = blockedStr.replace(/\?1\?/, blocked).replace(/\?2\?/, itemsCount);
+
+    if (whitelisted + hidden)
+    {
+      blockedStr += " " + abp.getString("blocked_count_addendum");
+      blockedStr = blockedStr.replace(/\?1\?/, whitelisted).replace(/\?2\?/, hidden);
+    }
+
     E("abp-tooltip-blocked").setAttribute("value", blockedStr);
 
-    var filterSort = function(a, b) {
+    let filterSort = function(a, b)
+    {
       return filterCount[b] - filterCount[a];
     };
-    for (var filter in filterCount)
+    for (let filter in filterCount)
       activeFilters.push(filter);
     activeFilters = activeFilters.sort(filterSort);
+
+    if (activeFilters.length > 0)
+    {
+      let filtersContainer = E("abp-tooltip-filters");
+      while (filtersContainer.firstChild)
+        filtersContainer.removeChild(filtersContainer.firstChild);
+  
+      for (let i = 0; i < activeFilters.length && i < 3; i++)
+      {
+        let descr = document.createElement("description");
+        descr.setAttribute("value", activeFilters[i] + " (" + filterCount[activeFilters[i]] + ")");
+        filtersContainer.appendChild(descr);
+      }
+    }
   }
 
   E("abp-tooltip-filters-label").hidden = (activeFilters.length == 0);
   E("abp-tooltip-filters").hidden = (activeFilters.length == 0);
-  if (activeFilters.length > 0) {
-    var filtersContainer = E("abp-tooltip-filters");
-    while (filtersContainer.firstChild)
-      filtersContainer.removeChild(filtersContainer.firstChild);
-
-    for (var i = 0; i < activeFilters.length && i < 3; i++) {
-      var descr = document.createElement("description");
-      descr.setAttribute("value", activeFilters[i] + " (" + filterCount[activeFilters[i]] + ")");
-      filtersContainer.appendChild(descr);
-    }
-    if (activeFilters.length > 3) {
-      var descr = document.createElement("description");
-      descr.setAttribute("value", "...");
-      filtersContainer.appendChild(descr);
-    }
-  }
+  E("abp-tooltip-more-filters").hidden = (activeFilters.length <= 3);
 }
 
 /**
@@ -674,7 +779,7 @@
 
       siteWhitelist = abp.Filter.fromText("@@||" + host + "^$document");
       whitelistItemSite.setAttribute("checked", siteWhitelist.subscriptions.length && !siteWhitelist.disabled);
-      whitelistItemSite.setAttribute("label", whitelistItemSite.getAttribute("labeltempl").replace(/--/, host));
+      whitelistItemSite.setAttribute("label", whitelistItemSite.getAttribute("labeltempl").replace(/\?1\?/, host));
       whitelistItemSite.hidden = false;
 
       pageWhitelist = abp.Filter.fromText("@@|" + location.spec + ending + "$document");
@@ -685,7 +790,7 @@
     {
       siteWhitelist = abp.Filter.fromText("@@|" + location.spec + "|");
       whitelistItemSite.setAttribute("checked", siteWhitelist.subscriptions.length && !siteWhitelist.disabled);
-      whitelistItemSite.setAttribute("label", whitelistItemSite.getAttribute("labeltempl").replace(/--/, location.spec.replace(/^mailto:/, "")));
+      whitelistItemSite.setAttribute("label", whitelistItemSite.getAttribute("labeltempl").replace(/\?1\?/, location.spec.replace(/^mailto:/, "")));
       whitelistItemSite.hidden = false;
     }
   }
@@ -875,6 +980,7 @@
 
   E("abp-image-menuitem").hidden = (nodeType != "IMAGE" && backgroundData == null);
   E("abp-object-menuitem").hidden = (nodeType != "OBJECT");
+  E("abp-media-menuitem").hidden = (nodeType != "MEDIA");
   E("abp-frame-menuitem").hidden = (frameData == null);
 
   let location = getCurrentLocation();

=== modified file 'chrome/content/ui/composer.js'
--- chrome/content/ui/composer.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/composer.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -87,6 +87,18 @@
       suggestions[4] = suggestions[3];
     }
 
+    try
+    {
+      let effectiveTLD = Cc["@mozilla.org/network/effective-tld-service;1"].getService(Ci.nsIEffectiveTLDService);
+      suggestions[5] = effectiveTLD.getBaseDomainFromHost(url.host) + "^";
+      if (suggestions[5] != suggestions[4])
+        addSuggestion(suggestions[5]);
+    }
+    catch (e)
+    {
+      suggestions[5] = suggestions[5];
+    }
+
     E("patternGroup").value = (prefs.composer_default in suggestions ? suggestions[prefs.composer_default] : suggestions[1]);
   }
   catch (e)
@@ -146,7 +158,10 @@
   E("collapse").value = "";
   E("collapse").setAttribute("label", collapseDefault.label);
 
-  E("disabledWarning").hidden = prefs.enabled;
+  let warning = E("disabledWarning");
+  generateLinkText(warning);
+  warning.hidden = prefs.enabled;
+
   updatePatternSelection();
 }
 
@@ -249,7 +264,7 @@
     if (subscription && subscription.disabled)
     {
       warning.subscription = subscription;
-      warning.firstChild.textContent = warning.getAttribute("textTemplate").replace(/%S/g, subscription.title);
+      generateLinkText(warning, subscription.title);
       warning.hidden = false;
     }
     else
@@ -259,6 +274,30 @@
     E("groupDisabledWarning").hidden = true;
 }
 
+function generateLinkText(element, replacement)
+{
+  let template = element.getAttribute("textTemplate");
+  if (typeof replacement != "undefined")
+    template = template.replace(/\?1\?/g, replacement)
+
+  let beforeLink, linkText, afterLink;
+  if (/(.*)\[link\](.*)\[\/link\](.*)/.test(template))
+    [beforeLink, linkText, afterLink] = [RegExp.$1, RegExp.$2, RegExp.$3];
+  else
+    [beforeLink, linkText, afterLink] = ["", template, ""];
+
+  while (element.firstChild && element.firstChild.nodeType != Node.ELEMENT_NODE)
+    element.removeChild(element.firstChild);
+  while (element.lastChild && element.lastChild.nodeType != Node.ELEMENT_NODE)
+    element.removeChild(element.lastChild);
+  if (!element.firstChild)
+    return;
+
+  element.firstChild.textContent = linkText;
+  element.insertBefore(document.createTextNode(beforeLink), element.firstChild);
+  element.appendChild(document.createTextNode(afterLink));
+}
+
 function updatePatternSelection()
 {
   let pattern = E("patternGroup").value;

=== modified file 'chrome/content/ui/composer.xul'
--- chrome/content/ui/composer.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/composer.xul	2010-05-04 14:45:07 +0000
@@ -17,7 +17,7 @@
    -
    - The Initial Developer of the Original Code is
    - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
@@ -53,12 +53,12 @@
     <tooltip id="domainRestrictionHelp" label="&domainRestriction.help;"/>
   </popupset>
 
-  <description id="disabledWarning" hidden="true">
-    &disabled.warning.beforeLink;<label class="text-link" value="&disabled.warning.link;" onclick="doEnable()"/>&disabled.warning.afterLink;
+  <description id="disabledWarning" hidden="true" textTemplate="&disabled.warning;">
+    <label class="text-link" onclick="doEnable()"/>
   </description>
 
-  <description id="groupDisabledWarning" textTemplate="&groupDisabled.warning.beforeLink;" hidden="true">
-    dummy <label class="text-link" value="&groupDisabled.warning.link;" onclick="enableSubscription(this.parentNode.subscription)"/>&groupDisabled.warning.afterLink;
+  <description id="groupDisabledWarning" textTemplate="&groupDisabled.warning;" hidden="true">
+    <label class="text-link" onclick="enableSubscription(this.parentNode.subscription)"/>
   </description>
 
   <hbox id="filterBox" align="center">
@@ -84,12 +84,14 @@
           <textbox id="customPattern" flex="1" oninput="updateCustomPattern()"/>
         </hbox>
       </radiogroup>
-      <hbox id="anchorGroup" pack="start" align="center">
+      <hbox id="anchorGroup" pack="start" align="baseline">
         <label value="&anchors.label;"/>
-        <checkbox id="anchorStart" labelRegular="&anchor.start.label;" accesskeyRegular="&anchor.start.accesskey;"
-                                   labelFlexible="&anchor.start.flexible.label;" accesskeyFlexible="&anchor.start.flexible.accesskey;"
-                                   oncommand="updateFilter()"/>
-        <checkbox id="anchorEnd" label="&anchor.end.label;" accesskey="&anchor.end.accesskey;" oncommand="updateFilter()"/>
+        <description flex="1" style="margin: 0; padding: 0;">
+          <checkbox id="anchorStart" labelRegular="&anchor.start.label;" accesskeyRegular="&anchor.start.accesskey;"
+                                     labelFlexible="&anchor.start.flexible.label;" accesskeyFlexible="&anchor.start.flexible.accesskey;"
+                                     oncommand="updateFilter()"/>
+          <checkbox id="anchorEnd" label="&anchor.end.label;" accesskey="&anchor.end.accesskey;" oncommand="updateFilter()"/>
+        </description>
       </hbox>
     </groupbox>
     <groupbox id="options">

=== modified file 'chrome/content/ui/fennecOverlay.js'
--- chrome/content/ui/fennecOverlay.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/fennecOverlay.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Fabrice Desré.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -63,8 +63,12 @@
   for (let i = 0; i < subscriptions.length; i++)
   {
     let item = subscriptions[i];
-    menu.appendItem(item.getAttribute("title"), item.getAttribute("url"), null);
-    if (currentSubscription && item.getAttribute("url") == currentSubscription.url)
+    let url = item.getAttribute("url");
+    if (!url)
+      continue;
+
+    menu.appendItem(item.getAttribute("title"), url, null);
+    if (currentSubscription && url == currentSubscription.url)
       menu.selectedIndex = menu.itemCount - 1;
   }
 
@@ -91,7 +95,7 @@
   currentSubscription.title = title;
 
   filterStorage.addSubscription(currentSubscription);
-  abp.synchronizer.execute(currentSubscription);
+  abp.synchronizer.execute(currentSubscription, false);
   filterStorage.saveToDisk();
 }
 
@@ -141,6 +145,90 @@
   E("abp-subscription-btn-ok").focus();
 }
 
+function updateFennecStatusUI()
+{
+  let siteInfo1 = E("abp-site-info1");
+  let siteInfo2 = E("abp-site-info2");
+  if (siteInfo1 && siteInfo2)
+    siteInfo2.parentNode.removeChild(siteInfo2);
+
+  let siteInfo = siteInfo1 || siteInfo2;
+
+  siteInfo.addEventListener("click", toggleFennecWhitelist, false);
+
+  let status = "disabled";
+  let host = null;
+  if (abp.prefs.enabled)
+  {
+    status = "enabled";
+    let location = getCurrentLocation();
+    if (location instanceof Ci.nsIURL && abp.policy.isBlockableScheme(location))
+    {
+      try
+      {
+        host = location.host.replace(/^www\./, "");
+      } catch (e) {}
+    }
+
+    if (host && abp.policy.isWhitelisted(location.spec))
+      status = "disabled_site";
+    else if (host)
+      status = "enabled_site";
+  }
+
+  let statusText = abp.getString("fennec_status_" + status);
+  if (host)
+    statusText = statusText.replace(/\?1\?/g, host);
+
+  if (siteInfo == siteInfo1)
+    siteInfo.setAttribute("title", statusText);
+  else
+    E("abp-status-text").textContent = statusText;
+  siteInfo.setAttribute("abpstate", status);
+}
+
+function toggleFennecWhitelist()
+{
+  if (!abp.prefs.enabled)
+    return;
+
+  let location = getCurrentLocation();
+  if (location instanceof Ci.nsIURL && abp.policy.isBlockableScheme(location))
+  {
+    try
+    {
+      host = location.host.replace(/^www\./, "");
+    } catch (e) {}
+  }
+
+  if (!host)
+    return;
+
+  if (abp.policy.isWhitelisted(location.spec))
+    removeWhitelist();
+  else
+    toggleFilter(abp.Filter.fromText("@@||" + host + "^$document"));
+
+  updateFennecStatusUI();
+}
+
+if (typeof window.IdentityHandler == "function" && typeof window.IdentityHandler.prototype.show == "function")
+{
+  // HACK: Hook IdentityHandler.show() to init our UI
+  let oldShow = window.IdentityHandler.prototype.show;
+  window.IdentityHandler.prototype.show = function()
+  {
+    try
+    {
+      updateFennecStatusUI();
+    }
+    finally
+    {
+      oldShow.apply(this, arguments);
+    }
+  }
+}
+
 abp.runAsync(function() abp.init());
 
 E("addons-list").addEventListener("AddonOptionsLoad", onCreateOptions, false);

=== modified file 'chrome/content/ui/fennecOverlay.xul'
--- chrome/content/ui/fennecOverlay.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/fennecOverlay.xul	2010-05-04 14:45:07 +0000
@@ -17,10 +17,11 @@
    -
    - The Initial Developer of the Original Code is
    - Fabrice Desré.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
+   -  Wladimir Palant
    -
    - ***** END LICENSE BLOCK ***** -->
 
@@ -30,23 +31,23 @@
   <!-- Window extensions -->
   <window id="main-window">
     <box id="abp-hooks"
-      init="
-        let loader = Cc['@mozilla.org/moz/jssubscript-loader;1'].getService(Ci.mozIJSSubScriptLoader);
-        loader.loadSubScript('chrome://adblockplus/content/ui/fennecOverlay.js');
-      "
       getBrowser="return window.getBrowser();"
-      addTab="
-        /* work around bug 528406 and bug 531071 */
-        var url = arguments[0];
-        window.BrowserUI.newTab('about:blank');
-        Cc['@mozilla.org/timer;1'].createInstance(Ci.nsITimer)
-                                  .initWithCallback(function()
-        {
-          window.getBrowser().loadURI(url, null, null);
-          window.BrowserUI.closeAutoComplete(false);
-        }, 100, Ci.nsITimer.TYPE_ONE_SHOT);"
+      addTab="abp.runAsync(window.BrowserUI.newTab, window.BrowserUI, arguments[0]);"
       getContextMenu="return null"
       getToolbox="return null"
       getDefaultToolbar="return null"/>
   </window>
+
+  <!-- Page actions container - Fennec 1.1+ -->
+  <hbox id="pageactions-container">
+    <pageaction id="abp-site-info1" class="abp-site-info"/>
+  </hbox>
+
+  <!-- Identity container - trash bin for site-related info in Fennec 1.0 -->
+  <vbox id="identity-container">
+    <hbox id="abp-site-info2" class="abp-site-info" align="center">
+      <image id="abp-status-image"/>
+      <label id="abp-status-text"/>
+    </hbox>
+  </vbox>
 </overlay>

=== modified file 'chrome/content/ui/fennecSettings.xul'
--- chrome/content/ui/fennecSettings.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/fennecSettings.xul	2010-05-04 14:45:07 +0000
@@ -17,22 +17,18 @@
    -
    - The Initial Developer of the Original Code is
    - Fabrice Desré.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
+   -  Wladimir Palant
    -
    - ***** END LICENSE BLOCK ***** -->
    
-<!DOCTYPE vbox [
-<!ENTITY % settingsDTD SYSTEM "chrome://adblockplus/locale/settings.dtd">
-<!ENTITY % subscriptionDTD SYSTEM "chrome://adblockplus/locale/tip_subscriptions.dtd">
-%subscriptionDTD;
-%settingsDTD;
-]>
+<!DOCTYPE vbox SYSTEM "chrome://adblockplus/locale/settings.dtd">
 <vbox xmlns="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul">
   <setting pref="extensions.adblockplus.enabled" type="bool" title="&enable.label;"/>
-  <setting type="control" title="&subscribe.label;">
+  <setting type="control" title="&fennec.subscription.label;">
     <menulist id="adblockplus-subscription-list"/>
   </setting>
   <setting pref="extensions.adblockplus.fastcollapse" type="bool" title="&collapse.label;"

=== modified file 'chrome/content/ui/fennecSubscription.xul'
--- chrome/content/ui/fennecSubscription.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/fennecSubscription.xul	2010-05-04 14:45:07 +0000
@@ -17,7 +17,7 @@
    -
    - The Initial Developer of the Original Code is
    - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
@@ -29,7 +29,7 @@
 <?xml-stylesheet href="chrome://adblockplus/skin/subscription.css" type="text/css"?>
 
 <!DOCTYPE dialog [
-<!ENTITY % subst SYSTEM "chrome://adblockplus/locale/subscription.dtd">
+<!ENTITY % subst SYSTEM "chrome://adblockplus/locale/subscriptionSelection.dtd">
 <!ENTITY % prompts SYSTEM "chrome://browser/locale/prompt.dtd">
 %subst;
 %prompts;
@@ -48,7 +48,7 @@
   <command id="abp-subscription-cmd-cancel" oncommand="document.getElementById('abpEditSubscription').close();"/>
 </commandset>
 
-<label value="&dialog.newtitle;"/>
+<label value="&dialog.title;"/>
 
 <grid class="prompt-message">
   <columns>

=== modified file 'chrome/content/ui/findbar.js'
--- chrome/content/ui/findbar.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/findbar.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):

=== modified file 'chrome/content/ui/firefoxOverlay.xul'
--- chrome/content/ui/firefoxOverlay.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/firefoxOverlay.xul	2010-05-04 14:45:07 +0000
@@ -17,7 +17,7 @@
    -
    - The Initial Developer of the Original Code is
    - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
@@ -34,7 +34,11 @@
     <commandset id="abp-commandset"/>
     <box id="abp-hooks"
       getBrowser="return window.gBrowser;"
-      addTab="window.gBrowser.loadOneTab(arguments[0], null, null, null, false);"
+      addTab="
+        if (arguments[1] &amp;&amp; 'openNewTabWith' in window)
+          window.openNewTabWith(arguments[0], window.content.document, null, arguments[1], false);
+        else
+          window.gBrowser.loadOneTab(arguments[0], null, null, null, false);"
       getContextMenu="return E('contentAreaContextMenu');"
       getToolbox="return E('navigator-toolbox')"
       getDefaultToolbar="return E('nav-bar');"/>
@@ -78,6 +82,7 @@
   <popup id="contentAreaContextMenu">
     <menuitem id="abp-image-menuitem"/>
     <menuitem id="abp-object-menuitem"/>
+    <menuitem id="abp-media-menuitem"/>
     <menuitem id="abp-frame-menuitem"/>
     <menuitem id="abp-removeWhitelist-menuitem"/>
   </popup>

=== modified file 'chrome/content/ui/flasher.js'
--- chrome/content/ui/flasher.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/flasher.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):

=== modified file 'chrome/content/ui/mailOverlay.xul'
--- chrome/content/ui/mailOverlay.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/mailOverlay.xul	2010-05-04 14:45:07 +0000
@@ -17,7 +17,7 @@
    -
    - The Initial Developer of the Original Code is
    - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
@@ -33,10 +33,10 @@
     <keyset id="abp-keyset"/>
     <commandset id="abp-commandset"/>
     <box id="abp-hooks" getBrowser="return window.messageContent;"
-      addTab="let tabmail = E('tabmail');return (tabmail ? tabmail.openTab('contentTab', {contentPage: arguments[0]}) : false);"
+      addTab="window.openNewTabWith(arguments[0], (arguments[1] ? window.content.document : null), (arguments[1] ? arguments[1].shiftKey : false));"
       getContextMenu="return E('messagePaneContext');"
       getToolbox="return E('mail-toolbox')"
-      getDefaultToolbar="return E('mail-bar2') || E('msgToolbar');" toolbarInsertBefore="return E('button-junk');"/>
+      getDefaultToolbar="return E('msgToolbar');" toolbarInsertBefore="return E('button-junk');"/>
   </window>
 
   <!-- Status bar -->
@@ -59,6 +59,7 @@
   <popup id="messagePaneContext">
     <menuitem id="abp-image-menuitem"/>
     <menuitem id="abp-object-menuitem"/>
+    <menuitem id="abp-media-menuitem"/>
     <menuitem id="abp-frame-menuitem"/>
     <menuitem id="abp-removeWhitelist-menuitem"/>
   </popup>

=== modified file 'chrome/content/ui/overlay.js'
--- chrome/content/ui/overlay.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/overlay.js	2010-05-04 14:45:07 +0000
@@ -15,22 +15,32 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
  *
  * ***** END LICENSE BLOCK ***** */
 
-window.addEventListener("load", function()
 {
-  // Abuse sandboxes so get an execution context for our code
-  let sandbox = new Components.utils.Sandbox(window);
-  sandbox.window = window;
-  sandbox.document = document;
+  let appInfo = Components.classes["@mozilla.org/xre/app-info;1"]
+                          .getService(Components.interfaces.nsIXULAppInfo);
+  let isFennec = (appInfo.ID == "{a23983c0-fd0e-11dc-95ff-0800200c9a66}");
 
-  let loader = Components.classes["@mozilla.org/moz/jssubscript-loader;1"]
-                         .getService(Components.interfaces.mozIJSSubScriptLoader)
-  loader.loadSubScript("chrome://adblockplus/content/ui/utils.js", sandbox);
-  loader.loadSubScript("chrome://adblockplus/content/ui/browserWindow.js", sandbox);
-}, false);
+  // Use UIReady event to initialize in Fennec (bug 531071)
+  window.addEventListener(isFennec ? "UIReady" : "load", function()
+  {
+    // Abuse sandboxes so get an execution context for our code
+    let sandbox = new Components.utils.Sandbox(window);
+    sandbox.window = window;
+    sandbox.document = document;
+    sandbox.isFennec = isFennec;
+  
+    let loader = Components.classes["@mozilla.org/moz/jssubscript-loader;1"]
+                           .getService(Components.interfaces.mozIJSSubScriptLoader)
+    loader.loadSubScript("chrome://adblockplus/content/ui/utils.js", sandbox);
+    loader.loadSubScript("chrome://adblockplus/content/ui/browserWindow.js", sandbox);
+    if (isFennec)
+      loader.loadSubScript("chrome://adblockplus/content/ui/fennecOverlay.js", sandbox);
+  }, false);
+}

=== modified file 'chrome/content/ui/overlayGeneral.xul'
--- chrome/content/ui/overlayGeneral.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/overlayGeneral.xul	2010-05-04 14:45:07 +0000
@@ -17,7 +17,7 @@
    -
    - The Initial Developer of the Original Code is
    - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
@@ -37,6 +37,7 @@
   <script type="application/x-javascript;version=1.7" src="overlay.js"/>  
   
   <popupset id="abp-popupset">
+    <!-- Icon's tooltip -->
     <tooltip id="abp-tooltip" orient="vertical">
       <description id="abp-tooltip-action" hidden="true"/>
       <label id="abp-tooltip-status-label" value="&status.tooltip;"/>
@@ -45,11 +46,14 @@
       <description id="abp-tooltip-blocked" hidden="true"/>
       <label id="abp-tooltip-filters-label" value="&filters.tooltip;" hidden="true"/>
       <vbox id="abp-tooltip-filters" hidden="true"/>
+      <description id="abp-tooltip-more-filters" value="…" hidden="true"/>
     </tooltip>
+
+    <!-- Icon's context menu -->
     <popup id="abp-status-popup">
       <menuitem id="abp-status-opensidebar" label="&opensidebar.label;" accesskey="&opensidebar.accesskey;" key="abp-key-sidebar" command="abp-command-sidebar"/>
       <menuitem id="abp-status-closesidebar" label="&closesidebar.label;" accesskey="&closesidebar.accesskey;" key="abp-key-sidebar" command="abp-command-sidebar"/>
-      <menuitem id="abp-status-settings" label="&settings.label;..." accesskey="&settings.accesskey;" key="abp-key-settings" command="abp-command-settings"/>
+      <menuitem id="abp-status-settings" label="&settings.label;…" accesskey="&settings.accesskey;" key="abp-key-settings" command="abp-command-settings"/>
       <menuseparator id="abp-status-whitelist-sep"/>
       <menuitem id="abp-status-whitelistsite" labeltempl="&whitelist.site.label;" type="checkbox" command="abp-command-togglesitewhitelist"/>
       <menuitem id="abp-status-whitelistpage" label="&whitelist.page.label;" type="checkbox" command="abp-command-togglepagewhitelist"/>
@@ -80,26 +84,27 @@
     <command id="abp-command-enable" oncommand="//"/>
   </commandset>
 
-  <statusbarpanel id="abp-status" context="abp-status-popup">
-    <image tooltip="abp-tooltip"/>
-    <label tooltip="abp-tooltip"/>
-  </statusbarpanel>
+  <statusbarpanel id="abp-status" class="statusbarpanel-iconic"
+      context="abp-status-popup" tooltip="abp-tooltip"/>
 
   <toolbarbutton id="abp-toolbarbutton" label="&toolbarbutton.label;"
       tooltip="abp-tooltip" context="abp-status-popup">
     <menupopup id="abp-toolbar-popup"/>
   </toolbarbutton>
 
+  <box id="abp-hooks" objtabtext="&objecttab.title;" objtabtooltip="&objecttab.tooltip;"/>
+
   <!-- Tools menu -->
-  <menuitem id="abp-menuitem" label="&menuitem.label;..." accesskey="&menuitem.accesskey;" key="abp-key-settings" command="abp-command-settings"/>
+  <menuitem id="abp-menuitem" label="&menuitem.label;…" accesskey="&menuitem.accesskey;" key="abp-key-settings" command="abp-command-settings"/>
 
   <!-- View menu -->
   <menuitem id="abp-blockableitems" label="&view.blockableItems.label;" type="checkbox" autocheck="false" key="abp-key-sidebar" command="abp-command-sidebar"/>
 
   <!-- Context menu -->
-  <menuitem id="abp-image-menuitem" label="&context.image.label;..." hidden="true"/>
-  <menuitem id="abp-object-menuitem" label="&context.object.label;..." hidden="true"/>
-  <menuitem id="abp-frame-menuitem" label="&context.frame.label;..." hidden="true"/>
+  <menuitem id="abp-image-menuitem" label="&context.image.label;…" hidden="true"/>
+  <menuitem id="abp-object-menuitem" label="&context.object.label;…" hidden="true"/>
+  <menuitem id="abp-media-menuitem" label="&context.media.label;…" hidden="true"/>
+  <menuitem id="abp-frame-menuitem" label="&context.frame.label;…" hidden="true"/>
   <menuitem id="abp-removeWhitelist-menuitem" label="&context.removeWhitelist.label;" hidden="true"/>
 
   <!-- Fake sidebar -->

=== modified file 'chrome/content/ui/prismOverlay.xul'
--- chrome/content/ui/prismOverlay.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/prismOverlay.xul	2010-05-04 14:45:07 +0000
@@ -50,6 +50,7 @@
   <menupopup id="popup_content"> 
     <menuitem id="abp-image-menuitem"/>
     <menuitem id="abp-object-menuitem"/>
+    <menuitem id="abp-media-menuitem"/>
     <menuitem id="abp-frame-menuitem"/>
     <menuitem id="abp-removeWhitelist-menuitem"/>
   </menupopup>

=== modified file 'chrome/content/ui/seamonkeyOverlay.xul'
--- chrome/content/ui/seamonkeyOverlay.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/seamonkeyOverlay.xul	2010-05-04 14:45:07 +0000
@@ -17,7 +17,7 @@
    -
    - The Initial Developer of the Original Code is
    - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
@@ -34,7 +34,11 @@
     <commandset id="abp-commandset"/>
     <box id="abp-hooks"
       getBrowser="return window.gBrowser;"
-      addTab="window.gBrowser.addTab(arguments[0], null, null, true);"
+      addTab="
+        if (arguments[1] &amp;&amp; 'openNewTabWith' in window)
+          window.openNewTabWith(arguments[0], window.content.document, arguments[1].shiftKey);
+        else
+          window.gBrowser.addTab(arguments[0], null, null, true);"
       getContextMenu="return E('contentAreaContextMenu');"
       getToolbox="return E('navigator-toolbox')"
       getDefaultToolbar="return E('PersonalToolbar');"  toolbarInsertBefore="return E('bookmarks-button');"/>
@@ -65,6 +69,7 @@
   <popup id="contentAreaContextMenu">
     <menuitem id="abp-image-menuitem"/>
     <menuitem id="abp-object-menuitem"/>
+    <menuitem id="abp-media-menuitem"/>
     <menuitem id="abp-frame-menuitem"/>
     <menuitem id="abp-removeWhitelist-menuitem"/>
   </popup>

=== modified file 'chrome/content/ui/settings.js'
--- chrome/content/ui/settings.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/settings.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -324,7 +324,7 @@
     return result;
 
   if (subscription instanceof abp.DownloadableSubscription && subscription.upgradeRequired)
-    result.push(abp.getString("subscription_wrong_version").replace(/--/, subscription.requiredVersion));
+    result.push(abp.getString("subscription_wrong_version").replace(/\?1\?/, subscription.requiredVersion));
 
   if (subscription instanceof abp.DownloadableSubscription)
     result.push(abp.getString("subscription_source") + " " + subscription.url);
@@ -340,7 +340,7 @@
     status += abp.getString("subscription_status_lastdownload_inprogress");
   else
   {
-    status += (subscription.lastDownload > 0 ? new Date(subscription.lastDownload * 1000).toLocaleFormat("%x %X") : abp.getString("subscription_status_lastdownload_unknown"));
+    status += (subscription.lastDownload > 0 ? formatTime(subscription.lastDownload * 1000) : abp.getString("subscription_status_lastdownload_unknown"));
     if (subscription instanceof abp.DownloadableSubscription && subscription.downloadStatus)
     {
       try {
@@ -358,7 +358,7 @@
  */
 function clearList()
 {
-  if (confirm(abp.getString("clearall_warning")))
+  if (abp.confirm(window, abp.getString("clearall_warning")))
     treeView.removeUserFilters();
 }
 
@@ -368,9 +368,9 @@
  */
 function resetHitCounts(resetAll)
 {
-  if (resetAll && confirm(abp.getString("resethitcounts_warning")))
+  if (resetAll && abp.confirm(window, abp.getString("resethitcounts_warning")))
     filterStorage.resetHitCounts(null);
-  else if (!resetAll && confirm(abp.getString("resethitcounts_selected_warning")))
+  else if (!resetAll && abp.confirm(window, abp.getString("resethitcounts_selected_warning")))
   {
     let filters = treeView.getSelectedFilters(false);
     filterStorage.resetHitCounts(filters.map(function(filter)
@@ -402,6 +402,24 @@
 }
 
 /**
+ * Formats a unix time according to user's locale.
+ * @param {Integer} time  unix time in milliseconds
+ * @return {String} formatted date and time
+ */
+function formatTime(time)
+{
+  try
+  {
+    return new Date(time).toLocaleFormat("%x %X");
+  }
+  catch(e)
+  {
+    // toLocaleFormat might throw (bug 508783)
+    return new Date(time).toString();
+  }
+}
+
+/**
  * Saves new default download dir after the user chose a different directory to
  * save his files to.
  * @param {nsIFile} dir
@@ -498,7 +516,7 @@
       let minVersion = RegExp.$1;
       let warning = "";
       if (minVersion && abp.versionComparator.compare(minVersion, abp.getInstalledVersion()) > 0)
-        warning = abp.getString("import_filters_wrong_version").replace(/--/, minVersion) + "\n\n";
+        warning = abp.getString("import_filters_wrong_version").replace(/\?1\?/, minVersion) + "\n\n";
 
       let promptService = Cc["@mozilla.org/embedcomp/prompt-service;1"].getService(Ci.nsIPromptService);
       let flags = promptService.BUTTON_TITLE_IS_STRING * promptService.BUTTON_POS_0 +
@@ -518,7 +536,7 @@
       treeView.ensureSelection(0);
     }
     else 
-      alert(abp.getString("invalid_filters_file"));
+      abp.alert(window, abp.getString("invalid_filters_file"));
   }
 }
 
@@ -563,7 +581,9 @@
           let filterVersion;
           if (filter instanceof abp.RegExpFilter)
           {
-            if (/^(?:@@)?\|\|/.test(filter.text) || (!abp.Filter.regexpRegExp.test(filter.text) && /\^/.test(filter.text)))
+            if (filter.contentType & abp.RegExpFilter.typeMap.ELEMHIDE)
+              filterVersion = "1.2";
+            else if (/^(?:@@)?\|\|/.test(filter.text) || (!abp.Filter.regexpRegExp.test(filter.text) && /\^/.test(filter.text)))
               filterVersion = "1.1";
             else if (filter.includeDomains != null || filter.excludeDomains != null)
               filterVersion = "1.0.1";
@@ -627,7 +647,7 @@
     catch (e)
     {
       dump("Adblock Plus: error writing to file: " + e + "\n");
-      alert(abp.getString("filters_write_error"));
+      abp.alert(window, abp.getString("filters_write_error"));
     }
   }
 }
@@ -882,34 +902,42 @@
  */
 function editSubscription(/**Subscription*/ subscription)
 {
+  let hasSubscription = function(url) treeView.subscriptions.indexOf(getSubscriptionByURL(url)) >= 0;
   let result = {};
-  if (subscription)
-    openDialog("subscription.xul", "_blank", "chrome,centerscreen,modal", subscription, result);
-  else
-    openDialog("tip_subscriptions.xul", "_blank", "chrome,centerscreen,resizable,dialog=no,modal", result);
+  openDialog("subscriptionSelection.xul", "_blank", "chrome,centerscreen,modal,resizable,dialog=no", subscription, result, hasSubscription);
 
   if (!("url" in result))
     return;
 
-  let newSubscription = getSubscriptionByURL(result.url);
-  if (!newSubscription)
-    return;
-
-  if (subscription && subscription != newSubscription)
-    treeView.removeSubscription(subscription);
-
-  treeView.addSubscription(newSubscription);
-
-  newSubscription.title = result.title;
-  newSubscription.disabled = result.disabled;
-  newSubscription.autoDownload = result.autoDownload;
-
-  treeView.invalidateSubscriptionInfo(newSubscription);
-
-  onChange();
-
-  if (newSubscription instanceof abp.DownloadableSubscription && !newSubscription.lastDownload)
-    synchronizer.execute(newSubscription.__proto__);
+  let subscriptionResults = [[result.url, result.title]];
+  if ("mainSubscriptionURL" in result)
+    subscriptionResults.push([result.mainSubscriptionURL, result.mainSubscriptionTitle]);
+
+  let changed = false;
+  for each (let [url, title] in subscriptionResults)
+  {
+    let newSubscription = getSubscriptionByURL(url);
+    if (!newSubscription)
+      continue;
+  
+    changed = true;
+    if (subscription && subscription != newSubscription)
+      treeView.removeSubscription(subscription);
+  
+    treeView.addSubscription(newSubscription);
+  
+    newSubscription.title = title;
+    newSubscription.disabled = result.disabled;
+    newSubscription.autoDownload = result.autoDownload;
+  
+    treeView.invalidateSubscriptionInfo(newSubscription);
+
+    if (newSubscription instanceof abp.DownloadableSubscription && !newSubscription.lastDownload)
+      synchronizer.execute(newSubscription.__proto__, false);
+  }
+
+  if (changed)
+    onChange();
 }
 
 /**
@@ -948,7 +976,7 @@
         return;
     }
 
-    if (selectedSubscription && selectedSubscription instanceof abp.RegularSubscription && confirm(abp.getString("remove_subscription_warning")))
+    if (selectedSubscription && selectedSubscription instanceof abp.RegularSubscription && abp.confirm(window, abp.getString("remove_subscription_warning")))
       treeView.removeSubscription(selectedSubscription);
   }
 }
@@ -1029,7 +1057,7 @@
 {
   let [subscription, filter] = treeView.getRowInfo(treeView.selection.currentIndex);
   if (subscription instanceof abp.DownloadableSubscription)
-    synchronizer.execute(subscription.__proto__, forceDownload);
+    synchronizer.execute(subscription.__proto__, true, forceDownload);
 }
 
 /**
@@ -1039,7 +1067,7 @@
 {
   for each (let subscription in treeView.subscriptions)
     if (subscription instanceof abp.DownloadableSubscription)
-      synchronizer.execute(subscription.__proto__, forceDownload);
+      synchronizer.execute(subscription.__proto__, true, forceDownload);
 }
 
 /**
@@ -1123,6 +1151,42 @@
 }
 
 /**
+ * Updates the state of copy/paste commands whenever selection changes.
+ */
+function updateCommands()
+{
+  // Retrieve selected items
+  let selected = treeView.getSelectedInfo(true);
+
+  // Check whether all selected items belong to the same subscription
+  let selectedSubscription = null;
+  for each (let [subscription, filter] in selected)
+  {
+    if (!selectedSubscription)
+      selectedSubscription = subscription;
+    else if (subscription != selectedSubscription)
+    {
+      // More than one subscription selected, ignoring it
+      selectedSubscription = null;
+      break;
+    }
+  }
+
+  // Check whether any filters have been selected and whether any of them can be removed
+  let hasFilters = selected.some(function([subscription, filter]) filter instanceof abp.Filter);
+  let hasRemovable = selected.some(function([subscription, filter]) subscription instanceof abp.SpecialSubscription && filter instanceof abp.Filter);
+
+  // Check whether clipboard contains text
+  let clipboard = Cc["@mozilla.org/widget/clipboard;1"].getService(Ci.nsIClipboard);
+  let hasFlavour = clipboard.hasDataMatchingFlavors(["text/unicode"], 1, clipboard.kGlobalClipboard);
+
+  E("copy-command").setAttribute("disabled", !hasFilters);
+  E("cut-command").setAttribute("disabled", !hasRemovable);
+  E("paste-command").setAttribute("disabled", !hasFlavour);
+  E("remove-command").setAttribute("disabled", !(hasRemovable || selectedSubscription instanceof abp.RegularSubscription));
+}
+
+/**
  * Updates the contents of the context menu, making sure the right
  * items are checked/enabled.
  */
@@ -1150,22 +1214,9 @@
     }
   }
 
-  // Check whether any patterns have been selected and whether any of them can be removed
-  let hasFilters = selected.some(function(info)
-  {
-    let [subscription, filter] = info;
-    return filter instanceof abp.Filter;
-  });
-  let hasRemovable = selected.some(function(info)
-  {
-    let [subscription, filter] = info;
-    return subscription instanceof abp.SpecialSubscription && filter instanceof abp.Filter;
-  });
-  let activeFilters = selected.filter(function(info)
-  {
-    let [subscription, filter] = info;
-    return filter instanceof abp.ActiveFilter;
-  });
+  // Check whether any filters have been selected and which filters can be enabled/disabled
+  let hasFilters = selected.some(function([subscription, filter]) filter instanceof abp.Filter);
+  let activeFilters = selected.filter(function([subscription, filter]) filter instanceof abp.ActiveFilter);
 
   if (selectedSubscription instanceof abp.RegularSubscription)
   {
@@ -1188,15 +1239,6 @@
   E("context-movegroupup").setAttribute("disabled", !selectedSubscription || treeView.isFirstSubscription(selectedSubscription));
   E("context-movegroupdown").setAttribute("disabled", !selectedSubscription || treeView.isLastSubscription(selectedSubscription));
 
-  let clipboard = Cc["@mozilla.org/widget/clipboard;1"].getService(Ci.nsIClipboard);
-
-  let hasFlavour = clipboard.hasDataMatchingFlavors(["text/unicode"], 1, clipboard.kGlobalClipboard);
-
-  E("copy-command").setAttribute("disabled", !hasFilters);
-  E("cut-command").setAttribute("disabled", !hasRemovable);
-  E("paste-command").setAttribute("disabled", !hasFlavour);
-  E("remove-command").setAttribute("disabled", !(hasRemovable || selectedSubscription instanceof abp.RegularSubscription));
-
   if (activeFilters.length || (selectedSubscription && !currentFilter))
   {
     let current = activeFilters.length ? activeFilters[0][1] : selectedSubscription;
@@ -1456,12 +1498,16 @@
     if (sortColumn)
       this.resort(sortColumn, sortDir);
 
-    // Make sure we stop the editor when scrolling
+    // Make sure we stop the editor when scrolling or resizing window
     let me = this;
     this.boxObject.treeBody.addEventListener("DOMMouseScroll", function()
     {
       me.stopEditor(true);
     }, false);
+    window.addEventListener("resize", function()
+    {
+      me.stopEditor(true);
+    }, false);
   },
 
   get rowCount()
@@ -1508,7 +1554,7 @@
         if (col == "col-hitcount")
           return filter.hitCount;
         else
-          return (filter.lastHit ? new Date(filter.lastHit).toLocaleFormat("%x %X") : null);
+          return (filter.lastHit ? formatTime(filter.lastHit) : null);
       }
       else
         return null;

=== modified file 'chrome/content/ui/settings.xul'
--- chrome/content/ui/settings.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/settings.xul	2010-05-04 14:45:07 +0000
@@ -17,7 +17,7 @@
    -
    - The Initial Developer of the Original Code is
    - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
@@ -45,7 +45,7 @@
   ondialogaccept="applyChanges(); return true;"
   ondialogextra2="treeView.startEditor(true)"
   buttons="accept,cancel,extra2"
-  buttonlabelextra2="&add.label;..."
+  buttonlabelextra2="&add.label;…"
   buttonaccesskeyextra2="&add.accesskey;"
   width="600"
   height="450"
@@ -97,9 +97,9 @@
 <popupset id="abpPopups">
   <popup id="listitem-context" onpopupshowing="return fillContext()">
     <menuitem id="context-synchsubscription" label="&context.synchsubscription.label;" oncommand="synchSubscription(event.shiftKey)" key="synchsubscription-key" />
-    <menuitem id="context-editsubscription" label="&context.editsubscription.label;..." oncommand="editFilter('subscription')" key="edit-key"/>
+    <menuitem id="context-editsubscription" label="&context.editsubscription.label;…" oncommand="editFilter('subscription')" key="edit-key"/>
     <menuitem id="context-edit" label="&context.edit.label;" oncommand="editFilter('filter')" key="edit-key"/>
-    <menuitem id="context-resethitcount" label="&context.resethitcount.label;..." oncommand="resetHitCounts(false)"/>
+    <menuitem id="context-resethitcount" label="&context.resethitcount.label;…" oncommand="resetHitCounts(false)"/>
     <menuitem id="context-moveup" label="&context.moveup.label;" oncommand="treeView.moveFilter(true)" key="moveup-key"/>
     <menuitem id="context-movedown" label="&context.movedown.label;" oncommand="treeView.moveFilter(false)" key="movedown-key"/>
     <menuseparator/>
@@ -121,26 +121,26 @@
   <menubar id="menu" onpopupshowing="treeView.stopEditor(true, true);">
     <menu id="filters-menu" label="&filters.label;" accesskey="&filters.accesskey;">
       <menupopup id="filters-popup" onpopupshowing="fillFiltersPopup()">
-        <menuitem id="addfilter" label="&add.label;..." accesskey="&add.accesskey;" key="addfilter-key" oncommand="treeView.startEditor(true)"/>
+        <menuitem id="addfilter" label="&add.label;…" accesskey="&add.accesskey;" key="addfilter-key" oncommand="treeView.startEditor(true)"/>
         <menuseparator/>
-        <menuitem id="addsubscription" label="&addsubscription.label;..." accesskey="&addsubscription.accesskey;" command="addsubscription-command"/>
+        <menuitem id="addsubscription" label="&addsubscription.label;…" accesskey="&addsubscription.accesskey;" command="addsubscription-command"/>
         <menuitem id="synchsubscriptions" label="&synchsubscriptions.label;" accesskey="&synchsubscriptions.accesskey;" key="synchsubscriptions-key" command="synchsubscriptions-command"/>
         <menuseparator/>
-        <menuitem id="import" label="&import.label;..." accesskey="&import.accesskey;" key="import-key" command="import-command"/>
-        <menuitem id="export" label="&export.label;..." accesskey="&export.accesskey;" key="export-key" command="export-command"/>
-        <menuitem id="clearall" label="&clearall.label;..." accesskey="&clearall.accesskey;" oncommand="clearList()"/>
+        <menuitem id="import" label="&import.label;…" accesskey="&import.accesskey;" key="import-key" command="import-command"/>
+        <menuitem id="export" label="&export.label;…" accesskey="&export.accesskey;" key="export-key" command="export-command"/>
+        <menuitem id="clearall" label="&clearall.label;…" accesskey="&clearall.accesskey;" oncommand="clearList()"/>
         <menuseparator/>
-        <menuitem id="resethitcounts" label="&resethitcounts.label;..." accesskey="&resethitcounts.accesskey;" oncommand="resetHitCounts(true)"/>
+        <menuitem id="resethitcounts" label="&resethitcounts.label;…" accesskey="&resethitcounts.accesskey;" oncommand="resetHitCounts(true)"/>
       </menupopup>
     </menu>
     <menu id="edit-menu" label="&edit.label;" accesskey="&edit.accesskey;">
-      <menupopup id="edit-popup" onpopupshowing="fillContext()">
+      <menupopup id="edit-popup">
         <menuitem id="cut" label="&cut.label;" accesskey="&cut.accesskey;" command="cut-command" key="cut-key"/>
         <menuitem id="copy" label="&copy.label;" accesskey="&copy.accesskey;" command="copy-command" key="copy-key"/>
         <menuitem id="paste" label="&paste.label;" accesskey="&paste.accesskey;" command="paste-command" key="paste-key"/>
         <menuitem id="remove" label="&remove.label;" accesskey="&remove.accesskey;" command="remove-command" key="remove-key"/>
         <menuseparator/>
-        <menuitem id="find" label="&menu.find.label;..." accesskey="&menu.find.accesskey;" command="find-command" key="find-key"/>
+        <menuitem id="find" label="&menu.find.label;…" accesskey="&menu.find.accesskey;" command="find-command" key="find-key"/>
         <menuitem id="find-again" label="&menu.findagain.label;" accesskey="&menu.findagain.accesskey;" command="find-again-command" key="find-again-key"/>
       </menupopup>
     </menu>
@@ -184,7 +184,7 @@
         <menuitem id="faqLink" label="&faq.label;" accesskey="&faq.accesskey;" oncommand="abp.loadInBrowser('&faq.url;')"/>
         <menuitem id="filtersLink" label="&filterdoc.label;" accesskey="&filterdoc.accesskey;" oncommand="abp.loadInBrowser('&filterdoc.url;')"/>
         <menuseparator/>
-        <menuitem id="aboutAbp" label="&about.label;..." accesskey="&about.accesskey;" oncommand="openAbout()"/>
+        <menuitem id="aboutAbp" label="&about.label;…" accesskey="&about.accesskey;" oncommand="openAbout()"/>
       </menupopup>
     </menu>
   </menubar>
@@ -198,7 +198,7 @@
 
 <vbox id="listarea" flex="1">
   <stack id="listStack" flex="1">
-    <tree id="list" persist="closedSubscriptions" flex="1" seltype="multiple" hidecolumnpicker="true" enableColumnDrag="true">
+    <tree id="list" onselect="updateCommands()" context="listitem-context" persist="closedSubscriptions" flex="1" seltype="multiple" hidecolumnpicker="true" enableColumnDrag="true">
       <treecols context="treecols-context">
         <treecol id="col-filter" label="&filter.column;" primary="true" flex="10" persist="width ordinal sortDirection hidden"/>
         <splitter class="tree-splitter"/>
@@ -211,7 +211,7 @@
         <treecol id="col-lasthit" label="&lasthit.column;" hidden="true" flex="4" persist="width ordinal sortDirection hidden"/>
       </treecols>
 
-      <treechildren tooltip="tree-tooltip" context="listitem-context" onclick="onListClick(event)" ondblclick="onListDblClick(event)" ondraggesture="onListDragGesture(event)"/>
+      <treechildren tooltip="tree-tooltip" onclick="onListClick(event)" ondblclick="onListDblClick(event)" ondraggesture="onListDragGesture(event)"/>
     </tree>
     <hbox id="listEditorParent" align="center" hidden="true">
       <textbox id="listEditor" class="tree-input" flex="1"/>

=== modified file 'chrome/content/ui/sidebar.js'
--- chrome/content/ui/sidebar.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/sidebar.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -40,15 +40,21 @@
 
 var abpHooks = null;
 
+/**
+ * Cached value of "enabled" preference, for onPrefChange.
+ */
+var oldEnabled = abp.prefs.enabled;
+
 function init() {
   var list = E("list");
   list.view = treeView;
 
   // Restore previous state
   var params = abp.getParams();
-  if (params && params.search) {
-    E("searchField").value = params.search;
-    treeView.setFilter(params.search);
+  if (params && params.filter)
+  {
+    E("searchField").value = params.filter;
+    treeView.setFilter(params.filter);
   }
   if (params && params.focus && E(params.focus))
     E(params.focus).focus();
@@ -89,6 +95,7 @@
   reloadDisabledFilters();
   filterStorage.addFilterObserver(reloadDisabledFilters);
   filterStorage.addSubscriptionObserver(reloadDisabledFilters);
+  abp.prefs.addListener(onPrefChange);
 
   // Activate flasher
   list.addEventListener("select", onSelectionChange, false);
@@ -120,12 +127,26 @@
   RequestList.removeListener(handleItemChange);
   filterStorage.removeFilterObserver(reloadDisabledFilters);
   filterStorage.removeSubscriptionObserver(reloadDisabledFilters);
+  abp.prefs.removeListener(onPrefChange);
 
   abpHooks.getBrowser().removeEventListener("select", handleTabChange, false);
   mainWin.removeEventListener("unload", mainUnload, false);
 }
 
 /**
+ * Tracks preference changes, calls reloadDisabledFilters whenever Adblock Plus
+ * is enabled/disabled.
+ */
+function onPrefChange()
+{
+  if (abp.prefs.enabled != oldEnabled)
+  {
+    oldEnabled = abp.prefs.enabled;
+    reloadDisabledFilters();
+  }
+}
+
+/**
  * Updates matchers for disabled filters (global disabledBlacklistMatcher and
  * disabledWhitelistMatcher variables), called on each filter change.
  */
@@ -134,15 +155,20 @@
   disabledBlacklistMatcher.clear();
   disabledWhitelistMatcher.clear();
 
-  for each (let subscription in filterStorage.subscriptions)
+  if (abp.prefs.enabled)
   {
-    if (subscription.disabled)
-      continue;
-
-    for each (let filter in subscription.filters)
-      if (filter instanceof abp.RegExpFilter && filter.disabled)
-        (filter instanceof abp.BlockingFilter ? disabledBlacklistMatcher : disabledWhitelistMatcher).add(filter);
+    for each (let subscription in filterStorage.subscriptions)
+    {
+      if (subscription.disabled)
+        continue;
+  
+      for each (let filter in subscription.filters)
+        if (filter instanceof abp.RegExpFilter && filter.disabled)
+          (filter instanceof abp.BlockingFilter ? disabledBlacklistMatcher : disabledWhitelistMatcher).add(filter);
+    }
   }
+
+  treeView.setData(treeView.allData);
 }
 
 // Called whenever list selection changes - triggers flasher
@@ -335,7 +361,7 @@
     let filter = item.filter;
     let menuItem = E(filter.disabled ? "contextEnableFilter" : "contextDisableFilter");
     menuItem.filter = filter;
-    menuItem.setAttribute("label", menuItem.getAttribute("labeltempl").replace(/--/, filter.text));
+    menuItem.setAttribute("label", menuItem.getAttribute("labeltempl").replace(/\?1\?/, filter.text));
     menuItem.hidden = false;
 
     if (filter instanceof abp.ActiveFilter && !filter.disabled && filter.subscriptions.length && !filter.subscriptions.some(function(subscription) !(subscription instanceof abp.SpecialSubscription)))
@@ -352,7 +378,7 @@
         menuItem.item = item;
         menuItem.filter = filter;
         menuItem.domain = domain;
-        menuItem.setAttribute("label", menuItem.getAttribute("labeltempl").replace(/--/, domain));
+        menuItem.setAttribute("label", menuItem.getAttribute("labeltempl").replace(/\?1\?/, domain));
         menuItem.hidden = false;
       }
     }
@@ -384,7 +410,7 @@
   }
   else if (event.button == 1)
   {
-    openInTab(item);
+    openInTab(item, event);
     event.preventDefault();
   }
 }
@@ -404,14 +430,14 @@
 /**
  * Opens the item in a new tab.
  */
-function openInTab(item)
+function openInTab(item, /**Event*/ event)
 {
   if (!item)
     item = treeView.getSelectedItem();
   if (!item || item.typeDescr == "ELEMHIDE")
     return;
 
-  abp.loadInBrowser(item.location, mainWin);
+  abp.loadInBrowser(item.location, mainWin, event);
 }
 
 function doBlock() {
@@ -478,7 +504,7 @@
       {
         if (/^DOMAIN=(.*)/.test(options[i]))
         {
-          let domains = RegExp.$1.split("|").filter(function(d) d != domain && d != "~" + domain && d.lastIndexOf("." + domain) != d.length - domain.length - 1);
+          let domains = RegExp.$1.split("|").filter(function(d) d != domain && d != "~" + domain && (d.length <= domain.length || d.lastIndexOf("." + domain) != d.length - domain.length - 1));
           domains.push("~" + domain);
           options[i] = "DOMAIN=" + domains.join("|");
           found = true;
@@ -498,7 +524,7 @@
     if (/^([^#]+)(#.*)/.test(text))
     {
       let selector = RegExp.$2;
-      let domains = RegExp.$1.toUpperCase().split(",").filter(function(d) d != domain && d != "~" + domain && d.lastIndexOf("." + domain) != d.length - domain.length - 1);
+      let domains = RegExp.$1.toUpperCase().split(",").filter(function(d) d != domain && (d.length <= domain.length || d != "~" + domain && d.lastIndexOf("." + domain) != d.length - domain.length - 1));
       domains.push("~" + domain);
       text = domains.join(",").toLowerCase() + selector;
     }
@@ -971,6 +997,8 @@
     this.allData = data;
     for each (let item in this.allData)
     {
+      if (item.filter instanceof abp.RegExpFilter && item.filter.disabled)
+        item.filter = null;
       if (!item.filter)
         item.filter = disabledWhitelistMatcher.matchesAny(item.location, item.typeDescr, item.docDomain, item.thirdParty);
       if (!item.filter)

=== modified file 'chrome/content/ui/sidebar.xul'
--- chrome/content/ui/sidebar.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/sidebar.xul	2010-05-04 14:45:07 +0000
@@ -17,7 +17,7 @@
    -
    - The Initial Developer of the Original Code is
    - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
@@ -91,14 +91,14 @@
     </tooltip>
 
     <popup id="context" onpopupshowing="return fillInContext(event)">
-      <menuitem id="contextBlock" label="&context.block.label;..." oncommand="doBlock()" key="block-key"/>
-      <menuitem id="contextWhitelist" label="&context.whitelist.label;..." oncommand="doBlock()" key="block-key"/>
-      <menuitem id="contextEditFilter" label="&context.editfilter.label;..." oncommand="editFilter()"/>
+      <menuitem id="contextBlock" label="&context.block.label;…" oncommand="doBlock()" key="block-key"/>
+      <menuitem id="contextWhitelist" label="&context.whitelist.label;…" oncommand="doBlock()" key="block-key"/>
+      <menuitem id="contextEditFilter" label="&context.editfilter.label;…" oncommand="editFilter()"/>
       <menuitem id="contextDisableFilter" labeltempl="&context.disablefilter.label;" oncommand="enableFilter(this.filter, false)"/>
       <menuitem id="contextEnableFilter" labeltempl="&context.enablefilter.label;" oncommand="enableFilter(this.filter, true)"/>
       <menuitem id="contextDisableOnSite" labeltempl="&context.disablefilteronsite.label;" oncommand="disableOnSite(this.item, this.filter, this.domain)"/>
       <menuseparator id="contextOpenSep"/>
-      <menuitem id="contextOpen" label="&context.open.label;" oncommand="openInTab(null)"/>
+      <menuitem id="contextOpen" label="&context.open.label;" oncommand="openInTab(null, event)"/>
       <menuitem id="contextFlash" label="&context.flash.label;" oncommand="onSelectionChange()"/>
       <menuitem id="contextCopy" label="&context.copy.label;" command="copy-command" key="copy-key"/>
       <menuitem id="contextCopyFilter" label="&context.copyFilter.label;" oncommand="copyFilter()"/>
@@ -116,7 +116,7 @@
     <description id="reattachButton" value="&reattach.label;" onclick="if (this.getAttribute('disabled') != 'true') detach(false)" hidden="true"/>
   </hbox>
 
-  <tree id="list" flex="1" seltype="multiple" enableColumnDrag="true"
+  <tree id="list" context="context" flex="1" seltype="multiple" enableColumnDrag="true"
         defaultSort="state descending" persist="defaultSort"
         onkeypress="if (event.keyCode == event.DOM_VK_RETURN || event.keyCode == event.DOM_VK_ENTER) doBlock()">
     <treecols>
@@ -133,7 +133,7 @@
       <treecol id="docDomain" label="&docDomain.label;" width="100" hidden="true" persist="width ordinal sortDirection hidden"/>
     </treecols>
 
-    <treechildren tooltip="tooltip" context="context"
+    <treechildren tooltip="tooltip"
                   onclick="handleClick(event)"
                   ondblclick="handleDblClick(event)"
                   noitemslabel="&noitems.label;"

=== modified file 'chrome/content/ui/sidebarDetached.xul'
--- chrome/content/ui/sidebarDetached.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/sidebarDetached.xul	2010-05-04 14:45:07 +0000
@@ -17,7 +17,7 @@
    -
    - The Initial Developer of the Original Code is
    - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
    - the Initial Developer. All Rights Reserved.
    -
    - Contributor(s):
@@ -35,6 +35,15 @@
   persist="screenX screenY width height sizemode"
   onclose="document.getElementById('abp-command-sidebar').doCommand(); return false;">
 
+  <script type="application/x-javascript">
+    // Some people actually switch off browser.frames.enabled and are surprised
+    // that things stop working...
+    window.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+          .getInterface(Components.interfaces.nsIWebNavigation)
+          .QueryInterface(Components.interfaces.nsIDocShell)
+          .allowSubframes = true;
+  </script>
+
   <keyset id="detached-keyset">
     <key keycode="VK_ESCAPE" command="abp-command-sidebar"/> 
     <key modifiers="accel" key="w" command="abp-command-sidebar"/> 

=== removed file 'chrome/content/ui/subscription.js'
--- chrome/content/ui/subscription.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/subscription.js	1970-01-01 00:00:00 +0000
@@ -1,119 +0,0 @@
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is Adblock Plus.
- *
- * The Initial Developer of the Original Code is
- * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *
- * ***** END LICENSE BLOCK ***** */
-
-var subscription = null;
-var result = null;
-var autoAdd = false;
-
-function init() {
-  if (window.arguments)
-  {
-    // In K-Meleon we might get the arguments wrapped
-    for (var i = 0; i < window.arguments.length; i++)
-      if (window.arguments[i] && "wrappedJSObject" in window.arguments[i])
-        window.arguments[i] = window.arguments[i].wrappedJSObject;
-
-    [subscription, result] = window.arguments;
-  }
-
-  autoAdd = !result;
-  if (!result)
-    result = {};
-
-  if (subscription)
-  {
-    document.getElementById("location").value = subscription.url;
-    document.getElementById("title").value = subscription.title;
-  }
-  else
-    document.getElementById("title").value = "";
-
-  if (subscription instanceof abp.Subscription)
-  {
-    document.getElementById("enabled").setAttribute("checked", !subscription.disabled);
-    if (subscription instanceof abp.ExternalSubscription)
-    {
-      document.getElementById("location").setAttribute("disabled", "true");
-      document.getElementById("external-description").hidden = false;
-      document.getElementById("autodownload").setAttribute("checked", "true");
-      document.getElementById("autodownload").setAttribute("disabled", "true");
-    }
-    else
-    {
-      document.getElementById("edit-description").hidden = false;
-      document.getElementById("autodownload").setAttribute("checked", subscription.autoDownload);
-    }
-  }
-  else
-  {
-    document.title = document.documentElement.getAttribute("newtitle");
-    document.getElementById("new-description").hidden = false;
-    document.getElementById("enabled").setAttribute("checked", "true");
-    document.getElementById("autodownload").setAttribute("checked", "true");
-  }
-}
-
-function saveSubscription()
-{
-  var add = !(subscription instanceof abp.Subscription);
-  var url = (add || subscription instanceof abp.DownloadableSubscription ? document.getElementById("location").value.replace(/^\s+/, "").replace(/\s+$/, "").replace(/^~+/, "") : subscription.url);
-  if (!url)
-  {
-    alert(abp.getString("subscription_no_location"));
-    document.getElementById("location").focus();
-    return false;
-  }
-
-  if (add || subscription.url != url)
-  {
-    var file = Cc["@mozilla.org/file/local;1"].createInstance(Ci.nsILocalFile);
-    try {
-      file.initWithPath(url);
-      var ioService = Cc["@mozilla.org/network/io-service;1"].getService(Ci.nsIIOService);
-      url = ioService.newFileURI(file).spec;
-    } catch (e2) {
-      let uri = abp.makeURL(url);
-      if (!uri)
-      {
-        alert(abp.getString("subscription_invalid_location"));
-        document.getElementById("location").focus();
-        return false;
-      }
-      url = uri.spec;
-    }
-  }
-
-  result.url = url;
-  result.title = document.getElementById("title").value.replace(/^\s+/, "").replace(/\s+$/, "");
-  if (!result.title)
-    result.title = result.url;
-
-  result.autoDownload = document.getElementById("autodownload").checked;
-  result.disabled = !document.getElementById("enabled").checked;
-
-  if (autoAdd)
-    abp.addSubscription(result.url, result.title, result.autoDownload, result.disabled);
-
-  return true;
-}

=== removed file 'chrome/content/ui/subscription.xul'
--- chrome/content/ui/subscription.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/subscription.xul	1970-01-01 00:00:00 +0000
@@ -1,74 +0,0 @@
-<?xml version="1.0"?>
-
-<!-- ***** BEGIN LICENSE BLOCK *****
-   - Version: MPL 1.1
-   -
-   - The contents of this file are subject to the Mozilla Public License Version
-   - 1.1 (the "License"); you may not use this file except in compliance with
-   - the License. You may obtain a copy of the License at
-   - http://www.mozilla.org/MPL/
-   -
-   - Software distributed under the License is distributed on an "AS IS" basis,
-   - WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
-   - for the specific language governing rights and limitations under the
-   - License.
-   -
-   - The Original Code is Adblock Plus.
-   -
-   - The Initial Developer of the Original Code is
-   - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
-   - the Initial Developer. All Rights Reserved.
-   -
-   - Contributor(s):
-   -
-   - ***** END LICENSE BLOCK ***** -->
-
-<?xml-stylesheet href="chrome://global/skin/" type="text/css"?>
-<?xml-stylesheet href="chrome://adblockplus/skin/subscription.css" type="text/css"?>
-
-<!DOCTYPE dialog SYSTEM "chrome://adblockplus/locale/subscription.dtd">
-
-<dialog
-  xmlns="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"
-  buttons="accept,cancel"
-  title="&dialog.title;"
-  newtitle="&dialog.newtitle;"
-  id="abpEditSubscription"
-  windowtype="abp:subscription"
-  onload="init()"
-  ondialogaccept="return saveSubscription()">
-
-<script type="application/x-javascript;version=1.7" src="utils.js"/>
-<script type="application/x-javascript;version=1.7" src="subscription.js"/>
-
-<description id="new-description" hidden="true">&new.description; &autodownload.description;</description>
-<description id="edit-description" hidden="true">&edit.description; &autodownload.description;</description>
-<description id="external-description" hidden="true">&external.description;</description>
-
-<grid>
-  <columns>
-    <column/>
-    <column flex="1"/> 
-  </columns>
-  <rows>
-    <row id="titleRow" align="center">
-      <label value="&title.label;" accesskey="&title.accesskey;" control="title"/>
-      <textbox id="title"/>
-    </row>
-    <row id="locationRow" align="center">
-      <label value="&location.label;" accesskey="&location.accesskey;" control="location"/>
-      <textbox id="location"/>
-    </row>
-    <row id="autodownloadRow">
-      <spacer/>
-      <checkbox id="autodownload" label="&autodownload.label;" accesskey="&autodownload.accesskey;"/>
-    </row>
-    <row id="enabledRow">
-      <spacer/>
-      <checkbox id="enabled" label="&enabled.label;" accesskey="&enabled.accesskey;"/>
-    </row>
-  </rows>
-</grid>
-
-</dialog>

=== added file 'chrome/content/ui/subscriptionSelection.js'
--- chrome/content/ui/subscriptionSelection.js	1970-01-01 00:00:00 +0000
+++ chrome/content/ui/subscriptionSelection.js	2010-05-04 14:45:07 +0000
@@ -0,0 +1,626 @@
+/* ***** BEGIN LICENSE BLOCK *****
+ * Version: MPL 1.1
+ *
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
+ *
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ *
+ * The Original Code is Adblock Plus.
+ *
+ * The Initial Developer of the Original Code is
+ * Wladimir Palant.
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
+ * the Initial Developer. All Rights Reserved.
+ *
+ * Contributor(s):
+ *
+ * ***** END LICENSE BLOCK ***** */
+
+let newInstall = true;
+let editMode = true;
+let autoAdd = false;
+let source = null;
+let result = null;
+let initialized = false;
+
+/**
+ * Suppresses window resizing while the window is loading or if the window is loaded in a browser tab.
+ * @type Boolean
+ */
+let suppressResize = true;
+
+let closing = false;
+let subscriptionListLoading = false;
+let appLocale = "en-US";
+
+let adblockID = "{34274bf4-1d97-a289-e984-17e546307e4f}";
+let filtersetG = "filtersetg@updater";
+
+function init()
+{
+  if (window.arguments  && window.arguments.length)
+  {
+    // In K-Meleon we might get the arguments wrapped
+    for (var i = 0; i < window.arguments.length; i++)
+      if (window.arguments[i] && "wrappedJSObject" in window.arguments[i])
+        window.arguments[i] = window.arguments[i].wrappedJSObject;
+
+    newInstall = false;
+    [source, result] = window.arguments;
+    if (window.arguments.length > 2 && window.arguments[2])
+      window.hasSubscription = window.arguments[2];
+  }
+
+  if (!result)
+  {
+    result = {};
+    autoAdd = true;
+  }
+  if (!source)
+  {
+    editMode = false;
+    source = {title: "", url: "", disabled: false, external: false, autoDownload: true, mainSubscriptionTitle: null, mainSubscriptionURL: null};
+  }
+  else
+  {
+    if (typeof source.mainSubscriptionURL == "undefined")
+      source.mainSubscriptionURL = source.mainSubscriptionTitle = null;
+  }
+
+  E("description-newInstall").hidden = !newInstall;
+  if (newInstall)
+    document.documentElement.setAttribute("newInstall", "true");
+
+  E("subscriptionsBox").hidden = E("all-subscriptions-container").hidden
+    = E("subscriptionInfo").hidden = editMode;
+
+  E("fromWebText").hidden = !editMode || source instanceof abp.Subscription;
+  E("editText").hidden = !(source instanceof abp.Subscription) || source instanceof abp.ExternalSubscription;
+  E("externalText").hidden = !(source instanceof abp.ExternalSubscription);
+  E("differentSubscription").hidden = !editMode;
+  document.documentElement.getButton("extra2").hidden = editMode;
+
+  setCustomSubscription(source.title, source.url,
+                        source.mainSubscriptionTitle, source.mainSubscriptionURL);
+
+  if (source instanceof abp.Subscription)
+  {
+    document.title = document.documentElement.getAttribute("edittitle");
+    document.documentElement.getButton("accept").setAttribute("label", document.documentElement.getAttribute("buttonlabelacceptedit"))
+  }
+
+  if (source instanceof abp.ExternalSubscription)
+  {
+    E("location").setAttribute("disabled", "true");
+    E("autoDownload").setAttribute("disabled", "true");
+    E("autoDownload").checked = true;
+  }
+  else
+    E("autoDownload").checked = source.autoDownload;
+
+  // Find filter subscription suggestion based on user's browser locale
+  try
+  {
+    appLocale = Cc["@mozilla.org/chrome/chrome-registry;1"].getService(Ci.nsIXULChromeRegistry).getSelectedLocale("adblockplus");
+  }
+  catch (e)
+  {
+    Cu.reportError(e);
+  }
+
+  initialized = true;
+
+  if (!editMode)
+  {
+    let list = E("subscriptions");
+    let items = list.menupopup.childNodes;
+    let selectedItem = null;
+    let selectedPrefix = null;
+    let matchCount = 0;
+    for (let i = 0; i < items.length; i++)
+    {
+      let item = items[i];
+      let prefixes = item.getAttribute("_prefixes");
+      if (!prefixes)
+        continue;
+  
+      if (!selectedItem)
+        selectedItem = item;
+  
+      let prefix = checkPrefixMatch(prefixes, appLocale);
+      if (prefix)
+      {
+        item.setAttribute("class", "localeMatch");
+        if (!selectedPrefix || selectedPrefix.length < prefix.length)
+        {
+          selectedItem = item;
+          selectedPrefix = prefix;
+          matchCount = 1;
+        }
+        else if (selectedPrefix && selectedPrefix.length == prefix.length)
+        {
+          matchCount++;
+
+          // If multiple items have a matching prefix of the same length:
+          // Select one of the items randomly, probability should be the same
+          // for all items. So we replace the previous match here with
+          // probability 1/N (N being the number of matches).
+          if (Math.random() * matchCount < 1)
+          {
+            selectedItem = item;
+            selectedPrefix = prefix;
+          }
+        }
+      }
+    }
+    list.selectedItem = selectedItem;
+
+    // Warn if Adblock or Filterset.G Updater are installed
+    if (isExtensionActive(adblockID))
+      E("adblock-warning").hidden = false;
+  
+    if (isExtensionActive(filtersetG))
+      E("filtersetg-warning").hidden = false;
+  
+    if ("Filterset.G" in filterStorage.knownSubscriptions &&
+        !filterStorage.knownSubscriptions["Filterset.G"].disabled)
+    {
+      E("filtersetg-warning").hidden = false;
+    }
+  }
+
+  // Only resize if we are a chrome window (not loaded into a browser tab)
+  if (window.QueryInterface(Ci.nsIInterfaceRequestor).getInterface(Ci.nsIWebNavigation).QueryInterface(Ci.nsIDocShellTreeItem).itemType == Ci.nsIDocShellTreeItem.typeChrome)
+    suppressResize = false;
+}
+
+function checkPrefixMatch(prefixes, appLocale)
+{
+  if (!prefixes)
+    return null;
+
+  for each (let prefix in prefixes.split(/,/))
+    if (new RegExp("^" + prefix + "\\b").test(appLocale))
+      return prefix;
+
+  return null;
+}
+
+function collapseElements()
+{
+  if (!suppressResize && window.windowState == Ci.nsIDOMChromeWindow.STATE_NORMAL)
+  {
+    let diff = 0;
+    for (let i = 0; i < arguments.length; i++)
+      diff -= arguments[i].boxObject.height;
+    window.resizeBy(0, diff);
+    window.moveBy(0, -diff/2);
+  }
+  for (let i = 0; i < arguments.length; i++)
+    arguments[i].hidden = true;
+}
+
+function showElements()
+{
+  for (let i = 0; i < arguments.length; i++)
+    arguments[i].hidden = false;
+
+  let scrollBox = E("content-scroll").boxObject;
+  if (!suppressResize && window.windowState == Ci.nsIDOMChromeWindow.STATE_NORMAL && scrollBox instanceof Ci.nsIScrollBoxObject)
+  {
+    // Force reflow
+    for (let i = 0; i < arguments.length; i++)
+      arguments[i].boxObject.height;
+
+    let scrollHeight = {};
+    scrollBox.getScrolledSize({}, scrollHeight);
+    if (scrollHeight.value > scrollBox.height)
+    {
+      let diff = scrollHeight.value - scrollBox.height;
+      window.resizeBy(0, diff);
+      window.moveBy(0, -diff/2);
+    }
+  }
+}
+
+function onSelectionChange()
+{
+  if (!initialized)
+    return;
+
+  let selectedSubscription = E("subscriptions").value;
+
+  // Show/hide extra UI widgets for custom subscriptions, resize window appropriately
+  let container = E("all-subscriptions-container");
+  let inputFields = E("differentSubscription");
+  if (container.hidden && !selectedSubscription)
+    showElements(container, inputFields);
+  else if (!container.hidden && selectedSubscription)
+    collapseElements(container, inputFields);
+
+  // Make sure to hide "Add different subscription button" if we are already in that mode
+  document.documentElement.getButton("extra2").hidden = !selectedSubscription;
+
+  if (!selectedSubscription)
+  {
+    loadSubscriptionList();
+    E("title").focus();
+  }
+
+  updateSubscriptionInfo();
+}
+
+function updateSubscriptionInfo()
+{
+  let selectedSubscription = E("subscriptions").selectedItem;
+  if (!selectedSubscription.value)
+    selectedSubscription = E("all-subscriptions").selectedItem;
+
+  E("subscriptionInfo").setAttribute("invisible", !selectedSubscription);
+  if (selectedSubscription)
+  {
+    let url = selectedSubscription.getAttribute("_url");
+    let homePage = selectedSubscription.getAttribute("_homepage")
+
+    let viewLink = E("view-list");
+    viewLink.setAttribute("_url", url);
+    viewLink.setAttribute("tooltiptext", url);
+
+    let homePageLink = E("visit-homepage");
+    homePageLink.hidden = !homePage;
+    if (homePage)
+    {
+      homePageLink.setAttribute("_url", homePage);
+      homePageLink.setAttribute("tooltiptext", homePage);
+    }
+  }
+}
+
+function reloadSubscriptionList()
+{
+  subscriptionListLoading = false;
+  loadSubscriptionList();
+}
+
+function loadSubscriptionList()
+{
+  if (subscriptionListLoading)
+    return;
+
+  E("all-subscriptions-container").selectedIndex = 0;
+
+  let request = new XMLHttpRequest();
+  let errorHandler = function()
+  {
+    E("all-subscriptions-container").selectedIndex = 2;
+  };
+  let successHandler = function()
+  {
+    if (!request.responseXML || request.responseXML.documentElement.localName != "subscriptions")
+    {
+      errorHandler();
+      return;
+    }
+
+    try
+    {
+      processSubscriptionList(request.responseXML);
+    }
+    catch (e)
+    {
+      Cu.reportError(e);
+      errorHandler();
+    }
+  };
+
+  request.open("GET", abp.prefs.subscriptions_listurl);
+  request.onerror = errorHandler;
+  request.onload = successHandler;
+  request.send(null);
+
+  subscriptionListLoading = true;
+}
+
+function processSubscriptionList(doc)
+{
+  let list = E("all-subscriptions");
+  while (list.firstChild)
+    list.removeChild(list.firstChild);
+
+  addSubscriptions(list, doc.documentElement, 0, null, null);
+  E("all-subscriptions-container").selectedIndex = 1;
+}
+
+function addSubscriptions(list, parent, level, parentTitle, parentURL)
+{
+  for (let i = 0; i < parent.childNodes.length; i++)
+  {
+    let node = parent.childNodes[i];
+    if (node.nodeType != Node.ELEMENT_NODE || node.localName != "subscription")
+      continue;
+
+    if (node.getAttribute("type") != "ads" || node.getAttribute("deprecated") == "true")
+      continue;
+
+    let variants = node.getElementsByTagName("variants");
+    if (!variants.length || !variants[0].childNodes.length)
+      continue;
+    variants = variants[0].childNodes;
+
+    let isFirst = true;
+    let mainTitle = null;
+    let mainURL = null;
+    for (let j = 0; j < variants.length; j++)
+    {
+      let variant = variants[j];
+      if (variant.nodeType != Node.ELEMENT_NODE || variant.localName != "variant")
+        continue;
+
+      let item = document.createElement("richlistitem");
+      item.setAttribute("_title", variant.getAttribute("title"));
+      item.setAttribute("_url", variant.getAttribute("url"));
+      if (parentTitle && parentURL && variant.getAttribute("complete") != "true")
+      {
+        item.setAttribute("_supplementForTitle", parentTitle);
+        item.setAttribute("_supplementForURL", parentURL);
+      }
+      item.setAttribute("tooltiptext", variant.getAttribute("url"));
+      item.setAttribute("_homepage", node.getAttribute("homepage"));
+
+      let title = document.createElement("description");
+      if (isFirst)
+      {
+        if (checkPrefixMatch(node.getAttribute("prefixes"), appLocale))
+          title.setAttribute("class", "title localeMatch");
+        else
+          title.setAttribute("class", "title");
+        title.textContent = node.getAttribute("title");
+        mainTitle = variant.getAttribute("title");
+        mainURL = variant.getAttribute("url");
+        isFirst = false;
+      }
+      title.setAttribute("flex", "1");
+      title.style.marginLeft = (20 * level) + "px";
+      item.appendChild(title);
+  
+      let variantTitle = document.createElement("description");
+      variantTitle.setAttribute("class", "variant");
+      variantTitle.textContent = variant.getAttribute("title");
+      variantTitle.setAttribute("crop", "end");
+      item.appendChild(variantTitle);
+
+      list.appendChild(item);
+    }
+
+    let supplements = node.getElementsByTagName("supplements");
+    if (supplements.length)
+      addSubscriptions(list, supplements[0], level + 1, mainTitle, mainURL);
+  }
+}
+
+function onAllSelectionChange()
+{
+  let selectedItem = E("all-subscriptions").selectedItem;
+  if (!selectedItem)
+    return;
+
+  setCustomSubscription(selectedItem.getAttribute("_title"), selectedItem.getAttribute("_url"),
+                        selectedItem.getAttribute("_supplementForTitle"), selectedItem.getAttribute("_supplementForURL"));
+
+  updateSubscriptionInfo();
+}
+
+function setCustomSubscription(title, url, mainSubscriptionTitle, mainSubscriptionURL)
+{
+  E("title").value = title;
+  E("location").value = url;
+
+  let messageElement = E("supplementMessage");
+  let addMainCheckbox = E("addMainSubscription");
+  if (mainSubscriptionURL && !hasSubscription(mainSubscriptionURL))
+  {
+    if (messageElement.hidden)
+      showElements(messageElement, addMainCheckbox);
+
+    let beforeLink, afterLink;
+    if (/(.*)\?1\?(.*)/.test(messageElement.getAttribute("_textTemplate")))
+      [beforeLink, afterLink] = [RegExp.$1, RegExp.$2, RegExp.$3];
+    else
+      [beforeLink, afterLink] = [messageElement.getAttribute("_textTemplate"), ""];
+
+    while (messageElement.firstChild)
+      messageElement.removeChild(messageElement.firstChild);
+    messageElement.appendChild(document.createTextNode(beforeLink));
+    let link = document.createElement("label");
+    link.className = "text-link";
+    link.setAttribute("tooltiptext", mainSubscriptionURL);
+    link.addEventListener("click", function() abp.loadInBrowser(mainSubscriptionURL), false);
+    link.textContent = mainSubscriptionTitle;
+    messageElement.appendChild(link);
+    messageElement.appendChild(document.createTextNode(afterLink));
+    
+    addMainCheckbox.value = mainSubscriptionURL;
+    addMainCheckbox.setAttribute("_mainSubscriptionTitle", mainSubscriptionTitle)
+    addMainCheckbox.label = addMainCheckbox.getAttribute("_labelTemplate").replace(/\?1\?/g, mainSubscriptionTitle);
+    addMainCheckbox.accessKey = addMainCheckbox.accessKey;
+  }
+  else if (!messageElement.hidden)
+    collapseElements(messageElement, addMainCheckbox);
+}
+
+function selectCustomSubscription()
+{
+  let list = E("subscriptions")
+  list.selectedItem = list.menupopup.lastChild;
+}
+
+function validateURL(url)
+{
+  url = url.replace(/^\s+/, "").replace(/\s+$/, "");
+
+  // Is this a file path?
+  try {
+    let file = Cc["@mozilla.org/file/local;1"].createInstance(Ci.nsILocalFile);
+    file.initWithPath(url);
+    return Cc["@mozilla.org/network/io-service;1"].getService(Ci.nsIIOService).newFileURI(file).spec;
+  } catch (e) {}
+
+  // Is this a valid URL?
+  let uri = abp.makeURL(url);
+  if (uri)
+    return uri.spec;
+
+  return null;
+}
+
+function addSubscription()
+{
+  let list = E("subscriptions");
+  let url;
+  let title;
+  let autoDownload;
+  if (list.value)
+  {
+    url = list.value;
+    title = list.label;
+    autoDownload = true;
+  }
+  else
+  {
+    url = E("location").value;
+    if (!(source instanceof abp.ExternalSubscription))
+      url = validateURL(url);
+    if (!url)
+    {
+      abp.alert(window, abp.getString("subscription_invalid_location"));
+      E("location").focus();
+      return false;
+    }
+
+    title = E("title").value.replace(/^\s+/, "").replace(/\s+$/, "");
+    if (!title)
+      title = url;
+
+    autoDownload = E("autoDownload").checked;
+  }
+
+  result.url = url;
+  result.title = title;
+  result.autoDownload = autoDownload;
+  result.disabled = source.disabled;
+
+  let addMainCheckbox = E("addMainSubscription")
+  if (!addMainCheckbox.hidden && addMainCheckbox.checked)
+  {
+    result.mainSubscriptionTitle = addMainCheckbox.getAttribute("_mainSubscriptionTitle");
+    result.mainSubscriptionURL = addMainCheckbox.value;
+  }
+
+  if (autoAdd)
+  {
+    abp.addSubscription(result.url, result.title, result.autoDownload, result.disabled);
+    if ("mainSubscriptionURL" in result)
+      abp.addSubscription(result.mainSubscriptionURL, result.mainSubscriptionTitle, result.autoDownload, result.disabled);
+  }
+
+  closing = true;
+  return true;
+}
+
+function hasSubscription(url)
+{
+  return abp.filterStorage.subscriptions.some(function(subscription) subscription instanceof abp.DownloadableSubscription && subscription.url == url);
+}
+
+function checkUnload()
+{
+  if (newInstall && !closing)
+    return abp.getString("subscription_notAdded_warning");
+
+  return undefined;
+}
+
+function onDialogCancel()
+{
+  let message = checkUnload();
+  if (!message)
+    return true;
+
+  message += " " + abp.getString("subscription_notAdded_warning_addendum");
+  closing = abp.confirm(window, message);
+  return closing;
+}
+
+function uninstallExtension(id)
+{
+  let extensionManager = Cc["@mozilla.org/extensions/manager;1"].getService(Ci.nsIExtensionManager);
+  if (extensionManager.getItemForID(id))
+  {
+    let location = extensionManager.getInstallLocation(id);
+    if (location && !location.canAccess)
+    {
+      // Cannot uninstall, need to disable
+      extensionManager.disableItem(id);
+    }
+    else
+    {
+      extensionManager.uninstallItem(id);
+    }
+  }
+}
+
+function isExtensionActive(id)
+{
+  if (!("@mozilla.org/extensions/manager;1" in Cc))
+    return false;
+
+  let extensionManager = Cc["@mozilla.org/extensions/manager;1"].getService(Ci.nsIExtensionManager);
+
+  // First check whether the extension is installed
+  if (!extensionManager.getItemForID(id))
+    return false;
+
+  let ds = extensionManager.datasource;
+  let rdfService = Cc["@mozilla.org/rdf/rdf-service;1"].getService(Ci.nsIRDFService);
+  let source = rdfService.GetResource("urn:mozilla:item:" + id);
+
+  // Check whether extension is disabled
+  let link = rdfService.GetResource("http://www.mozilla.org/2004/em-rdf#isDisabled");
+  let target = ds.GetTarget(source, link, true);
+  if (target instanceof Ci.nsIRDFLiteral && target.Value == "true")
+    return false;
+
+  // Check whether an operation is pending for the extension
+  link = rdfService.GetResource("http://www.mozilla.org/2004/em-rdf#opType");
+  if (ds.GetTarget(source, link, false))
+    return false;
+
+  return true;
+}
+
+function uninstallAdblock()
+{
+  uninstallExtension(adblockID);
+  E("adblock-warning").hidden = true;
+}
+
+function uninstallFiltersetG()
+{
+  // Disable further updates
+  abp.denyFiltersetG = true;
+
+  // Uninstall extension
+  uninstallExtension(filtersetG);
+
+  // Remove filter subscription
+  if ("Filterset.G" in filterStorage.knownSubscriptions)
+    filterStorage.removeSubscription(filterStorage.knownSubscriptions["Filterset.G"]);
+
+  E("filtersetg-warning").hidden = true;
+}

=== added file 'chrome/content/ui/subscriptionSelection.xul'
--- chrome/content/ui/subscriptionSelection.xul	1970-01-01 00:00:00 +0000
+++ chrome/content/ui/subscriptionSelection.xul	2010-05-04 14:45:07 +0000
@@ -0,0 +1,115 @@
+<?xml version="1.0"?>
+
+<!-- ***** BEGIN LICENSE BLOCK *****
+   - Version: MPL 1.1
+   -
+   - The contents of this file are subject to the Mozilla Public License Version
+   - 1.1 (the "License"); you may not use this file except in compliance with
+   - the License. You may obtain a copy of the License at
+   - http://www.mozilla.org/MPL/
+   -
+   - Software distributed under the License is distributed on an "AS IS" basis,
+   - WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+   - for the specific language governing rights and limitations under the
+   - License.
+   -
+   - The Original Code is Adblock Plus.
+   -
+   - The Initial Developer of the Original Code is
+   - Wladimir Palant.
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
+   - the Initial Developer. All Rights Reserved.
+   -
+   - Contributor(s):
+   -
+   - ***** END LICENSE BLOCK ***** -->
+
+<?xml-stylesheet href="chrome://global/skin/" type="text/css"?>
+<?xml-stylesheet href="chrome://adblockplus/skin/subscriptionSelection.css" type="text/css"?>
+
+<!DOCTYPE dialog SYSTEM "chrome://adblockplus/locale/subscriptionSelection.dtd">
+
+<dialog
+  xmlns="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"
+  buttons="accept,cancel,extra2"
+  buttonlabelaccept="&addSubscription.label;"
+  buttonlabelacceptedit="&saveSubscription.label;"
+  buttonlabelextra2="&other.label;"
+  buttonaccesskeyextra2="&other.accesskey;"
+  title="&dialog.title;"
+  edittitle="&dialog.title.edit;"
+  id="abpSubscriptionSelection"
+  windowtype="abp:subscriptionSelection"
+  onload="init()"
+  onbeforeunload="return checkUnload()"
+  ondialogcancel="return onDialogCancel()"
+  ondialogaccept="return addSubscription()"
+  ondialogextra2="selectCustomSubscription()">
+
+<script type="application/x-javascript;version=1.7" src="utils.js"/>
+<script type="application/x-javascript;version=1.7" src="subscriptionSelection.js"/>
+
+<scrollbox id="content-scroll" orient="vertical" flex="1">
+  <description id="description-newInstall">&description.newInstall;</description>
+  <hbox id="adblock-warning" align="center" hidden="true">
+    <button id="adblock-uninstall" label="&adblock.uninstall;" oncommand="uninstallAdblock()"/>
+    <description flex="1">&adblock.warning;</description>
+  </hbox>
+  <hbox id="filtersetg-warning" align="center" hidden="true">
+    <button id="filtersetg-uninstall" label="&filterset.g.uninstall;" oncommand="uninstallFiltersetG()"/>
+    <description flex="1">
+      &filterset.g.warning;
+      <label class="text-link" _url="&filterset.g.moreinfo.url;" tooltiptext="&filterset.g.moreinfo.url;" value="&filterset.g.moreinfo;" onclick="abp.loadInBrowser(this.getAttribute('_url'))"/>
+    </description>
+  </hbox>
+  
+  <vbox id="subscriptionsBox">
+    <label control="subscriptions">&subscriptionSelector.label;</label>
+    <menulist id="subscriptions" label=" " onselect="onSelectionChange()">
+      <menupopup datasources="subscriptions.xml" ref="*" querytype="xml">
+        <template>
+          <menuitem uri="?" label="?title" value="?url" _url="?url" _homepage="?homepage" _prefixes="?prefixes"/>
+        </template>
+      </menupopup>
+    </menulist>
+  </vbox>
+  
+  <deck id="all-subscriptions-container" selectedIndex="0" flex="1" hidden="true">
+    <vbox pack="center">
+      <progressmeter id="all-subscriptions-loading" mode="undetermined"/>
+    </vbox>
+    <richlistbox id="all-subscriptions" onselect="onAllSelectionChange()"/>
+    <vbox pack="center" align="center">
+      <description value="&list.download.failed;"/>
+      <hbox>
+        <button label="&list.download.retry;" oncommand="reloadSubscriptionList()"/>
+        <button label="&list.download.website;" _url="&list.website.url;" oncommand="abp.loadInBrowser(this.getAttribute('_url'))"/>
+      </hbox>
+    </vbox>
+  </deck>
+  
+  <hbox id="subscriptionInfo" invisible="true">
+    <label id="view-list" class="text-link" value="&viewList.label;" onclick="abp.loadInBrowser(this.getAttribute('_url'))"/>
+    <spacer flex="1"/>
+    <label id="visit-homepage" class="text-link" value="&visitHomepage.label;" onclick="abp.loadInBrowser(this.getAttribute('_url'))"/>
+  </hbox>
+  
+  <description id="fromWebText" hidden="true">&fromWeb.description;</description>
+  <description id="editText" hidden="true">&edit.description;</description>
+  <description id="externalText" hidden="true">&external.description;</description>
+
+  <groupbox id="differentSubscription" hidden="true">
+    <label value="&title.label;" accesskey="&title.accesskey;" control="title"/>
+    <textbox id="title"/>
+  
+    <label value="&location.label;" accesskey="&location.accesskey;" control="location"/>
+    <textbox id="location"/>
+
+    <checkbox id="autoDownload" label="&autodownload.label;" accesskey="&autodownload.accesskey;"/>
+  </groupbox>
+
+  <description id="supplementMessage" hidden="true" _textTemplate="&supplementMessage;">&supplementMessage;</description>
+  <checkbox id="addMainSubscription" hidden="true" checked="true" _labelTemplate="&addMain.label;" label="&addMain.label;" accesskey="&addMain.accesskey;"/>
+</scrollbox>
+
+</dialog>

=== modified file 'chrome/content/ui/subscriptions.xml'
--- chrome/content/ui/subscriptions.xml	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/subscriptions.xml	2010-05-04 14:45:07 +0000
@@ -1,31 +1,56 @@
 <?xml version="1.0"?>
 
+<!DOCTYPE subscriptions SYSTEM "chrome://adblockplus/locale/subscriptionSelection.dtd">
+
 <subscriptions>
-  <subscription title="EasyList (USA)"
+  <subscription title="EasyList (English)"
                 url="https://easylist-downloads.adblockplus.org/easylist.txt"
-                homepage="http://easylist.adblockplus.org/"/>
-  <subscription title="EasyList Germany (Deutschland) + EasyList"
+                homepage="http://easylist.adblockplus.org/"
+                prefixes="en"
+                author="Ares2, Michael, Erunno"/>
+  <subscription title="ChinaList (汉语)"
+                url="http://adblock-chinalist.googlecode.com/svn/trunk/adblock.txt"
+                homepage="http://code.google.com/p/adblock-chinalist/"
+                prefixes="zh"
+                author="Gythialy"/>
+  <subscription title="EasyList Germany+EasyList (Deutsch)"
                 url="https://easylist-downloads.adblockplus.org/ares+easylist.txt"
-                homepage="http://forums.lanik.us/viewforum.php?f=90"/>
-  <subscription title="Liste FR (France) + EasyList"
+                homepage="http://easylist.adblockplus.org/"
+                prefixes="de"
+                author="Ares2, Erunno"/>
+  <subscription title="Fanboy's List (English)"
+                url="http://www.fanboy.co.nz/adblock/fanboy-adblocklist-current-expanded.txt"
+                homepage="http://www.fanboy.co.nz/adblock/"
+                prefixes="en"
+                author="fanboy, Hubird"/>
+  <subscription title="Filter von Dr.Evil (Deutsch)"
+                url="http://adblock.maltekraus.de/adblock.txt"
+                homepage="http://www.camp-firefox.de/forum/viewtopic.php?t=55998"
+                prefixes="de"
+                author="Dr.Evil"/>
+  <subscription title="Liste FR+EasyList (français)"
                 url="https://easylist-downloads.adblockplus.org/liste_fr+easylist.txt"
-                homepage="http://forums.lanik.us/viewforum.php?f=91"/>
-  <subscription title="ChinaList (中国)"
-                url="http://adblock-chinalist.googlecode.com/svn/trunk/adblock.txt"
-                homepage="http://code.google.com/p/adblock-chinalist/"/>
-  <subscription title="Filter von Dr.Evil (Deutschland)"
-                url="http://maltekraus.de/Firefox/adblock.txt"
-                homepage="http://www.camp-firefox.de/forum/viewtopic.php?t=55998"/>
-  <subscription title="Morpeh Rus List (Россия) + EasyList"
-                url="https://easylist-downloads.adblockplus.org/morpeh+easylist.txt"
-                homepage="http://adblockplus.mihalkin.ru/"/>
-  <subscription title="Corset (Korea) + EasyList"
-                url="https://easylist-downloads.adblockplus.org/corset+easylist.txt"
-                homepage="http://www.brianyi.com/corset/"/>
-  <subscription title="ROList (România) + EasyList"
+                homepage="http://forums.lanik.us/viewforum.php?f=91"
+                prefixes="fr"
+                author="Lian"/>
+  <subscription title="ROList+EasyList (românesc)"
                 url="https://easylist-downloads.adblockplus.org/rolist+easylist.txt"
-                homepage="http://www.picpoc.ro/"/>
-  <subscription title="Việt Nam List (Việt Nam) + EasyList"
+                homepage="http://www.picpoc.ro/"
+                prefixes="ro"
+                author="MenetZ"/>
+  <subscription title="RuAdList (русский, українська)"
+                url="http://ruadlist.googlecode.com/svn/trunk/adblock.txt"
+                homepage="http://code.google.com/p/ruadlist/"
+                prefixes="ru,uk"
+                author="Lain_13"/>
+  <subscription title="Việt Nam List+EasyList (Việt)"
                 url="https://easylist-downloads.adblockplus.org/abpvn+easylist.txt"
-                homepage="http://code.google.com/p/adblockplus-vietnam/"/>
+                homepage="http://code.google.com/p/adblockplus-vietnam/"
+                prefixes="vi"
+                author="NGUYỄN Mạnh Hùng"/>
+  <subscription title="&other.label;…"
+                url=""
+                homepage=""
+                prefixes=""
+                author=""/>
 </subscriptions>

=== added file 'chrome/content/ui/thunderbirdOverlay.xul'
--- chrome/content/ui/thunderbirdOverlay.xul	1970-01-01 00:00:00 +0000
+++ chrome/content/ui/thunderbirdOverlay.xul	2010-05-04 14:45:07 +0000
@@ -0,0 +1,72 @@
+<?xml version="1.0"?>
+
+<!-- ***** BEGIN LICENSE BLOCK *****
+   - Version: MPL 1.1
+   -
+   - The contents of this file are subject to the Mozilla Public License Version
+   - 1.1 (the "License"); you may not use this file except in compliance with
+   - the License. You may obtain a copy of the License at
+   - http://www.mozilla.org/MPL/
+   -
+   - Software distributed under the License is distributed on an "AS IS" basis,
+   - WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+   - for the specific language governing rights and limitations under the
+   - License.
+   -
+   - The Original Code is Adblock Plus.
+   -
+   - The Initial Developer of the Original Code is
+   - Wladimir Palant.
+   - Portions created by the Initial Developer are Copyright (C) 2006-2010
+   - the Initial Developer. All Rights Reserved.
+   -
+   - Contributor(s):
+   -
+   - ***** END LICENSE BLOCK ***** -->
+
+<?xul-overlay href="chrome://adblockplus/content/ui/overlayGeneral.xul"?>
+
+<overlay id="abp-overlay" xmlns="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul">
+  <!-- Window extensions -->
+  <window id="messengerWindow">
+    <popupset id="abp-popupset"/>
+    <keyset id="abp-keyset"/>
+    <commandset id="abp-commandset"/>
+    <box id="abp-hooks" getBrowser="return window.messageContent;"
+      addTab="E('tabmail').openTab('contentTab', {contentPage: arguments[0]});"
+      getContextMenu="return E('messagePaneContext');"
+      getToolbox="return E('mail-toolbox')"
+      getDefaultToolbar="return E('mail-bar3');" toolbarInsertBefore="return E('button-tag');"/>
+  </window>
+
+  <!-- Status bar -->
+  <statusbar id="status-bar">
+    <statusbarpanel id="abp-status"/>
+  </statusbar> 
+
+  <!-- Toolbar -->
+  <toolbar id="header-view-toolbar">
+    <toolbarbutton id="abp-toolbarbutton" type="menu-button" insertbefore="hdrReplyButton"
+        class="toolbarbutton-1 msgHeaderView-button"/>
+  </toolbar>
+
+  <!-- Tools menu -->
+  <menupopup id="taskPopup">
+    <menuitem id="abp-menuitem" insertafter="downloadmgr,javaScriptConsole"/>
+  </menupopup>
+
+  <!-- Context menu -->
+  <popup id="messagePaneContext">
+    <menuitem id="abp-image-menuitem"/>
+    <menuitem id="abp-object-menuitem"/>
+    <menuitem id="abp-media-menuitem"/>
+    <menuitem id="abp-frame-menuitem"/>
+    <menuitem id="abp-removeWhitelist-menuitem"/>
+  </popup>
+
+  <!-- Fake sidebar -->
+  <vbox id="messagepanebox">
+    <splitter id="abp-sidebar-splitter"/>
+    <vbox id="abp-sidebar"/>
+  </vbox>
+</overlay>

=== removed file 'chrome/content/ui/tip_subscriptions.js'
--- chrome/content/ui/tip_subscriptions.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/tip_subscriptions.js	1970-01-01 00:00:00 +0000
@@ -1,164 +0,0 @@
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is Adblock Plus.
- *
- * The Initial Developer of the Original Code is
- * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *
- * ***** END LICENSE BLOCK ***** */
-
-let autoAdd;
-let result;
-
-let adblockID = "{34274bf4-1d97-a289-e984-17e546307e4f}";
-let filtersetG = "filtersetg@updater";
-
-function init()
-{
-  autoAdd = !("arguments" in window && window.arguments && window.arguments.length);
-  result = (autoAdd ? {disabled: false, external: false, autoDownload: true} : window.arguments[0]);
-  document.getElementById("description-par1").hidden = !autoAdd;
-
-  if (isExtensionActive(adblockID))
-    document.getElementById("adblock-warning").hidden = false;
-
-  if (isExtensionActive(filtersetG))
-    document.getElementById("filtersetg-warning").hidden = false;
-
-  if ("Filterset.G" in filterStorage.knownSubscriptions &&
-      !filterStorage.knownSubscriptions["Filterset.G"].disabled)
-  {
-    document.getElementById("filtersetg-warning").hidden = false;
-  }
-
-  document.getElementById("subscriptions").selectedIndex = 0;
-}
-
-function addSubscriptions() {
-  var group = document.getElementById("subscriptions");
-  var selected = group.selectedItem;
-  if (!selected)
-    return;
-
-  result.url = selected.getAttribute("_url");
-  result.title = selected.getAttribute("_title");
-  result.autoDownload = true;
-  result.disabled = false;
-
-  if (autoAdd)
-    abp.addSubscription(result.url, result.title, result.autoDownload, result.disabled);
-}
-
-function addOther() {
-  openDialog("subscription.xul", "_blank", "chrome,centerscreen,modal", null, result);
-  if ("url" in result)
-  {
-    if (autoAdd)
-      abp.addSubscription(result.url, result.title, result.autoDownload, result.disabled);
-    window.close();
-  }
-}
-
-function handleKeyPress(e) {
-  switch (e.keyCode) {
-    case e.DOM_VK_PAGE_UP:
-    case e.DOM_VK_PAGE_DOWN:
-    case e.DOM_VK_END:
-    case e.DOM_VK_HOME:
-    case e.DOM_VK_LEFT:
-    case e.DOM_VK_RIGHT:
-    case e.DOM_VK_UP:
-    case e.DOM_VK_DOWN:
-      return false;
-  }
-  return true;
-}
-
-function handleCommand(event)
-{
-  let scrollBox = document.getElementById("subscriptionsScrollbox")
-                          .boxObject
-                          .QueryInterface(Ci.nsIScrollBoxObject);
-  scrollBox.ensureElementIsVisible(event.target);
-  scrollBox.ensureElementIsVisible(event.target.nextSibling);
-}
-
-function uninstallExtension(id)
-{
-  let extensionManager = Cc["@mozilla.org/extensions/manager;1"].getService(Ci.nsIExtensionManager);
-  if (extensionManager.getItemForID(id))
-  {
-    let location = extensionManager.getInstallLocation(id);
-    if (location && !location.canAccess)
-    {
-      // Cannot uninstall, need to disable
-      extensionManager.disableItem(id);
-    }
-    else
-    {
-      extensionManager.uninstallItem(id);
-    }
-  }
-}
-
-function isExtensionActive(id)
-{
-  let extensionManager = Cc["@mozilla.org/extensions/manager;1"].getService(Ci.nsIExtensionManager);
-
-  // First check whether the extension is installed
-  if (!extensionManager.getItemForID(id))
-    return false;
-
-  let ds = extensionManager.datasource;
-  let rdfService = Cc["@mozilla.org/rdf/rdf-service;1"].getService(Ci.nsIRDFService);
-  let source = rdfService.GetResource("urn:mozilla:item:" + id);
-
-  // Check whether extension is disabled
-  let link = rdfService.GetResource("http://www.mozilla.org/2004/em-rdf#isDisabled");
-  let target = ds.GetTarget(source, link, true);
-  if (target instanceof Ci.nsIRDFLiteral && target.Value == "true")
-    return false;
-
-  // Check whether an operation is pending for the extension
-  link = rdfService.GetResource("http://www.mozilla.org/2004/em-rdf#opType");
-  if (ds.GetTarget(source, link, false))
-    return false;
-
-  return true;
-}
-
-function uninstallAdblock()
-{
-  uninstallExtension(adblockID);
-  document.getElementById("adblock-warning").hidden = true;
-}
-
-function uninstallFiltersetG()
-{
-  // Disable further updates
-  abp.denyFiltersetG = true;
-
-  // Uninstall extension
-  uninstallExtension(filtersetG);
-
-  // Remove filter subscription
-  if ("Filterset.G" in filterStorage.knownSubscriptions)
-    filterStorage.removeSubscription(filterStorage.knownSubscriptions["Filterset.G"]);
-
-  document.getElementById("filtersetg-warning").hidden = true;
-}

=== removed file 'chrome/content/ui/tip_subscriptions.xul'
--- chrome/content/ui/tip_subscriptions.xul	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/tip_subscriptions.xul	1970-01-01 00:00:00 +0000
@@ -1,102 +0,0 @@
-<?xml version="1.0"?>
-
-<!-- ***** BEGIN LICENSE BLOCK *****
-   - Version: MPL 1.1
-   -
-   - The contents of this file are subject to the Mozilla Public License Version
-   - 1.1 (the "License"); you may not use this file except in compliance with
-   - the License. You may obtain a copy of the License at
-   - http://www.mozilla.org/MPL/
-   -
-   - Software distributed under the License is distributed on an "AS IS" basis,
-   - WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
-   - for the specific language governing rights and limitations under the
-   - License.
-   -
-   - The Original Code is Adblock Plus.
-   -
-   - The Initial Developer of the Original Code is
-   - Wladimir Palant.
-   - Portions created by the Initial Developer are Copyright (C) 2006-2009
-   - the Initial Developer. All Rights Reserved.
-   -
-   - Contributor(s):
-   -
-   - ***** END LICENSE BLOCK ***** -->
-
-<?xml-stylesheet href="chrome://global/skin/" type="text/css"?>
-<?xml-stylesheet href="chrome://adblockplus/skin/tip_subscriptions.css" type="text/css"?>
-
-<!DOCTYPE dialog SYSTEM "chrome://adblockplus/locale/tip_subscriptions.dtd">
-
-<dialog
-  xmlns="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"
-  buttons="accept,cancel,extra2"
-  buttonlabelaccept="&subscribe.label;"
-  buttonaccesskeyaccept="&subscribe.accesskey;"
-  buttonlabelextra2="&other.label;"
-  buttonaccesskeyextra2="&other.accesskey;"
-  title="&dialog.title;"
-  id="abpTipSubscriptions"
-  windowtype="abp:tip:subscriptions"
-  width="550"
-  height="500"
-  onload="init()"
-  ondialogaccept="addSubscriptions()"
-  ondialogextra2="addOther()">
-
-<script type="application/x-javascript;version=1.7" src="utils.js"/>
-<script type="application/x-javascript;version=1.7" src="tip_subscriptions.js"/>
-
-<hbox>
-  <vbox flex="1">
-    <description id="description-par1">&description.par1;</description>
-    <vbox id="adblock-warning" hidden="true">
-      <description>&adblock.warning;</description>
-      <hbox>
-        <button id="adblock-uninstall" label="&adblock.uninstall;" oncommand="uninstallAdblock()"/>
-      </hbox>
-    </vbox>
-    <vbox id="filtersetg-warning" hidden="true">
-      <description>
-        &filterset.g.warning;
-        <description class="moreinfo" _url="&filterset.g.moreinfo.url;" tooltiptext="&filterset.g.moreinfo.url;" value="&filterset.g.moreinfo;" onclick="abp.loadInBrowser(this.getAttribute('_url'))"/>
-      </description>
-      <hbox>
-        <button id="filtersetg-uninstall" label="&filterset.g.uninstall;" oncommand="uninstallFiltersetG()"/>
-      </hbox>
-    </vbox>
-    <description id="description-par2">&description.par2;</description>
-  </vbox>
-  <vbox>
-    <vbox flex="1" pack="center">
-      <hbox pack="center">
-        <image id="icon"/>
-      </hbox>
-    </vbox>
-    <description class="fulllist" _url="&full-list.url;" tooltiptext="&full-list.url;" value="&full-list.label;" onclick="abp.loadInBrowser(this.getAttribute('_url'))"/>
-  </vbox>
-</hbox>
-
-<radiogroup id="subscriptions" flex="1" onkeypress="return handleKeyPress(event)" oncommand="handleCommand(event)">
-  <scrollbox id="subscriptionsScrollbox" flex="1" orient="vertical" datasources="subscriptions.xml" ref="*" querytype="xml">
-    <template>
-      <hbox uri="?" class="container" align="center">
-        <radio _title="?title" _url="?url"/>
-        <vbox flex="1" onclick="this.previousSibling.radioGroup.selectedItem = this.previousSibling;">
-          <hbox>
-            <description class="title" value="?title" flex="1"/>
-            <description class="homepage" _url="?homepage" tooltiptext="?homepage" value="&homepage.label;" onclick="abp.loadInBrowser(this.getAttribute('_url'));event.stopPropagation();"/>
-          </hbox>
-          <hbox pack="start">
-            <description class="location" value="?url" onclick="abp.loadInBrowser(this.getAttribute('value'));event.stopPropagation();"/>
-          </hbox>
-        </vbox>
-      </hbox>
-    </template>
-  </scrollbox>
-</radiogroup>
-
-<description flex="1" id="note">&note;</description>
-
-</dialog>

=== modified file 'chrome/content/ui/utils.js'
--- chrome/content/ui/utils.js	2010-01-07 17:25:17 +0000
+++ chrome/content/ui/utils.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):

=== modified file 'chrome/content/utils.js'
--- chrome/content/utils.js	2010-01-07 17:25:17 +0000
+++ chrome/content/utils.js	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -27,15 +27,58 @@
  * This file is included from AdblockPlus.js.
  */
 
-var threadManager = Cc["@mozilla.org/thread-manager;1"].getService(Ci.nsIThreadManager);
-
-// String service
-var stringService = Cc["@mozilla.org/intl/stringbundle;1"].getService(Ci.nsIStringBundleService);
-var strings = stringService.createBundle("chrome://adblockplus/locale/global.properties");
-abp.getString = function(name) {
+XPCOMUtils.defineLazyServiceGetter(this, "threadManager", "@mozilla.org/thread-manager;1", "nsIThreadManager");
+
+var strings = null;
+
+/**
+ * Retrieves a string from global.properties string bundle, will throw if string isn't found.
+ * 
+ * @param {String} name  string name
+ * @return {String}
+ */
+abp.getString = function(name)
+{
+  if (!strings)
+  {
+    strings = Cc["@mozilla.org/intl/stringbundle;1"]
+                .getService(Ci.nsIStringBundleService)
+                .createBundle("chrome://adblockplus/locale/global.properties");
+  }
   return strings.GetStringFromName(name);
 };
 
+/**
+ * Shows an alert message like window.alert() but with a custom title.
+ * 
+ * @param {Window} parentWindow  parent window of the dialog (can be null)
+ * @param {String} message  message to be displayed
+ * @param {String} [title]  dialog title, default title will be used if omitted
+ */
+function alert(parentWindow, message, title)
+{
+  if (!title)
+    title = abp.getString("default_dialog_title");
+  Cc["@mozilla.org/embedcomp/prompt-service;1"].getService(Ci.nsIPromptService).alert(parentWindow, title, message);
+}
+abp.alert = alert;
+
+/**
+ * Asks the user for a confirmation like window.confirm() but with a custom title.
+ * 
+ * @param {Window} parentWindow  parent window of the dialog (can be null)
+ * @param {String} message  message to be displayed
+ * @param {String} [title]  dialog title, default title will be used if omitted
+ * @return {Bool}
+ */
+function confirm(parentWindow, message, title)
+{
+  if (!title)
+    title = abp.getString("default_dialog_title");
+  return Cc["@mozilla.org/embedcomp/prompt-service;1"].getService(Ci.nsIPromptService).confirm(null, title, message);
+}
+abp.confirm = confirm;
+
 // Retrieves the window object for a node or returns null if it isn't possible
 function getWindow(node) {
   if (node && node.nodeType != Node.DOCUMENT_NODE)
@@ -85,32 +128,6 @@
 }
 abp.makeURL = makeURL;
 
-// Generates a click handler for object tabs
-function generateClickHandler(wnd, data) {
-  return function(event) {
-    event.preventDefault();
-    wnd.openDialog("chrome://adblockplus/content/ui/composer.xul", "_blank", "chrome,centerscreen,resizable,dialog=no,dependent", wnd, data); 
-  }
-}
-
-// Creates a tab above/below the new object node
-function addObjectTab(wnd, node, data, tab)
-{
-  if (!node.parentNode)
-    return;
-
-  // Click event handler
-  tab.setAttribute("href", data.location);
-  tab.setAttribute("class", policy.objtabClass);
-  tab.addEventListener("click", generateClickHandler(wnd, data), false);
-
-  // Insert tab into the document
-  if (node.nextSibling)
-    node.parentNode.insertBefore(tab, node.nextSibling);
-  else
-    node.parentNode.appendChild(tab);
-}
-
 /**
  * Posts an action to the event queue of the current thread to run it
  * asynchronously. Any additional parameters to this function are passed

=== modified file 'chrome/locale/ar/about.dtd'
--- chrome/locale/ar/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ar/about.dtd	2010-05-04 14:45:07 +0000
@@ -6,3 +6,7 @@
 <!ENTITY homepage.url "http://adblockplus.org/">
 <!ENTITY author.label "المنفذ">
 <!ENTITY contributors.label "المتطوعين">
+<!ENTITY developers.label "مطورين:">
+<!ENTITY designers.label "مصممي الجرافيكس:">
+<!ENTITY subscriptionAuthors.label "مؤلفو اشتراكات الفلاتر:">
+<!ENTITY translators.label "المترجمون:">

=== modified file 'chrome/locale/ar/composer.dtd'
--- chrome/locale/ar/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ar/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "إضافة فلتر">
 <!ENTITY advanced.label "عرض متقدم">
 <!ENTITY basic.label "عرض أساسي">
-<!ENTITY disabled.warning.beforeLink "آدبلوك بلس معطل حالياً. ما زال يمكنك إضافة الفلاتر و لكن لن يتم تطبيقهم إلا إذا قمت">
-<!ENTITY disabled.warning.link "بتفعيل آدبلوك بلس">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "إن مجموعة الفلاتر &quot;&#37;S&quot; التي تنوي إضافة هذا الفلتر إليها معطلة حالياً. يمكنك إضافة هذا الفلتر ولكنه لن يكون فعالاً إلا في حال">
-<!ENTITY groupDisabled.warning.link "تفعيل مجموعة الفلاتر">
-<!ENTITY groupDisabled.warning.afterLink ".">
+<!ENTITY disabled.warning "آدبلوك بلس معطل حالياً. ما زال يمكنك إضافة الفلاتر و لكن لن يتم تطبيقهم إلا إذا قمت [link]بتفعيل آدبلوك بلس[/link].">
+<!ENTITY groupDisabled.warning "إن مجموعة الفلاتر &quot;?1?&quot; التي تنوي إضافة هذا الفلتر إليها معطلة حالياً. يمكنك إضافة هذا الفلتر ولكنه لن يكون فعالاً إلا في حال [link]تفعيل مجموعة الفلاتر[/link].">
 <!ENTITY filter.label "فلتر جديد :">
 <!ENTITY filter.accesskey "ف">
 <!ENTITY preferences.label "عرض الفلاتر الموجودة...">

=== modified file 'chrome/locale/ar/global.properties'
--- chrome/locale/ar/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/ar/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,13 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=الإعلانات أصبحت من الأمس!
-status_active_label=آدبلوك
-status_disabled_label=تعطيل
+default_dialog_title=Adblock Plus
 action0_tooltip=اضغط لتظهر القائمة المرافقة، اضغط بالزر الأوسط للتشغيل/التعطيل
 action1_tooltip=اضغط لفتح/إغلاق العناصر المحجوبة، اضغط بالزر الأوسط للتشغيل/ التعطيل
 action2_tooltip=اضغط لفتح الخيارات، اضغط بالزر الأوسط للتشغيل/التعطيل
 action3_tooltip=اضغط لتشغيل/تعطيل آدبلوك بلاس
-active_tooltip=آدبلوك بلاس فعال الآن
 disabled_tooltip=آدبلوك بلاس معطل الآن
+active_tooltip=إن آدبلوك بلس مفعل. هناك  ?1? اشتراك فلتر و ?2? فلاتر مخصصة قيد الاستعمال
 whitelisted_tooltip=آدبلوك بلاس فعال الآن، و لكنه معطل بالنسبة لهذه الصفحة
-blocked_count_tooltip=-- خارج عن --
+blocked_count_tooltip=?1? خارج عن ?2?
+blocked_count_addendum=المسموح به ?1? والمخفي ?2?
 no_blocking_suggestions=لا يوجد عناصر للحجب في هذه الصفحة
 whitelisted_page=تم تعطيل آدبلوك بلاس في الصفحة الحالية
 whitelist_description=قوانين الاستثناءات
@@ -16,7 +15,7 @@
 invalid_description=فلاتر خاطئة
 elemhide_description=قوانين إخفاء العنصر
 subscription_description=اشتراك فلتر
-subscription_wrong_version=بعض الفلاتر الموجودة في هذا الاشتراك تتطلب آدبلوك بلاس لتعميل جيداً
+subscription_wrong_version=بعض الفلاتر الموجودة في هذا الاشتراك تتطلب آدبلوك بلس ?1? لتعميل جيداً
 subscription_source=المصدر
 subscription_status=الحالة
 subscription_status_autodownload=تحديث أوتوماتيكي
@@ -26,7 +25,7 @@
 subscription_status_lastdownload_inprogress=جاري التحميل
 subscription_status_lastdownload_unknown=غير متاح
 remove_subscription_warning=هل أنت حقاً راغب بإزالة هذا الاشتراك؟
-import_filters_wrong_version=تحذير : بعض الفلاتر في هذه القائمة تتطلب آدبلوك بلاس لتعميل جيداً. يجب عليك التحديث إلى آخر إصدار من آدبلوك بلاس قبل استيراد هذه القائمة.
+import_filters_wrong_version=تحذير : بعض الفلاتر في هذه القائمة تتطلب آدبلوك بلس ?1? لتعميل جيداً. يجب عليك التحديث إلى آخر إصدار من آدبلوك بلاس قبل استيراد هذه القائمة.
 import_filters_warning=هل تريد استبدال فلاترك الحالية أم إضافة الفلاتر الجديدة في نهاية القائمة؟
 import_filters_title=استيراد فلاتر
 export_filters_title=تصدير فلاتر
@@ -38,9 +37,9 @@
 filter_regexp_tooltip=هذا الفلتر إما "تعبر منطقي" أو أقصر من أن تتم تحسينه. الكثير من هذه الفلاتر قد تؤدي إلى بطء في التصفح
 filter_elemhide_duplicate_id=فقط ID واحد للعنصر الذي سيتم إخفاؤه يمكن أن يحدد
 filter_elemhide_nocriteria=لم يتم تحديد صيغة للتعرف على العنصر لإخفاؤه
-subscription_no_location=الرجاء إدخال الموقع لتحميل الفلاتر منه
+subscription_notAdded_warning=لم تقم بإضافة أي اشتراك فلتر. بدون اشتراك فلتر ستضطر لإضافة الفلاتر يدوياً
+subscription_notAdded_warning_addendum=هل تريد المتابعة؟
 subscription_invalid_location=موقع قائمة الفلتر ليس صحيح كعنوان ويب و لا كاسم ملف
-subscription_location_exists=لقد اشتركت سابقاً في القائمة الخاصة بهذا الفلتر
 synchronize_invalid_url=فشل الأمر، ليس عنوان صحيح
 synchronize_connection_error=فشل الأمر بسبب فشل التحميل
 synchronize_invalid_data=فشل الأمر، ليست قائمة فلاتر صحيحة
@@ -65,3 +64,7 @@
 type_label_dtd=DTD
 type_label_media=صوت\فيديو
 type_label_font=الخط
+fennec_status_enabled=آدبلوك بلس مفعل
+fennec_status_disabled=آدبلوك بلس معطل
+fennec_status_enabled_site=آدبلوك بلس مفعل على ?1?
+fennec_status_disabled_site=آدبلوك بلس معطل على ?1?

=== added file 'chrome/locale/ar/meta.properties'
--- chrome/locale/ar/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ar/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=مؤيد مارديني
+name=Adblock Plus
+description=الإعلانات أصبحت من الأمس!
+description.short=هل أنت مزعوج من الإعلانات و من تتبعك من قبل المواقع ومن كل تلك الشرائط الإعلانية؟ قم بتحميل آدبلوك بلس للتتحكم بتصفحك للويب وتغير الطريقة التي تنظر بها إلى الإنترنت.\n\nفيديو قصير توضيحي متوافر على العنوان:http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=يسمح لك آدبلوك بلس بالتحكم بالإنترنت وبالطريقة التي تنظر بها إلى الويب بالشكل الذي تريده. ان هذه الإضافة مدعومة من أكثر من أربعين اشتراك فلتر في عشرات اللغات والتي يتم ضبطها تلقائيا لفوائد تتراوح بين إزالة الإعلانات إلى حجب المواقع الضارة. يسمح آدبلوك بلس أيضا بتعديل الفلاتر بمساعدة العديد من المزايا الهامة كخيار لإزالة الصور وتبويبة لحجب عناصر الفلاش والجافا وقائمة بالعناصر التي يمكن حجبها لإزالة السكريبتات وملفات الستايل.

=== modified file 'chrome/locale/ar/overlay.dtd'
--- chrome/locale/ar/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ar/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -8,6 +8,7 @@
 <!ENTITY context.image.label "صورة آدبلوك">
 <!ENTITY context.object.label "عنصر آدبلوك">
 <!ENTITY context.frame.label "إطار آدبلوك">
+<!ENTITY context.media.label "آدبلوك بلس : حجب أوديو\فيديو">
 <!ENTITY context.removeWhitelist.label "آدبلوك بلس : إعادة التفعيل في هذه الصفحة">
 <!ENTITY sidebar.title "العناصر المحجوبة في الصفحة الحالية">
 <!ENTITY settings.label "تفضيلات">
@@ -16,7 +17,7 @@
 <!ENTITY opensidebar.accesskey "ج">
 <!ENTITY closesidebar.label "إغلاق العناصر المحجوبة">
 <!ENTITY closesidebar.accesskey "ج">
-<!ENTITY whitelist.site.label "تعطيل">
+<!ENTITY whitelist.site.label "تعطيل على ?1?">
 <!ENTITY whitelist.page.label "تعطيل في هذه الصفحة فقط">
 <!ENTITY objecttab.title "منع">
 <!ENTITY objecttab.tooltip "اضغط هنا لمنع هذا العنصر مع آدبلوك بلاس">

=== modified file 'chrome/locale/ar/settings.dtd'
--- chrome/locale/ar/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ar/settings.dtd	2010-05-04 14:45:07 +0000
@@ -88,3 +88,4 @@
 <!ENTITY context.disable.label "تعطيل">
 <!ENTITY apply.label "تطبيق">
 <!ENTITY apply.accesskey "ب">
+<!ENTITY fennec.subscription.label "اشتراك فلتر">

=== modified file 'chrome/locale/ar/sidebar.dtd'
--- chrome/locale/ar/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ar/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "حجب هذا العنصر">
 <!ENTITY context.editfilter.label "تعديل الفلتر الفعال">
 <!ENTITY context.whitelist.label "إضافة قانون استثنائي إلى هذا العنصر">
-<!ENTITY context.disablefilter.label "تعطيل الفلتر --">
-<!ENTITY context.enablefilter.label "إعادة تفعيل الفلتر --">
-<!ENTITY context.disablefilteronsite.label "تعطيل هذا الفلتر على --">
+<!ENTITY context.disablefilter.label "تعطيل الفلتر ?1?">
+<!ENTITY context.enablefilter.label "إعادة تفعيل الفلتر ?1?">
+<!ENTITY context.disablefilteronsite.label "تعطيل هذا الفلتر على ?1?">
 <!ENTITY context.open.label "فتح في تبويب جديد">
 <!ENTITY context.flash.label "إضاءة حواف العنصر">
 <!ENTITY context.copy.label "نسخ عنوان العنصر">

=== removed file 'chrome/locale/ar/subscription.dtd'
--- chrome/locale/ar/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ar/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "تعديل اشتراك فلتر">
-<!ENTITY dialog.newtitle "إضافة اشتراك إلى فلتر">
-<!ENTITY new.description "الرجاء إدخال عنوان الويب أو عنوان الملف الذي يحوي قائمة بالفلاتر لاستخدامها ضمن آدبلوك بلاس.">
-<!ENTITY edit.description "سيتم تحميل قائمة الفلتر هذا من الموقع الذي تم تحديده.">
-<!ENTITY external.description "هذا الاشتراك هو اشتراك إضافي إلى هذا الفلتر، و سيبقى هذا الاشتراك محدثاً باستمرار من خلال الإضافة التي أنشأت هذا الاشتراك.">
-<!ENTITY autodownload.description "إذا اخترت &quot;تحديث أوتوماتيكي&quot; سيتم التأكد من هذا الموقع كل يوم. بتعطيل هذا الخيار ستبقى قادراً على التحديث يدوياً من قائمة المقرونة باسم الفلتر.">
-<!ENTITY location.label "موقع قائمة الفلاتر">
-<!ENTITY location.accesskey "م">
-<!ENTITY title.label "عنوان الاشتراك">
-<!ENTITY title.accesskey "ع">
-<!ENTITY autodownload.label "تحديث أوتوماتيكي">
-<!ENTITY autodownload.accesskey "ث">
-<!ENTITY enabled.label "تفعيل الفلاتر">
-<!ENTITY enabled.accesskey "ف">

=== added file 'chrome/locale/ar/subscriptionSelection.dtd'
--- chrome/locale/ar/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ar/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "أهلاً بك في آدبلوك بلاس">
+<!ENTITY dialog.title.edit "تعديل اشتراك فلتر">
+<!ENTITY description.newInstall "سيكون آدبلوك بلس أكثر فعالية ان قمت بإضافة اشتراك فلاتر. اشتراكات الفلاتر تقدم مجانا من قبل مستخدمين آخرين لآدبلوك بلس. الاشتراك الأكثر ملائمة للغتك مختار أصلا">
+<!ENTITY adblock.warning "قام آدبلوك بلس بتحديد أن &quot;آدبلوك&quot; أو نسخة قديمة من &quot;آدبلوك بلس&quot; منصبة. تشغيل &quot;آدبلوك&quot; و &quot;آدبلوك بلس&quot; معاً يمكن أن يسبب مشاكل و يجب تجنبه. ننصحك بإزالة &quot;آدبلوك&quot; الآن.">
+<!ENTITY adblock.uninstall "إزالة آدبلوك.">
+<!ENTITY filterset.g.warning "يبدو أنك تستخدم Filterset.G، بالكاد تم تطوير هذا الفلتر في السنوات الماضية لذلك فهو يسبب المشاكل مع مواقع الويب، يفضل إزالته الآن.">
+<!ENTITY filterset.g.moreinfo "معلومات إضافية">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "إزالة Filterset.G">
+<!ENTITY subscriptionSelector.label "الرجاء اختيار اشتراك فلتر من القائمة:">
+<!ENTITY viewList.label "عرض فلاتر">
+<!ENTITY visitHomepage.label "زيارة الصفحة الرئيسية">
+<!ENTITY addSubscription.label "إضافة اشتراك">
+<!ENTITY saveSubscription.label "حفظ اشتراك">
+<!ENTITY other.label "إضافة اشتراك آخر">
+<!ENTITY other.accesskey "آ">
+<!ENTITY list.download.failed "فشل آدبلوك بلس في جلب قائمة الاشتراكات">
+<!ENTITY list.download.retry "إعادة المحاولة">
+<!ENTITY list.download.website "عرض الموقع">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions Copy">
+<!ENTITY fromWeb.description "الرجاء تأكيد رغبتك في إضافة اشتراك الفلتر هذا. يمكنك أن تغير عنوان أو موقع الاشتراك قبل اضافته.">
+<!ENTITY edit.description "تستطيع تغيير عنوان أو موقع هذا الاشتراك حسب الحاجة">
+<!ENTITY external.description "ان اشتراك الفلتر هذا خارجي وسيتم تحديثه من قبل الإضافة التي أنشأته">
+<!ENTITY title.label "عنوان الاشتراك">
+<!ENTITY title.accesskey "ع">
+<!ENTITY location.label "موقع قائمة الفلاتر">
+<!ENTITY location.accesskey "م">
+<!ENTITY autodownload.label "تحديث أوتوماتيكي">
+<!ENTITY autodownload.accesskey "ث">
+<!ENTITY supplementMessage "اشتراك الفلتر هذا يجب أن يستخدم مع اشتراك الفلتر &quot;?1?&quot; والذي لم تستعمله بعد">
+<!ENTITY addMain.label "إضافة اشتراك الفلتر &quot;?1?&quot; أيضا">
+<!ENTITY addMain.accesskey "ش">

=== removed file 'chrome/locale/ar/tip_subscriptions.dtd'
--- chrome/locale/ar/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ar/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "أهلاً بك في آدبلوك بلاس">
-<!ENTITY description.par1 "شكراً لتحميلك آدبلوك بلاس. هذه الإضافة يمكنها أن تزيل 99&#37; من الإعلانات التي تراها في الويب. على كل حال، إزالة الإعلانات بصورة فعالة يتطلب منك اختيار مجموعة جيدة من الفلاتر. يمكنك إنشاؤها بنفسك أو استخدام فلاتر جاهزة يقوم البعض بإنشائها لك. و حتى في هذه الحالة سيظل من الممكن أن تضيف فلاترك الخاصك لإزالة الإعلانات عند الضرورة.">
-<!ENTITY description.par2 "يمكنك اختيار اشتراك واحد من هذه القائمة من الاشتراكات المستحسنة (و يمكن إضافة المزيد من الاشتراكات من صفحة خيارات آدبلوك بلاس و ذلك شيء غير ضروري">
-<!ENTITY note "ملاحظة : تكون قائمة الفلاتر أكثر فعالية عندما تستخدم مع المواقع التي تنتمي إلى المنطقة التي تم عمل القائمة خصيصاً لها">
-<!ENTITY adblock.warning "قام آدبلوك بلس بتحديد أن &quot;آدبلوك&quot; أو نسخة قديمة من &quot;آدبلوك بلس&quot; منصبة. تشغيل &quot;آدبلوك&quot; و &quot;آدبلوك بلس&quot; معاً يمكن أن يسبب مشاكل و يجب تجنبه. ننصحك بإزالة &quot;آدبلوك&quot; الآن.">
-<!ENTITY adblock.uninstall "إزالة آدبلوك.">
-<!ENTITY filterset.g.warning "يبدو أنك تستخدم Filterset.G، بالكاد تم تطوير هذا الفلتر في السنوات الماضية لذلك فهو يسبب المشاكل مع مواقع الويب، يفضل إزالته الآن.">
-<!ENTITY filterset.g.moreinfo "معلومات إضافية">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "إزالة Filterset.G">
-<!ENTITY homepage.label "الصفحة الرئيسية">
-<!ENTITY subscribe.label "اشتراك">
-<!ENTITY subscribe.accesskey "ش">
-<!ENTITY other.label "إضافة اشتراك آخر">
-<!ENTITY other.accesskey "آ">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "عرض كل الاشتراكات">

=== added directory 'chrome/locale/be'
=== removed directory 'chrome/locale/be-BY'
=== removed file 'chrome/locale/be-BY/.incomplete'
=== removed file 'chrome/locale/be-BY/about.dtd'
--- chrome/locale/be-BY/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/be-BY/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Пра Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Вэрсія">
-<!ENTITY description "Adblock Plus дазваляе Вам вырашыць, што Вы больш не жадаеце бачыць ў Сеціве.
-Вам не патрэбна пампаваць усе банэры й рэкляму, бо калі Вам нешта зь яе не падабаецца – скажыце аб гэтым Adblock Plus!">
-<!ENTITY homepage.label "Хатняя старонка Adblock Plus:">
-<!ENTITY author.label "Аўтар:">
-<!ENTITY contributors.label "Укладчыкі:">

=== removed file 'chrome/locale/be-BY/composer.dtd'
=== removed file 'chrome/locale/be-BY/global.properties'
=== removed file 'chrome/locale/be-BY/overlay.dtd'
=== removed file 'chrome/locale/be-BY/settings.dtd'
--- chrome/locale/be-BY/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/be-BY/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-<!ENTITY dialog.title "Наладкі Adblock Plus">
-<!ENTITY filters.label "Фільтры">
-<!ENTITY filters.accesskey "Ф">
-<!ENTITY add.label "Дадаць фільтар">
-<!ENTITY add.accesskey "Д">
-<!ENTITY addsubscription.label "Дадаць падпіску на фільтар">
-<!ENTITY addsubscription.accesskey "П">
-<!ENTITY synchsubscriptions.label "Аднавіць усе падпіскі">
-<!ENTITY synchsubscriptions.accesskey "А">
-<!ENTITY import.label "Імпартаваць фільтры">
-<!ENTITY import.accesskey "І">
-<!ENTITY export.label "Экспартаваць фільтры">
-<!ENTITY export.accesskey "Э">
-<!ENTITY clearall.label "Выдаліць усе фільтры">
-<!ENTITY clearall.accesskey "У">
-<!ENTITY resethitcounts.label "Скінуць статыстыку">
-<!ENTITY resethitcounts.accesskey "К">
-<!ENTITY edit.label "Рэдагаваць">
-<!ENTITY edit.accesskey "Р">
-<!ENTITY cut.label "Выразаць">
-<!ENTITY cut.accesskey "Ы">
-<!ENTITY copy.label "Капіяваць">
-<!ENTITY copy.accesskey "К">
-<!ENTITY paste.label "Уставіць">
-<!ENTITY paste.accesskey "С">
-<!ENTITY remove.label "Выдаліць">
-<!ENTITY remove.accesskey "Д">
-<!ENTITY menu.find.label "Пошук">
-<!ENTITY menu.find.accesskey "Ш">
-<!ENTITY menu.findagain.label "Паўтарыць пошук">
-<!ENTITY menu.findagain.accesskey "Ў">
-<!ENTITY options.label "Наладкі">
-<!ENTITY options.accesskey "Л">
-<!ENTITY enable.label "Уключыць Adblock Plus">
-<!ENTITY enable.accesskey "К">
-<!ENTITY showintoolbar.label "Show in toolbar">
-<!ENTITY showintoolbar.accesskey "B">
-<!ENTITY showinstatusbar.label "Show in status bar">
-<!ENTITY showinstatusbar.accesskey "S">
-<!ENTITY objecttabs.label "Паказваць закладкі на Flash і Java">
-<!ENTITY objecttabs.accesskey "З">
-<!ENTITY collapse.label "Сьціскаць заблякаваныя элемэнты">
-<!ENTITY collapse.accesskey "Ь">
-<!ENTITY help.label "Дапамога">
-<!ENTITY help.accesskey "Д">
-<!ENTITY faq.label "Пытаньні й адказы">
-<!ENTITY faq.accesskey "П">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Напісаньне фільтраў для Adblock Plus">
-<!ENTITY filterdoc.accesskey "Н">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Пра Adblock Plus">
-<!ENTITY about.accesskey "Р">
-<!ENTITY description "Дадайце адрасы, якія Вы жадаеце заблякаваць, ці вылучце іх з выпаднага сьпісу. Вы можаце ўжываць * для таго, каб ствараць агульныя правілы. Прасунутыя карыстальнікі могуць карыстацца рэгульрнымі выразамі кшталту /banner\d+\.gif$/.">
-<!ENTITY enabled.column "Уключанае">
-<!ENTITY hitcount.column "Хітоў">
-<!ENTITY lasthit.column "Апошні">
-<!ENTITY context.edit.label "Рэдагаваць">
-<!ENTITY context.resethitcount.label "Скінуць статыстыку для фільтра">
-<!ENTITY context.synchsubscription.label "Аднавіць падпіску">
-<!ENTITY context.editsubscription.label "Рэдагаваць падпіску">
-<!ENTITY context.moveup.label "Перасунуць уверх">
-<!ENTITY context.movedown.label "Перасунуць уніз">
-<!ENTITY context.movegroupup.label "Перасунуць групу уверх">
-<!ENTITY context.movegroupdown.label "Перасунуць групу уніз">
-<!ENTITY apply.label "Прымяніць">
-<!ENTITY apply.accesskey "П">

=== removed file 'chrome/locale/be-BY/sidebar.dtd'
=== removed file 'chrome/locale/be-BY/subscription.dtd'
--- chrome/locale/be-BY/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/be-BY/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY dialog.title "Праўка падпіскі на сіты">
-<!ENTITY dialog.newtitle "Даданне падпіскі на сіты">
-<!ENTITY new.description "Увядзіце, калі ласка, адрас сеціва ці назву 
-файла, дзе змяшчаецца спіс сітаў Adblock Plus.">
-<!ENTITY edit.description "Спіс сітаў гэтай падпіскі будзе сцягвацца
-з наступнага месца.">
-<!ENTITY external.description "Гэта вонкавая падпіска на сіты, спіс яе сітаў
-будзе абнаўляцца пашырэннем, якое стварыла
-гэтую падпіску.">
-<!ENTITY autodownload.description "Калі вы выбераце &apos;Абнаўляць самастойна&apos;, абнаўленні
-ў гэтым месцы будуць шукацца штодзённа. Інакш, калі
-параметар будзе забаронены, вы можаце запусціць
-абнаўленне ўручную ў кантэкставым меню падпіскі.">
-<!ENTITY location.label "Месцазнаходжанне спіса сітаў:">
-<!ENTITY location.accesskey "с">
-<!ENTITY title.label "Назва падпіскі:">
-<!ENTITY title.accesskey "Н">
-<!ENTITY autodownload.label "Абнаўляць самастойна">
-<!ENTITY autodownload.accesskey "А">
-<!ENTITY enabled.label "Дазволіць сіты">
-<!ENTITY enabled.accesskey "Д">

=== removed file 'chrome/locale/be-BY/tip_subscriptions.dtd'
--- chrome/locale/be-BY/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/be-BY/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,1 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus вітае Вас">

=== added file 'chrome/locale/be/.incomplete'
=== added file 'chrome/locale/be/about.dtd'
--- chrome/locale/be/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/be/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,8 @@
+<!ENTITY dialog.title "Пра Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Вэрсія">
+<!ENTITY description "Adblock Plus дазваляе Вам вырашыць, што Вы больш не жадаеце бачыць ў Сеціве.
+Вам не патрэбна пампаваць усе банэры й рэкляму, бо калі Вам нешта зь яе не падабаецца – скажыце аб гэтым Adblock Plus!">
+<!ENTITY homepage.label "Хатняя старонка Adblock Plus:">
+<!ENTITY author.label "Аўтар:">
+<!ENTITY contributors.label "Укладчыкі:">

=== added file 'chrome/locale/be/settings.dtd'
--- chrome/locale/be/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/be/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,67 @@
+<!ENTITY dialog.title "Наладкі Adblock Plus">
+<!ENTITY filters.label "Фільтры">
+<!ENTITY filters.accesskey "Ф">
+<!ENTITY add.label "Дадаць фільтар">
+<!ENTITY add.accesskey "Д">
+<!ENTITY addsubscription.label "Дадаць падпіску на фільтар">
+<!ENTITY addsubscription.accesskey "П">
+<!ENTITY synchsubscriptions.label "Аднавіць усе падпіскі">
+<!ENTITY synchsubscriptions.accesskey "А">
+<!ENTITY import.label "Імпартаваць фільтры">
+<!ENTITY import.accesskey "І">
+<!ENTITY export.label "Экспартаваць фільтры">
+<!ENTITY export.accesskey "Э">
+<!ENTITY clearall.label "Выдаліць усе фільтры">
+<!ENTITY clearall.accesskey "У">
+<!ENTITY resethitcounts.label "Скінуць статыстыку">
+<!ENTITY resethitcounts.accesskey "К">
+<!ENTITY edit.label "Рэдагаваць">
+<!ENTITY edit.accesskey "Р">
+<!ENTITY cut.label "Выразаць">
+<!ENTITY cut.accesskey "Ы">
+<!ENTITY copy.label "Капіяваць">
+<!ENTITY copy.accesskey "К">
+<!ENTITY paste.label "Уставіць">
+<!ENTITY paste.accesskey "С">
+<!ENTITY remove.label "Выдаліць">
+<!ENTITY remove.accesskey "Д">
+<!ENTITY menu.find.label "Пошук">
+<!ENTITY menu.find.accesskey "Ш">
+<!ENTITY menu.findagain.label "Паўтарыць пошук">
+<!ENTITY menu.findagain.accesskey "Ў">
+<!ENTITY options.label "Наладкі">
+<!ENTITY options.accesskey "Л">
+<!ENTITY enable.label "Уключыць Adblock Plus">
+<!ENTITY enable.accesskey "К">
+<!ENTITY showintoolbar.label "Show in toolbar">
+<!ENTITY showintoolbar.accesskey "B">
+<!ENTITY showinstatusbar.label "Show in status bar">
+<!ENTITY showinstatusbar.accesskey "S">
+<!ENTITY objecttabs.label "Паказваць закладкі на Flash і Java">
+<!ENTITY objecttabs.accesskey "З">
+<!ENTITY collapse.label "Сьціскаць заблякаваныя элемэнты">
+<!ENTITY collapse.accesskey "Ь">
+<!ENTITY help.label "Дапамога">
+<!ENTITY help.accesskey "Д">
+<!ENTITY faq.label "Пытаньні й адказы">
+<!ENTITY faq.accesskey "П">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Напісаньне фільтраў для Adblock Plus">
+<!ENTITY filterdoc.accesskey "Н">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Пра Adblock Plus">
+<!ENTITY about.accesskey "Р">
+<!ENTITY description "Дадайце адрасы, якія Вы жадаеце заблякаваць, ці вылучце іх з выпаднага сьпісу. Вы можаце ўжываць * для таго, каб ствараць агульныя правілы. Прасунутыя карыстальнікі могуць карыстацца рэгульрнымі выразамі кшталту /banner\d+\.gif$/.">
+<!ENTITY enabled.column "Уключанае">
+<!ENTITY hitcount.column "Хітоў">
+<!ENTITY lasthit.column "Апошні">
+<!ENTITY context.edit.label "Рэдагаваць">
+<!ENTITY context.resethitcount.label "Скінуць статыстыку для фільтра">
+<!ENTITY context.synchsubscription.label "Аднавіць падпіску">
+<!ENTITY context.editsubscription.label "Рэдагаваць падпіску">
+<!ENTITY context.moveup.label "Перасунуць уверх">
+<!ENTITY context.movedown.label "Перасунуць уніз">
+<!ENTITY context.movegroupup.label "Перасунуць групу уверх">
+<!ENTITY context.movegroupdown.label "Перасунуць групу уніз">
+<!ENTITY apply.label "Прымяніць">
+<!ENTITY apply.accesskey "П">

=== added file 'chrome/locale/be/subscriptionSelection.dtd'
--- chrome/locale/be/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/be/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,7 @@
+<!ENTITY dialog.title.edit "Праўка падпіскі на сіты">
+<!ENTITY title.label "Назва падпіскі:">
+<!ENTITY title.accesskey "Н">
+<!ENTITY location.label "Месцазнаходжанне спіса сітаў:">
+<!ENTITY location.accesskey "с">
+<!ENTITY autodownload.label "Абнаўляць самастойна">
+<!ENTITY autodownload.accesskey "А">

=== added directory 'chrome/locale/bg'
=== removed directory 'chrome/locale/bg-BG'
=== removed file 'chrome/locale/bg-BG/.incomplete'
=== removed file 'chrome/locale/bg-BG/about.dtd'
--- chrome/locale/bg-BG/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/bg-BG/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-<!ENTITY dialog.title "Относно Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Версия">
-<!ENTITY description "Adblock Plus Ви позволява да решите какво не искате да виждате в интернет.
-Вече не е необходимо да изтегляте всички реклами и банери,
-ако не ги искате - кажете на Adblock Plus!">
-<!ENTITY homepage.label "Страница на Adblock Plus:">
-<!ENTITY author.label "Автор:">
-<!ENTITY contributors.label "Сътрудници:">

=== removed file 'chrome/locale/bg-BG/composer.dtd'
=== removed file 'chrome/locale/bg-BG/global.properties'
--- chrome/locale/bg-BG/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/bg-BG/global.properties	1970-01-01 00:00:00 +0000
@@ -1,7 +0,0 @@
-subscription_location_exists=Вече сте абонирани за този списък.
-synchronize_invalid_url=Грешка, невалиден адрес
-new_filter_group_title=Нов филтър
-type_label_image=картинка
-type_label_document=документ
-type_label_elemhide=скрит
-type_label_xmlhttprequest=XML заявка

=== removed file 'chrome/locale/bg-BG/overlay.dtd'
=== removed file 'chrome/locale/bg-BG/settings.dtd'
=== removed file 'chrome/locale/bg-BG/sidebar.dtd'
=== removed file 'chrome/locale/bg-BG/subscription.dtd'
=== removed file 'chrome/locale/bg-BG/tip_subscriptions.dtd'
=== added file 'chrome/locale/bg/about.dtd'
--- chrome/locale/bg/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/bg/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Относно Adblock Плюс">
+<!ENTITY caption.title "Adblock Плюс">
+<!ENTITY version.title "Версия">
+<!ENTITY description "Adblock Плюс Ви позволява да решите какво не искате да виждате в Интернет. Вече не е необходимо да изтегляте всички реклами и банери, ако не ги искате - премахнете ги с Adblock Plus!">
+<!ENTITY homepage.label "Страница на Adblock Плюс:">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "Автор:">
+<!ENTITY contributors.label "Сътрудници:">
+<!ENTITY developers.label "Разработчици:">
+<!ENTITY designers.label "Графични дизайнери:">
+<!ENTITY subscriptionAuthors.label "Автори на филтъра за абонаменти:">
+<!ENTITY translators.label "Преводачи:">

=== added file 'chrome/locale/bg/composer.dtd'
--- chrome/locale/bg/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/bg/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Добави Adblock Плюс правило за филтър">
+<!ENTITY accept.label "Добави Филтър">
+<!ENTITY advanced.label "Разширен изглед">
+<!ENTITY basic.label "Основен изглед">
+<!ENTITY disabled.warning "Adblock Плюс е изключена. Все още можете да добавите филтри, но те няма да се прилагат, освен ако не [link]Включите Adblock Плюс[/link].">
+<!ENTITY groupDisabled.warning "Филтър групата &quot;?1?&quot; от този филтър ще бъдат добавени но е забранена. Все още можете да добавите и филтъра, но те няма да се прилагат, освен ако не [link]включите тази Филтърна Група[/link].">
+<!ENTITY filter.label "Нов Филтър:">
+<!ENTITY filter.accesskey "Ф">
+<!ENTITY preferences.label "Покажи съществуващите филтри...">
+<!ENTITY preferences.accesskey "П">
+<!ENTITY type.filter.label "Блокиране на филтъра">
+<!ENTITY type.filter.accesskey "Б">
+<!ENTITY type.whitelist.label "Изключение от правилото">
+<!ENTITY type.whitelist.accesskey "И">
+<!ENTITY pattern.label "Търсете модел">
+<!ENTITY pattern.explanation "Моделът може да бъде част от адрес; звездичка (*) да действа като заместващи символи. Филтърът ще се прилага само за адресите, отговарящи на предвидения образец.">
+<!ENTITY regexp.warning "Моделът който сте въвели ще бъде интерпретиран като регулярен израз, които не могат да бъдат ефективно обработени с Adblock Плюс и могат да забавят твоят браузър. Ако не възнамерявате да използвате регулярен израз, добавете звездичка (*) към края на модела.">
+<!ENTITY shortpattern.warning "Моделът които сте въвели е твърде кратък, за да бъде оптимизиран и може да забави вашия браузър. Препоръчително е да изберете по-дълъг низ за този филтър, за да позволи Adblock Плюс за по-ефективна обработка на филтъра.">
+<!ENTITY custom.pattern.label "Избрани:">
+<!ENTITY custom.pattern.accesskey "И">
+<!ENTITY anchors.label "Приемам само модел:">
+<!ENTITY anchor.start.label "в началото на адреса">
+<!ENTITY anchor.start.accesskey "в">
+<!ENTITY anchor.start.flexible.label "в началото на домейн името">
+<!ENTITY anchor.start.flexible.accesskey "в">
+<!ENTITY anchor.end.label "в краят на адресът">
+<!ENTITY anchor.end.accesskey "в">
+<!ENTITY options.label "Настройки">
+<!ENTITY domainRestriction.label "Ограничаване на домейн:">
+<!ENTITY domainRestriction.accesskey "О">
+<!ENTITY domainRestriction.help "Използвайте тази опция, за да зададете една или повече области, разделени с бар линия (|). Филтърът ще се прилага само за избран(и) домейн(и). А тилда (~) пред името на домейна се посочва, че филтърът не се прилага в този домейн.">
+<!ENTITY firstParty.label "Първа страна само">
+<!ENTITY firstParty.accesskey "п">
+<!ENTITY thirdParty.label "Трети страни само">
+<!ENTITY thirdParty.accesskey "т">
+<!ENTITY matchCase.label "Съвпадение на регистъра">
+<!ENTITY matchCase.accesskey "с">
+<!ENTITY types.label "Прилага за типове:">
+<!ENTITY selectAllTypes.label "Избери всички">
+<!ENTITY unselectAllTypes.label "Не избирай нищо">
+<!ENTITY collapse.label "Свиване на блокирани:">
+<!ENTITY collapse.accesskey "С">
+<!ENTITY collapse.default.yes.label "Ползвай по подразбиране(да)">
+<!ENTITY collapse.default.no.label "Ползвай по подразбиране(не)">
+<!ENTITY collapse.yes.label "Да">
+<!ENTITY collapse.no.label "Не">

=== added file 'chrome/locale/bg/global.properties'
--- chrome/locale/bg/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/bg/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Плюс
+action0_tooltip=Щракнете за да извадите контекстното меню, средно щракване за включване/изключване.
+action1_tooltip=Щракнете за да отворите/затворите блокираните параграфи, средно щракване за включване/изключване.
+action2_tooltip=Кликнете за да отворите предпочитанията, средно щракване за включване/изключване.
+action3_tooltip=Щракнете за включване/изключване Adblock Плюс.
+disabled_tooltip=Adblock Плюс е изключен.
+active_tooltip=Adblock Плюс е включен, ?1? абонамента за филтриране и ?2? потребителски филтър(а) се използват.
+whitelisted_tooltip=Adblock Плюс е изключен на текущата страница.
+blocked_count_tooltip=?1? от ?2?
+blocked_count_addendum=(също разрешени:?1?, скрити: ?2?)
+no_blocking_suggestions=Няма блокирани позиции на текущата страница
+whitelisted_page=Adblock Плюс беше изключен за текущата страница
+whitelist_description=Моите правила за изключения
+filterlist_description=Моите правила за Ad Blocking
+invalid_description=Моите неправилни правила
+elemhide_description=Моите правила за скриване на елемент
+subscription_description=Филтър за абонаменти:
+subscription_wrong_version=Някои филтри в този абонамент изискват Adblock Плюс ?1? за да работят правилно.
+subscription_source=Източник:
+subscription_status=Състояние:
+subscription_status_autodownload=Автоматично обновен
+subscription_status_manualdownload=Ръчно обновен
+subscription_status_externaldownload=Обновен външно (друго разширение)
+subscription_status_lastdownload=Последно изтеглен:
+subscription_status_lastdownload_inprogress=Изтегляне...
+subscription_status_lastdownload_unknown=Няма данни
+remove_subscription_warning=Наистина ли искате да премахнете този абонамент?
+import_filters_wrong_version=Внимание: някои от филтрите в този списък изискват Adblock Плюс ?1? да работят правилно. Може би трябва да надстроите до най-новата версия на Adblock Плюс преди вноса на този списък.
+import_filters_warning=Искате ли да замените текущите филтри или да добавите нови филтри в края на списъка?
+import_filters_title=Внасяне на филтри
+export_filters_title=Изнасяне на филтри
+invalid_filters_file=Невалиден файл с филтри за Adblock Плюс
+filters_write_error=Имаше грешка при записването на филтрите във файла. Уверете се, че файлът не е защитен срещу запис или е отворен в друго приложение.
+clearall_warning=Наистина ли искате да премахнете всички филтри от списъка?
+resethitcounts_warning=Наистина ли искате да нулирате броячите за ползването на всички филтри? Забележка: Тази операция не може да бъде отменена.
+resethitcounts_selected_warning=Наистина ли искате да нулирате броячите за ползването на избраните филтри? Забележка: Тази операция не може да бъде отменена.
+filter_regexp_tooltip=Този филтър или е регулярен израз или е твърде кратък, за да се оптимизира. Твърде много от тези филтри могат да забавят сърфирането.
+filter_elemhide_duplicate_id=Може да бъде задаван само един ID на елемент за скриване
+filter_elemhide_nocriteria=Не е зададен критерий за разпознаване на елемент за скриване
+subscription_notAdded_warning=Вие не сте добавили абонамент за филтри. Без абонамент  за филтри ще трябва да добавяте Adblock Плюс филтрите ръчно.
+subscription_notAdded_warning_addendum=Искате ли да продължите?
+subscription_invalid_location=Местоположението на списъка с филтри или не е валиден URL или не е валидно името на файла.
+synchronize_invalid_url=Грешка, невалиден адрес
+synchronize_connection_error=Провал, неуспешно изтегляне
+synchronize_invalid_data=Провал, невалиден списък с филтри
+synchronize_checksum_mismatch=Провал, несъвпадение на контролната сума
+synchronize_ok=Успешно
+overwrite=Презапис
+append=Добавяне
+new_filter_group_title=Нов филтър
+type_label_other=Добавяне
+type_label_script=скрипт
+type_label_image=картинка
+type_label_stylesheet=интерфейс
+type_label_object=обект
+type_label_subdocument=рамка
+type_label_document=документ
+type_label_background=заден фон
+type_label_elemhide=скрит
+type_label_xbl=XBL обвързване
+type_label_ping=ping връзка
+type_label_xmlhttprequest=XML заявка
+type_label_object_subrequest=обект под заявка
+type_label_dtd=DTD
+type_label_media=аудио/видео
+type_label_font=шрифт
+fennec_status_enabled=Adblock Плюс е включен.
+fennec_status_disabled=Adblock Плюс е изключен.
+fennec_status_enabled_site=Adblock Плюс е включен на ?1?.
+fennec_status_disabled_site=Adblock Плюс е изключен на ?1?.

=== added file 'chrome/locale/bg/meta.properties'
--- chrome/locale/bg/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/bg/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Ивайло Йовчев (s0urce)
+name=Adblock Plus
+description=Рекламите бяха вчера!
+description.short=Недоволни сте от обяви? Притеснявани сте от банери? Инсталирайте Adblock Плюс сега, за да си възвърнете контрола и начина, по който гледате в Интернет.\n\nКратък видео преглед можете да намерите на http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Плюс ви позволява да си възвърнете контрола върху Интернет и да видите Интернет по начина, по който искате. Добавката е подкрепена от над четиридесет филтъра за абонамент на десетки езици, които автоматично го конфигурират за цели, вариращи от премахване на онлайн реклама до блокиране на всички известни зловредни програми. Adblock Плюс също ви позволява да персонализирате своите филтри с помощта на множество полезни функции, включително контекстна възможност за снимки, раздел за блокиране за Flash и Java обекти, както и списък на блокирани продукти за премахване на скриптове и стилове.

=== added file 'chrome/locale/bg/overlay.dtd'
--- chrome/locale/bg/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/bg/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Статус:">
+<!ENTITY blocked.tooltip "Блокирани предмети от тази страница:">
+<!ENTITY filters.tooltip "Най активни филтри:">
+<!ENTITY menuitem.label "Adblock Плюс Настройки">
+<!ENTITY menuitem.accesskey "Н">
+<!ENTITY toolbarbutton.label "Adblock Плюс">
+<!ENTITY view.blockableItems.label "Adblock Плюс: Блокирани Предмети">
+<!ENTITY context.image.label "Adblock Плюс: Блокирани Картинки">
+<!ENTITY context.object.label "Adblock Плюс:Блокирани Обекти">
+<!ENTITY context.frame.label "Adblock Плюс:Блокирани Фреймове">
+<!ENTITY context.media.label "Adblock Плюс: Блокирани аудио/видео">
+<!ENTITY context.removeWhitelist.label "Adblock Плюс: Пусни за тази страница">
+<!ENTITY sidebar.title "Блокирани предмети на тази страница">
+<!ENTITY settings.label "Настройки">
+<!ENTITY settings.accesskey "Н">
+<!ENTITY opensidebar.label "Отвори блокирани предмети">
+<!ENTITY opensidebar.accesskey "О">
+<!ENTITY closesidebar.label "Затвори блокирани предмети">
+<!ENTITY closesidebar.accesskey "З">
+<!ENTITY whitelist.site.label "Забрани на ?1?">
+<!ENTITY whitelist.page.label "Забрани на тази страница само">
+<!ENTITY objecttab.title "Блокирай">
+<!ENTITY objecttab.tooltip "Щракни тук за да блокираш този обект със Adblock Плюс">

=== added file 'chrome/locale/bg/settings.dtd'
--- chrome/locale/bg/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/bg/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus Настройки">
+<!ENTITY filters.label "Филтри">
+<!ENTITY filters.accesskey "Ф">
+<!ENTITY add.label "Добави Филтър">
+<!ENTITY add.accesskey "Д">
+<!ENTITY addsubscription.label "Добави абонамент за филтър">
+<!ENTITY addsubscription.accesskey "Д">
+<!ENTITY synchsubscriptions.label "Обнови всички абонаменти">
+<!ENTITY synchsubscriptions.accesskey "О">
+<!ENTITY import.label "Вмъкни филтри">
+<!ENTITY import.accesskey "В">
+<!ENTITY export.label "Изнеси Потребителски филтри">
+<!ENTITY export.accesskey "И">
+<!ENTITY clearall.label "Премахване на всички потребителски филтри">
+<!ENTITY clearall.accesskey "П">
+<!ENTITY resethitcounts.label "Нулиране на хит статистиката">
+<!ENTITY resethitcounts.accesskey "Н">
+<!ENTITY edit.label "Промени">
+<!ENTITY edit.accesskey "П">
+<!ENTITY cut.label "Изрежи">
+<!ENTITY cut.accesskey "И">
+<!ENTITY copy.label "Копирай">
+<!ENTITY copy.accesskey "К">
+<!ENTITY paste.label "Постави">
+<!ENTITY paste.accesskey "П">
+<!ENTITY remove.label "Изтрий">
+<!ENTITY remove.accesskey "И">
+<!ENTITY menu.find.label "Намери">
+<!ENTITY menu.find.accesskey "Н">
+<!ENTITY menu.findagain.label "Намери отново">
+<!ENTITY menu.findagain.accesskey "Н">
+<!ENTITY view.label "Изглед">
+<!ENTITY view.accesskey "И">
+<!ENTITY sort.label "Сортирай по">
+<!ENTITY sort.accesskey "С">
+<!ENTITY sort.none.label "Несортирани">
+<!ENTITY sort.none.accesskey "Н">
+<!ENTITY sort.ascending.label "А &gt; Я сортиране">
+<!ENTITY sort.ascending.accesskey "А">
+<!ENTITY sort.descending.label "Я &gt; А Сортиране">
+<!ENTITY sort.descending.accesskey "Я">
+<!ENTITY options.label "Настройки">
+<!ENTITY options.accesskey "Н">
+<!ENTITY enable.label "Включи  Adblock Плюс">
+<!ENTITY enable.accesskey "В">
+<!ENTITY showintoolbar.label "Покажи в лентата с инструменти">
+<!ENTITY showintoolbar.accesskey "П">
+<!ENTITY showinstatusbar.label "Покажи в лентата на състоянието">
+<!ENTITY showinstatusbar.accesskey "П">
+<!ENTITY objecttabs.label "Покажи разделите за Flash и Java">
+<!ENTITY objecttabs.accesskey "П">
+<!ENTITY collapse.label "Свиване на блокираните елементи">
+<!ENTITY collapse.accesskey "С">
+<!ENTITY help.label "Помощ">
+<!ENTITY help.accesskey "П">
+<!ENTITY gettingStarted.label "Как да започнем">
+<!ENTITY gettingStarted.accesskey "К">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Често Задавани Въпроси">
+<!ENTITY faq.accesskey "Ч">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Писане Adblock Плюс филтри">
+<!ENTITY filterdoc.accesskey "П">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Относно Adblock Плюс">
+<!ENTITY about.accesskey "О">
+<!ENTITY description "Следните филтри определиха кои адреси да бъдат блокирани и кои от тях трябва да се разрешат:">
+<!ENTITY filter.column "Филтър правило">
+<!ENTITY filter.accesskey "Ф">
+<!ENTITY slow.column "Покажи филтри">
+<!ENTITY slow.accesskey "П">
+<!ENTITY enabled.column "Включен">
+<!ENTITY enabled.accesskey "В">
+<!ENTITY hitcount.column "Посещения">
+<!ENTITY hitcount.accesskey "П">
+<!ENTITY lasthit.column "Последни Посещения">
+<!ENTITY lasthit.accesskey "П">
+<!ENTITY context.edit.label "Промени филтър">
+<!ENTITY context.resethitcount.label "Нулирай хит статистика за филтър">
+<!ENTITY context.synchsubscription.label "Обнови абонамента сега">
+<!ENTITY context.editsubscription.label "Промени абонамента">
+<!ENTITY context.moveup.label "Премести филтъра нагоре">
+<!ENTITY context.movedown.label "Премести филтъра надолу">
+<!ENTITY context.movegroupup.label "Премести групата нагоре">
+<!ENTITY context.movegroupdown.label "Премести групата надолу">
+<!ENTITY context.enable.label "Разреши">
+<!ENTITY context.disable.label "Забрани">
+<!ENTITY apply.label "Приложи">
+<!ENTITY apply.accesskey "П">
+<!ENTITY fennec.subscription.label "Филтър абонамент">

=== added file 'chrome/locale/bg/sidebar.dtd'
--- chrome/locale/bg/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/bg/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Плюс: Блокирани продукти (отделени)">
+<!ENTITY detach.label "Отдели">
+<!ENTITY reattach.label "Свържи отново">
+<!ENTITY search.label "Търси:">
+<!ENTITY search.accesskey "Т">
+<!ENTITY type.label "Тип">
+<!ENTITY address.label "Адрес">
+<!ENTITY filter.label "Филтър">
+<!ENTITY state.label "Състояние">
+<!ENTITY size.label "Размер">
+<!ENTITY docDomain.label "Източник на документа">
+<!ENTITY noitems.label "Няма блокирани продукти">
+<!ENTITY whitelisted.label "Разрешена странница">
+<!ENTITY tooltip.address.label "Адрес:">
+<!ENTITY tooltip.type.label "Тип:">
+<!ENTITY tooltip.type.blocked "(блокиран)">
+<!ENTITY tooltip.type.whitelisted "(разрешен)">
+<!ENTITY tooltip.size.label "Размер:">
+<!ENTITY tooltip.docDomain.label "Източник на документа:">
+<!ENTITY tooltip.filter.label "Филтър в сила:">
+<!ENTITY tooltip.filterSource.label "Източник на филтъра">
+<!ENTITY context.block.label "Блокирай този продукт">
+<!ENTITY context.editfilter.label "Редактиране на филтъра в сила:">
+<!ENTITY context.whitelist.label "Добави изключващо правило за продукта">
+<!ENTITY context.disablefilter.label "Да изключа ли филтър ?1?">
+<!ENTITY context.enablefilter.label "Повторно включване на филтъра ?1?">
+<!ENTITY context.disablefilteronsite.label "Да изключа ли този филтър за ?1?">
+<!ENTITY context.open.label "Отвори в нов под прозорец">
+<!ENTITY context.flash.label "Рамки на флаш продукти">
+<!ENTITY context.copy.label "Копирай адреса на продукта">
+<!ENTITY context.copyFilter.label "Копирай филтъра">
+<!ENTITY context.selectAll.label "Избери всички">

=== added file 'chrome/locale/bg/subscriptionSelection.dtd'
--- chrome/locale/bg/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/bg/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Добавяне на абонамент за филтъра за Adblock Плюс">
+<!ENTITY dialog.title.edit "Редактиране на абонамента за филтъра">
+<!ENTITY description.newInstall "Adblock Плюс ще бъде най-ефективен, ако добавите филтър абонамент. Филтър абонаментите са предоставени от други потребители на Adblock Плюс безплатно. Най-подходящ абонамент за вашият език е вече избран.">
+<!ENTITY adblock.warning "Adblock Плюс е открил, че Adblock или стара версия на Adblock Плюс е инсталирана вече. Работещи двете програми Adblock и Adblock Плюс заедно може да предизвикат проблеми и трябва да се избягва едновременната им работа. Препоръчително е да деинсталирате Adblock сега.">
+<!ENTITY adblock.uninstall "Деинсталирай Adblock">
+<!ENTITY filterset.g.warning "Изглежда, че използвате Filterset.G. Този филтър и списък е в поддръжка от последните няколко години и е честа причина за проблемите с уеб сайтовете. Препоръчително е да деинсталирате Filterset.G сега.">
+<!ENTITY filterset.g.moreinfo "Още информация">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Деинсталирай Filterset.G">
+<!ENTITY subscriptionSelector.label "Моля изберете абонамент за филтър от списъка:">
+<!ENTITY viewList.label "Покажи филтрите">
+<!ENTITY visitHomepage.label "Посетете началната страница">
+<!ENTITY addSubscription.label "Добави абонамент">
+<!ENTITY saveSubscription.label "Запиши абонамента">
+<!ENTITY other.label "Добави друг абонамент">
+<!ENTITY other.accesskey "Д">
+<!ENTITY list.download.failed "Adblock Плюс не успя да извлече списък с абонаменти.">
+<!ENTITY list.download.retry "Опитайте отново">
+<!ENTITY list.download.website "Покажи сайтът">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Моля, потвърдете, че желаете да добавите този абонамент за филтър. Може да промените заглавието или местоположението преди да го добавите.">
+<!ENTITY edit.description "Може да променяте заглавието или местоположението на абонамента колкото е необходимо.">
+<!ENTITY external.description "Това е външен абонамент филтър, той ще бъде актуализиран с разширението което е създадено от този абонамент.">
+<!ENTITY title.label "Заглавие на абонамента:">
+<!ENTITY title.accesskey "З">
+<!ENTITY location.label "Местоположение на списъка с филтрите:">
+<!ENTITY location.accesskey "М">
+<!ENTITY autodownload.label "Автоматично обновявай филтрите">
+<!ENTITY autodownload.accesskey "А">
+<!ENTITY supplementMessage "Този филтър абонамент е предназначен да се използва с филтър подписка &quot;?1?&quot; Които не използвате все още.">
+<!ENTITY addMain.label "Добави абонамент филтър &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "Д">

=== removed file 'chrome/locale/bn-IN/about.dtd'
=== removed file 'chrome/locale/bn-IN/composer.dtd'
=== removed file 'chrome/locale/bn-IN/global.properties'
=== removed file 'chrome/locale/bn-IN/overlay.dtd'
=== removed file 'chrome/locale/bn-IN/settings.dtd'
=== removed file 'chrome/locale/bn-IN/sidebar.dtd'
=== removed file 'chrome/locale/bn-IN/subscription.dtd'
=== added file 'chrome/locale/bn-IN/subscriptionSelection.dtd'
--- chrome/locale/bn-IN/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/bn-IN/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,1 @@
+<!ENTITY dialog.title "Adblock Plus -এ স্বাগতম">

=== removed file 'chrome/locale/bn-IN/tip_subscriptions.dtd'
--- chrome/locale/bn-IN/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/bn-IN/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,1 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus -এ স্বাগতম">

=== added directory 'chrome/locale/ca'
=== removed directory 'chrome/locale/ca-AD'
=== removed file 'chrome/locale/ca-AD/about.dtd'
--- chrome/locale/ca-AD/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ca-AD/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-<!ENTITY dialog.title "Sobre Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Versió">
-<!ENTITY description "Adblock Plus et permet decidir que no vols veure a la xarxa.
-Ja no has de descarregar tots els anuncis i pancartes, si no els vols - digues-ho a Adblock Plus!">
-<!ENTITY homepage.label "Pàgina principal de Adblock Plus:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Autor">
-<!ENTITY contributors.label "Contribuïdors:">

=== removed file 'chrome/locale/ca-AD/composer.dtd'
--- chrome/locale/ca-AD/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ca-AD/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Afegir una regla de filtre d&apos;Adblock Plus">
-<!ENTITY accept.label "Afegir filtre">
-<!ENTITY advanced.label "Visualització avançada">
-<!ENTITY basic.label "Visualització bàsica">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus està desactivat. Encara es poden afegir filtres però no seran aplicats a menys que">
-<!ENTITY disabled.warning.link "activis Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "El filtre de grup &quot;&#37;S&quot; que aquest filtre hauria de ser afegit està deshabilitat.Pots afegir-lo encara però no apareixerà fins que">
-<!ENTITY groupDisabled.warning.link "habilitis el filtre de grup">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Nou filtre:">
-<!ENTITY filter.accesskey "n">
-<!ENTITY preferences.label "Mostra filtres existents...">
-<!ENTITY preferences.accesskey "S">
-<!ENTITY type.filter.label "Filtre de bloqueig">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "Excepció">
-<!ENTITY type.whitelist.accesskey "x">
-<!ENTITY pattern.label "Cerca un patró">
-<!ENTITY pattern.explanation "El patró pot ser qualsevol part de l&apos;adreça, el símbol ^ serveix de comodí. El filtre només s&apos;aplicarà a adreces que concordin amb el filtre">
-<!ENTITY regexp.warning "El patró que s&apos;ha entrat serà interpretat com una expressió regular. Massa expressions regulars poden alentir la navegació. Si no es volia utilitzar una expressió regular, afegir el símbol ^ al final del patró.">
-<!ENTITY shortpattern.warning "El patró entrat es massa curt per ser optimitzat, massa patrons d&apos;aquest tipus poden alentir la navegació. Es recomana una cadena de text més llarga per aquest filtre.">
-<!ENTITY custom.pattern.label "Personalitzar:">
-<!ENTITY custom.pattern.accesskey "P">
-<!ENTITY anchors.label "Accepta només un patró:">
-<!ENTITY anchor.start.label "al començament de l&apos;adreça">
-<!ENTITY anchor.start.accesskey "c">
-<!ENTITY anchor.start.flexible.label "al començament del nom de domini">
-<!ENTITY anchor.start.flexible.accesskey "c">
-<!ENTITY anchor.end.label "al final de l&apos;adreça">
-<!ENTITY anchor.end.accesskey "f">
-<!ENTITY options.label "Opcions">
-<!ENTITY domainRestriction.label "Restringeix al domini:">
-<!ENTITY domainRestriction.accesskey "d">
-<!ENTITY domainRestriction.help "Especifica un o més dominis separats pel símbol &quot;|&quot;,, el filtre només s&apos;aplicarà a aquests dominis. El símbol &quot;~&quot; abans d&apos;un nom de domini significa que els filtre no s&apos;ha d&apos;aplicar en aquell domini.">
-<!ENTITY firstParty.label "Només originals">
-<!ENTITY firstParty.accesskey "o">
-<!ENTITY thirdParty.label "Només de tercers">
-<!ENTITY thirdParty.accesskey "T">
-<!ENTITY matchCase.label "Diferencia majúscules i minúscules">
-<!ENTITY matchCase.accesskey "M">
-<!ENTITY types.label "Aplicar als tipus:">
-<!ENTITY selectAllTypes.label "Selecciona-ho tot">
-<!ENTITY unselectAllTypes.label "No seleccionis res">
-<!ENTITY collapse.label "Col·lapsar els bloquejats:">
-<!ENTITY collapse.accesskey "l">
-<!ENTITY collapse.default.yes.label "Utilitza per defecte (si)">
-<!ENTITY collapse.default.no.label "Utilitza per defecte (no)">
-<!ENTITY collapse.yes.label "Si">
-<!ENTITY collapse.no.label "No">

=== removed file 'chrome/locale/ca-AD/global.properties'
--- chrome/locale/ca-AD/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/ca-AD/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Els anuncis eren ahir
-status_active_label=Adblock
-status_disabled_label=Desactivat
-action0_tooltip=Clica per activar el menu contextual, clica amb el botó del mig per activar/desactivar.
-action1_tooltip=Clica per obrir/tancar els elements bloquejables, clica amb el botó del mig per activar/desactivar.
-action2_tooltip=Clica per obrir les preferències, clica amb el botó del mig per activar/desactivar.
-action3_tooltip=Clica per activar/desactivar Adblock Plus
-active_tooltip=Adblock Plus està actiu
-disabled_tooltip=Adblock Plus està desactivat
-whitelisted_tooltip=Adblock Plus està actiu però desactivat en la pàgina actual
-blocked_count_tooltip=-- de --
-no_blocking_suggestions=La pàgina actual no conté elements bloquejables
-whitelisted_page=Adblock Plus ha estat desactivat per la pàgina actual
-whitelist_description=Regles d'excepció
-filterlist_description=Filtres d'anuncis
-invalid_description=Filtres invàlids
-elemhide_description=Regles per amagar elements
-subscription_description=Subscripció de filtres
-subscription_wrong_version=Alguns filtres d'aquesta subscripció requereixen Adblock Plus -- per funcionar correctament!
-subscription_source=Orígen:
-subscription_status=Estat:
-subscription_status_autodownload=Actualitzat automàticament
-subscription_status_manualdownload=Actualitzat manualment
-subscription_status_externaldownload=Actualitzat externament (una altra extensió)
-subscription_status_lastdownload=Ultima descàrrega
-subscription_status_lastdownload_inprogress=Descarregant...
-subscription_status_lastdownload_unknown=N/A
-remove_subscription_warning=Realment desitges eliminar aquesta subscripció?
-import_filters_wrong_version=Avís: alguns dels filtres en aquesta llista requereixen Adblock Plus -- per funcionar bé. Caldria actualitzar a l'última versió abans d'importar la llista
-import_filters_warning=Desitges substituïr els filtres actuals o afegir els nous filtres al final de la llista?
-import_filters_title=Importar filtres
-export_filters_title=Exportar filtres
-invalid_filters_file=Filtre Adblock Plus invàlid
-filters_write_error=Hi ha hagut un error escriving els filtre al fitxer. Comprova que els fitxer no està protegit contra l'escriptura o bloquejat per un altre programa
-clearall_warning=Realment desitges eliminar tots els filtres de la llista?
-resethitcounts_warning=Realment desitges reiniciar el comptador d'encerts per tots els filtres? La operació no es pot desfer!
-resethitcounts_selected_warning=Realment desitges reiniciar el comptador d'encerts per tots els filtres sel.lecionats? La operació no es pot desfer!
-filter_regexp_tooltip=El filtre és una expressió regular o és massa curt per ser optimitzat. Massa d'aquests filtres poden alentir la vostra navegació.
-filter_elemhide_duplicate_id=Només un identificador de l'element pot ser especificat
-filter_elemhide_nocriteria=Cap criteri especificat per reconeixes l'element a amagar
-subscription_no_location=Siusplau, entra una localització des d'on descarregar els filtres.
-subscription_invalid_location=La llista de filtres no és una URL vàlida ni un nom de fitxer vàlid.
-subscription_location_exists=Ja estàs subscrit a aquesta llista de filtres
-synchronize_invalid_url=Fallada, no és una adreça vàlida
-synchronize_connection_error=Fallada, error en la descàrrega
-synchronize_invalid_data=Fallada, no és una llista vàlida de filtres
-synchronize_checksum_mismatch=Error, el checksum no concorda
-synchronize_ok=Èxit
-overwrite=Sobreescriure
-append=Afegir
-new_filter_group_title=Nou filtre
-type_label_other=Un altre
-type_label_script=script
-type_label_image=imatge
-type_label_stylesheet=llista d'estils
-type_label_object=objecte
-type_label_subdocument=marc
-type_label_document=document
-type_label_background=fons
-type_label_elemhide=amagat
-type_label_xbl=Víncle XBL
-type_label_ping=enllaça ping
-type_label_xmlhttprequest=Petició XML
-type_label_object_subrequest=Subpetició d'objecte
-type_label_dtd=DTD
-type_label_media=audio/video
-type_label_font=font

=== removed file 'chrome/locale/ca-AD/overlay.dtd'
--- chrome/locale/ca-AD/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ca-AD/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Estat:">
-<!ENTITY blocked.tooltip "Elements bloquejats en aquesta pàgina:">
-<!ENTITY filters.tooltip "Filtres més actius:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Elements bloquejables">
-<!ENTITY context.image.label "Adblock imatge">
-<!ENTITY context.object.label "Adblock Objecte">
-<!ENTITY context.frame.label "Adblock Marc">
-<!ENTITY context.removeWhitelist.label "Adblock Plus:Rehabilita aquesta pàgina">
-<!ENTITY sidebar.title "Elements bloquejables a la pàgina actual">
-<!ENTITY settings.label "Preferències">
-<!ENTITY settings.accesskey "P">
-<!ENTITY opensidebar.label "Obre elements bloquejables">
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "Tanca elements bloquejables">
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Desactiva Adblock Plus a --">
-<!ENTITY whitelist.page.label "Desactiva només en aquesta pàgina">
-<!ENTITY objecttab.title "Bloqueja">
-<!ENTITY objecttab.tooltip "Clica aquí per bloquejar aquest objecte amb Adblock Plus">

=== removed file 'chrome/locale/ca-AD/settings.dtd'
--- chrome/locale/ca-AD/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ca-AD/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Preferències d&apos;Adblock Plus">
-<!ENTITY filters.label "Filtres">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Afegir filtre">
-<!ENTITY add.accesskey "G">
-<!ENTITY addsubscription.label "Afegir subscripció al filtre">
-<!ENTITY addsubscription.accesskey "S">
-<!ENTITY synchsubscriptions.label "Actualitza totes les subscripcions">
-<!ENTITY synchsubscriptions.accesskey "A">
-<!ENTITY import.label "Importar filtres">
-<!ENTITY import.accesskey "M">
-<!ENTITY export.label "Exportar Filtres">
-<!ENTITY export.accesskey "X">
-<!ENTITY clearall.label "Eliminar tots els filtres">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "Reinicia les estadístiques d&apos;encerts">
-<!ENTITY resethitcounts.accesskey "R">
-<!ENTITY edit.label "Edita">
-<!ENTITY edit.accesskey "E">
-<!ENTITY cut.label "Retalla">
-<!ENTITY cut.accesskey "L">
-<!ENTITY copy.label "Copia">
-<!ENTITY copy.accesskey "C">
-<!ENTITY paste.label "Enganxa">
-<!ENTITY paste.accesskey "x">
-<!ENTITY remove.label "Suprimeix">
-<!ENTITY remove.accesskey "u">
-<!ENTITY menu.find.label "Cerca">
-<!ENTITY menu.find.accesskey "R">
-<!ENTITY menu.findagain.label "Torna a cercar">
-<!ENTITY menu.findagain.accesskey "T">
-<!ENTITY view.label "Visualitza">
-<!ENTITY view.accesskey "V">
-<!ENTITY sort.label "Ordena per">
-<!ENTITY sort.accesskey "O">
-<!ENTITY sort.none.label "Desordenat">
-<!ENTITY sort.none.accesskey "D">
-<!ENTITY sort.ascending.label "Ordre A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Ordre Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Opcions">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Activa Adblock Plus">
-<!ENTITY enable.accesskey "A">
-<!ENTITY showintoolbar.label "Mostra a la barra d&apos;eines">
-<!ENTITY showintoolbar.accesskey "B">
-<!ENTITY showinstatusbar.label "Mostra a la barra d&apos;estat">
-<!ENTITY showinstatusbar.accesskey "S">
-<!ENTITY objecttabs.label "Mostra les pestanyes a Flash i Java">
-<!ENTITY objecttabs.accesskey "T">
-<!ENTITY collapse.label "Col·lapsa els elements bloquejats">
-<!ENTITY collapse.accesskey "L">
-<!ENTITY help.label "Ajuda">
-<!ENTITY help.accesskey "u">
-<!ENTITY gettingStarted.label "Començant">
-<!ENTITY gettingStarted.accesskey "C">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Preguntes més demanades (FAQ)">
-<!ENTITY faq.accesskey "F">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Escrivint filtres de Adblock Plus">
-<!ENTITY filterdoc.accesskey "E">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Sobre Adblock Plus">
-<!ENTITY about.accesskey "B">
-<!ENTITY description "Afegeix les adreces que desitgis bloquejar, per suggerències comprova la llista desplegable. Pots utilitzar * com a comodí per crear filtres més generals. Usuaris avançats poden utilitzar expressions regulars com /banner\d+\.gif$/.">
-<!ENTITY filter.column "Regla de filtre">
-<!ENTITY filter.accesskey "F">
-<!ENTITY slow.column "Filtres d&apos;aminorament">
-<!ENTITY slow.accesskey "w">
-<!ENTITY enabled.column "Activat">
-<!ENTITY enabled.accesskey "n">
-<!ENTITY hitcount.column "Encerts">
-<!ENTITY hitcount.accesskey "H">
-<!ENTITY lasthit.column "Ultim encert">
-<!ENTITY lasthit.accesskey "L">
-<!ENTITY context.edit.label "Edita filtre">
-<!ENTITY context.resethitcount.label "Reinicia estadístiques del filtre">
-<!ENTITY context.synchsubscription.label "Actualitza la subscripció ara">
-<!ENTITY context.editsubscription.label "Edita la subscripció">
-<!ENTITY context.moveup.label "Mou amunt">
-<!ENTITY context.movedown.label "Mou avall">
-<!ENTITY context.movegroupup.label "Mou grup amunt">
-<!ENTITY context.movegroupdown.label "Mou grup avall">
-<!ENTITY context.enable.label "Activa">
-<!ENTITY context.disable.label "Desactiva">
-<!ENTITY apply.label "Aplicar">
-<!ENTITY apply.accesskey "A">

=== removed file 'chrome/locale/ca-AD/sidebar.dtd'
--- chrome/locale/ca-AD/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ca-AD/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "AdBlock Plus: Elements Bloquejables (Separat)">
-<!ENTITY detach.label "Separar">
-<!ENTITY reattach.label "Reenganxar">
-<!ENTITY search.label "Cercar">
-<!ENTITY search.accesskey "r">
-<!ENTITY type.label "Tipus">
-<!ENTITY address.label "Adreça">
-<!ENTITY filter.label "Filtre">
-<!ENTITY state.label "Estat">
-<!ENTITY size.label "Mida">
-<!ENTITY docDomain.label "Font del document">
-<!ENTITY noitems.label "Elements no bloquejables">
-<!ENTITY whitelisted.label "Pàgina a la llista de permesos">
-<!ENTITY tooltip.address.label "Adreça">
-<!ENTITY tooltip.type.label "Tipus">
-<!ENTITY tooltip.type.blocked "(bloquejat)">
-<!ENTITY tooltip.type.whitelisted "(a la llista de permesos)">
-<!ENTITY tooltip.size.label "Mida">
-<!ENTITY tooltip.docDomain.label "Font del document:">
-<!ENTITY tooltip.filter.label "Filtre actiu">
-<!ENTITY tooltip.filterSource.label "Filtre d&apos;origen">
-<!ENTITY context.block.label "Bloqueja aquest element">
-<!ENTITY context.editfilter.label "Editar filtre actiu">
-<!ENTITY context.whitelist.label "Afegeix regla d&apos;excepció per l&apos;element">
-<!ENTITY context.disablefilter.label "Desactivar filtre">
-<!ENTITY context.enablefilter.label "Reactivar filtre">
-<!ENTITY context.disablefilteronsite.label "Desactiva aquest filtre a --">
-<!ENTITY context.open.label "Obrir en una nova pestanya">
-<!ENTITY context.flash.label "Pampalluguejar vores de l&apos;element">
-<!ENTITY context.copy.label "Copia l&apos;adreça de l&apos;element">
-<!ENTITY context.copyFilter.label "Copia Filtre">
-<!ENTITY context.selectAll.label "Selecciona tots">

=== removed file 'chrome/locale/ca-AD/subscription.dtd'
--- chrome/locale/ca-AD/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ca-AD/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Edita subscripció del filtre">
-<!ENTITY dialog.newtitle "Afegeix subscripció al filtre">
-<!ENTITY new.description "Siusplau, entra l&apos;adreça o fitxer amb la llista de filtres de Adblock Plus">
-<!ENTITY edit.description "La llista de filtres es baixarà de la localització donada.">
-<!ENTITY external.description "Això és una subscripció externa al filtre, la llsita de filtres serà mantinguda al dia per la extensió que la va crear.">
-<!ENTITY autodownload.description "Si sel.leciones &apos;Actualitzar automàticament&apos; aquest localització serà comprovada diàriament. Amb aquesta opció desactivada encara es pot sol.licitar una actualització manualment des del menú contextual de la subscripció.">
-<!ENTITY location.label "Filtra la localització de la llista:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Títol de la subscripció:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Actualitza automàticament">
-<!ENTITY autodownload.accesskey "Z">
-<!ENTITY enabled.label "Activa filtres">
-<!ENTITY enabled.accesskey "A">

=== removed file 'chrome/locale/ca-AD/tip_subscriptions.dtd'
--- chrome/locale/ca-AD/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ca-AD/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Benvinguts a Adblock Plus">
-<!ENTITY description.par1 "Gràcies per instal.lar AdBlock Plus. Aquesta extensió pot eliminar el 99&#37; del anuncis que veus a la xarxa. De totes maneres, un filtratge efectiu requereix que defineixis un bon conjunt de filtres. Ho pots fer tu mateix, o bé subscriure&apos;t a una llista de filtres que altres mantenen per tu. Encara serà possible que afegeixis els teus propis filtres i que desactivis/eliminis les subscripcions si ho creus necessari">
-<!ENTITY description.par2 "Pots triar una subscripció de la llista de subscripcions recomanades a sota (es poden afegir més subscripcions a les preferències d&apos;Adblock Plus més tard tot i que normalment no és necessari)">
-<!ENTITY note "Nota: Una llista de filtres es més efectiva quan s&apos;aplica a llocs web de la regió per la que es va crear el filtre.">
-<!ENTITY adblock.warning "Adblock Plus ha detectat que Adblock o una versió anterior de Adblock Plus està instal·lat. Executar Adblock i Adblock Plus en Paralel pot causar problemes i s&apos;hauria d&apos;evitar. Es recomana desinstal·lar Adblock.">
-<!ENTITY adblock.uninstall "Desinstal·lar Adblock">
-<!ENTITY filterset.g.warning "Sembla que s&apos;utilitza Filterset.G Aquest filtre quasi no s&apos;ha actualitzat en els últims anys i és una causa comú de problemes amb llocs web. Es recomana desinstal·lar Filterset.G ara.">
-<!ENTITY filterset.g.moreinfo "Més informació">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Desinstal·lar Filterset.G">
-<!ENTITY homepage.label "Pàgina principal">
-<!ENTITY subscribe.label "Subscriure">
-<!ENTITY subscribe.accesskey "S">
-<!ENTITY other.label "Afegir una altra subscripció">
-<!ENTITY other.accesskey "A">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Veure totes les subscripcions">

=== added file 'chrome/locale/ca/about.dtd'
--- chrome/locale/ca/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ca/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,13 @@
+<!ENTITY dialog.title "Sobre Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versió">
+<!ENTITY description "Adblock Plus et permet decidir que no vols veure a la xarxa.
+Ja no has de descarregar tots els anuncis i pancartes, si no els vols - digues-ho a Adblock Plus!">
+<!ENTITY homepage.label "Pàgina principal de Adblock Plus:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Autor">
+<!ENTITY contributors.label "Contribuïdors:">
+<!ENTITY developers.label "Desenvolupadors/es:">
+<!ENTITY designers.label "Dissenyadors/es gràfics:">
+<!ENTITY subscriptionAuthors.label "Autors/es del filtre de subscripció:">
+<!ENTITY translators.label "Traductors/es:">

=== added file 'chrome/locale/ca/composer.dtd'
--- chrome/locale/ca/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ca/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Afegir una regla de filtre d'Adblock Plus">
+<!ENTITY accept.label "Afegir filtre">
+<!ENTITY advanced.label "Visualització avançada">
+<!ENTITY basic.label "Visualització bàsica">
+<!ENTITY disabled.warning "Adblock Plus està desactivat. Encara es poden afegir filtres però no seran aplicats a menys que [link]activis Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "El filtre de grup &quot;?1?&quot; que aquest filtre hauria de ser afegit està deshabilitat.Pots afegir-lo encara però no apareixerà fins que [link]habilitis el filtre de grup[/link].">
+<!ENTITY filter.label "Nou filtre:">
+<!ENTITY filter.accesskey "n">
+<!ENTITY preferences.label "Mostra filtres existents...">
+<!ENTITY preferences.accesskey "S">
+<!ENTITY type.filter.label "Filtre de bloqueig">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Excepció">
+<!ENTITY type.whitelist.accesskey "x">
+<!ENTITY pattern.label "Cerca un patró">
+<!ENTITY pattern.explanation "El patró pot ser qualsevol part de l'adreça, el símbol ^ serveix de comodí. El filtre només s'aplicarà a adreces que concordin amb el filtre">
+<!ENTITY regexp.warning "El patró que s'ha entrat serà interpretat com una expressió regular. Massa expressions regulars poden alentir la navegació. Si no es volia utilitzar una expressió regular, afegir el símbol ^ al final del patró.">
+<!ENTITY shortpattern.warning "El patró entrat es massa curt per ser optimitzat, massa patrons d'aquest tipus poden alentir la navegació. Es recomana una cadena de text més llarga per aquest filtre.">
+<!ENTITY custom.pattern.label "Personalitzar:">
+<!ENTITY custom.pattern.accesskey "P">
+<!ENTITY anchors.label "Accepta només un patró:">
+<!ENTITY anchor.start.label "al començament de l'adreça">
+<!ENTITY anchor.start.accesskey "c">
+<!ENTITY anchor.start.flexible.label "al començament del nom de domini">
+<!ENTITY anchor.start.flexible.accesskey "c">
+<!ENTITY anchor.end.label "al final de l'adreça">
+<!ENTITY anchor.end.accesskey "f">
+<!ENTITY options.label "Opcions">
+<!ENTITY domainRestriction.label "Restringeix al domini:">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "Especifica un o més dominis separats pel símbol &quot;|&quot;,, el filtre només s'aplicarà a aquests dominis. El símbol &quot;~&quot; abans d'un nom de domini significa que els filtre no s'ha d'aplicar en aquell domini.">
+<!ENTITY firstParty.label "Només originals">
+<!ENTITY firstParty.accesskey "o">
+<!ENTITY thirdParty.label "Només de tercers">
+<!ENTITY thirdParty.accesskey "T">
+<!ENTITY matchCase.label "Diferencia majúscules i minúscules">
+<!ENTITY matchCase.accesskey "M">
+<!ENTITY types.label "Aplicar als tipus:">
+<!ENTITY selectAllTypes.label "Selecciona-ho tot">
+<!ENTITY unselectAllTypes.label "No seleccionis res">
+<!ENTITY collapse.label "Col·lapsar els bloquejats:">
+<!ENTITY collapse.accesskey "l">
+<!ENTITY collapse.default.yes.label "Utilitza per defecte (si)">
+<!ENTITY collapse.default.no.label "Utilitza per defecte (no)">
+<!ENTITY collapse.yes.label "Sí">
+<!ENTITY collapse.no.label "No">

=== added file 'chrome/locale/ca/global.properties'
--- chrome/locale/ca/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ca/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Clica per activar el menu contextual, clica amb el botó del mig per activar/desactivar.
+action1_tooltip=Clica per obrir/tancar els elements bloquejables, clica amb el botó del mig per activar/desactivar.
+action2_tooltip=Clica per obrir les preferències, clica amb el botó del mig per activar/desactivar.
+action3_tooltip=Clica per activar/desactivar Adblock Plus
+disabled_tooltip=Adblock Plus està desactivat
+active_tooltip=Adblock Plus està habilitat, ?1? subscripció (ns) de filtre i ?2? filtre personalitzats(s) en ús.
+whitelisted_tooltip=Adblock Plus està actiu però desactivat en la pàgina actual
+blocked_count_tooltip=?1?  de ?2?
+blocked_count_addendum=(també a la llista blanca: ?1?, amagats: ?2?)
+no_blocking_suggestions=La pàgina actual no conté elements bloquejables
+whitelisted_page=Adblock Plus ha estat desactivat per la pàgina actual
+whitelist_description=Regles d'excepció
+filterlist_description=Filtres d'anuncis
+invalid_description=Filtres invàlids
+elemhide_description=Regles per amagar elements
+subscription_description=Subscripció de filtres
+subscription_wrong_version=Alguns filtres d'aquesta subscripció requereixen Adblock Plus ?1? per funcionar correctament!
+subscription_source=Orígen:
+subscription_status=Estat:
+subscription_status_autodownload=Actualitzat automàticament
+subscription_status_manualdownload=Actualitzat manualment
+subscription_status_externaldownload=Actualitzat externament (una altra extensió)
+subscription_status_lastdownload=Ultima descàrrega
+subscription_status_lastdownload_inprogress=Descarregant...
+subscription_status_lastdownload_unknown=N/A
+remove_subscription_warning=Realment desitges eliminar aquesta subscripció?
+import_filters_wrong_version=Avís: alguns dels filtres en aquesta llista requereixen Adblock Plus ?1? per funcionar bé. Caldria actualitzar a l'última versió abans d'importar la llista
+import_filters_warning=Desitges substituir els filtres actuals o afegir els nous filtres al final de la llista?
+import_filters_title=Importar filtres
+export_filters_title=Exportar filtres
+invalid_filters_file=Filtre Adblock Plus invàlid
+filters_write_error=Hi ha hagut un error escriving els filtre al fitxer. Comprova que els fitxer no està protegit contra l'escriptura o bloquejat per un altre programa
+clearall_warning=Realment desitges eliminar tots els filtres de la llista?
+resethitcounts_warning=Realment desitges reiniciar el comptador d'encerts per tots els filtres? La operació no es pot desfer!
+resethitcounts_selected_warning=Realment desitges reiniciar el comptador d'encerts per tots els filtres sel.lecionats? La operació no es pot desfer!
+filter_regexp_tooltip=El filtre és una expressió regular o és massa curt per ser optimitzat. Massa d'aquests filtres poden alentir la vostra navegació.
+filter_elemhide_duplicate_id=Només un identificador de l'element pot ser especificat
+filter_elemhide_nocriteria=Cap criteri especificat per reconeixes l'element a amagar
+subscription_notAdded_warning=No has afegit cap subscripció de filtre.Sense una subscripció de filtre necessitaràs afegir filtres Adblock Plus de forma manual.
+subscription_notAdded_warning_addendum=Ho vols fer?
+subscription_invalid_location=La llista de filtres no és una URL vàlida ni un nom de fitxer vàlid.
+synchronize_invalid_url=Fallada, no és una adreça vàlida
+synchronize_connection_error=Fallada, error en la descàrrega
+synchronize_invalid_data=Fallada, no és una llista vàlida de filtres
+synchronize_checksum_mismatch=Error, el checksum no concorda
+synchronize_ok=Èxit
+overwrite=Sobreescriure
+append=Afegir
+new_filter_group_title=Nou filtre
+type_label_other=Un altre
+type_label_script=script
+type_label_image=imatge
+type_label_stylesheet=llista d'estils
+type_label_object=objecte
+type_label_subdocument=marc
+type_label_document=document
+type_label_background=fons
+type_label_elemhide=amagat
+type_label_xbl=Víncle XBL
+type_label_ping=enllaça ping
+type_label_xmlhttprequest=Petició XML
+type_label_object_subrequest=Subpetició d'objecte
+type_label_dtd=DTD
+type_label_media=audio/video
+type_label_font=font
+fennec_status_enabled=Adblock Plus està activat.
+fennec_status_disabled=Adblock Plus està desactivat.
+fennec_status_enabled_site=Adblock Plus està activat en ?1?.
+fennec_status_disabled_site=Adblock Plus està desactivat en ?1?.

=== added file 'chrome/locale/ca/meta.properties'
--- chrome/locale/ca/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ca/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=el_libre www.catmidia.cat
+name=Adblock Plus
+description=Els anuncis eren ahir
+description.short=Molest/a pels anuncis?Preocupat per seguiment?Instal·la Adblock Plus ara per recuperar el control d'Internet i canviar la manera com veus la web.\n\n Aquí teniu un breu resum en vídeo a http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus li permet recuperar el control d'Internet i veure la web de la manera que desitja. L'afegit compta amb el suport de més de 40 subscripcions de filtres en desenes d'idiomes, que automàticament ho configurarà per a propòsits com l'eliminació de la publicitat en línia per bloquejar tots els dominis de malware conegut. Adblock Plus també us permet personalitzar els filtres amb l'assistència d'una varietat de característiques útils, incloent una opció de context per a les imatges, una fitxa per categories per als objectes de Flash i Java, i una llista d'elements amb bloqueig per eliminar els scripts i fulls d'estil.

=== added file 'chrome/locale/ca/overlay.dtd'
--- chrome/locale/ca/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ca/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Estat:">
+<!ENTITY blocked.tooltip "Elements bloquejats en aquesta pàgina:">
+<!ENTITY filters.tooltip "Filtres més actius:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Elements bloquejables">
+<!ENTITY context.image.label "Adblock imatge">
+<!ENTITY context.object.label "Adblock Objecte">
+<!ENTITY context.frame.label "Adblock Marc">
+<!ENTITY context.media.label "Adblock Plus: Bloqueja àudio/vídeo">
+<!ENTITY context.removeWhitelist.label "Adblock Plus:Rehabilita aquesta pàgina">
+<!ENTITY sidebar.title "Elements bloquejables a la pàgina actual">
+<!ENTITY settings.label "Preferències">
+<!ENTITY settings.accesskey "P">
+<!ENTITY opensidebar.label "Obre elements bloquejables">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "Tanca elements bloquejables">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "Desactiva Adblock Plus a ?1?">
+<!ENTITY whitelist.page.label "Desactiva només en aquesta pàgina">
+<!ENTITY objecttab.title "Bloqueja">
+<!ENTITY objecttab.tooltip "Clica aquí per bloquejar aquest objecte amb Adblock Plus">

=== added file 'chrome/locale/ca/settings.dtd'
--- chrome/locale/ca/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ca/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Preferències d&apos;Adblock Plus">
+<!ENTITY filters.label "Filtres">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Afegir filtre">
+<!ENTITY add.accesskey "G">
+<!ENTITY addsubscription.label "Afegir subscripció al filtre">
+<!ENTITY addsubscription.accesskey "S">
+<!ENTITY synchsubscriptions.label "Actualitza totes les subscripcions">
+<!ENTITY synchsubscriptions.accesskey "A">
+<!ENTITY import.label "Importar filtres">
+<!ENTITY import.accesskey "M">
+<!ENTITY export.label "Exportar Filtres">
+<!ENTITY export.accesskey "X">
+<!ENTITY clearall.label "Eliminar tots els filtres">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "Reinicia les estadístiques d&apos;encerts">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "Edita">
+<!ENTITY edit.accesskey "E">
+<!ENTITY cut.label "Retalla">
+<!ENTITY cut.accesskey "L">
+<!ENTITY copy.label "Copia">
+<!ENTITY copy.accesskey "C">
+<!ENTITY paste.label "Enganxa">
+<!ENTITY paste.accesskey "x">
+<!ENTITY remove.label "Suprimeix">
+<!ENTITY remove.accesskey "u">
+<!ENTITY menu.find.label "Cerca">
+<!ENTITY menu.find.accesskey "R">
+<!ENTITY menu.findagain.label "Torna a cercar">
+<!ENTITY menu.findagain.accesskey "T">
+<!ENTITY view.label "Visualitza">
+<!ENTITY view.accesskey "V">
+<!ENTITY sort.label "Ordena per">
+<!ENTITY sort.accesskey "O">
+<!ENTITY sort.none.label "Desordenat">
+<!ENTITY sort.none.accesskey "D">
+<!ENTITY sort.ascending.label "Ordre A &gt; Z">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Ordre Z &gt; A">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Opcions">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Activa Adblock Plus">
+<!ENTITY enable.accesskey "A">
+<!ENTITY showintoolbar.label "Mostra a la barra d&apos;eines">
+<!ENTITY showintoolbar.accesskey "B">
+<!ENTITY showinstatusbar.label "Mostra a la barra d&apos;estat">
+<!ENTITY showinstatusbar.accesskey "S">
+<!ENTITY objecttabs.label "Mostra les pestanyes a Flash i Java">
+<!ENTITY objecttabs.accesskey "T">
+<!ENTITY collapse.label "Col·lapsa els elements bloquejats">
+<!ENTITY collapse.accesskey "L">
+<!ENTITY help.label "Ajuda">
+<!ENTITY help.accesskey "u">
+<!ENTITY gettingStarted.label "Començant">
+<!ENTITY gettingStarted.accesskey "C">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Preguntes més demanades (FAQ)">
+<!ENTITY faq.accesskey "F">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Escrivint filtres de Adblock Plus">
+<!ENTITY filterdoc.accesskey "E">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Sobre Adblock Plus">
+<!ENTITY about.accesskey "B">
+<!ENTITY description "Afegeix les adreces que desitgis bloquejar, per suggerències comprova la llista desplegable. Pots utilitzar * com a comodí per crear filtres més generals. Usuaris avançats poden utilitzar expressions regulars com /banner\d+\.gif$/.">
+<!ENTITY filter.column "Regla de filtre">
+<!ENTITY filter.accesskey "F">
+<!ENTITY slow.column "Filtres d&apos;aminorament">
+<!ENTITY slow.accesskey "w">
+<!ENTITY enabled.column "Activat">
+<!ENTITY enabled.accesskey "n">
+<!ENTITY hitcount.column "Encerts">
+<!ENTITY hitcount.accesskey "H">
+<!ENTITY lasthit.column "Ultim encert">
+<!ENTITY lasthit.accesskey "L">
+<!ENTITY context.edit.label "Edita filtre">
+<!ENTITY context.resethitcount.label "Reinicia estadístiques del filtre">
+<!ENTITY context.synchsubscription.label "Actualitza la subscripció ara">
+<!ENTITY context.editsubscription.label "Edita la subscripció">
+<!ENTITY context.moveup.label "Mou amunt">
+<!ENTITY context.movedown.label "Mou avall">
+<!ENTITY context.movegroupup.label "Mou grup amunt">
+<!ENTITY context.movegroupdown.label "Mou grup avall">
+<!ENTITY context.enable.label "Activa">
+<!ENTITY context.disable.label "Desactiva">
+<!ENTITY apply.label "Aplicar">
+<!ENTITY apply.accesskey "A">
+<!ENTITY fennec.subscription.label "Subcripció de filtre">

=== added file 'chrome/locale/ca/sidebar.dtd'
--- chrome/locale/ca/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ca/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "AdBlock Plus: Elements Bloquejables (Separat)">
+<!ENTITY detach.label "Separar">
+<!ENTITY reattach.label "Reenganxar">
+<!ENTITY search.label "Cercar">
+<!ENTITY search.accesskey "r">
+<!ENTITY type.label "Tipus">
+<!ENTITY address.label "Adreça">
+<!ENTITY filter.label "Filtre">
+<!ENTITY state.label "Estat">
+<!ENTITY size.label "Mida">
+<!ENTITY docDomain.label "Font del document">
+<!ENTITY noitems.label "Elements no bloquejables">
+<!ENTITY whitelisted.label "Pàgina a la llista de permesos">
+<!ENTITY tooltip.address.label "Adreça">
+<!ENTITY tooltip.type.label "Tipus">
+<!ENTITY tooltip.type.blocked "(bloquejat)">
+<!ENTITY tooltip.type.whitelisted "(a la llista de permesos)">
+<!ENTITY tooltip.size.label "Mida">
+<!ENTITY tooltip.docDomain.label "Font del document:">
+<!ENTITY tooltip.filter.label "Filtre actiu">
+<!ENTITY tooltip.filterSource.label "Filtre d'origen">
+<!ENTITY context.block.label "Bloqueja aquest element">
+<!ENTITY context.editfilter.label "Editar filtre actiu">
+<!ENTITY context.whitelist.label "Afegeix regla d'excepció per l'element">
+<!ENTITY context.disablefilter.label "Desactivar filtre ?1?">
+<!ENTITY context.enablefilter.label "Reactivar filtre ?1?">
+<!ENTITY context.disablefilteronsite.label "Desactiva aquest filtre a ?1?">
+<!ENTITY context.open.label "Obrir en una nova pestanya">
+<!ENTITY context.flash.label "Pampalluguejar vores de l'element">
+<!ENTITY context.copy.label "Copia l'adreça de l'element">
+<!ENTITY context.copyFilter.label "Copia Filtre">
+<!ENTITY context.selectAll.label "Selecciona tots">

=== added file 'chrome/locale/ca/subscriptionSelection.dtd'
--- chrome/locale/ca/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ca/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Afegeix la subscripció de filtre per a Adblock Plus">
+<!ENTITY dialog.title.edit "Edita subscripció del filtre">
+<!ENTITY description.newInstall "Adblock Plus serà més eficaç si s'afegeix un filtre de subscripció. Filtre subscripcions són proporcionats per altres usuaris de Adblock Plus gratis en el preu. La subscripció més adequat per al seu idioma ja està seleccionat.">
+<!ENTITY adblock.warning "Adblock Plus ha detectat que Adblock o una versió anterior de Adblock Plus està instal·lat. Executar Adblock i Adblock Plus en Paralel pot causar problemes i s'hauria d'evitar. Es recomana desinstal·lar Adblock.">
+<!ENTITY adblock.uninstall "Desinstal·lar Adblock">
+<!ENTITY filterset.g.warning "Sembla que s'utilitza Filterset.G Aquest filtre quasi no s'ha actualitzat en els últims anys i és una causa comú de problemes amb llocs web. Es recomana desinstal·lar Filterset.G ara.">
+<!ENTITY filterset.g.moreinfo "Més informació">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Desinstal·lar Filterset.G">
+<!ENTITY subscriptionSelector.label "Si us plau tria una subscripció de filtre a la llista:">
+<!ENTITY viewList.label "Veure filtres">
+<!ENTITY visitHomepage.label "Vista la pàgina web">
+<!ENTITY addSubscription.label "Afegeix subscripció">
+<!ENTITY saveSubscription.label "Salva subscripció">
+<!ENTITY other.label "Afegir una altra subscripció">
+<!ENTITY other.accesskey "A">
+<!ENTITY list.download.failed "Adblock Plus ha fallat en trobar la llista de les subscripcions.">
+<!ENTITY list.download.retry "Torna-ho a provar">
+<!ENTITY list.download.website "Veure pàgina web">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Si us plau confirma que vols afegir aquesta subscripció de filtre.Pots canviar el títol de la subscripció o la localització abans d'afegir-la.">
+<!ENTITY edit.description "Pots canviar el títol o localització segons sigui necessari.">
+<!ENTITY external.description "Aquesta és una subscripció de filtre externa; serà actualitzada per l'extensió que l'ha creada.">
+<!ENTITY title.label "Títol de la subscripció:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Filtra la localització de la llista:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Actualitza automàticament">
+<!ENTITY autodownload.accesskey "Z">
+<!ENTITY supplementMessage "Aquesta subscripció de filtre s'ha de fer servir amb la subscripció de filtre &quot;?1?&quot; que encara no fas servir.">
+<!ENTITY addMain.label "Afegeix subscripció de filtre &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "s">

=== added directory 'chrome/locale/cs'
=== removed directory 'chrome/locale/cs-CZ'
=== removed file 'chrome/locale/cs-CZ/about.dtd'
--- chrome/locale/cs-CZ/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/cs-CZ/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "O rozšíření Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Verze">
-<!ENTITY description "Adblock Plus vám umožní rozhodovat o tom, co nechcete na web stránkách vidět. Mimo jiné vám umožní blokování nežádoucích všudypřítomných reklam. S Adblock Plus se s nimi už nikdy nemusíte na webu setkat.">
-<!ENTITY homepage.label "Domovské stránky Adblock Plus:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Autor:">
-<!ENTITY contributors.label "Spoluautoři:">

=== removed file 'chrome/locale/cs-CZ/composer.dtd'
--- chrome/locale/cs-CZ/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/cs-CZ/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Přidat pravidlo filtru Adblock Plus">
-<!ENTITY accept.label "Přidat filtr">
-<!ENTITY advanced.label "Rozšířené zobrazení">
-<!ENTITY basic.label "Základní zobrazení">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus je momentálně zakázán. Můžete stále přidávat filtry, ale nebudou aplikovány dokud">
-<!ENTITY disabled.warning.link "nepovolíte Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Skupina filtrů &quot;&#37;S&quot;, do které chcete přidat tento filtr, je momentálně zakázaná. Filtr můžete přidat, ale nebude aplikován, dokud">
-<!ENTITY groupDisabled.warning.link "nepovolíte skupinu filtrů">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Nový filtr:">
-<!ENTITY filter.accesskey "f">
-<!ENTITY preferences.label "Zobrazit existující filtry...">
-<!ENTITY preferences.accesskey "e">
-<!ENTITY type.filter.label "Blokující filtr">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "Výjimka">
-<!ENTITY type.whitelist.accesskey "V">
-<!ENTITY pattern.label "Vyhledat vzor">
-<!ENTITY pattern.explanation "Vzor může být jakákoli část adresy, znak * funguje jako divoká karta. Filtr bude aplikován pouze na adresy odpovídající vzoru.">
-<!ENTITY regexp.warning "Vzor, který jste zadali, bude interpretován jako regulární výraz. Mnoho regulárních výrazů může zpomalit vaše prohlížení stránek. Pokud jste nechěli použít regulární výraz, přidejte znak * na konec vzoru.">
-<!ENTITY shortpattern.warning "Vzor, který jste zadali, je příliš krátký, aby mohl být optimalizován. Mnoho takových výrazů může zpomalit vaše prohlížení stránek. Je doporučeno, abyste pro tento filtr zadali delší řetězec.">
-<!ENTITY custom.pattern.label "Vlastní:">
-<!ENTITY custom.pattern.accesskey "n">
-<!ENTITY anchors.label "Povolit vzor pouze:">
-<!ENTITY anchor.start.label "na začátku adresy">
-<!ENTITY anchor.start.accesskey "z">
-<!ENTITY anchor.start.flexible.label "na začátku názvu domény">
-<!ENTITY anchor.start.flexible.accesskey "z">
-<!ENTITY anchor.end.label "na konci adresy">
-<!ENTITY anchor.end.accesskey "k">
-<!ENTITY options.label "Možnosti">
-<!ENTITY domainRestriction.label "Omezit na doménu:">
-<!ENTITY domainRestriction.accesskey "d">
-<!ENTITY domainRestriction.help "Zadejte jednu nebo více domén oddělených znakem &quot;|&quot;, filtr bude poté použit pouze na těchto doménách. Znak &quot;~&quot; před názvem domény zajistí, že filtr nebude na této doméně použit.">
-<!ENTITY firstParty.label "Pouze vlastní filtry">
-<!ENTITY firstParty.accesskey "a">
-<!ENTITY thirdParty.label "Pouze filtry třetích stran">
-<!ENTITY thirdParty.accesskey "t">
-<!ENTITY matchCase.label "Rozlišovat velikost">
-<!ENTITY matchCase.accesskey "R">
-<!ENTITY types.label "Použít na typy:">
-<!ENTITY selectAllTypes.label "Vybrat vše">
-<!ENTITY unselectAllTypes.label "Zrušit výběr">
-<!ENTITY collapse.label "Minimalizovat blokované objekty:">
-<!ENTITY collapse.accesskey "i">
-<!ENTITY collapse.default.yes.label "Použít výchozí (ano)">
-<!ENTITY collapse.default.no.label "Použít výchozí (ne)">
-<!ENTITY collapse.yes.label "Ano">
-<!ENTITY collapse.no.label "Ne">

=== removed file 'chrome/locale/cs-CZ/global.properties'
--- chrome/locale/cs-CZ/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/cs-CZ/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=A reklamy jsou minulostí!
-status_active_label=Adblock
-status_disabled_label=Neaktivní
-action0_tooltip=Levé tlačítko: Otevřít místní nabídku
-action1_tooltip=Levé tlačítko: Otevřít blokovatelné prvky
-action2_tooltip=Levé tlačítko: Otevřít předvolby
-action3_tooltip=Klepnutím povolit/zakázat Adblock Plus
-active_tooltip=Adblock Plus je aktivní
-disabled_tooltip=Adblock Plus je zakázán
-whitelisted_tooltip=Adblock Plus je aktivní, ale pro aktuální stránku byl zakázán.
-blocked_count_tooltip=-- z --
-no_blocking_suggestions=Na této stránce nebyly nalezeny prvky k zablokování
-whitelisted_page=Adblock Plus byl pro aktuální stránku zakázán
-whitelist_description=Mé výjimky
-filterlist_description=Má pravidla blokování reklam
-invalid_description=Má chybná pravidla
-elemhide_description=Má pravidla pro skrývání elementů
-subscription_description=Cizí sady filtrů:
-subscription_wrong_version=Některé filtry v tomto seznamu vyžadují ke správné funkci Adblock Plus --
-subscription_source=Zdroj:
-subscription_status=Stav:
-subscription_status_autodownload=Automaticky aktualizováno
-subscription_status_manualdownload=Manuálně aktualizováno
-subscription_status_externaldownload=Aktualizováno externě (jiným rozšířením)
-subscription_status_lastdownload=Naposledy staženo:
-subscription_status_lastdownload_inprogress=Stahuji...
-subscription_status_lastdownload_unknown=neznámo
-remove_subscription_warning=Skutečně si přejete odstranit tuto sadu cizích filtrů ?
-import_filters_wrong_version=Varování: Některé z filtrů tohoto seznamu vyžadují ke správné funkčnosti Adblock Plus --. Pravděpodobně byste měli aktualizovat Adblock Plus před importováním tohoto seznamu.
-import_filters_warning=Přejete si nahradit aktuální filtry nebo chcete nové filtry přidat na konec seznamu?
-import_filters_title=Importovat filtry
-export_filters_title=Exportovat filtry
-invalid_filters_file=Toto není soubor filtrů Adblock Plus.
-filters_write_error=Nepodařilo se zapsat filtry do souboru. Ujistěte se, že soubor není chráněn proti zápisu nebo blokován jiným programem.
-clearall_warning=Opravdu chcete odstranit všechny filtry ze seznamu?
-resethitcounts_warning=Opravdu chcete vynulovat počítadla všech filtrů? Tuto operaci nelze vrátit zpět.
-resethitcounts_selected_warning=Opravdu chcete vynulovat počítadla vybraných filtrů? Tuto operaci nelze vrátit zpět.
-filter_regexp_tooltip=Tento filtr je buď regulární výraz nebo je příliš krátký, aby mohl být optimalizován. Příliš mnoho takových filtrů může zpomalit vaše prohlížení stránek.
-filter_elemhide_duplicate_id=Může být uvedeno pouze jedno ID elementu, který má být skryt
-filter_elemhide_nocriteria=Nebyla uvedena žádná kritérie pro rozpoznání elementu, který má být skryt
-subscription_no_location=Zadejte prosím adresu, ze které se mají stahovat cizí filtry.
-subscription_invalid_location=Zadaná adresa seznamu cizích filtrů je buď nesprávná URL nebo obsahuje nesprávné jméno souboru.
-subscription_location_exists=Tento seznam cizích filtrů již odebíráte.
-synchronize_invalid_url=Chyba, toto je nekorektní adresa.
-synchronize_connection_error=Chyba, nepodařilo se stáhnout soubor
-synchronize_invalid_data=Chyba, stažený soubor není souborem filtrů Adblock Plus
-synchronize_checksum_mismatch=Chyba, neodpovídá kontrolní součet
-synchronize_ok=Úspěch
-overwrite=Přepsat
-append=Přidat
-new_filter_group_title=Nový filtr
-type_label_other=Ostatní
-type_label_script=Skript
-type_label_image=Obrázek
-type_label_stylesheet=Šablona kaskádových stylů
-type_label_object=Objekt
-type_label_subdocument=Rámec
-type_label_document=Dokument
-type_label_background=Pozadí
-type_label_elemhide=skryto
-type_label_xbl=XBL vazba
-type_label_ping=link ping
-type_label_xmlhttprequest=XML požadavek
-type_label_object_subrequest=Subpožadavek objektu
-type_label_dtd=DTD
-type_label_media=audio/video
-type_label_font=Písmo

=== removed file 'chrome/locale/cs-CZ/overlay.dtd'
--- chrome/locale/cs-CZ/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/cs-CZ/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Stav:">
-<!ENTITY blocked.tooltip "Blokované prvky na této stránce:">
-<!ENTITY filters.tooltip "Nejúčinnější filtry:">
-<!ENTITY menuitem.label "Předvolby Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Blokovatelné objekty">
-<!ENTITY context.image.label "Blokovat obrázek">
-<!ENTITY context.object.label "Blokovat objekt">
-<!ENTITY context.frame.label "Blokovat rámec">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Znovu povolit na této stránce">
-<!ENTITY sidebar.title "Adblock Plus: Blokovatelné objekty na zobrazené stránce">
-<!ENTITY settings.label "Předvolby">
-<!ENTITY settings.accesskey "d">
-<!ENTITY opensidebar.label "Zobrazit blokovatelné objekty">
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "Skrýt seznam blokovatelných objektů">
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Vypnout na --">
-<!ENTITY whitelist.page.label "Vypnout pouze na této stránce">
-<!ENTITY objecttab.title "Blokovat">
-<!ENTITY objecttab.tooltip "Klepněte zde pro blokování tohoto objektu pomocí Adblock Plus">

=== removed file 'chrome/locale/cs-CZ/settings.dtd'
--- chrome/locale/cs-CZ/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/cs-CZ/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Předvolby Adblock Plus">
-<!ENTITY filters.label "Filtry">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Přidat filtr">
-<!ENTITY add.accesskey "P">
-<!ENTITY addsubscription.label "Přidat cizí filtry">
-<!ENTITY addsubscription.accesskey "c">
-<!ENTITY synchsubscriptions.label "Aktualizovat všechny cizí sady filtrů">
-<!ENTITY synchsubscriptions.accesskey "A">
-<!ENTITY import.label "Importovat filtry ze souboru">
-<!ENTITY import.accesskey "I">
-<!ENTITY export.label "Exportovat vlastní filtry do souboru">
-<!ENTITY export.accesskey "x">
-<!ENTITY clearall.label "Odstranit všechny vlastní filtry">
-<!ENTITY clearall.accesskey "O">
-<!ENTITY resethitcounts.label "Vynulovat počítadla zásahů">
-<!ENTITY resethitcounts.accesskey "V">
-<!ENTITY edit.label "Úpravy">
-<!ENTITY edit.accesskey "A">
-<!ENTITY cut.label "Vyjmout">
-<!ENTITY cut.accesskey "j">
-<!ENTITY copy.label "Kopírovat">
-<!ENTITY copy.accesskey "K">
-<!ENTITY paste.label "Vložit">
-<!ENTITY paste.accesskey "l">
-<!ENTITY remove.label "Smazat">
-<!ENTITY remove.accesskey "z">
-<!ENTITY menu.find.label "Najít">
-<!ENTITY menu.find.accesskey "N">
-<!ENTITY menu.findagain.label "Najít další">
-<!ENTITY menu.findagain.accesskey "d">
-<!ENTITY view.label "Zobrazit">
-<!ENTITY view.accesskey "Z">
-<!ENTITY sort.label "Seřadit podle">
-<!ENTITY sort.accesskey "S">
-<!ENTITY sort.none.label "Neřadit">
-<!ENTITY sort.none.accesskey "N">
-<!ENTITY sort.ascending.label "Vzestupně (A-Z)">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Sestupně (Z-A)">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Možnosti">
-<!ENTITY options.accesskey "M">
-<!ENTITY enable.label "Aktivovat Adblock Plus">
-<!ENTITY enable.accesskey "k">
-<!ENTITY showintoolbar.label "Zobrazit v nástrojové liště">
-<!ENTITY showintoolbar.accesskey "b">
-<!ENTITY showinstatusbar.label "Zobrazit ve stavovém řádku">
-<!ENTITY showinstatusbar.accesskey "r">
-<!ENTITY objecttabs.label "Zobrazovat ouška u objektů Java a Flash">
-<!ENTITY objecttabs.accesskey "o">
-<!ENTITY collapse.label "Minimalizovat blokované objekty">
-<!ENTITY collapse.accesskey "i">
-<!ENTITY help.label "Nápověda">
-<!ENTITY help.accesskey "v">
-<!ENTITY gettingStarted.label "Začínáme">
-<!ENTITY gettingStarted.accesskey "Z">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Často kladené dotazy (FAQ)">
-<!ENTITY faq.accesskey "q">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Psaní Adblock Plus filtrů">
-<!ENTITY filterdoc.accesskey "f">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "O doplňku Adblock Plus">
-<!ENTITY about.accesskey "o">
-<!ENTITY description "Následující filtry rozhodují, které adresy budou blokovány a které budou povoleny:">
-<!ENTITY filter.column "Pravidlo filtru">
-<!ENTITY filter.accesskey "P">
-<!ENTITY slow.column "Pomalé filtry">
-<!ENTITY slow.accesskey "m">
-<!ENTITY enabled.column "Aktivní">
-<!ENTITY enabled.accesskey "k">
-<!ENTITY hitcount.column "Zásahy">
-<!ENTITY hitcount.accesskey "h">
-<!ENTITY lasthit.column "Poslední zásah">
-<!ENTITY lasthit.accesskey "l">
-<!ENTITY context.edit.label "Přidat filtr">
-<!ENTITY context.resethitcount.label "Vynulovat počítadlo zásahů tohoto filtru">
-<!ENTITY context.synchsubscription.label "Aktualizovat seznam cizích filtrů">
-<!ENTITY context.editsubscription.label "Upravit cizí filtry">
-<!ENTITY context.moveup.label "Posunout filtr nahoru">
-<!ENTITY context.movedown.label "Posunout filtr dolů">
-<!ENTITY context.movegroupup.label "Posunout skupinu nahoru">
-<!ENTITY context.movegroupdown.label "Posunout skupinu dolů">
-<!ENTITY context.enable.label "Povolit">
-<!ENTITY context.disable.label "Zakázat">
-<!ENTITY apply.label "Použít">
-<!ENTITY apply.accesskey "U">

=== removed file 'chrome/locale/cs-CZ/sidebar.dtd'
--- chrome/locale/cs-CZ/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/cs-CZ/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Blokovatelné prvky (odděleno)">
-<!ENTITY detach.label "Oddělit">
-<!ENTITY reattach.label "Připojit">
-<!ENTITY search.label "Hledat:">
-<!ENTITY search.accesskey "H">
-<!ENTITY type.label "Typ">
-<!ENTITY address.label "Adresa">
-<!ENTITY filter.label "Filtr">
-<!ENTITY state.label "Stav">
-<!ENTITY size.label "Velikost">
-<!ENTITY docDomain.label "Zdroj dokumentu">
-<!ENTITY noitems.label "Nic nebylo zablokováno">
-<!ENTITY whitelisted.label "Adresa je na bílé listině">
-<!ENTITY tooltip.address.label "Adresa:">
-<!ENTITY tooltip.type.label "Typ:">
-<!ENTITY tooltip.type.blocked "(blokováno)">
-<!ENTITY tooltip.type.whitelisted "(na bílé listině)">
-<!ENTITY tooltip.size.label "Velikost:">
-<!ENTITY tooltip.docDomain.label "Zdroj dokumentu:">
-<!ENTITY tooltip.filter.label "Použité filtry:">
-<!ENTITY tooltip.filterSource.label "Zdroj filtru:">
-<!ENTITY context.block.label "Blokovat tento objekt">
-<!ENTITY context.editfilter.label "Upravit příslušný filtr">
-<!ENTITY context.whitelist.label "Přidat výjimku pro tento objekt">
-<!ENTITY context.disablefilter.label "Zakázat filtr --">
-<!ENTITY context.enablefilter.label "Opět povolit filtr --">
-<!ENTITY context.disablefilteronsite.label "Zakázat tento filtr na --">
-<!ENTITY context.open.label "Otevřít v novém panelu">
-<!ENTITY context.flash.label "Blikání obrysu objektu">
-<!ENTITY context.copy.label "Kopírovat adresu objektu">
-<!ENTITY context.copyFilter.label "Kopírovat filtr">
-<!ENTITY context.selectAll.label "Vybrat vše">

=== removed file 'chrome/locale/cs-CZ/subscription.dtd'
--- chrome/locale/cs-CZ/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/cs-CZ/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-<!ENTITY dialog.title "Upravit sadu cizích filtrů">
-<!ENTITY dialog.newtitle "Přidat sadu cizích filtrů">
-<!ENTITY new.description "Níže zadejte URL adresu souboru obsahujícího seznam
-cizích filtrů pro AdBlock Plus.">
-<!ENTITY edit.description "Seznam filtrů bude stažen ze zadané adresy.">
-<!ENTITY external.description "Tuto sadu filtrů zaregistrovalo jiné rozšíření. To ji má plně ve své režii a stará se o její aktualizaci.">
-<!ENTITY autodownload.description "Pokud povolíte automatickou aktualizaci cizích 
-filtrů, bude automaticky každý den stažena jejich
-aktuální verze. Pokud tuto volbu nepovolíte, bude
-stále možné provádět aktualizace alespoň manuálně
-pomocí příslušné volby v místní nabídce.">
-<!ENTITY location.label "Umístění sady filtrů:">
-<!ENTITY location.accesskey "U">
-<!ENTITY title.label "Označení cizích filtrů:">
-<!ENTITY title.accesskey "O">
-<!ENTITY autodownload.label "Automaticky aktualizovat">
-<!ENTITY autodownload.accesskey "A">
-<!ENTITY enabled.label "Aplikovat filtry">
-<!ENTITY enabled.accesskey "p">

=== removed file 'chrome/locale/cs-CZ/tip_subscriptions.dtd'
--- chrome/locale/cs-CZ/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/cs-CZ/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Přidat sadu cizích filtrů Adblock Plus">
-<!ENTITY description.par1 "Děkujeme, že jste nainstalovali Adblock Plus. Toto rozšíření Vám umožní odstranit 99&#37; reklam na webu. Efektivní blokování reklam ovšem vyžaduje dobře vytvořenou sadu filtrů. Ty můžete přidat sami, nebo si jednoduše můžete objednat příjem sad filtrů, které spravuje někdo jiný. I tak bude možné přidávat vlastní filtry i vypnout nebo odstranit používané cizí filtry.">
-<!ENTITY description.par2 "Níže si můžete vybrat ze seznamu doporučených sad cizích filtrů (další cizí filtry můžete přidat v Předvolbách Adblock Plus později, i když to většinou není nutné):">
-<!ENTITY note "Poznámka: Nejúčinnější sada filtrů bude pochopitelně právě ta, jejíž správce má nejblíže vašemu regionu či jazyku.">
-<!ENTITY adblock.warning "Adblock Plus zjistil, že je nainstalován Adblock nebo starší verze Adblocku Plus. Používání Adblocku a Adblocku Plus zároveň může způsobovat problémy a je lepší se tomu vyhnout. Je doporučeno, abyste nyní odinstalovali Adblock.">
-<!ENTITY adblock.uninstall "Odinstalovat Adblock">
-<!ENTITY filterset.g.warning "Zdá se, že používáte Filterset.G. Tento seznam filtrů nebyl v poslední době téměř spravován a je častým zdrojem problémů s webovými stránkami. Je doporučeno, abyste není odinstalovali Filterset.G.">
-<!ENTITY filterset.g.moreinfo "Více informací">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Odinstalovat Filterset.G">
-<!ENTITY homepage.label "Domovská stránka">
-<!ENTITY subscribe.label "Přidat">
-<!ENTITY subscribe.accesskey "P">
-<!ENTITY other.label "Přidat další sadu cizích filtrů">
-<!ENTITY other.accesskey "d">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Zobrazit všechny sady cizích filtrů">

=== added file 'chrome/locale/cs/about.dtd'
--- chrome/locale/cs/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/cs/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "O rozšíření Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Verze">
+<!ENTITY description "Adblock Plus vám umožní rozhodovat o tom, co nechcete na web stránkách vidět. Mimo jiné vám umožní blokování nežádoucích všudypřítomných reklam. S Adblock Plus se s nimi už nikdy nemusíte na webu setkat.">
+<!ENTITY homepage.label "Domovské stránky Adblock Plus:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Autor:">
+<!ENTITY contributors.label "Spoluautoři:">
+<!ENTITY developers.label "Vývojáří:">
+<!ENTITY designers.label "Grafici:">
+<!ENTITY subscriptionAuthors.label "Autoři sad cizích filtrů:">
+<!ENTITY translators.label "Překladatelé:">

=== added file 'chrome/locale/cs/composer.dtd'
--- chrome/locale/cs/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/cs/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Přidat pravidlo filtru Adblock Plus">
+<!ENTITY accept.label "Přidat filtr">
+<!ENTITY advanced.label "Rozšířené zobrazení">
+<!ENTITY basic.label "Základní zobrazení">
+<!ENTITY disabled.warning "Adblock Plus je momentálně zakázán. Můžete stále přidávat filtry, ale nebudou aplikovány dokud [link]nepovolíte Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Skupina filtrů &quot;?1?&quot;, do které chcete přidat tento filtr, je momentálně zakázaná. Filtr můžete přidat, ale nebude aplikován, dokud [link]nepovolíte skupinu filtrů[/link].">
+<!ENTITY filter.label "Nový filtr:">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "Zobrazit existující filtry...">
+<!ENTITY preferences.accesskey "e">
+<!ENTITY type.filter.label "Blokující filtr">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Výjimka">
+<!ENTITY type.whitelist.accesskey "V">
+<!ENTITY pattern.label "Vyhledat vzor">
+<!ENTITY pattern.explanation "Vzor může být jakákoli část adresy, znak * funguje jako divoká karta. Filtr bude aplikován pouze na adresy odpovídající vzoru.">
+<!ENTITY regexp.warning "Vzor, který jste zadali, bude interpretován jako regulární výraz. Mnoho regulárních výrazů může zpomalit vaše prohlížení stránek. Pokud jste nechěli použít regulární výraz, přidejte znak * na konec vzoru.">
+<!ENTITY shortpattern.warning "Vzor, který jste zadali, je příliš krátký, aby mohl být optimalizován. Mnoho takových výrazů může zpomalit vaše prohlížení stránek. Je doporučeno, abyste pro tento filtr zadali delší řetězec.">
+<!ENTITY custom.pattern.label "Vlastní:">
+<!ENTITY custom.pattern.accesskey "n">
+<!ENTITY anchors.label "Povolit vzor pouze:">
+<!ENTITY anchor.start.label "na začátku adresy">
+<!ENTITY anchor.start.accesskey "z">
+<!ENTITY anchor.start.flexible.label "na začátku názvu domény">
+<!ENTITY anchor.start.flexible.accesskey "z">
+<!ENTITY anchor.end.label "na konci adresy">
+<!ENTITY anchor.end.accesskey "k">
+<!ENTITY options.label "Možnosti">
+<!ENTITY domainRestriction.label "Omezit na doménu:">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "Zadejte jednu nebo více domén oddělených znakem &quot;|&quot;, filtr bude poté použit pouze na těchto doménách. Znak &quot;~&quot; před názvem domény zajistí, že filtr nebude na této doméně použit.">
+<!ENTITY firstParty.label "Pouze vlastní filtry">
+<!ENTITY firstParty.accesskey "a">
+<!ENTITY thirdParty.label "Pouze filtry třetích stran">
+<!ENTITY thirdParty.accesskey "t">
+<!ENTITY matchCase.label "Rozlišovat velikost">
+<!ENTITY matchCase.accesskey "R">
+<!ENTITY types.label "Použít na typy:">
+<!ENTITY selectAllTypes.label "Vybrat vše">
+<!ENTITY unselectAllTypes.label "Zrušit výběr">
+<!ENTITY collapse.label "Minimalizovat blokované objekty:">
+<!ENTITY collapse.accesskey "i">
+<!ENTITY collapse.default.yes.label "Použít výchozí (ano)">
+<!ENTITY collapse.default.no.label "Použít výchozí (ne)">
+<!ENTITY collapse.yes.label "Ano">
+<!ENTITY collapse.no.label "Ne">

=== added file 'chrome/locale/cs/global.properties'
--- chrome/locale/cs/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/cs/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Levé tlačítko: Otevřít místní nabídku
+action1_tooltip=Levé tlačítko: Otevřít blokovatelné prvky
+action2_tooltip=Levé tlačítko: Otevřít předvolby
+action3_tooltip=Klepnutím povolit/zakázat Adblock Plus
+disabled_tooltip=Adblock Plus je zakázán
+active_tooltip=Adblock Plus je aktivní, cizí sady filtrů: ?1?, vlastní filtry: ?2?
+whitelisted_tooltip=Adblock Plus je aktivní, ale pro aktuální stránku byl zakázán.
+blocked_count_tooltip=?1? z ?2?
+blocked_count_addendum=(povoleno výjimkou: ?1?, skryto: ?2?)
+no_blocking_suggestions=Na této stránce nebyly nalezeny prvky k zablokování
+whitelisted_page=Adblock Plus byl pro aktuální stránku zakázán
+whitelist_description=Mé výjimky
+filterlist_description=Má pravidla blokování reklam
+invalid_description=Má chybná pravidla
+elemhide_description=Má pravidla pro skrývání elementů
+subscription_description=Cizí sady filtrů:
+subscription_wrong_version=Některé filtry v tomto seznamu vyžadují ke správné funkci Adblock Plus ?1?
+subscription_source=Zdroj:
+subscription_status=Stav:
+subscription_status_autodownload=Automaticky aktualizováno
+subscription_status_manualdownload=Manuálně aktualizováno
+subscription_status_externaldownload=Aktualizováno externě (jiným rozšířením)
+subscription_status_lastdownload=Naposledy staženo:
+subscription_status_lastdownload_inprogress=Stahuji...
+subscription_status_lastdownload_unknown=neznámo
+remove_subscription_warning=Skutečně si přejete odstranit tuto sadu cizích filtrů ?
+import_filters_wrong_version=Varování: Některé z filtrů tohoto seznamu vyžadují ke správné funkčnosti Adblock Plus ?1?. Pravděpodobně byste měli aktualizovat Adblock Plus před importováním tohoto seznamu.
+import_filters_warning=Přejete si nahradit aktuální filtry nebo chcete nové filtry přidat na konec seznamu?
+import_filters_title=Importovat filtry
+export_filters_title=Exportovat filtry
+invalid_filters_file=Toto není soubor filtrů Adblock Plus.
+filters_write_error=Nepodařilo se zapsat filtry do souboru. Ujistěte se, že soubor není chráněn proti zápisu nebo blokován jiným programem.
+clearall_warning=Opravdu chcete odstranit všechny filtry ze seznamu?
+resethitcounts_warning=Opravdu chcete vynulovat počítadla všech filtrů? Tuto operaci nelze vrátit zpět.
+resethitcounts_selected_warning=Opravdu chcete vynulovat počítadla vybraných filtrů? Tuto operaci nelze vrátit zpět.
+filter_regexp_tooltip=Tento filtr je buď regulární výraz nebo je příliš krátký, aby mohl být optimalizován. Příliš mnoho takových filtrů může zpomalit vaše prohlížení stránek.
+filter_elemhide_duplicate_id=Může být uvedeno pouze jedno ID elementu, který má být skryt
+filter_elemhide_nocriteria=Nebyla uvedena žádná kritérie pro rozpoznání elementu, který má být skryt
+subscription_notAdded_warning=Nepřidali jste cizí sadu filtrů. Bez sady filtrů budete muset přidávat pravidla do Adblocku Plus manuálně.
+subscription_notAdded_warning_addendum=Chcete pokračovat?
+subscription_invalid_location=Zadaná adresa seznamu cizích filtrů je buď nesprávná URL nebo obsahuje nesprávné jméno souboru.
+synchronize_invalid_url=Chyba, toto je nekorektní adresa.
+synchronize_connection_error=Chyba, nepodařilo se stáhnout soubor
+synchronize_invalid_data=Chyba, stažený soubor není souborem filtrů Adblock Plus
+synchronize_checksum_mismatch=Chyba, neodpovídá kontrolní součet
+synchronize_ok=Úspěch
+overwrite=Přepsat
+append=Přidat
+new_filter_group_title=Nový filtr
+type_label_other=Ostatní
+type_label_script=Skript
+type_label_image=Obrázek
+type_label_stylesheet=Šablona kaskádových stylů
+type_label_object=Objekt
+type_label_subdocument=Rámec
+type_label_document=Dokument
+type_label_background=Pozadí
+type_label_elemhide=skryto
+type_label_xbl=XBL vazba
+type_label_ping=link ping
+type_label_xmlhttprequest=XML požadavek
+type_label_object_subrequest=Subpožadavek objektu
+type_label_dtd=DTD
+type_label_media=audio/video
+type_label_font=Písmo
+fennec_status_enabled=Adblock Plus je povolený.
+fennec_status_disabled=Adblock Plus je zakázaný.
+fennec_status_enabled_site=Adblock Plus je povolený na ?1?.
+fennec_status_disabled_site=Adblock Plus je zakázaný na ?1?.

=== added file 'chrome/locale/cs/meta.properties'
--- chrome/locale/cs/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/cs/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Jakub Tománek
+name=Adblock Plus
+description=A reklamy jsou minulostí!
+description.short=Jste otráveni reklamami? Nebaví vás být sledováni? Obtěžují vás bannery? Nainstalujte Adblock Plus, získejte opět kontrolu nad internetem a změňte způsob, jakým web prohlížíte.
+description.long=Adblock Plus vám umožňuje získat kontrolu na internetem a prohlížet stránky způsobem, jaký si zvolíte vy, ne reklamy na stránkách. Tento doplněk je podporován více než čtyřiceti sadami cizích filtrů v desítkách jazyků, které automaticky nastavují blokování reklam a známých domén se škodlivým software. Adblock Plus vám též umožňuje nastavit vlastní filtry obsahu za pomoci různých užitečných funkcí jako jsou místní nabídka pro obrázky, blokovací ouška u Flash a Java objektů, a seznam blokovatelných položek umožňující odstranění skriptů a šablon stylů.

=== added file 'chrome/locale/cs/overlay.dtd'
--- chrome/locale/cs/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/cs/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Stav:">
+<!ENTITY blocked.tooltip "Blokované prvky na této stránce:">
+<!ENTITY filters.tooltip "Nejúčinnější filtry:">
+<!ENTITY menuitem.label "Předvolby Adblock Plus">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Blokovatelné objekty">
+<!ENTITY context.image.label "Blokovat obrázek">
+<!ENTITY context.object.label "Blokovat objekt">
+<!ENTITY context.frame.label "Blokovat rámec">
+<!ENTITY context.media.label "Adblock Plus: Blokovat audio/video">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Znovu povolit na této stránce">
+<!ENTITY sidebar.title "Adblock Plus: Blokovatelné objekty na zobrazené stránce">
+<!ENTITY settings.label "Předvolby">
+<!ENTITY settings.accesskey "d">
+<!ENTITY opensidebar.label "Zobrazit blokovatelné objekty">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "Skrýt seznam blokovatelných objektů">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "Vypnout na ?1?">
+<!ENTITY whitelist.page.label "Vypnout pouze na této stránce">
+<!ENTITY objecttab.title "Blokovat">
+<!ENTITY objecttab.tooltip "Klepněte zde pro blokování tohoto objektu pomocí Adblock Plus">

=== added file 'chrome/locale/cs/settings.dtd'
--- chrome/locale/cs/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/cs/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Předvolby Adblock Plus">
+<!ENTITY filters.label "Filtry">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Přidat filtr">
+<!ENTITY add.accesskey "P">
+<!ENTITY addsubscription.label "Přidat cizí filtry">
+<!ENTITY addsubscription.accesskey "c">
+<!ENTITY synchsubscriptions.label "Aktualizovat všechny cizí sady filtrů">
+<!ENTITY synchsubscriptions.accesskey "A">
+<!ENTITY import.label "Importovat filtry ze souboru">
+<!ENTITY import.accesskey "I">
+<!ENTITY export.label "Exportovat vlastní filtry do souboru">
+<!ENTITY export.accesskey "x">
+<!ENTITY clearall.label "Odstranit všechny vlastní filtry">
+<!ENTITY clearall.accesskey "O">
+<!ENTITY resethitcounts.label "Vynulovat počítadla zásahů">
+<!ENTITY resethitcounts.accesskey "V">
+<!ENTITY edit.label "Úpravy">
+<!ENTITY edit.accesskey "A">
+<!ENTITY cut.label "Vyjmout">
+<!ENTITY cut.accesskey "j">
+<!ENTITY copy.label "Kopírovat">
+<!ENTITY copy.accesskey "K">
+<!ENTITY paste.label "Vložit">
+<!ENTITY paste.accesskey "l">
+<!ENTITY remove.label "Smazat">
+<!ENTITY remove.accesskey "z">
+<!ENTITY menu.find.label "Najít">
+<!ENTITY menu.find.accesskey "N">
+<!ENTITY menu.findagain.label "Najít další">
+<!ENTITY menu.findagain.accesskey "d">
+<!ENTITY view.label "Zobrazit">
+<!ENTITY view.accesskey "Z">
+<!ENTITY sort.label "Seřadit podle">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "Neřadit">
+<!ENTITY sort.none.accesskey "N">
+<!ENTITY sort.ascending.label "Vzestupně (A-Z)">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Sestupně (Z-A)">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Možnosti">
+<!ENTITY options.accesskey "M">
+<!ENTITY enable.label "Aktivovat Adblock Plus">
+<!ENTITY enable.accesskey "k">
+<!ENTITY showintoolbar.label "Zobrazit v nástrojové liště">
+<!ENTITY showintoolbar.accesskey "b">
+<!ENTITY showinstatusbar.label "Zobrazit ve stavovém řádku">
+<!ENTITY showinstatusbar.accesskey "r">
+<!ENTITY objecttabs.label "Zobrazovat ouška u objektů Java a Flash">
+<!ENTITY objecttabs.accesskey "o">
+<!ENTITY collapse.label "Minimalizovat blokované objekty">
+<!ENTITY collapse.accesskey "i">
+<!ENTITY help.label "Nápověda">
+<!ENTITY help.accesskey "v">
+<!ENTITY gettingStarted.label "Začínáme">
+<!ENTITY gettingStarted.accesskey "Z">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Často kladené dotazy (FAQ)">
+<!ENTITY faq.accesskey "q">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Psaní Adblock Plus filtrů">
+<!ENTITY filterdoc.accesskey "f">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "O doplňku Adblock Plus">
+<!ENTITY about.accesskey "o">
+<!ENTITY description "Následující filtry rozhodují, které adresy budou blokovány a které budou povoleny:">
+<!ENTITY filter.column "Pravidlo filtru">
+<!ENTITY filter.accesskey "P">
+<!ENTITY slow.column "Pomalé filtry">
+<!ENTITY slow.accesskey "m">
+<!ENTITY enabled.column "Aktivní">
+<!ENTITY enabled.accesskey "k">
+<!ENTITY hitcount.column "Zásahy">
+<!ENTITY hitcount.accesskey "h">
+<!ENTITY lasthit.column "Poslední zásah">
+<!ENTITY lasthit.accesskey "l">
+<!ENTITY context.edit.label "Přidat filtr">
+<!ENTITY context.resethitcount.label "Vynulovat počítadlo zásahů tohoto filtru">
+<!ENTITY context.synchsubscription.label "Aktualizovat seznam cizích filtrů">
+<!ENTITY context.editsubscription.label "Upravit cizí filtry">
+<!ENTITY context.moveup.label "Posunout filtr nahoru">
+<!ENTITY context.movedown.label "Posunout filtr dolů">
+<!ENTITY context.movegroupup.label "Posunout skupinu nahoru">
+<!ENTITY context.movegroupdown.label "Posunout skupinu dolů">
+<!ENTITY context.enable.label "Povolit">
+<!ENTITY context.disable.label "Zakázat">
+<!ENTITY apply.label "Použít">
+<!ENTITY apply.accesskey "U">
+<!ENTITY fennec.subscription.label "Cizí sada filtrů">

=== added file 'chrome/locale/cs/sidebar.dtd'
--- chrome/locale/cs/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/cs/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Blokovatelné prvky (odděleno)">
+<!ENTITY detach.label "Oddělit">
+<!ENTITY reattach.label "Připojit">
+<!ENTITY search.label "Hledat:">
+<!ENTITY search.accesskey "H">
+<!ENTITY type.label "Typ">
+<!ENTITY address.label "Adresa">
+<!ENTITY filter.label "Filtr">
+<!ENTITY state.label "Stav">
+<!ENTITY size.label "Velikost">
+<!ENTITY docDomain.label "Zdroj dokumentu">
+<!ENTITY noitems.label "Nic nebylo zablokováno">
+<!ENTITY whitelisted.label "Adresa je na bílé listině">
+<!ENTITY tooltip.address.label "Adresa:">
+<!ENTITY tooltip.type.label "Typ:">
+<!ENTITY tooltip.type.blocked "(blokováno)">
+<!ENTITY tooltip.type.whitelisted "(na bílé listině)">
+<!ENTITY tooltip.size.label "Velikost:">
+<!ENTITY tooltip.docDomain.label "Zdroj dokumentu:">
+<!ENTITY tooltip.filter.label "Použité filtry:">
+<!ENTITY tooltip.filterSource.label "Zdroj filtru:">
+<!ENTITY context.block.label "Blokovat tento objekt">
+<!ENTITY context.editfilter.label "Upravit příslušný filtr">
+<!ENTITY context.whitelist.label "Přidat výjimku pro tento objekt">
+<!ENTITY context.disablefilter.label "Zakázat filtr ?1?">
+<!ENTITY context.enablefilter.label "Opět povolit filtr ?1?">
+<!ENTITY context.disablefilteronsite.label "Zakázat tento filtr na ?1?">
+<!ENTITY context.open.label "Otevřít v novém panelu">
+<!ENTITY context.flash.label "Blikání obrysu objektu">
+<!ENTITY context.copy.label "Kopírovat adresu objektu">
+<!ENTITY context.copyFilter.label "Kopírovat filtr">
+<!ENTITY context.selectAll.label "Vybrat vše">

=== added file 'chrome/locale/cs/subscriptionSelection.dtd'
--- chrome/locale/cs/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/cs/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Přidat sadu cizích filtrů Adblock Plus">
+<!ENTITY dialog.title.edit "Upravit sadu cizích filtrů">
+<!ENTITY description.newInstall "Adblock Plus bude fungovat nejefektivněji, pokud přidáte cizí sadu filtrů. Cizí sady vytváří zdarma ostatní uživatelé Adblocku Plus. Nejvhodnější sada pro váš jazyk byla již vybrána.">
+<!ENTITY adblock.warning "Adblock Plus zjistil, že je nainstalován Adblock nebo starší verze Adblocku Plus. Používání Adblocku a Adblocku Plus zároveň může způsobovat problémy a je lepší se tomu vyhnout. Je doporučeno, abyste nyní odinstalovali Adblock.">
+<!ENTITY adblock.uninstall "Odinstalovat Adblock">
+<!ENTITY filterset.g.warning "Zdá se, že používáte Filterset.G. Tento seznam filtrů nebyl v poslední době téměř spravován a je častým zdrojem problémů s webovými stránkami. Je doporučeno, abyste není odinstalovali Filterset.G.">
+<!ENTITY filterset.g.moreinfo "Více informací">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Odinstalovat Filterset.G">
+<!ENTITY subscriptionSelector.label "Prosím vyberte cizí sadu filtrů ze seznamu:">
+<!ENTITY viewList.label "Zobrazit pravidla">
+<!ENTITY visitHomepage.label "Navštívit domovskou stránku">
+<!ENTITY addSubscription.label "Přidat cizí sadu filtrů">
+<!ENTITY saveSubscription.label "Uložit odběr cizí sady filtrů">
+<!ENTITY other.label "Přidat další sadu cizích filtrů">
+<!ENTITY other.accesskey "d">
+<!ENTITY list.download.failed "Adblocku Plus se nepodařilo získat seznam cizích sad filtrů.">
+<!ENTITY list.download.retry "Zkusit znovu">
+<!ENTITY list.download.website "Zobrazit webovou stránku">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Prosím potvrďte, že chcete přidat tuto cizí sadu filtrů. Můžete změnít její titulek nebo umístění před jejím přidáním.">
+<!ENTITY edit.description "Pokud to bude nutné, můžete změnit titulek nebo umístění cizí sady filtrů.">
+<!ENTITY external.description "Toto je cizí sada filtrů přidaná jiným rozšířením; o její aktualizaci se bude starat rozšíření, které ji přidalo.">
+<!ENTITY title.label "Označení cizích filtrů:">
+<!ENTITY title.accesskey "O">
+<!ENTITY location.label "Umístění sady filtrů:">
+<!ENTITY location.accesskey "U">
+<!ENTITY autodownload.label "Automaticky aktualizovat">
+<!ENTITY autodownload.accesskey "A">
+<!ENTITY supplementMessage "Tato cizí sada filtrů je určena k používání se sadou &quot;?1?&quot;, kterou ještě nepoužíváte.">
+<!ENTITY addMain.label "Přidat také cizí sadu filtrů &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "s">

=== added directory 'chrome/locale/cy'
=== removed directory 'chrome/locale/cy-GB'
=== removed file 'chrome/locale/cy-GB/.incomplete'
=== removed file 'chrome/locale/cy-GB/about.dtd'
=== removed file 'chrome/locale/cy-GB/composer.dtd'
=== removed file 'chrome/locale/cy-GB/global.properties'
--- chrome/locale/cy-GB/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/cy-GB/global.properties	1970-01-01 00:00:00 +0000
@@ -1,28 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Y gorffennol yw hysbysebion!
-status_active_label=Adblock
-status_disabled_label=Wedi'i anablu
-action0_tooltip=Cliciwch i ddod a'r dewislen cysywllt, clic canol i'w alluogi/anablu.
-action1_tooltip=Cliciwch i agor/cau eitemau blocadwy, clic canol i'w alluogi/anablu.
-action2_tooltip=Cliciwch i agor dewisiadau, clic canol i'w alluogi/anablu.
-action3_tooltip=Cliciwch i alluogi/anablu Adblock Plws.
-active_tooltip=Mae Adblock Plws yn weithredol.
-disabled_tooltip=Mae Adblock Plws wedi cael ei anablu.
-whitelisted_tooltip=Mae Adblock Plws yn weithredol, ond mae hi wedi cael ei anablu ar y dudalen gyfredol.
-blocked_count_tooltip=-- allan o --
-no_blocking_suggestions=Dim eitemau blocadwy ar y tudalen gyfredol
-whitelisted_page=Mae Adblock Plws wedi cael ei anablu ar y dudalen gyfredol
-whitelist_description=Rheolau eithriadol
-filterlist_description=Ffilterau hysbysebion
-invalid_description=Ffilterau annilys
-elemhide_description=Rheolau cuddio elfen
-subscription_description=Tanysgrifiad ffilterau:
-subscription_wrong_version=Mae angen Adblock Plws -- arnoch i rhai o'r ffilteri i weithio'n iawn!
-subscription_source=Ffynhonell:
-subscription_status=Statws:
-subscription_status_autodownload=Wedi'i ddiweddaru'n awtomatig
-subscription_status_manualdownload=Wedi'i ddiweddaru'n seinglawr
-subscription_status_externaldownload=Wedi'i ddiweddaru'n allanol (estyniad arall)
-subscription_status_lastdownload=Lawrlwythiad dywethaf
-subscription_status_lastdownload_inprogress=Yn lawrlwytho...
-subscription_status_lastdownload_unknown=Ddim yn berthnasol
-remove_subscription_warning=Ydych chi wir eisiau dileu'r tanysgrifiad hon?

=== removed file 'chrome/locale/cy-GB/overlay.dtd'
=== removed file 'chrome/locale/cy-GB/settings.dtd'
=== removed file 'chrome/locale/cy-GB/sidebar.dtd'
=== removed file 'chrome/locale/cy-GB/subscription.dtd'
--- chrome/locale/cy-GB/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/cy-GB/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-<!ENTITY dialog.title "Golygu tanysgrifiadau ffilter">
-<!ENTITY dialog.newtitle "Ychwanegu tansygrifiad ffilter">
-<!ENTITY new.description "Ysgrifennwch y cyfeiriad gwe neu ffeil sydd yn cynnwys rhestr o ffilteri Adblock Plus os gwelwch yn dda.">
-<!ENTITY edit.description "Mi fydd y rhestr ffilteri yn cael ei ddadlwytho o&apos;r lleoliad a rhoddir.">
-<!ENTITY location.label "Lleoliad y rhestr ffilteri:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.accesskey "N">

=== removed file 'chrome/locale/cy-GB/tip_subscriptions.dtd'
=== added file 'chrome/locale/cy/.incomplete'
=== added file 'chrome/locale/cy/global.properties'
--- chrome/locale/cy/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/cy/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,24 @@
+action0_tooltip=Cliciwch i ddod a'r dewislen cysywllt, clic canol i'w alluogi/anablu.
+action1_tooltip=Cliciwch i agor/cau eitemau blocadwy, clic canol i'w alluogi/anablu.
+action2_tooltip=Cliciwch i agor dewisiadau, clic canol i'w alluogi/anablu.
+action3_tooltip=Cliciwch i alluogi/anablu Adblock Plws.
+disabled_tooltip=Mae Adblock Plws wedi cael ei anablu.
+whitelisted_tooltip=Mae Adblock Plws yn weithredol, ond mae hi wedi cael ei anablu ar y dudalen gyfredol.
+blocked_count_tooltip=?1? allan o ?2?
+no_blocking_suggestions=Dim eitemau blocadwy ar y tudalen gyfredol
+whitelisted_page=Mae Adblock Plws wedi cael ei anablu ar y dudalen gyfredol
+whitelist_description=Rheolau eithriadol
+filterlist_description=Ffilterau hysbysebion
+invalid_description=Ffilterau annilys
+elemhide_description=Rheolau cuddio elfen
+subscription_description=Tanysgrifiad ffilterau:
+subscription_wrong_version=Mae angen Adblock Plws ?1? arnoch i rhai o'r ffilteri i weithio'n iawn!
+subscription_source=Ffynhonell:
+subscription_status=Statws:
+subscription_status_autodownload=Wedi'i ddiweddaru'n awtomatig
+subscription_status_manualdownload=Wedi'i ddiweddaru'n seinglawr
+subscription_status_externaldownload=Wedi'i ddiweddaru'n allanol (estyniad arall)
+subscription_status_lastdownload=Lawrlwythiad dywethaf
+subscription_status_lastdownload_inprogress=Yn lawrlwytho...
+subscription_status_lastdownload_unknown=Ddim yn berthnasol
+remove_subscription_warning=Ydych chi wir eisiau dileu'r tanysgrifiad hon?

=== added file 'chrome/locale/cy/meta.properties'
--- chrome/locale/cy/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/cy/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=Y gorffennol yw hysbysebion!

=== added file 'chrome/locale/cy/subscriptionSelection.dtd'
--- chrome/locale/cy/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/cy/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+<!ENTITY dialog.title.edit "Golygu tanysgrifiadau ffilter">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Lleoliad y rhestr ffilteri:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.accesskey "P">

=== added directory 'chrome/locale/da'
=== removed directory 'chrome/locale/da-DK'
=== removed file 'chrome/locale/da-DK/about.dtd'
--- chrome/locale/da-DK/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/da-DK/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Om Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Version">
-<!ENTITY description "Adblock Plus lader dig bestemme hvad du ikke vil se på nettet. Du behøver ikke downloade alle reklamerne og bannerne længere, hvis du ikke vil have dem - lad Adblock Plus gøre arbejdet!">
-<!ENTITY homepage.label "Adblock Plus hjemmeside:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Forfatter:">
-<!ENTITY contributors.label "Bidragydere:">

=== removed file 'chrome/locale/da-DK/composer.dtd'
--- chrome/locale/da-DK/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/da-DK/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Tilføj Adblock Plus filterregel">
-<!ENTITY accept.label "Tilføj filter">
-<!ENTITY advanced.label "Avanceret visning">
-<!ENTITY basic.label "Grundlæggende visning">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus er i øjeblikket deaktiveret. Du kan stadig tilføje filtre men disse vil ikke blive benyttet med mindre du">
-<!ENTITY disabled.warning.link "aktiverer Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Filtergruppen &quot;&#37;S&quot; som dette filer skal tilføjes til er deaktiveret i øjeblikket. Du kan stadig tilføje filteret men det vil ikke blive benyttet med mindre du">
-<!ENTITY groupDisabled.warning.link "aktiverer filtergruppen">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Nyt filter:">
-<!ENTITY filter.accesskey "N">
-<!ENTITY preferences.label "Vis eksisterende filtre...">
-<!ENTITY preferences.accesskey "s">
-<!ENTITY type.filter.label "Blokeringsfilter">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "Undtagelsesregel">
-<!ENTITY type.whitelist.accesskey "U">
-<!ENTITY pattern.label "Kig efter mønster">
-<!ENTITY pattern.explanation "Mønsteret kan være enhver del af adressen, tegnet * bruges som jokertegn. Filteret vil kun blive benyttet på adresser der matcher mønsteret.">
-<!ENTITY regexp.warning "Det indtastede mønster vil blive fortolket som et regulært udtryk. Mange regulære udtryk kan gøre din browser langsommere. Hvis det ikke var din intention at bruge regulære udtryk, tilføj et * tegn i slutningen af mønsteret.">
-<!ENTITY shortpattern.warning "Det indtastede mønster er for kort til at blive optimeret, mange sådanne mønstre kan gøre din browser langsommere. Det anbefales at du vælger en længere streng for dette filter.">
-<!ENTITY custom.pattern.label "Brugerdefineret:">
-<!ENTITY custom.pattern.accesskey "r">
-<!ENTITY anchors.label "Accepter kun mønster:">
-<!ENTITY anchor.start.label "i begyndelsen af adressen">
-<!ENTITY anchor.start.accesskey "g">
-<!ENTITY anchor.start.flexible.label "i begyndelsen af domænenavnet">
-<!ENTITY anchor.start.flexible.accesskey "g">
-<!ENTITY anchor.end.label "i slutningen af adressen">
-<!ENTITY anchor.end.accesskey "l">
-<!ENTITY options.label "Indstillinger">
-<!ENTITY domainRestriction.label "Begræns til domæne:">
-<!ENTITY domainRestriction.accesskey "d">
-<!ENTITY domainRestriction.help "Angiv ét eller flere domæner adskilt af symbolet &quot;|&quot;, så vil filteret kun blive anvendt på disse domæner. Symbolet &quot;~&quot; foran et domæne angiver at filteret ikke skal anvendes på dette domæne.">
-<!ENTITY firstParty.label "Kun førsteparts">
-<!ENTITY firstParty.accesskey "f">
-<!ENTITY thirdParty.label "Kun tredjeparts">
-<!ENTITY thirdParty.accesskey "t">
-<!ENTITY matchCase.label "Match store/små bogstaver">
-<!ENTITY matchCase.accesskey "M">
-<!ENTITY types.label "Benyt på typer:">
-<!ENTITY selectAllTypes.label "Vælg alle">
-<!ENTITY unselectAllTypes.label "Vælg ingen">
-<!ENTITY collapse.label "Sammenfold blokeret:">
-<!ENTITY collapse.accesskey "o">
-<!ENTITY collapse.default.yes.label "Brug standard (ja)">
-<!ENTITY collapse.default.no.label "Brug standard (nej)">
-<!ENTITY collapse.yes.label "Ja">
-<!ENTITY collapse.no.label "Nej">

=== removed file 'chrome/locale/da-DK/global.properties'
--- chrome/locale/da-DK/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/da-DK/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Reklamer er fortid!
-status_active_label=Adblock
-status_disabled_label=Slået fra
-action0_tooltip=Klik for at bringe kontekstmenuen op, midterklik for at aktivere/deaktivere.
-action1_tooltip=Klik for at åbne/lukke blokérbare elementer, midterklik for at aktivere/deaktivere.
-action2_tooltip=Klik for at åbne indstillingerne, midterklik for at aktivere/deaktivere.
-action3_tooltip=Klik for at aktivere/deaktivere Adblock Plus.
-active_tooltip=Adblock Plus er aktiv.
-disabled_tooltip=Adblock Plus er deaktiveret.
-whitelisted_tooltip=Adblock Plus er aktiv men slået fra på nuværende side.
-blocked_count_tooltip=-- ud af --
-no_blocking_suggestions=Ingen blokerbare elementer fundet på nuværende side
-whitelisted_page=Adblock Plus er slået fra for nuværende side
-whitelist_description=Mine undtagelsesregler
-filterlist_description=Mine reklamefiltre
-invalid_description=Mine ugyldige filtre
-elemhide_description=Mine skjul elementer-regler
-subscription_description=Filterabonnement:
-subscription_wrong_version=Nogle filtre i dette abonnement kræver Adblock Plus -- for at virke ordentligt!
-subscription_source=Kilde:
-subscription_status=Status:
-subscription_status_autodownload=Opdateres automatisk
-subscription_status_manualdownload=Opdateres manuelt
-subscription_status_externaldownload=Opdateres eksternt (af en anden udvidelse)
-subscription_status_lastdownload=Sidst hentet:
-subscription_status_lastdownload_inprogress=Henter...
-subscription_status_lastdownload_unknown=Findes ikke
-remove_subscription_warning=Vil du virkelig fjerne dette abonnement?
-import_filters_wrong_version=Advarsel: nogle af filtrene i denne liste kræver Adblock Plus -- for at virke ordentligt. Du skal sandsynligvis opdatere til seneste Adblock Plus-version før import af denne liste.
-import_filters_warning=Vil du erstatte dine nuværende filtre eller tilføje de nye filtre til slutningen af listen?
-import_filters_title=Importer filtre
-export_filters_title=Eksporter filtre
-invalid_filters_file=Ikke en gyldig Adblock Plus filtre-fil.
-filters_write_error=Der skete en fejl ved skrivning af filtrene til filen. Sikr dig at filen ikke er skrivebeskyttet eller holdes låst af et andet program.
-clearall_warning=Vil du virkelig fjerne alle filtre fra listen?
-resethitcounts_warning=Er du sikker på at du vil nulstille hittællerne for alle filtre? Denne operation kan ikke fortrydes!
-resethitcounts_selected_warning=Er du sikker på at du vil nulstille hittællerne for de valgte filtre? Denne operation kan ikke fortrydes!
-filter_regexp_tooltip=Dette filter er enten et regulært udtryk eller for kort til at blive optimeret. For mange af disse kan gøre din browser langsommere.
-filter_elemhide_duplicate_id=Kun ét ID for elementet der skal skjules kan angives
-filter_elemhide_nocriteria=Ingen kriterier angivet for at genkende elementet der skal skjules
-subscription_no_location=Indtast venligst en placering at downloade filtre fra.
-subscription_invalid_location=Filterliste-placering er hverken en gyldig URL eller et gyldigt filnavn.
-subscription_location_exists=Du er allerede abonnent til denne filterliste
-synchronize_invalid_url=Fejlede, ikke en gyldig adresse
-synchronize_connection_error=Fejlede, hentningsfejl
-synchronize_invalid_data=Fejlede, ikke en gyldig liste over filtre
-synchronize_checksum_mismatch=Fejlede, checksum matcher ikke
-synchronize_ok=Succes
-overwrite=Overskriv
-append=Tilføj
-new_filter_group_title=Nyt filter
-type_label_other=andet
-type_label_script=script
-type_label_image=billede
-type_label_stylesheet=stilark
-type_label_object=objekt
-type_label_subdocument=ramme
-type_label_document=dokument
-type_label_background=baggrund
-type_label_elemhide=skjult
-type_label_xbl=XBL-binding
-type_label_ping=link ping
-type_label_xmlhttprequest=XML-forespørgsel
-type_label_object_subrequest=objekt underforespørgsel
-type_label_dtd=DTD
-type_label_media=audio/video
-type_label_font=skrifttype

=== removed file 'chrome/locale/da-DK/overlay.dtd'
--- chrome/locale/da-DK/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/da-DK/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Status:">
-<!ENTITY blocked.tooltip "Blokerede emner på denne side:">
-<!ENTITY filters.tooltip "Mest aktive filtre:">
-<!ENTITY menuitem.label "Adblock Plus indstillinger">
-<!ENTITY menuitem.accesskey "A">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Blokérbare elementer">
-<!ENTITY context.image.label "Adblock Billede">
-<!ENTITY context.object.label "Adblock Objekt">
-<!ENTITY context.frame.label "Adblock Ramme">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Gen-aktivér på denne side">
-<!ENTITY sidebar.title "Blokérbare elementer på nuværende side">
-<!ENTITY settings.label "Præferencer">
-<!ENTITY settings.accesskey "F">
-<!ENTITY opensidebar.label "Åbn blokérbare elementer">
-<!ENTITY opensidebar.accesskey "b">
-<!ENTITY closesidebar.label "Luk blokérbare elementer">
-<!ENTITY closesidebar.accesskey "b">
-<!ENTITY whitelist.site.label "Slå fra på --">
-<!ENTITY whitelist.page.label "Slå fra på denne ene side">
-<!ENTITY objecttab.title "Bloker">
-<!ENTITY objecttab.tooltip "Klik her for at blokere dette objekt med Adblock Plus">

=== removed file 'chrome/locale/da-DK/settings.dtd'
--- chrome/locale/da-DK/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/da-DK/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus præferencer">
-<!ENTITY filters.label "Filtre">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Tilføj filter">
-<!ENTITY add.accesskey "T">
-<!ENTITY addsubscription.label "Tilføj filter-abonnement">
-<!ENTITY addsubscription.accesskey "B">
-<!ENTITY synchsubscriptions.label "Opdater alle abonnementer">
-<!ENTITY synchsubscriptions.accesskey "d">
-<!ENTITY import.label "Importer filtre">
-<!ENTITY import.accesskey "M">
-<!ENTITY export.label "Eksporter brugerdefinerede filtre">
-<!ENTITY export.accesskey "P">
-<!ENTITY clearall.label "Fjern alle brugerdefinerede filtre">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "Nulstil hit-statistikker">
-<!ENTITY resethitcounts.accesskey "N">
-<!ENTITY edit.label "Rediger">
-<!ENTITY edit.accesskey "R">
-<!ENTITY cut.label "Klip">
-<!ENTITY cut.accesskey "K">
-<!ENTITY copy.label "Kopier">
-<!ENTITY copy.accesskey "o">
-<!ENTITY paste.label "Sæt ind">
-<!ENTITY paste.accesskey "æ">
-<!ENTITY remove.label "Slet">
-<!ENTITY remove.accesskey "S">
-<!ENTITY menu.find.label "Find">
-<!ENTITY menu.find.accesskey "F">
-<!ENTITY menu.findagain.label "Find igen">
-<!ENTITY menu.findagain.accesskey "g">
-<!ENTITY view.label "Vis">
-<!ENTITY view.accesskey "i">
-<!ENTITY sort.label "Sorter efter">
-<!ENTITY sort.accesskey "S">
-<!ENTITY sort.none.label "Usorteret">
-<!ENTITY sort.none.accesskey "U">
-<!ENTITY sort.ascending.label "A &gt; Z sorteringsorden">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Z &gt; A sorteringsorden">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Indstillinger">
-<!ENTITY options.accesskey "d">
-<!ENTITY enable.label "Slå Adblock Plus til">
-<!ENTITY enable.accesskey "I">
-<!ENTITY showintoolbar.label "Vis i værktøjslinje">
-<!ENTITY showintoolbar.accesskey "V">
-<!ENTITY showinstatusbar.label "Vis i statuslinje">
-<!ENTITY showinstatusbar.accesskey "s">
-<!ENTITY objecttabs.label "Vis faner på Flash og Java">
-<!ENTITY objecttabs.accesskey "J">
-<!ENTITY collapse.label "Sammenklap blokerede elementer">
-<!ENTITY collapse.accesskey "m">
-<!ENTITY help.label "Hjælp">
-<!ENTITY help.accesskey "H">
-<!ENTITY gettingStarted.label "Kom godt i gang (engelsk)">
-<!ENTITY gettingStarted.accesskey "a">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Ofte Stillede Spørgsmål">
-<!ENTITY faq.accesskey "f">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Skriver Adblock Plus filtre">
-<!ENTITY filterdoc.accesskey "R">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Om Adblock Plus">
-<!ENTITY about.accesskey "B">
-<!ENTITY description "Følgende filtre afgør hvilke adresser der skal blokeres og hvilke der skal tillades:">
-<!ENTITY filter.column "Filterregel">
-<!ENTITY filter.accesskey "F">
-<!ENTITY slow.column "Langsomme filtre">
-<!ENTITY slow.accesskey "o">
-<!ENTITY enabled.column "Slået til">
-<!ENTITY enabled.accesskey "l">
-<!ENTITY hitcount.column "Hits">
-<!ENTITY hitcount.accesskey "H">
-<!ENTITY lasthit.column "Seneste hit">
-<!ENTITY lasthit.accesskey "i">
-<!ENTITY context.edit.label "Redigér filter">
-<!ENTITY context.resethitcount.label "Nulstil hitsstatistik for filter">
-<!ENTITY context.synchsubscription.label "Opdatér abonnement nu">
-<!ENTITY context.editsubscription.label "Redigér abonnement">
-<!ENTITY context.moveup.label "Flyt filter op">
-<!ENTITY context.movedown.label "Flyt filter ned">
-<!ENTITY context.movegroupup.label "Flyt gruppe op">
-<!ENTITY context.movegroupdown.label "Flyt gruppe ned">
-<!ENTITY context.enable.label "Aktiver">
-<!ENTITY context.disable.label "Deaktiver">
-<!ENTITY apply.label "Anvend">
-<!ENTITY apply.accesskey "v">

=== removed file 'chrome/locale/da-DK/sidebar.dtd'
--- chrome/locale/da-DK/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/da-DK/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus blokérbare elementer (frakoblet)">
-<!ENTITY detach.label "Frakobl">
-<!ENTITY reattach.label "Gentilkobl">
-<!ENTITY search.label "Søg:">
-<!ENTITY search.accesskey "ø">
-<!ENTITY type.label "Type">
-<!ENTITY address.label "Adresse">
-<!ENTITY filter.label "Filter">
-<!ENTITY state.label "Tilstand">
-<!ENTITY size.label "Størrelse">
-<!ENTITY docDomain.label "Dokument-kilde">
-<!ENTITY noitems.label "Ingen blokérbare emner">
-<!ENTITY whitelisted.label "Hvidlistet side">
-<!ENTITY tooltip.address.label "Adresse:">
-<!ENTITY tooltip.type.label "Type:">
-<!ENTITY tooltip.type.blocked "(blokeret)">
-<!ENTITY tooltip.type.whitelisted "(hvidlistet)">
-<!ENTITY tooltip.size.label "Størrelse:">
-<!ENTITY tooltip.docDomain.label "Dokument-kilde:">
-<!ENTITY tooltip.filter.label "Fungerende filter:">
-<!ENTITY tooltip.filterSource.label "Filter kilde:">
-<!ENTITY context.block.label "Blokér dette element">
-<!ENTITY context.editfilter.label "Redigér nuværende filter">
-<!ENTITY context.whitelist.label "Tilføj undtagelsesregel for element">
-<!ENTITY context.disablefilter.label "Deaktiver filter --">
-<!ENTITY context.enablefilter.label "Gen-aktiver filter --">
-<!ENTITY context.disablefilteronsite.label "Deaktiver dette filter på --">
-<!ENTITY context.open.label "Åbn i nyt faneblad">
-<!ENTITY context.flash.label "Blink med elementets kanter">
-<!ENTITY context.copy.label "Kopier elementets adresse">
-<!ENTITY context.copyFilter.label "Kopier filter">
-<!ENTITY context.selectAll.label "Vælg alle">

=== removed file 'chrome/locale/da-DK/subscription.dtd'
--- chrome/locale/da-DK/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/da-DK/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Rediger filter-abonnement">
-<!ENTITY dialog.newtitle "Tilføj filter-abonnement">
-<!ENTITY new.description "Indtast venligst webadressen eller filen der indeholder en liste over Adblock Plus-filtre.">
-<!ENTITY edit.description "Filterlisten for dette abonnement vil blive downloadet fra det angivne sted.">
-<!ENTITY external.description "Dette er et eksternt filter-abonnement, filterlisten vil blive holdt opdateret af den udvidelse der har oprettet dette abonnement.">
-<!ENTITY autodownload.description "Hvis du vælger &apos;Opdater automatisk&apos; vil denne placering blive checket for opdateringer dagligt. Med denne indstilling slået fra kan du stadig udløse en manuel opdatering fra abonnementets kontekstmenu.">
-<!ENTITY location.label "Filterliste-placering:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Abonnement-titel:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Opdater automatisk">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.label "Slå filtre til">
-<!ENTITY enabled.accesskey "I">

=== removed file 'chrome/locale/da-DK/tip_subscriptions.dtd'
--- chrome/locale/da-DK/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/da-DK/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Velkommen til Adblock Plus filterabonnement">
-<!ENTITY description.par1 "Tak for at du installerede Adblock Plus. Denne udvidelse kan eliminere 99&#37; af reklamerne du ser på nettet. Effektiv reklamefiltrering kræver dog at du definerer et godt sæt filtre. Du kan gøre dette selv, eller du kan blot abonnere på filterlister som andre vedligeholder for dig. Det er fortsat muligt at tilføje dine egne filtre eller deaktivere/fjerne abonnementer når nødvendigt.">
-<!ENTITY description.par2 "Du kan vælge et abonnement fra listen over anbefalede abonnementer herunder (yderligere abonnementer kan tilføjes i Adblock Plus indstillinger senere, men normalt er dette ikke nødvendigt):">
-<!ENTITY note "Bemærk: Et filter er typisk mest effektivt når anvendt på websider fra samme region som filterlisten kommer fra eller er lavet til.">
-<!ENTITY adblock.warning "Adblock Plus har bemærket at Adblock eller en ældre version af Adblock Plus er installeret. Brug af både Adblock og Adblock Plus samtidig kan forårsage problemer og bør undgås. Det anbefales at du afinstallerer Adblock nu.">
-<!ENTITY adblock.uninstall "Afinstaller Adblock">
-<!ENTITY filterset.g.warning "Det ser ud til at du bruger Filterset.G. Denne filterliste er knapt blevet vedligeholdt de seneste par år og er en almindelig årsag til problemer med websider. Det anbefales at du afinstallerer Filterset.G nu.">
-<!ENTITY filterset.g.moreinfo "Mere information">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Afinstaller Filterset.G">
-<!ENTITY homepage.label "Hjemmeside">
-<!ENTITY subscribe.label "Abonnér">
-<!ENTITY subscribe.accesskey "o">
-<!ENTITY other.label "Tilføj endnu et abonnement">
-<!ENTITY other.accesskey "T">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Vis alle abonnementer">

=== added file 'chrome/locale/da/about.dtd'
--- chrome/locale/da/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/da/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,8 @@
+<!ENTITY dialog.title "Om Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Version">
+<!ENTITY description "Adblock Plus lader dig bestemme hvad du ikke vil se på nettet. Du behøver ikke downloade alle reklamerne og bannerne længere, hvis du ikke vil have dem - lad Adblock Plus gøre arbejdet!">
+<!ENTITY homepage.label "Adblock Plus hjemmeside:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Forfatter:">
+<!ENTITY contributors.label "Bidragydere:">

=== added file 'chrome/locale/da/composer.dtd'
--- chrome/locale/da/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/da/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Tilføj Adblock Plus filterregel">
+<!ENTITY accept.label "Tilføj filter">
+<!ENTITY advanced.label "Avanceret visning">
+<!ENTITY basic.label "Grundlæggende visning">
+<!ENTITY disabled.warning "Adblock Plus er i øjeblikket deaktiveret. Du kan stadig tilføje filtre men disse vil ikke blive benyttet med mindre du [link]aktiverer Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Filtergruppen &quot;?1?&quot; som dette filer skal tilføjes til er deaktiveret i øjeblikket. Du kan stadig tilføje filteret men det vil ikke blive benyttet med mindre du [link]aktiverer filtergruppen[/link].">
+<!ENTITY filter.label "Nyt filter:">
+<!ENTITY filter.accesskey "N">
+<!ENTITY preferences.label "Vis eksisterende filtre...">
+<!ENTITY preferences.accesskey "s">
+<!ENTITY type.filter.label "Blokeringsfilter">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Undtagelsesregel">
+<!ENTITY type.whitelist.accesskey "U">
+<!ENTITY pattern.label "Kig efter mønster">
+<!ENTITY pattern.explanation "Mønsteret kan være enhver del af adressen, tegnet * bruges som jokertegn. Filteret vil kun blive benyttet på adresser der matcher mønsteret.">
+<!ENTITY regexp.warning "Det indtastede mønster vil blive fortolket som et regulært udtryk. Mange regulære udtryk kan gøre din browser langsommere. Hvis det ikke var din intention at bruge regulære udtryk, tilføj et * tegn i slutningen af mønsteret.">
+<!ENTITY shortpattern.warning "Det indtastede mønster er for kort til at blive optimeret, mange sådanne mønstre kan gøre din browser langsommere. Det anbefales at du vælger en længere streng for dette filter.">
+<!ENTITY custom.pattern.label "Brugerdefineret:">
+<!ENTITY custom.pattern.accesskey "r">
+<!ENTITY anchors.label "Accepter kun mønster:">
+<!ENTITY anchor.start.label "i begyndelsen af adressen">
+<!ENTITY anchor.start.accesskey "g">
+<!ENTITY anchor.start.flexible.label "i begyndelsen af domænenavnet">
+<!ENTITY anchor.start.flexible.accesskey "g">
+<!ENTITY anchor.end.label "i slutningen af adressen">
+<!ENTITY anchor.end.accesskey "l">
+<!ENTITY options.label "Indstillinger">
+<!ENTITY domainRestriction.label "Begræns til domæne:">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "Angiv ét eller flere domæner adskilt af symbolet &quot;|&quot;, så vil filteret kun blive anvendt på disse domæner. Symbolet &quot;~&quot; foran et domæne angiver at filteret ikke skal anvendes på dette domæne.">
+<!ENTITY firstParty.label "Kun førsteparts">
+<!ENTITY firstParty.accesskey "f">
+<!ENTITY thirdParty.label "Kun tredjeparts">
+<!ENTITY thirdParty.accesskey "t">
+<!ENTITY matchCase.label "Match store/små bogstaver">
+<!ENTITY matchCase.accesskey "M">
+<!ENTITY types.label "Benyt på typer:">
+<!ENTITY selectAllTypes.label "Vælg alle">
+<!ENTITY unselectAllTypes.label "Vælg ingen">
+<!ENTITY collapse.label "Sammenfold blokeret:">
+<!ENTITY collapse.accesskey "o">
+<!ENTITY collapse.default.yes.label "Brug standard (ja)">
+<!ENTITY collapse.default.no.label "Brug standard (nej)">
+<!ENTITY collapse.yes.label "Ja">
+<!ENTITY collapse.no.label "Nej">

=== added file 'chrome/locale/da/global.properties'
--- chrome/locale/da/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/da/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,61 @@
+action0_tooltip=Klik for at bringe kontekstmenuen op, midterklik for at aktivere/deaktivere.
+action1_tooltip=Klik for at åbne/lukke blokérbare elementer, midterklik for at aktivere/deaktivere.
+action2_tooltip=Klik for at åbne indstillingerne, midterklik for at aktivere/deaktivere.
+action3_tooltip=Klik for at aktivere/deaktivere Adblock Plus.
+disabled_tooltip=Adblock Plus er deaktiveret.
+whitelisted_tooltip=Adblock Plus er aktiv men slået fra på nuværende side.
+blocked_count_tooltip=?1? ud af ?2?
+no_blocking_suggestions=Ingen blokerbare elementer fundet på nuværende side
+whitelisted_page=Adblock Plus er slået fra for nuværende side
+whitelist_description=Mine undtagelsesregler
+filterlist_description=Mine reklamefiltre
+invalid_description=Mine ugyldige filtre
+elemhide_description=Mine skjul elementer-regler
+subscription_description=Filterabonnement:
+subscription_wrong_version=Nogle filtre i dette abonnement kræver Adblock Plus ?1? for at virke ordentligt!
+subscription_source=Kilde:
+subscription_status=Status:
+subscription_status_autodownload=Opdateres automatisk
+subscription_status_manualdownload=Opdateres manuelt
+subscription_status_externaldownload=Opdateres eksternt (af en anden udvidelse)
+subscription_status_lastdownload=Sidst hentet:
+subscription_status_lastdownload_inprogress=Henter...
+subscription_status_lastdownload_unknown=Findes ikke
+remove_subscription_warning=Vil du virkelig fjerne dette abonnement?
+import_filters_wrong_version=Advarsel: nogle af filtrene i denne liste kræver Adblock Plus ?1? for at virke ordentligt. Du skal sandsynligvis opdatere til seneste Adblock Plus-version før import af denne liste.
+import_filters_warning=Vil du erstatte dine nuværende filtre eller tilføje de nye filtre til slutningen af listen?
+import_filters_title=Importer filtre
+export_filters_title=Eksporter filtre
+invalid_filters_file=Ikke en gyldig Adblock Plus filtre-fil.
+filters_write_error=Der skete en fejl ved skrivning af filtrene til filen. Sikr dig at filen ikke er skrivebeskyttet eller holdes låst af et andet program.
+clearall_warning=Vil du virkelig fjerne alle filtre fra listen?
+resethitcounts_warning=Er du sikker på at du vil nulstille hittællerne for alle filtre? Denne operation kan ikke fortrydes!
+resethitcounts_selected_warning=Er du sikker på at du vil nulstille hittællerne for de valgte filtre? Denne operation kan ikke fortrydes!
+filter_regexp_tooltip=Dette filter er enten et regulært udtryk eller for kort til at blive optimeret. For mange af disse kan gøre din browser langsommere.
+filter_elemhide_duplicate_id=Kun ét ID for elementet der skal skjules kan angives
+filter_elemhide_nocriteria=Ingen kriterier angivet for at genkende elementet der skal skjules
+subscription_invalid_location=Filterliste-placering er hverken en gyldig URL eller et gyldigt filnavn.
+synchronize_invalid_url=Fejlede, ikke en gyldig adresse
+synchronize_connection_error=Fejlede, hentningsfejl
+synchronize_invalid_data=Fejlede, ikke en gyldig liste over filtre
+synchronize_checksum_mismatch=Fejlede, checksum matcher ikke
+synchronize_ok=Succes
+overwrite=Overskriv
+append=Tilføj
+new_filter_group_title=Nyt filter
+type_label_other=andet
+type_label_script=script
+type_label_image=billede
+type_label_stylesheet=stilark
+type_label_object=objekt
+type_label_subdocument=ramme
+type_label_document=dokument
+type_label_background=baggrund
+type_label_elemhide=skjult
+type_label_xbl=XBL-binding
+type_label_ping=link ping
+type_label_xmlhttprequest=XML-forespørgsel
+type_label_object_subrequest=objekt underforespørgsel
+type_label_dtd=DTD
+type_label_media=audio/video
+type_label_font=skrifttype

=== added file 'chrome/locale/da/meta.properties'
--- chrome/locale/da/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/da/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=Reklamer er fortid!

=== added file 'chrome/locale/da/overlay.dtd'
--- chrome/locale/da/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/da/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,22 @@
+<!ENTITY status.tooltip "Status:">
+<!ENTITY blocked.tooltip "Blokerede emner på denne side:">
+<!ENTITY filters.tooltip "Mest aktive filtre:">
+<!ENTITY menuitem.label "Adblock Plus indstillinger">
+<!ENTITY menuitem.accesskey "A">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Blokérbare elementer">
+<!ENTITY context.image.label "Adblock Billede">
+<!ENTITY context.object.label "Adblock Objekt">
+<!ENTITY context.frame.label "Adblock Ramme">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Gen-aktivér på denne side">
+<!ENTITY sidebar.title "Blokérbare elementer på nuværende side">
+<!ENTITY settings.label "Præferencer">
+<!ENTITY settings.accesskey "F">
+<!ENTITY opensidebar.label "Åbn blokérbare elementer">
+<!ENTITY opensidebar.accesskey "b">
+<!ENTITY closesidebar.label "Luk blokérbare elementer">
+<!ENTITY closesidebar.accesskey "b">
+<!ENTITY whitelist.site.label "Slå fra på ?1?">
+<!ENTITY whitelist.page.label "Slå fra på denne ene side">
+<!ENTITY objecttab.title "Bloker">
+<!ENTITY objecttab.tooltip "Klik her for at blokere dette objekt med Adblock Plus">

=== added file 'chrome/locale/da/settings.dtd'
--- chrome/locale/da/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/da/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,89 @@
+<!ENTITY dialog.title "Adblock Plus præferencer">
+<!ENTITY filters.label "Filtre">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Tilføj filter">
+<!ENTITY add.accesskey "T">
+<!ENTITY addsubscription.label "Tilføj filter-abonnement">
+<!ENTITY addsubscription.accesskey "B">
+<!ENTITY synchsubscriptions.label "Opdater alle abonnementer">
+<!ENTITY synchsubscriptions.accesskey "d">
+<!ENTITY import.label "Importer filtre">
+<!ENTITY import.accesskey "M">
+<!ENTITY export.label "Eksporter brugerdefinerede filtre">
+<!ENTITY export.accesskey "P">
+<!ENTITY clearall.label "Fjern alle brugerdefinerede filtre">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "Nulstil hit-statistikker">
+<!ENTITY resethitcounts.accesskey "N">
+<!ENTITY edit.label "Rediger">
+<!ENTITY edit.accesskey "R">
+<!ENTITY cut.label "Klip">
+<!ENTITY cut.accesskey "K">
+<!ENTITY copy.label "Kopier">
+<!ENTITY copy.accesskey "o">
+<!ENTITY paste.label "Sæt ind">
+<!ENTITY paste.accesskey "æ">
+<!ENTITY remove.label "Slet">
+<!ENTITY remove.accesskey "S">
+<!ENTITY menu.find.label "Find">
+<!ENTITY menu.find.accesskey "F">
+<!ENTITY menu.findagain.label "Find igen">
+<!ENTITY menu.findagain.accesskey "g">
+<!ENTITY view.label "Vis">
+<!ENTITY view.accesskey "i">
+<!ENTITY sort.label "Sorter efter">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "Usorteret">
+<!ENTITY sort.none.accesskey "U">
+<!ENTITY sort.ascending.label "A &gt; Z sorteringsorden">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Z &gt; A sorteringsorden">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Indstillinger">
+<!ENTITY options.accesskey "d">
+<!ENTITY enable.label "Slå Adblock Plus til">
+<!ENTITY enable.accesskey "I">
+<!ENTITY showintoolbar.label "Vis i værktøjslinje">
+<!ENTITY showintoolbar.accesskey "V">
+<!ENTITY showinstatusbar.label "Vis i statuslinje">
+<!ENTITY showinstatusbar.accesskey "s">
+<!ENTITY objecttabs.label "Vis faner på Flash og Java">
+<!ENTITY objecttabs.accesskey "J">
+<!ENTITY collapse.label "Sammenklap blokerede elementer">
+<!ENTITY collapse.accesskey "m">
+<!ENTITY help.label "Hjælp">
+<!ENTITY help.accesskey "H">
+<!ENTITY gettingStarted.label "Kom godt i gang (engelsk)">
+<!ENTITY gettingStarted.accesskey "a">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Ofte Stillede Spørgsmål">
+<!ENTITY faq.accesskey "f">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Skriver Adblock Plus filtre">
+<!ENTITY filterdoc.accesskey "R">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Om Adblock Plus">
+<!ENTITY about.accesskey "B">
+<!ENTITY description "Følgende filtre afgør hvilke adresser der skal blokeres og hvilke der skal tillades:">
+<!ENTITY filter.column "Filterregel">
+<!ENTITY filter.accesskey "F">
+<!ENTITY slow.column "Langsomme filtre">
+<!ENTITY slow.accesskey "o">
+<!ENTITY enabled.column "Slået til">
+<!ENTITY enabled.accesskey "l">
+<!ENTITY hitcount.column "Hits">
+<!ENTITY hitcount.accesskey "H">
+<!ENTITY lasthit.column "Seneste hit">
+<!ENTITY lasthit.accesskey "i">
+<!ENTITY context.edit.label "Redigér filter">
+<!ENTITY context.resethitcount.label "Nulstil hitsstatistik for filter">
+<!ENTITY context.synchsubscription.label "Opdatér abonnement nu">
+<!ENTITY context.editsubscription.label "Redigér abonnement">
+<!ENTITY context.moveup.label "Flyt filter op">
+<!ENTITY context.movedown.label "Flyt filter ned">
+<!ENTITY context.movegroupup.label "Flyt gruppe op">
+<!ENTITY context.movegroupdown.label "Flyt gruppe ned">
+<!ENTITY context.enable.label "Aktiver">
+<!ENTITY context.disable.label "Deaktiver">
+<!ENTITY apply.label "Anvend">
+<!ENTITY apply.accesskey "v">

=== added file 'chrome/locale/da/sidebar.dtd'
--- chrome/locale/da/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/da/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus blokérbare elementer (frakoblet)">
+<!ENTITY detach.label "Frakobl">
+<!ENTITY reattach.label "Gentilkobl">
+<!ENTITY search.label "Søg:">
+<!ENTITY search.accesskey "ø">
+<!ENTITY type.label "Type">
+<!ENTITY address.label "Adresse">
+<!ENTITY filter.label "Filter">
+<!ENTITY state.label "Tilstand">
+<!ENTITY size.label "Størrelse">
+<!ENTITY docDomain.label "Dokument-kilde">
+<!ENTITY noitems.label "Ingen blokérbare emner">
+<!ENTITY whitelisted.label "Hvidlistet side">
+<!ENTITY tooltip.address.label "Adresse:">
+<!ENTITY tooltip.type.label "Type:">
+<!ENTITY tooltip.type.blocked "(blokeret)">
+<!ENTITY tooltip.type.whitelisted "(hvidlistet)">
+<!ENTITY tooltip.size.label "Størrelse:">
+<!ENTITY tooltip.docDomain.label "Dokument-kilde:">
+<!ENTITY tooltip.filter.label "Fungerende filter:">
+<!ENTITY tooltip.filterSource.label "Filter kilde:">
+<!ENTITY context.block.label "Blokér dette element">
+<!ENTITY context.editfilter.label "Redigér nuværende filter">
+<!ENTITY context.whitelist.label "Tilføj undtagelsesregel for element">
+<!ENTITY context.disablefilter.label "Deaktiver filter ?1?">
+<!ENTITY context.enablefilter.label "Gen-aktiver filter ?1?">
+<!ENTITY context.disablefilteronsite.label "Deaktiver dette filter på ?1?">
+<!ENTITY context.open.label "Åbn i nyt faneblad">
+<!ENTITY context.flash.label "Blink med elementets kanter">
+<!ENTITY context.copy.label "Kopier elementets adresse">
+<!ENTITY context.copyFilter.label "Kopier filter">
+<!ENTITY context.selectAll.label "Vælg alle">

=== added file 'chrome/locale/da/subscriptionSelection.dtd'
--- chrome/locale/da/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/da/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,15 @@
+<!ENTITY dialog.title.edit "Rediger filter-abonnement">
+<!ENTITY adblock.warning "Adblock Plus har bemærket at Adblock eller en ældre version af Adblock Plus er installeret. Brug af både Adblock og Adblock Plus samtidig kan forårsage problemer og bør undgås. Det anbefales at du afinstallerer Adblock nu.">
+<!ENTITY adblock.uninstall "Afinstaller Adblock">
+<!ENTITY filterset.g.warning "Det ser ud til at du bruger Filterset.G. Denne filterliste er knapt blevet vedligeholdt de seneste par år og er en almindelig årsag til problemer med websider. Det anbefales at du afinstallerer Filterset.G nu.">
+<!ENTITY filterset.g.moreinfo "Mere information">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Afinstaller Filterset.G">
+<!ENTITY other.label "Tilføj endnu et abonnement">
+<!ENTITY other.accesskey "T">
+<!ENTITY title.label "Abonnement-titel:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Filterliste-placering:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Opdater automatisk">
+<!ENTITY autodownload.accesskey "P">

=== added directory 'chrome/locale/de'
=== removed directory 'chrome/locale/de-DE'
=== removed file 'chrome/locale/de-DE/about.dtd'
--- chrome/locale/de-DE/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/de-DE/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title       "Über Adblock Plus">
-
-<!ENTITY caption.title      "Adblock Plus">
-<!ENTITY version.title      "Version">
-<!ENTITY description        "
-  Mit Adblock Plus können Sie entscheiden, was Sie im Internet sehen möchten
-  und was nicht. Sie brauchen die ganze Werbung nicht mehr herunterzuladen,
-  wenn Sie sie nicht sehen möchten - Adblock Plus regelt dies für Sie!
-">
-
-<!ENTITY homepage.label     "Adblock Plus im Internet:">
-<!ENTITY homepage.url       "http://adblockplus.org/de/">
-<!ENTITY author.label       "Entwickler:">
-<!ENTITY contributors.label "Beteiligte:">

=== removed file 'chrome/locale/de-DE/composer.dtd'
--- chrome/locale/de-DE/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/de-DE/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,54 +0,0 @@
-<!ENTITY dialog.title             "Neuen Filter hinzufügen">
-<!ENTITY accept.label             "Filter hinzufügen">
-<!ENTITY advanced.label           "Erweiterte Ansicht">
-<!ENTITY basic.label              "Standardansicht">
-
-<!ENTITY disabled.warning.beforeLink  "Adblock Plus ist deaktiviert. Sie können trotzdem den Filter hinzufügen, dieser wird jedoch erst angewandt, wenn Sie ">
-<!ENTITY disabled.warning.link    "Adblock Plus aktivieren">
-<!ENTITY disabled.warning.afterLink   ".">
-
-<!ENTITY groupDisabled.warning.beforeLink  "Die Filtergruppe &quot;&#x25;S&quot;, in die dieser Filter eingefügt wird, ist derzeit deaktiviert. Sie können trotzdem den Filter hinzufügen, dieser wird jedoch erst angewandt, wenn Sie ">
-<!ENTITY groupDisabled.warning.link        "diese Filtergruppe aktivieren">
-<!ENTITY groupDisabled.warning.afterLink   ".">
-
-<!ENTITY filter.label             "Neuer Filter:">
-<!ENTITY filter.accesskey         "r">
-<!ENTITY preferences.label        "Existierende Filter anzeigen...">
-<!ENTITY preferences.accesskey    "z">
-<!ENTITY type.filter.label        "Blockierregel">
-<!ENTITY type.filter.accesskey    "B">
-<!ENTITY type.whitelist.label     "Ausnahmeregel">
-<!ENTITY type.whitelist.accesskey "A">
-<!ENTITY pattern.label            "Muster suchen">
-<!ENTITY pattern.explanation      "Das Muster kann ein beliebiger Teil der Adresse sein, das Zeichen '*' kann dabei als Jokerzeichen verwendet werden. Der Filter wird nur auf Adressen angewandt, die auf das Muster passen.">
-<!ENTITY regexp.warning           "Das Muster, das Sie eingegeben haben, wird als regulärer Ausdruck interpretiert. Zu viele reguläre Ausdrücke könnten Ihren Browser verlangsamen. Falls Sie nicht beabsichtigt haben, reguläre Ausdrücke zu verwenden, fügen Sie einfach das Symbol '*' am Ende des Musters an.">
-<!ENTITY shortpattern.warning     "Das Muster, das Sie eingegeben haben, ist zu kurz zum Optimieren. Zu viele solche Muster könnten Ihren Browser verlangsamen. Es ist deshalb empfehlenswert, nach Möglichkeit einen längeren Muster für diesen Filter zu verwenden.">
-<!ENTITY custom.pattern.label     "Benutzerdefiniert:">
-<!ENTITY custom.pattern.accesskey "n">
-<!ENTITY anchors.label            "Muster nur akzeptieren:">
-<!ENTITY anchor.start.label       "am Anfang der Adresse">
-<!ENTITY anchor.start.accesskey   "f">
-<!ENTITY anchor.start.flexible.label      "am Anfang des Domain-Namens">
-<!ENTITY anchor.start.flexible.accesskey  "f">
-<!ENTITY anchor.end.label         "am Ende der Adresse">
-<!ENTITY anchor.end.accesskey     "d">
-<!ENTITY options.label            "Optionen">
-<!ENTITY domainRestriction.label      "Auf Domain beschränken:">
-<!ENTITY domainRestriction.accesskey  "m">
-<!ENTITY domainRestriction.help       "Geben Sie eine oder mehrere Domains an (Trennzeichen ist &quot;|&quot;), der Filter wird dann nur auf diesen Domains angewandt. Das Zeichen &quot;~&quot; vor einem Domainnamen bedeutet, dass der Filter auf dieser Domain nicht angewandt werden sollte.">
-<!ENTITY firstParty.label         "Nur für Elemente der Ursprungsseite">
-<!ENTITY firstParty.accesskey     "p">
-<!ENTITY thirdParty.label         "Nur für Elemente von Drittseiten">
-<!ENTITY thirdParty.accesskey     "t">
-<!ENTITY matchCase.label          "Groß-/Kleinschreibung beachten">
-<!ENTITY matchCase.accesskey      "K">
-<!ENTITY types.label              "Auf Elementtypen anwenden:">
-<!ENTITY selectAllTypes.label     "Alle auswählen">
-<!ENTITY unselectAllTypes.label   "Keine auswählen">
-
-<!ENTITY collapse.label           "Platz freigeben:">
-<!ENTITY collapse.accesskey       "g">
-<!ENTITY collapse.default.yes.label "Standardeinstellung (ja)">
-<!ENTITY collapse.default.no.label  "Standardeinstellung (nein)">
-<!ENTITY collapse.yes.label       "Ja">
-<!ENTITY collapse.no.label        "Nein">

=== removed file 'chrome/locale/de-DE/global.properties'
--- chrome/locale/de-DE/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/de-DE/global.properties	1970-01-01 00:00:00 +0000
@@ -1,78 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Werbung war gestern!
-
-status_active_label=Adblock
-status_disabled_label=Deaktiviert
-
-action0_tooltip=Kontextmenü anzeigen. Mittlere Maustaste schaltet Adblock Plus ein und aus.
-action1_tooltip=Liste blockierbarer Elemente öffnen bzw. schließen. Mittlere Maustaste schaltet Adblock Plus ein und aus.
-action2_tooltip=Adblock Plus Einstellungen öffnen. Mittlere Maustaste schaltet Adblock Plus ein und aus.
-action3_tooltip=Adblock Plus ein- bzw. ausschalten
-
-active_tooltip=Adblock Plus ist aktiviert
-disabled_tooltip=Adblock Plus ist deaktiviert
-whitelisted_tooltip=Adblock Plus ist aktiv, allerdings wurde es für diese Seite deaktiviert
-
-blocked_count_tooltip=-- von --
-
-no_blocking_suggestions=Auf der geöffneten Seite gibt es keine Elemente, die blockiert werden könnten
-whitelisted_page=Adblock Plus wurde für die geöffnete Seite deaktiviert
-
-whitelist_description=Meine Ausnahmeregeln
-filterlist_description=Meine Blockierregeln
-invalid_description=Meine fehlerhaften Regeln
-elemhide_description=Meine Regeln zum Verstecken von Elementen
-subscription_description=Filter-Abonnement:
-subscription_wrong_version=Einige Filter in diesem Abonnement benötigen Adblock Plus --, um korrekt zu funktionieren!
-subscription_source=Quelle:
-subscription_status=Status:
-subscription_status_autodownload=Automatische Aktualisierung
-subscription_status_manualdownload=Manuelle Aktualisierung
-subscription_status_externaldownload=Externe Aktualisierung (andere Erweiterung)
-subscription_status_lastdownload=Zuletzt aktualisiert:
-subscription_status_lastdownload_inprogress=jetzt...
-subscription_status_lastdownload_unknown=nie
-remove_subscription_warning=Sind Sie sicher, dass Sie dieses Abonnement entfernen möchten?
-import_filters_wrong_version=Warnung: einige Filter in dieser Liste benötigen Adblock Plus --, um korrekt zu funktionieren. Vielleicht sollten Sie die letzte Version von Adblock Plus installieren, bevor Sie diese Liste importieren.
-import_filters_warning=Sollen die importierten Filter die vorhandenen ersetzen oder sollen sie am Ende hinzugefügt werden?
-import_filters_title=Filter importieren
-export_filters_title=Filter exportieren
-invalid_filters_file=Die Datei ist keine gültige Adblock Plus Filter-Datei.
-filters_write_error=Beim Schreiben der Filter in die Datei ist ein Fehler aufgetreten. Eventuell ist die Datei schreibgeschützt oder wird von einem anderen Programm verwendet.
-clearall_warning=Sind Sie sicher, dass Sie alle Filter aus der Liste entfernen möchten?
-resethitcounts_warning=Sind Sie sicher, dass Sie die Statistik für alle Filter auf Null zurücksetzen möchten? Diese Änderung kann nicht rückgängig gemacht werden!
-resethitcounts_selected_warning=Sind Sie sicher, dass Sie die Statistik für die ausgewählten Filter auf Null zurücksetzen möchten? Diese Änderung kann nicht rückgängig gemacht werden!
-
-filter_regexp_tooltip=Dieser Filter ist entweder ein regulärer Ausdruck oder zu kurz zum Optimieren. Zu viele solche Filter könnten Ihren Browser verlangsamen.
-filter_elemhide_duplicate_id=Nur ein ID-Wert des zu versteckenden Elements kann angegeben werden
-filter_elemhide_nocriteria=Keine Kriterien angegeben, um das zu versteckende Element zu erkennen
-
-subscription_no_location=Bitte geben Sie die Adresse an, von der die Filter heruntergeladen werden sollen.
-subscription_invalid_location=Die eingegebene Adresse ist weder eine gültige Web-Adresse, noch ein gültiger Dateiname.
-subscription_location_exists=Sie haben dieses Abonnement bereits erstellt.
-synchronize_invalid_url=Fehler, ungültige Adresse
-synchronize_connection_error=Fehler, Download gescheitert
-synchronize_invalid_data=Fehler, keine gültige Filter-Liste
-synchronize_checksum_mismatch=Fehler, Prüfsumme ist falsch, möglicherweise ein Übertragungsfehler
-synchronize_ok=Erfolg
-
-overwrite=Überschreiben
-append=Hinzufügen
-
-new_filter_group_title=Neuer Filter
-
-type_label_other=Unbekannt
-type_label_script=Skript
-type_label_image=Grafik
-type_label_stylesheet=Stylesheet
-type_label_object=Objekt
-type_label_subdocument=Frame
-type_label_document=Dokument
-type_label_background=Hintergrund
-type_label_elemhide=Versteckt
-type_label_xbl=XBL
-type_label_ping=Link-Rückmeldung
-type_label_xmlhttprequest=XML-Anfrage
-type_label_object_subrequest=Objekt-Anfrage
-type_label_dtd=DTD
-type_label_media=Audio/Video
-type_label_font=Schriftart

=== removed file 'chrome/locale/de-DE/overlay.dtd'
--- chrome/locale/de-DE/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/de-DE/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,28 +0,0 @@
-<!ENTITY status.tooltip         "Status:">
-<!ENTITY blocked.tooltip        "Blockierte Elemente auf dieser Seite:">
-<!ENTITY filters.tooltip        "Am meisten angewandte Filter:">
-
-<!ENTITY menuitem.label         "Adblock Plus - Einstellungen">
-<!ENTITY menuitem.accesskey     "A">
-<!ENTITY toolbarbutton.label    "Adblock Plus">
-
-<!ENTITY view.blockableItems.label  "Adblock Plus: Elemente der geöffneten Seite">
-
-<!ENTITY context.image.label    "Adblock Plus: Grafik blockieren">
-<!ENTITY context.object.label   "Adblock Plus: Objekt blockieren">
-<!ENTITY context.frame.label    "Adblock Plus: Frame blockieren">
-<!ENTITY context.removeWhitelist.label  "Adblock Plus: Auf dieser Seite wieder aktivieren">
-
-<!ENTITY sidebar.title          "Elemente der geöffneten Seite">
-
-<!ENTITY settings.label         "Einstellungen">
-<!ENTITY settings.accesskey     "T">
-<!ENTITY opensidebar.label      "Blockierbare Elemente öffnen">
-<!ENTITY opensidebar.accesskey  "B">
-<!ENTITY closesidebar.label     "Blockierbare Elemente schließen">
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label   "Deaktivieren: auf --">
-<!ENTITY whitelist.page.label   "Deaktivieren: nur auf dieser Seite">
-
-<!ENTITY objecttab.title        "Blockieren">
-<!ENTITY objecttab.tooltip      "Klicken Sie hier, um dieses Objekt mit Adblock Plus zu blockieren">

=== removed file 'chrome/locale/de-DE/settings.dtd'
--- chrome/locale/de-DE/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/de-DE/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,102 +0,0 @@
-<!ENTITY dialog.title               "Adblock Plus - Einstellungen">
-
-<!ENTITY filters.label              "Filter">
-<!ENTITY filters.accesskey          "F">
-
-<!ENTITY add.label                  "Filter hinzufügen">
-<!ENTITY add.accesskey              "Z">
-<!ENTITY addsubscription.label      "Filter-Abonnement hinzufügen">
-<!ENTITY addsubscription.accesskey  "B">
-<!ENTITY synchsubscriptions.label       "Filter für alle Abonnements herunterladen">
-<!ENTITY synchsubscriptions.accesskey   "N">
-<!ENTITY import.label               "Filter importieren">
-<!ENTITY import.accesskey           "M">
-<!ENTITY export.label               "Benutzerfilter exportieren">
-<!ENTITY export.accesskey           "X">
-<!ENTITY clearall.label             "Alle Benutzerfilter entfernen">
-<!ENTITY clearall.accesskey         "L">
-<!ENTITY resethitcounts.label       "Trefferstatistik zurücksetzen">
-<!ENTITY resethitcounts.accesskey   "R">
-
-<!ENTITY edit.label                 "Bearbeiten">
-<!ENTITY edit.accesskey             "B">
-
-<!ENTITY cut.label                  "Ausschneiden">
-<!ENTITY cut.accesskey              "A">
-<!ENTITY copy.label                 "Kopieren">
-<!ENTITY copy.accesskey             "K">
-<!ENTITY paste.label                "Einfügen">
-<!ENTITY paste.accesskey            "E">
-<!ENTITY remove.label               "Löschen">
-<!ENTITY remove.accesskey           "L">
-<!ENTITY menu.find.label            "Filter durchsuchen">
-<!ENTITY menu.find.accesskey        "S">
-<!ENTITY menu.findagain.label       "Weitersuchen">
-<!ENTITY menu.findagain.accesskey   "N">
-
-<!ENTITY view.label                 "Ansicht">
-<!ENTITY view.accesskey             "s">
-
-<!ENTITY sort.label                 "Sortieren">
-<!ENTITY sort.accesskey             "S">
-<!ENTITY sort.none.label            "Unsortiert">
-<!ENTITY sort.none.accesskey        "U">
-<!ENTITY sort.ascending.label       "Aufsteigend">
-<!ENTITY sort.ascending.accesskey   "A">
-<!ENTITY sort.descending.label      "Absteigend">
-<!ENTITY sort.descending.accesskey  "b">
-
-<!ENTITY options.label              "Optionen">
-<!ENTITY options.accesskey          "O">
-
-<!ENTITY enable.label               "Adblock Plus aktivieren">
-<!ENTITY enable.accesskey           "N">
-<!ENTITY showintoolbar.label        "In Symbolleiste anzeigen">
-<!ENTITY showintoolbar.accesskey    "M">
-<!ENTITY showinstatusbar.label      "In Statusleiste anzeigen">
-<!ENTITY showinstatusbar.accesskey  "S">
-<!ENTITY objecttabs.label           "Tab zum Blockieren von Flash und Java anzeigen">
-<!ENTITY objecttabs.accesskey       "B">
-<!ENTITY collapse.label             "Platz von blockierten Elementen freigeben">
-<!ENTITY collapse.accesskey         "F">
-<!ENTITY help.label                 "Hilfe">
-<!ENTITY help.accesskey             "H">
-
-<!ENTITY gettingStarted.label       "Erste Schritte">
-<!ENTITY gettingStarted.accesskey   "S">
-<!ENTITY gettingStarted.url         "http://adblockplus.org/de/getting_started">
-<!ENTITY faq.label                  "Häufig gestellte Fragen">
-<!ENTITY faq.accesskey              "F">
-<!ENTITY faq.url                    "http://adblockplus.org/de/faq">
-<!ENTITY filterdoc.label            "Filter für Adblock Plus erstellen">
-<!ENTITY filterdoc.accesskey        "L">
-<!ENTITY filterdoc.url              "http://adblockplus.org/de/filters">
-<!ENTITY about.label                "Über Adblock Plus">
-<!ENTITY about.accesskey            "B">
-
-<!ENTITY description                "Die Filter in dieser Liste bestimmen, welche Adressen von Adblock Plus blockiert werden:">
-
-<!ENTITY filter.column              "Filterregel">
-<!ENTITY filter.accesskey           "F">
-<!ENTITY slow.column                "Langsam">
-<!ENTITY slow.accesskey             "L">
-<!ENTITY enabled.column             "Aktiv">
-<!ENTITY enabled.accesskey          "k">
-<!ENTITY hitcount.column            "Treffer">
-<!ENTITY hitcount.accesskey         "r">
-<!ENTITY lasthit.column             "Letzter Treffer">
-<!ENTITY lasthit.accesskey          "z">
-
-<!ENTITY context.edit.label         "Filter bearbeiten">
-<!ENTITY context.resethitcount.label      "Trefferstatistik für Filter zurücksetzen">
-<!ENTITY context.synchsubscription.label  "Filter jetzt neu herunterladen">
-<!ENTITY context.editsubscription.label   "Abonnement bearbeiten">
-<!ENTITY context.moveup.label       "Filter nach oben verschieben">
-<!ENTITY context.movedown.label     "Filter nach unten verschieben">
-<!ENTITY context.movegroupup.label        "Gruppe nach oben verschieben">
-<!ENTITY context.movegroupdown.label      "Gruppe nach unten verschieben">
-<!ENTITY context.enable.label       "Aktivieren">
-<!ENTITY context.disable.label      "Deaktivieren">
-
-<!ENTITY apply.label                "Anwenden">
-<!ENTITY apply.accesskey            "W">

=== removed file 'chrome/locale/de-DE/sidebar.dtd'
--- chrome/locale/de-DE/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/de-DE/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,37 +0,0 @@
-<!ENTITY detached.title           "Adblock Plus: Elemente der geöffneten Seite (abgekoppelt)">
-
-<!ENTITY detach.label             "Abkoppeln">
-<!ENTITY reattach.label           "Ankoppeln">
-
-<!ENTITY search.label             "Suchen:">
-<!ENTITY search.accesskey         "S">
-
-<!ENTITY type.label               "Typ">
-<!ENTITY address.label            "Adresse">
-<!ENTITY filter.label             "Filter">
-<!ENTITY state.label              "Status">
-<!ENTITY size.label               "Größe">
-<!ENTITY docDomain.label          "Ursprungsdomain">
-
-<!ENTITY noitems.label            "Keine Elemente zu blockieren">
-<!ENTITY whitelisted.label        "Deaktiviert auf dieser Seite">
-<!ENTITY tooltip.address.label    "Addresse:">
-<!ENTITY tooltip.type.label       "Typ:">
-<!ENTITY tooltip.type.blocked     "(blockiert)">
-<!ENTITY tooltip.type.whitelisted "(Ausnahmeregel aktiv)">
-<!ENTITY tooltip.size.label       "Größe:">
-<!ENTITY tooltip.docDomain.label  "Ursprungsdomain:">
-<!ENTITY tooltip.filter.label     "Angewandter Filter:">
-<!ENTITY tooltip.filterSource.label "Herkunft des Filters:">
-
-<!ENTITY context.block.label      "Dieses Element blockieren">
-<!ENTITY context.editfilter.label "Angewandten Filter bearbeiten">
-<!ENTITY context.whitelist.label  "Ausnahmeregel für das Element hinzufügen">
-<!ENTITY context.disablefilter.label  "Filter -- deaktivieren">
-<!ENTITY context.enablefilter.label   "Filter -- wieder aktivieren">
-<!ENTITY context.disablefilteronsite.label  "Diesen Filter auf -- deaktivieren">
-<!ENTITY context.open.label       "Adresse in neuem Tab öffnen">
-<!ENTITY context.flash.label      "Position des Elements aufzeigen">
-<!ENTITY context.copy.label       "Adresse des Elements kopieren">
-<!ENTITY context.copyFilter.label "Filter kopieren">
-<!ENTITY context.selectAll.label  "Alles auswählen">

=== removed file 'chrome/locale/de-DE/subscription.dtd'
--- chrome/locale/de-DE/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/de-DE/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,33 +0,0 @@
-<!ENTITY dialog.title               "Filter-Abonnement bearbeiten">
-<!ENTITY dialog.newtitle            "Filter-Abonnement hinzufügen">
-
-<!ENTITY new.description            "
-  Tragen Sie bitte die Web-Adresse oder den Dateinamen ein, wo die Liste mit Filtern
-  für Adblock Plus gefunden werden kann.
-">
-
-<!ENTITY edit.description           "
-  Die Filter-Liste für dieses Abonnement wird von der angegebenen Adresse
-  heruntergeladen.
-">
-
-<!ENTITY external.description       "
-  Das ist ein externes Filter-Abonnement, es wird von der
-  Erweiterung verwaltet, die es erstellt hat.
-">
-
-<!ENTITY autodownload.description   "
-  Falls 'Automatisch aktualisieren' auswählt ist, wird diese
-  Adresse täglich auf Änderungen überprüft. Ohne diese Option
-  kann die Aktualisierung immer noch manuell aus dem
-  Kontext-Menü des Abonnements gestartet werden.
-">
-
-<!ENTITY location.label             "Adresse der Filter-Liste:">
-<!ENTITY location.accesskey         "D">
-<!ENTITY title.label                "Bezeichnung des Abonnements:">
-<!ENTITY title.accesskey            "Z">
-<!ENTITY autodownload.label         "Automatisch aktualisieren">
-<!ENTITY autodownload.accesskey     "T">
-<!ENTITY enabled.label              "Filter aktivieren">
-<!ENTITY enabled.accesskey          "K">

=== removed file 'chrome/locale/de-DE/tip_subscriptions.dtd'
--- chrome/locale/de-DE/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/de-DE/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,48 +0,0 @@
-<!ENTITY dialog.title               "Filterabonnement für Adblock Plus hinzufügen">
-
-<!ENTITY description.par1           "
-  Danke, dass Sie Adblock Plus installiert haben. Diese Erweiterung erlaubt
-  es Ihnen, 99&#x25; der Werbung im Internet einfach zu blockieren. Allerdings
-  benötigt man wohldefinierte Filter, damit es optimal funktioniert.
-  Diese können Sie selber erstellen, oder Sie benutzen einfach Filterlisten,
-  die andere Ihnen zur Verfügung stellen. Falls Sie sich fürs letztere
-  entscheiden, können Sie natürlich weiterhin eigene Filter hinzufügen. Die
-  Filter-Abonnements können auch jederzeit deaktiviert oder ganz entfernt werden.
-">
-
-<!ENTITY description.par2           "
-  Unten finden Sie eine Auswahl empfohlener Filterlisten, von denen
-  Sie jetzt eine auswählen können (mehr Abonnements können später in den Adblock Plus
-  Einstellungen hinzugefügt werden, in der Regel ist das aber nicht nötig):
-">
-
-<!ENTITY note                       "
-  Bemerkung: In der Regel ist eine Filterliste dann am effektivsten, wenn sie
-  auf Webseiten der Region angewandt wird, für die sie erstellt wurde.
-">
-
-<!ENTITY adblock.warning            "
-  Adblock Plus hat festgestellt, dass Sie Adblock oder eine alte Version von Adblock Plus
-  installiert haben. Wenn Sie Adblock und Adblock Plus parallel ausführen, kann das Probleme
-  beim Browsen verursachen. Es wird empfohlen, Adblock jetzt zu deinstallieren.
-">
-<!ENTITY adblock.uninstall          "Adblock deinstallieren">
-
-<!ENTITY filterset.g.warning        "
-  Es scheint, dass Sie Filterset.G verwenden. Diese Filterliste wurde in den vergangenen Jahren
-  kaum aktualisiert und ist oft Ursache von Problemen auf Webseiten. Es wird empfohlen, Filterset.G
-  jetzt zu deinstallieren.
-">
-<!ENTITY filterset.g.moreinfo       "Weitere Informationen">
-<!ENTITY filterset.g.moreinfo.url   "http://adblockplus.org/de/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall      "Filterset.G deinstallieren">
-
-<!ENTITY homepage.label             "Webseite des Abonnements">
-
-<!ENTITY subscribe.label            "Abonnieren">
-<!ENTITY subscribe.accesskey        "B">
-<!ENTITY other.label                "Anderes Abonnement hinzufügen">
-<!ENTITY other.accesskey            "D">
- 
-<!ENTITY full-list.url              "http://adblockplus.org/de/subscriptions">
-<!ENTITY full-list.label            "Alle bekannten Abonnements anzeigen">

=== added file 'chrome/locale/de/about.dtd'
--- chrome/locale/de/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/de/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,19 @@
+<!ENTITY dialog.title       "Über Adblock Plus">
+
+<!ENTITY caption.title      "Adblock Plus">
+<!ENTITY version.title      "Version">
+<!ENTITY description        "
+  Mit Adblock Plus können Sie entscheiden, was Sie im Internet sehen möchten
+  und was nicht. Sie brauchen die ganze Werbung nicht mehr herunterzuladen,
+  wenn Sie sie nicht sehen möchten - Adblock Plus regelt dies für Sie!
+">
+
+<!ENTITY homepage.label     "Adblock Plus im Internet:">
+<!ENTITY homepage.url       "http://adblockplus.org/de/">
+<!ENTITY author.label       "Entwickler:">
+<!ENTITY contributors.label "Beteiligte:">
+
+<!ENTITY developers.label   "Entwickler:">
+<!ENTITY designers.label    "Grafikdesigner:">
+<!ENTITY subscriptionAuthors.label    "Autoren von Filterabonnements:">
+<!ENTITY translators.label  "Übersetzer:">

=== added file 'chrome/locale/de/composer.dtd'
--- chrome/locale/de/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/de/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,48 @@
+<!ENTITY dialog.title             "Neuen Filter hinzufügen">
+<!ENTITY accept.label             "Filter hinzufügen">
+<!ENTITY advanced.label           "Erweiterte Ansicht">
+<!ENTITY basic.label              "Standardansicht">
+
+<!ENTITY disabled.warning "Adblock Plus ist deaktiviert. Sie können trotzdem den Filter hinzufügen, dieser wird jedoch erst angewandt, wenn Sie [link]Adblock Plus aktivieren[/link].">
+<!ENTITY groupDisabled.warning "Die Filtergruppe &quot;?1?&quot;, in die dieser Filter eingefügt wird, ist derzeit deaktiviert. Sie können trotzdem den Filter hinzufügen, dieser wird jedoch erst angewandt, wenn Sie [link]diese Filtergruppe aktivieren[/link].">
+<!ENTITY filter.label             "Neuer Filter:">
+<!ENTITY filter.accesskey         "r">
+<!ENTITY preferences.label        "Existierende Filter anzeigen...">
+<!ENTITY preferences.accesskey    "z">
+<!ENTITY type.filter.label        "Blockierregel">
+<!ENTITY type.filter.accesskey    "B">
+<!ENTITY type.whitelist.label     "Ausnahmeregel">
+<!ENTITY type.whitelist.accesskey "A">
+<!ENTITY pattern.label            "Muster suchen">
+<!ENTITY pattern.explanation      "Das Muster kann ein beliebiger Teil der Adresse sein, das Zeichen '*' kann dabei als Jokerzeichen verwendet werden. Der Filter wird nur auf Adressen angewandt, die auf das Muster passen.">
+<!ENTITY regexp.warning           "Das Muster, das Sie eingegeben haben, wird als regulärer Ausdruck interpretiert. Zu viele reguläre Ausdrücke könnten Ihren Browser verlangsamen. Falls Sie nicht beabsichtigt haben, reguläre Ausdrücke zu verwenden, fügen Sie einfach das Symbol '*' am Ende des Musters an.">
+<!ENTITY shortpattern.warning     "Das Muster, das Sie eingegeben haben, ist zu kurz zum Optimieren. Zu viele solche Muster könnten Ihren Browser verlangsamen. Es ist deshalb empfehlenswert, nach Möglichkeit einen längeren Muster für diesen Filter zu verwenden.">
+<!ENTITY custom.pattern.label     "Benutzerdefiniert:">
+<!ENTITY custom.pattern.accesskey "n">
+<!ENTITY anchors.label            "Muster nur akzeptieren:">
+<!ENTITY anchor.start.label       "am Anfang der Adresse">
+<!ENTITY anchor.start.accesskey   "f">
+<!ENTITY anchor.start.flexible.label      "am Anfang des Domain-Namens">
+<!ENTITY anchor.start.flexible.accesskey  "f">
+<!ENTITY anchor.end.label         "am Ende der Adresse">
+<!ENTITY anchor.end.accesskey     "d">
+<!ENTITY options.label            "Optionen">
+<!ENTITY domainRestriction.label      "Auf Domain beschränken:">
+<!ENTITY domainRestriction.accesskey  "m">
+<!ENTITY domainRestriction.help       "Geben Sie eine oder mehrere Domains an (Trennzeichen ist &quot;|&quot;), der Filter wird dann nur auf diesen Domains angewandt. Das Zeichen &quot;~&quot; vor einem Domainnamen bedeutet, dass der Filter auf dieser Domain nicht angewandt werden sollte.">
+<!ENTITY firstParty.label         "Nur für Elemente der Ursprungsseite">
+<!ENTITY firstParty.accesskey     "p">
+<!ENTITY thirdParty.label         "Nur für Elemente von Drittseiten">
+<!ENTITY thirdParty.accesskey     "t">
+<!ENTITY matchCase.label          "Groß-/Kleinschreibung beachten">
+<!ENTITY matchCase.accesskey      "K">
+<!ENTITY types.label              "Auf Elementtypen anwenden:">
+<!ENTITY selectAllTypes.label     "Alle auswählen">
+<!ENTITY unselectAllTypes.label   "Keine auswählen">
+
+<!ENTITY collapse.label           "Platz freigeben:">
+<!ENTITY collapse.accesskey       "g">
+<!ENTITY collapse.default.yes.label "Standardeinstellung (ja)">
+<!ENTITY collapse.default.no.label  "Standardeinstellung (nein)">
+<!ENTITY collapse.yes.label       "Ja">
+<!ENTITY collapse.no.label        "Nein">

=== added file 'chrome/locale/de/global.properties'
--- chrome/locale/de/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/de/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,81 @@
+default_dialog_title=Adblock Plus
+
+action0_tooltip=Kontextmenü anzeigen. Mittlere Maustaste schaltet Adblock Plus ein und aus.
+action1_tooltip=Liste blockierbarer Elemente öffnen bzw. schließen. Mittlere Maustaste schaltet Adblock Plus ein und aus.
+action2_tooltip=Adblock Plus Einstellungen öffnen. Mittlere Maustaste schaltet Adblock Plus ein und aus.
+action3_tooltip=Adblock Plus ein- bzw. ausschalten
+
+disabled_tooltip=Adblock Plus ist deaktiviert.
+active_tooltip=Adblock Plus ist aktiv, ?1? Filterabonnement(s) and ?2? eigene Filter werden verwendet.
+whitelisted_tooltip=Adblock Plus ist auf dieser Seite deaktiviert.
+
+blocked_count_tooltip=?1? von ?2?
+blocked_count_addendum=(außerdem Ausnahmen: ?1?, versteckte Elemente: ?2?)
+
+no_blocking_suggestions=Auf der geöffneten Seite gibt es keine Elemente, die blockiert werden könnten
+whitelisted_page=Adblock Plus wurde für die geöffnete Seite deaktiviert
+
+whitelist_description=Meine Ausnahmeregeln
+filterlist_description=Meine Blockierregeln
+invalid_description=Meine fehlerhaften Regeln
+elemhide_description=Meine Regeln zum Verstecken von Elementen
+subscription_description=Filterabonnement:
+subscription_wrong_version=Einige Filter in diesem Abonnement benötigen Adblock Plus ?1?, um korrekt zu funktionieren!
+subscription_source=Quelle:
+subscription_status=Status:
+subscription_status_autodownload=Automatische Aktualisierung
+subscription_status_manualdownload=Manuelle Aktualisierung
+subscription_status_externaldownload=Externe Aktualisierung (andere Erweiterung)
+subscription_status_lastdownload=Zuletzt aktualisiert:
+subscription_status_lastdownload_inprogress=jetzt...
+subscription_status_lastdownload_unknown=nie
+remove_subscription_warning=Sind Sie sicher, dass Sie dieses Abonnement entfernen möchten?
+import_filters_wrong_version=Warnung: einige Filter in dieser Liste benötigen Adblock Plus ?1?, um korrekt zu funktionieren. Vielleicht sollten Sie die letzte Version von Adblock Plus installieren, bevor Sie diese Liste importieren.
+import_filters_warning=Sollen die importierten Filter die vorhandenen ersetzen oder sollen sie am Ende hinzugefügt werden?
+import_filters_title=Filter importieren
+export_filters_title=Filter exportieren
+invalid_filters_file=Die Datei ist keine gültige Adblock Plus Filterdatei.
+filters_write_error=Beim Schreiben der Filter in die Datei ist ein Fehler aufgetreten. Eventuell ist die Datei schreibgeschützt oder wird von einem anderen Programm verwendet.
+clearall_warning=Sind Sie sicher, dass Sie alle Filter aus der Liste entfernen möchten?
+resethitcounts_warning=Sind Sie sicher, dass Sie die Statistik für alle Filter auf Null zurücksetzen möchten? Diese Änderung kann nicht rückgängig gemacht werden!
+resethitcounts_selected_warning=Sind Sie sicher, dass Sie die Statistik für die ausgewählten Filter auf Null zurücksetzen möchten? Diese Änderung kann nicht rückgängig gemacht werden!
+
+filter_regexp_tooltip=Dieser Filter ist entweder ein regulärer Ausdruck oder zu kurz zum Optimieren. Zu viele solche Filter könnten Ihren Browser verlangsamen.
+filter_elemhide_duplicate_id=Nur ein ID-Wert des zu versteckenden Elements kann angegeben werden
+filter_elemhide_nocriteria=Keine Kriterien angegeben, um das zu versteckende Element zu erkennen
+
+subscription_notAdded_warning=Sie haben kein Filterabonnement hinzugefügt. Ohne ein Filterabonnement werden Sie die Filter für Adblock Plus manuell hinzufügen müssen.
+subscription_notAdded_warning_addendum=Wollen Sie ohne Filterabonnement fortfahren?
+subscription_invalid_location=Die eingegebene Adresse ist weder eine gültige Web-Adresse, noch ein gültiger Dateiname.
+synchronize_invalid_url=Fehler, ungültige Adresse
+synchronize_connection_error=Fehler, Download gescheitert
+synchronize_invalid_data=Fehler, keine gültige Filterliste
+synchronize_checksum_mismatch=Fehler, Prüfsumme ist falsch, möglicherweise ein Übertragungsfehler
+synchronize_ok=Erfolg
+
+overwrite=Überschreiben
+append=Hinzufügen
+
+new_filter_group_title=Neuer Filter
+
+type_label_other=Unbekannt
+type_label_script=Skript
+type_label_image=Grafik
+type_label_stylesheet=Stylesheet
+type_label_object=Objekt
+type_label_subdocument=Frame
+type_label_document=Dokument
+type_label_background=Hintergrund
+type_label_elemhide=Versteckt
+type_label_xbl=XBL
+type_label_ping=Link-Rückmeldung
+type_label_xmlhttprequest=XML-Anfrage
+type_label_object_subrequest=Objekt-Anfrage
+type_label_dtd=DTD
+type_label_media=Audio/Video
+type_label_font=Schriftart
+
+fennec_status_enabled=Adblock Plus ist deaktiviert.
+fennec_status_disabled=Adblock Plus ist aktiv.
+fennec_status_enabled_site=Adblock Plus ist auf ?1? aktiv.
+fennec_status_disabled_site=Adblock Plus ist auf ?1? deaktiviert.

=== added file 'chrome/locale/de/meta.properties'
--- chrome/locale/de/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/de/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Wladimir Palant
+name=Adblock Plus
+description=Werbung war gestern!
+description.short=Genervt von Werbung? Geplagt von Datensammlern? Jetzt Adblock Plus installieren, um die Kontrolle über das Internet wiederzuerlangen und es so zu erleben, wie es sein sollte.\n\nEine kurze Einleitung: http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Mit Adblock Plus haben Sie die Kontrolle wieder und bestimmen selber, was Sie sehen wollen. Die Erweiterung wird von über vierzig Filterabonnements für Dutzende Sprachen unterstützt, mit denen sie automatisch für verschiedene Einsatzzwecke konfiguriert wird, angefangen beim Blockieren von Werbung bis hin zum Blockieren bekannter bösartiger Webseiten. Mit Adblock Plus können Sie auch eigene Filter erstellen, unterstützt durch viele hilfreiche Features, z.B. ein Kontextmenü-Eintrag für Bilder, ein Tab zum Blockieren von Flash und Java, und die Liste blockierbarer Elemente zum Entfernen von Skripten.

=== added file 'chrome/locale/de/overlay.dtd'
--- chrome/locale/de/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/de/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,29 @@
+<!ENTITY status.tooltip         "Status:">
+<!ENTITY blocked.tooltip        "Blockierte Elemente auf dieser Seite:">
+<!ENTITY filters.tooltip        "Am meisten angewandte Filter:">
+
+<!ENTITY menuitem.label         "Adblock Plus - Einstellungen">
+<!ENTITY menuitem.accesskey     "A">
+<!ENTITY toolbarbutton.label    "Adblock Plus">
+
+<!ENTITY view.blockableItems.label  "Adblock Plus: Elemente der geöffneten Seite">
+
+<!ENTITY context.image.label    "Adblock Plus: Grafik blockieren">
+<!ENTITY context.object.label   "Adblock Plus: Objekt blockieren">
+<!ENTITY context.frame.label    "Adblock Plus: Frame blockieren">
+<!ENTITY context.media.label    "Adblock Plus: Audio-/Video-Element blockieren">
+<!ENTITY context.removeWhitelist.label  "Adblock Plus: Auf dieser Seite wieder aktivieren">
+
+<!ENTITY sidebar.title          "Elemente der geöffneten Seite">
+
+<!ENTITY settings.label         "Einstellungen">
+<!ENTITY settings.accesskey     "T">
+<!ENTITY opensidebar.label      "Blockierbare Elemente öffnen">
+<!ENTITY opensidebar.accesskey  "B">
+<!ENTITY closesidebar.label     "Blockierbare Elemente schließen">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label   "Deaktivieren: auf ?1?">
+<!ENTITY whitelist.page.label   "Deaktivieren: nur auf dieser Seite">
+
+<!ENTITY objecttab.title        "Blockieren">
+<!ENTITY objecttab.tooltip      "Klicken Sie hier, um dieses Objekt mit Adblock Plus zu blockieren">

=== added file 'chrome/locale/de/settings.dtd'
--- chrome/locale/de/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/de/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,104 @@
+<!ENTITY dialog.title               "Adblock Plus - Einstellungen">
+
+<!ENTITY filters.label              "Filter">
+<!ENTITY filters.accesskey          "F">
+
+<!ENTITY add.label                  "Filter hinzufügen">
+<!ENTITY add.accesskey              "Z">
+<!ENTITY addsubscription.label      "Filterabonnement hinzufügen">
+<!ENTITY addsubscription.accesskey  "B">
+<!ENTITY synchsubscriptions.label       "Filter für alle Abonnements herunterladen">
+<!ENTITY synchsubscriptions.accesskey   "N">
+<!ENTITY import.label               "Filter importieren">
+<!ENTITY import.accesskey           "M">
+<!ENTITY export.label               "Benutzerfilter exportieren">
+<!ENTITY export.accesskey           "X">
+<!ENTITY clearall.label             "Alle Benutzerfilter entfernen">
+<!ENTITY clearall.accesskey         "L">
+<!ENTITY resethitcounts.label       "Trefferstatistik zurücksetzen">
+<!ENTITY resethitcounts.accesskey   "R">
+
+<!ENTITY edit.label                 "Bearbeiten">
+<!ENTITY edit.accesskey             "B">
+
+<!ENTITY cut.label                  "Ausschneiden">
+<!ENTITY cut.accesskey              "A">
+<!ENTITY copy.label                 "Kopieren">
+<!ENTITY copy.accesskey             "K">
+<!ENTITY paste.label                "Einfügen">
+<!ENTITY paste.accesskey            "E">
+<!ENTITY remove.label               "Löschen">
+<!ENTITY remove.accesskey           "L">
+<!ENTITY menu.find.label            "Filter durchsuchen">
+<!ENTITY menu.find.accesskey        "S">
+<!ENTITY menu.findagain.label       "Weitersuchen">
+<!ENTITY menu.findagain.accesskey   "N">
+
+<!ENTITY view.label                 "Ansicht">
+<!ENTITY view.accesskey             "s">
+
+<!ENTITY sort.label                 "Sortieren">
+<!ENTITY sort.accesskey             "S">
+<!ENTITY sort.none.label            "Unsortiert">
+<!ENTITY sort.none.accesskey        "U">
+<!ENTITY sort.ascending.label       "Aufsteigend">
+<!ENTITY sort.ascending.accesskey   "A">
+<!ENTITY sort.descending.label      "Absteigend">
+<!ENTITY sort.descending.accesskey  "b">
+
+<!ENTITY options.label              "Optionen">
+<!ENTITY options.accesskey          "O">
+
+<!ENTITY enable.label               "Adblock Plus aktivieren">
+<!ENTITY enable.accesskey           "N">
+<!ENTITY showintoolbar.label        "In Symbolleiste anzeigen">
+<!ENTITY showintoolbar.accesskey    "M">
+<!ENTITY showinstatusbar.label      "In Statusleiste anzeigen">
+<!ENTITY showinstatusbar.accesskey  "S">
+<!ENTITY objecttabs.label           "Tab zum Blockieren von Flash und Java anzeigen">
+<!ENTITY objecttabs.accesskey       "B">
+<!ENTITY collapse.label             "Platz von blockierten Elementen freigeben">
+<!ENTITY collapse.accesskey         "F">
+<!ENTITY help.label                 "Hilfe">
+<!ENTITY help.accesskey             "H">
+
+<!ENTITY gettingStarted.label       "Erste Schritte">
+<!ENTITY gettingStarted.accesskey   "S">
+<!ENTITY gettingStarted.url         "http://adblockplus.org/de/getting_started">
+<!ENTITY faq.label                  "Häufig gestellte Fragen">
+<!ENTITY faq.accesskey              "F">
+<!ENTITY faq.url                    "http://adblockplus.org/de/faq">
+<!ENTITY filterdoc.label            "Filter für Adblock Plus erstellen">
+<!ENTITY filterdoc.accesskey        "L">
+<!ENTITY filterdoc.url              "http://adblockplus.org/de/filters">
+<!ENTITY about.label                "Über Adblock Plus">
+<!ENTITY about.accesskey            "B">
+
+<!ENTITY description                "Die Filter in dieser Liste bestimmen, welche Adressen von Adblock Plus blockiert werden:">
+
+<!ENTITY filter.column              "Filterregel">
+<!ENTITY filter.accesskey           "F">
+<!ENTITY slow.column                "Langsam">
+<!ENTITY slow.accesskey             "L">
+<!ENTITY enabled.column             "Aktiv">
+<!ENTITY enabled.accesskey          "k">
+<!ENTITY hitcount.column            "Treffer">
+<!ENTITY hitcount.accesskey         "r">
+<!ENTITY lasthit.column             "Letzter Treffer">
+<!ENTITY lasthit.accesskey          "z">
+
+<!ENTITY context.edit.label         "Filter bearbeiten">
+<!ENTITY context.resethitcount.label      "Trefferstatistik für Filter zurücksetzen">
+<!ENTITY context.synchsubscription.label  "Filter jetzt neu herunterladen">
+<!ENTITY context.editsubscription.label   "Abonnement bearbeiten">
+<!ENTITY context.moveup.label       "Filter nach oben verschieben">
+<!ENTITY context.movedown.label     "Filter nach unten verschieben">
+<!ENTITY context.movegroupup.label        "Gruppe nach oben verschieben">
+<!ENTITY context.movegroupdown.label      "Gruppe nach unten verschieben">
+<!ENTITY context.enable.label       "Aktivieren">
+<!ENTITY context.disable.label      "Deaktivieren">
+
+<!ENTITY apply.label                "Anwenden">
+<!ENTITY apply.accesskey            "W">
+
+<!ENTITY fennec.subscription.label  "Filterabonnement">

=== added file 'chrome/locale/de/sidebar.dtd'
--- chrome/locale/de/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/de/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,37 @@
+<!ENTITY detached.title           "Adblock Plus: Elemente der geöffneten Seite (abgekoppelt)">
+
+<!ENTITY detach.label             "Abkoppeln">
+<!ENTITY reattach.label           "Ankoppeln">
+
+<!ENTITY search.label             "Suchen:">
+<!ENTITY search.accesskey         "S">
+
+<!ENTITY type.label               "Typ">
+<!ENTITY address.label            "Adresse">
+<!ENTITY filter.label             "Filter">
+<!ENTITY state.label              "Status">
+<!ENTITY size.label               "Größe">
+<!ENTITY docDomain.label          "Ursprungsdomain">
+
+<!ENTITY noitems.label            "Keine Elemente zu blockieren">
+<!ENTITY whitelisted.label        "Deaktiviert auf dieser Seite">
+<!ENTITY tooltip.address.label    "Addresse:">
+<!ENTITY tooltip.type.label       "Typ:">
+<!ENTITY tooltip.type.blocked     "(blockiert)">
+<!ENTITY tooltip.type.whitelisted "(Ausnahmeregel aktiv)">
+<!ENTITY tooltip.size.label       "Größe:">
+<!ENTITY tooltip.docDomain.label  "Ursprungsdomain:">
+<!ENTITY tooltip.filter.label     "Angewandter Filter:">
+<!ENTITY tooltip.filterSource.label "Herkunft des Filters:">
+
+<!ENTITY context.block.label      "Dieses Element blockieren">
+<!ENTITY context.editfilter.label "Angewandten Filter bearbeiten">
+<!ENTITY context.whitelist.label  "Ausnahmeregel für das Element hinzufügen">
+<!ENTITY context.disablefilter.label  "Filter ?1? deaktivieren">
+<!ENTITY context.enablefilter.label   "Filter ?1? wieder aktivieren">
+<!ENTITY context.disablefilteronsite.label  "Diesen Filter auf ?1? deaktivieren">
+<!ENTITY context.open.label       "Adresse in neuem Tab öffnen">
+<!ENTITY context.flash.label      "Position des Elements aufzeigen">
+<!ENTITY context.copy.label       "Adresse des Elements kopieren">
+<!ENTITY context.copyFilter.label "Filter kopieren">
+<!ENTITY context.selectAll.label  "Alles auswählen">

=== added file 'chrome/locale/de/subscriptionSelection.dtd'
--- chrome/locale/de/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/de/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,56 @@
+<!ENTITY dialog.title               "Filterabonnement für Adblock Plus hinzufügen">
+<!ENTITY dialog.title.edit          "Filterabonnement bearbeiten">
+
+<!ENTITY description.newInstall     "
+  Adblock Plus funktioniert am besten, wenn ein Filterabonnement hinzugefügt wird.
+  Filterabonnements werden von anderen Adblock Plus Nutzern kostenfrei zur
+  Verfügung gestellt. Das Filterabonnement, das zu Ihrer Sprache am besten passt,
+  ist bereits voreingestellt.
+">
+
+<!ENTITY adblock.warning            "
+  Adblock Plus hat festgestellt, dass Sie Adblock oder eine alte Version von Adblock Plus
+  installiert haben. Wenn Sie Adblock und Adblock Plus parallel ausführen, kann das Probleme
+  beim Browsen verursachen. Es wird empfohlen, Adblock jetzt zu deinstallieren.
+">
+<!ENTITY adblock.uninstall          "Adblock deinstallieren">
+
+<!ENTITY filterset.g.warning        "
+  Es scheint, dass Sie Filterset.G verwenden. Diese Filterliste wurde in den vergangenen Jahren
+  kaum aktualisiert und ist oft Ursache von Problemen auf Webseiten. Es wird empfohlen, Filterset.G
+  jetzt zu deinstallieren.
+">
+<!ENTITY filterset.g.moreinfo       "Weitere Informationen">
+<!ENTITY filterset.g.moreinfo.url   "http://adblockplus.org/de/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall      "Filterset.G deinstallieren">
+
+<!ENTITY subscriptionSelector.label "Bitte wählen Sie ein Filterabonnement aus der Liste aus:">
+
+<!ENTITY viewList.label             "Filter ansehen">
+<!ENTITY visitHomepage.label        "Webseite der Filterliste besuchen">
+
+<!ENTITY addSubscription.label      "Filterabonnement hinzufügen">
+<!ENTITY saveSubscription.label     "Änderungen speichern">
+
+<!ENTITY other.label                "Anderes Abonnement hinzufügen">
+<!ENTITY other.accesskey            "d">
+ 
+<!ENTITY list.download.failed       "Adblock Plus konnte die Liste der Filterabonnements nicht herunterladen.">
+<!ENTITY list.download.retry        "Nochmal versuchen">
+<!ENTITY list.download.website      "Zur Webseite wechseln">
+<!ENTITY list.website.url           "http://adblockplus.org/de/subscriptions">
+
+<!ENTITY fromWeb.description        "Bitte bestätigen Sie, dass Sie dieses Filterabonnement hinzufügen möchten. Die Bezeichnung und Adresse der Abonnements können vor dem Hinzufügen geändert werden.">
+<!ENTITY edit.description           "Bitte ändern Sie die Bezeichnung und Adresse der Abonnements wie erforderlich.">
+<!ENTITY external.description       "Das ist ein externes Filterabonnement, es wird von der Erweiterung aktualisiert, die es erstellt hat.">
+
+<!ENTITY title.label                "Bezeichnung des Abonnements:">
+<!ENTITY title.accesskey            "z">
+<!ENTITY location.label             "Adresse der Filterliste:">
+<!ENTITY location.accesskey         "d">
+<!ENTITY autodownload.label         "Automatisch aktualisieren">
+<!ENTITY autodownload.accesskey     "t">
+
+<!ENTITY supplementMessage          "Dieses Filterabonnement sollte in Verbindung mit dem Filterabonnement &quot;?1?&quot; verwendet werden.">
+<!ENTITY addMain.label              "Filterabonnement &quot;?1?&quot; auch hinzufügen">
+<!ENTITY addMain.accesskey          "h">

=== added directory 'chrome/locale/el'
=== removed directory 'chrome/locale/el-GR'
=== removed file 'chrome/locale/el-GR/about.dtd'
--- chrome/locale/el-GR/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/el-GR/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-<!ENTITY dialog.title "Σχετικά με το Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Έκδοση">
-<!ENTITY description "
-	Με το Adblock Plus σας δίνεται η δυνατότητα να αποφασίζετε εσείς τι θέλετε να βλέπετε και τι όχι στις ιστοσελίδες.
-	Δεν χρειάζεται να βλέπετε διαφημίσεις πλέον αν δεν το θέλετε!
-	Απλά ενημερώστε το Adblock Plus!
-">
-<!ENTITY homepage.label "Ιστοσελίδα:">
-<!ENTITY homepage.url "http://adblockplus.org/en/">
-<!ENTITY author.label "Δημιουργός:">
-<!ENTITY contributors.label "Συντελεστές:">

=== removed file 'chrome/locale/el-GR/composer.dtd'
--- chrome/locale/el-GR/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/el-GR/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Προσθήκη κανόνα φίλτρου του Adblock Plus">
-<!ENTITY accept.label "Προσθήκη φίλτρου">
-<!ENTITY advanced.label "Για προχωρημένους">
-<!ENTITY basic.label "Βασική προβολή">
-<!ENTITY disabled.warning.beforeLink "Το Adblock Plus είναι απενεργοποιημένο. Μπορείτε να προσθέσετε φίλτρα αλλά αυτά θα εφαρμοστούν μόλις">
-<!ENTITY disabled.warning.link "ενεργοποιήσετε το Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Η ομάδα φίλτρων &quot;&#37;S&quot; στην οποία το φίλτρο θα πρέπει να προστεθεί είναι απενεργοποιημένη. Μπορείτε να προσθέσετε το φίλτρο, αλλά δεν θα εφαρμοστεί εκτός και αν">
-<!ENTITY groupDisabled.warning.link "ενεργοποιήσετε την ομάδα φίλτρων">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Νέο φίλτρο:">
-<!ENTITY filter.accesskey "φ">
-<!ENTITY preferences.label "Προβολή υπαρχόντων φίλτρων...">
-<!ENTITY preferences.accesskey "Π">
-<!ENTITY type.filter.label "Φίλτρο φραγής">
-<!ENTITY type.filter.accesskey "ρ">
-<!ENTITY type.whitelist.label "Κανόνας εξαίρεσης">
-<!ENTITY type.whitelist.accesskey "ξ">
-<!ENTITY pattern.label "Αναζήτηση μοτίβου">
-<!ENTITY pattern.explanation "Το μοτίβο μπορεί να είναι οποιοδήποτε μέρος της διεύθυνσης, το σύμβολο * δρα ως wildcard. Το φίλτρο θα εφαρμοστεί μόνο στις διευθύνσεις που ταιριάζουν στο μοτίβο.">
-<!ENTITY regexp.warning "Το μοτίβο που εισάγατε θα ερμηνευτεί σαν regular expression. Πολλά regular expressions μπορεί να μειώσουν την ταχύτητα πλοήγησης. Αν σκοπός σας δεν ήταν να χρησιμοποιήσετε regular expressions, προσθέστε το σύμβολο * στο τέλος του μοτίβου.">
-<!ENTITY shortpattern.warning "Το μοτίβο που εισάγατε είναι πολύ κοντό για να βελτιστοποιηθεί· πολλά τέτοια μοτίβα μπορεί να μειώσουν την ταχύτητα πλοήγησης. Προτείνεται να επιλέξετε ένα μακρύτερο μοτίβο για το φίλτρο.">
-<!ENTITY custom.pattern.label "Προσαρμογή:">
-<!ENTITY custom.pattern.accesskey "σ">
-<!ENTITY anchors.label "Αποδοχή του μοτίβου μόνο:">
-<!ENTITY anchor.start.label "στην αρχή της διεύθυνσης">
-<!ENTITY anchor.start.accesskey "α">
-<!ENTITY anchor.start.flexible.label "στην αρχή του ονόματος τομέα">
-<!ENTITY anchor.start.flexible.accesskey "α">
-<!ENTITY anchor.end.label "στο τέλος της διεύθυνσης">
-<!ENTITY anchor.end.accesskey "λ">
-<!ENTITY options.label "Επιλογές">
-<!ENTITY domainRestriction.label "Περιορισμός στον τομέα:">
-<!ENTITY domainRestriction.accesskey "μ">
-<!ENTITY domainRestriction.help "Δηλώστε έναν ή περισσότερους τομείς (domain) διαχωρισμένους με το σύμβολο &quot;|&quot;, και το φίλτρο θα εφαρμοστεί μόνο σε αυτούς. Το σύμβολο &quot;~&quot; πριν από τον τομέα σημαίνει πως το φίλτρο δεν θα εφαρμοστεί στο συγκεκριμένο τομέα.">
-<!ENTITY firstParty.label "Εκτός από τρίτους">
-<!ENTITY firstParty.accesskey "Ε">
-<!ENTITY thirdParty.label "Από τρίτους μόνο">
-<!ENTITY thirdParty.accesskey "τ">
-<!ENTITY matchCase.label "Ταίριασμα μικρών-κεφαλαίων">
-<!ENTITY matchCase.accesskey "κ">
-<!ENTITY types.label "Εφαρμογή στους τύπους:">
-<!ENTITY selectAllTypes.label "Επιλογή όλων">
-<!ENTITY unselectAllTypes.label "Επιλογή κανενός">
-<!ENTITY collapse.label "Σύμπτυξη στοιχείων:">
-<!ENTITY collapse.accesskey "χ">
-<!ENTITY collapse.default.yes.label "Χρήση προκαθορισμένου (ναι)">
-<!ENTITY collapse.default.no.label "Χρήση προκαθορισμένου (όχι)">
-<!ENTITY collapse.yes.label "Ναι">
-<!ENTITY collapse.no.label "Όχι">

=== removed file 'chrome/locale/el-GR/global.properties'
--- chrome/locale/el-GR/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/el-GR/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Αφήστε τις διαφημίσεις στο χθες!
-status_active_label=Adblock
-status_disabled_label=Απενεργοποιημένο
-action0_tooltip=Κλικ για το μενού περιεχομένου, μεσαίο κλικ για ενεργοποίηση/απενεργοποίηση.
-action1_tooltip=Κλικ για να ανοίξετε/κλείσετε τα στοιχεία προς φραγή, μεσαίο κλικ για ενεργοποίηση/απενεργοποίηση.
-action2_tooltip=Κλικ για τις επιλογές, μεσαίο κλικ για ενεργοποίηση/απενεργοποίηση.
-action3_tooltip=Κλικ για ενεργοποίηση/απενεργοποίηση.
-active_tooltip=Το Adblock Plus είναι ενεργό.
-disabled_tooltip=Το Adblock Plus είναι ανενεργό.
-whitelisted_tooltip=Το Adblock Plus είναι ενεργό αλλά απενεργοποιημένο για την τρέχουσα σελίδα.
-blocked_count_tooltip=-- από τα --
-no_blocking_suggestions=Δεν υπάρχουν αντικείμενα προς φραγή σε αυτή τη σελίδα
-whitelisted_page=Το Adblock Plus απενεργοποιήθηκε για την τρέχουσα σελίδα
-whitelist_description=Εξαιρέσεις
-filterlist_description=Φίλτρα διαφημίσεων
-invalid_description=Μη έγκυρα φίλτρα
-elemhide_description=Κανόνες απόκρυψης στοιχείων
-subscription_description=Συνδρομή:
-subscription_wrong_version=Μερικά φίλτρα αυτής της συνδρομής απαιτούν το Adblock Plus -- για να λειτουργήσουν!
-subscription_source=Πηγή:
-subscription_status=Κατάσταση:
-subscription_status_autodownload=Ενημερώθηκε αυτόματα
-subscription_status_manualdownload=Ενημερώθηκε χειροκίνητα
-subscription_status_externaldownload=Ενημερώθηκε από άλλη επέκταση
-subscription_status_lastdownload=Τελευταία ενημέρωση:
-subscription_status_lastdownload_inprogress=Σε εξέλιξη...
-subscription_status_lastdownload_unknown=Μ/Δ
-remove_subscription_warning=Θέλετε να απομακρύνετε αυτή τη συνδρομή;
-import_filters_wrong_version=Προειδοποίηση: μερικά από τα φίλτρα σε αυτή τη λίστα απαιτούν το Adblock Plus -- για να λειτουργήσουν. Προτείνεται η εγκατάσταση της τελευταίας έκδοσης του Adblock Plus πριν την εισαγωγή της λίστας.
-import_filters_warning=Θέλετε να αντικαταστήσετε τα υπάρχοντα φίλτρα ή να τα προσθέσετε στο τέλος της λίστας;
-import_filters_title=Εισαγωγή φίλτρων
-export_filters_title=Εξαγωγή φίλτρων
-invalid_filters_file=Μη έγκυρο αρχείο λίστας φίλτρων του Adblock Plus.
-filters_write_error=Σφάλμα κατά την εγγραφή των φίλτρων στο αρχείο. Βεβαιωθείτε πως το αρχείο δεν είναι προστατευμένο ή χρησιμοποιείται από άλλη εφαρμογή.
-clearall_warning=Θέλετε πραγματικά να απομακρύνετε όλα τα φίλτρα από τη λίστα;
-resethitcounts_warning=Θέλετε πραγματικά να μηδενίσετε τα στατιστικά επιτυχιών για όλα τα φίλτρα; Η ενέργεια αυτή είναι μη αναστρέψιμη!
-resethitcounts_selected_warning=Θέλετε πραγματικά να μηδενίσετε τα στατιστικά επιτυχιών για τα επιλεγμένα φίλτρα; Η ενέργεια αυτή είναι μη αναστρέψιμη!
-filter_regexp_tooltip=Αυτό το φίλτρο είναι ένα regular expression ή είναι πολύ κοντό ώστε να βελτιστοποιηθεί. Πολλά από αυτά τα φίλτρα μπορεί να μειώσουν την ταχύτητα πλοήγησης.
-filter_elemhide_duplicate_id=Μόνο μια ταυτότητα του στοιχείου προς απόκρυψη πρέπει να καθοριστεί
-filter_elemhide_nocriteria=Δεν καθορίστηκαν κριτήρια ώστε να αναγνωριστεί το στοιχείο που θα φιλτραριστεί
-subscription_no_location=Παρακαλώ εισάγετε την διεύθυνσης από την οποία θα ληφθούν τα φίλτρα.
-subscription_invalid_location=Η τοποθεσία της λίστας φίλτρων δεν είναι έγκυρη URL ούτε και όνομα αρχείου.
-subscription_location_exists=Είστε ήδη συνδρομητής σε αυτή τη λίστα.
-synchronize_invalid_url=Απέτυχε, μη έγκυρη διεύθυνση
-synchronize_connection_error=Απέτυχε, σφάλμα κατά τη λήψη
-synchronize_invalid_data=Απέτυχε, μη έγκυρη λίστα φίλτρων
-synchronize_checksum_mismatch=Απέτυχε, απόκλιση στον έλεγχο checksum
-synchronize_ok=Επιτυχής
-overwrite=Αντικατάσταση
-append=Προσθήκη στο τέλος
-new_filter_group_title=Νέο φίλτρο
-type_label_other=άλλο
-type_label_script=σενάριο εντολών
-type_label_image=εικόνα
-type_label_stylesheet=stylesheet
-type_label_object=αντικείμενο
-type_label_subdocument=πλαίσιο
-type_label_document=κείμενο
-type_label_background=παρασκήνιο
-type_label_elemhide=κρυφό
-type_label_xbl=XBL binding
-type_label_ping=link ping
-type_label_xmlhttprequest=XML request
-type_label_object_subrequest=object subrequest
-type_label_dtd=DTD
-type_label_media=ήχος/βίντεο
-type_label_font=γραμματοσειρά

=== removed file 'chrome/locale/el-GR/overlay.dtd'
--- chrome/locale/el-GR/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/el-GR/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Κατάσταση:">
-<!ENTITY blocked.tooltip "Στοιχεία που έχουν φραχθεί σε αυτή τη σελίδα:">
-<!ENTITY filters.tooltip "Φίλτρα με τις περισσότερες επιτυχίες:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Φιλτραρισμένα στοιχεία">
-<!ENTITY context.image.label "Adblock Plus: φραγή εικόνας">
-<!ENTITY context.object.label "Adblock Plus: φραγή αντικειμένου">
-<!ENTITY context.frame.label "Adblock Plus: φραγή πλαισίου">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Ενεργοποίηση σ&apos; αυτή την σελίδα">
-<!ENTITY sidebar.title "Στοιχεία προς φιλτράρισμα στην τρέχουσα σελίδα">
-<!ENTITY settings.label "Προτιμήσεις">
-<!ENTITY settings.accesskey "Π">
-<!ENTITY opensidebar.label "Άνοιγμα των φιλτραρισμένων στοιχείων">
-<!ENTITY opensidebar.accesskey "α">
-<!ENTITY closesidebar.label "Κλείσιμο των φιλτραρισμένων στοιχείων">
-<!ENTITY closesidebar.accesskey "α">
-<!ENTITY whitelist.site.label "Απενεργοποίηση στο --">
-<!ENTITY whitelist.page.label "Απενεργοποίηση σε αυτή τη σελίδα μόνο">
-<!ENTITY objecttab.title "Φραγή">
-<!ENTITY objecttab.tooltip "Κλικ εδώ για να φιλτράρετε αυτό το αντικείμενο με το Adblock Plus">

=== removed file 'chrome/locale/el-GR/settings.dtd'
--- chrome/locale/el-GR/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/el-GR/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Προτιμήσεις του Adblock Plus">
-<!ENTITY filters.label "Φίλτρα">
-<!ENTITY filters.accesskey "Φ">
-<!ENTITY add.label "Προσθήκη φίλτρου">
-<!ENTITY add.accesskey "Π">
-<!ENTITY addsubscription.label "Προσθήκη συνδρομής">
-<!ENTITY addsubscription.accesskey "σ">
-<!ENTITY synchsubscriptions.label "Ενημέρωση όλων των συνδρομών">
-<!ENTITY synchsubscriptions.accesskey "Ε">
-<!ENTITY import.label "Εισαγωγή φίλτρων">
-<!ENTITY import.accesskey "ι">
-<!ENTITY export.label "Εξαγωγή φίλτρων">
-<!ENTITY export.accesskey "ξ">
-<!ENTITY clearall.label "Απομάκρυνση όλων των φίλτρων">
-<!ENTITY clearall.accesskey "Α">
-<!ENTITY resethitcounts.label "Μηδενισμός στατιστικών">
-<!ENTITY resethitcounts.accesskey "Μ">
-<!ENTITY edit.label "Επεξεργασία">
-<!ENTITY edit.accesskey "Ε">
-<!ENTITY cut.label "Αποκοπή">
-<!ENTITY cut.accesskey "κ">
-<!ENTITY copy.label "Αντιγραφή">
-<!ENTITY copy.accesskey "γ">
-<!ENTITY paste.label "Επικόλληση">
-<!ENTITY paste.accesskey "π">
-<!ENTITY remove.label "Διαγραφή">
-<!ENTITY remove.accesskey "Δ">
-<!ENTITY menu.find.label "Αναζήτηση">
-<!ENTITY menu.find.accesskey "ζ">
-<!ENTITY menu.findagain.label "Εύρεση ξανά">
-<!ENTITY menu.findagain.accesskey "ξ">
-<!ENTITY view.label "Προβολή">
-<!ENTITY view.accesskey "ο">
-<!ENTITY sort.label "Ταξινόμηση κατά">
-<!ENTITY sort.accesskey "Τ">
-<!ENTITY sort.none.label "Χωρίς ταξινόμηση">
-<!ENTITY sort.none.accesskey "ω">
-<!ENTITY sort.ascending.label "Αύξουσα">
-<!ENTITY sort.ascending.accesskey "Α">
-<!ENTITY sort.descending.label "Φθίνουσα">
-<!ENTITY sort.descending.accesskey "θ">
-<!ENTITY options.label "Επιλογές">
-<!ENTITY options.accesskey "λ">
-<!ENTITY enable.label "Ενεργοποίηση του Adblock Plus">
-<!ENTITY enable.accesskey "Ε">
-<!ENTITY showintoolbar.label "Εμφάνιση στην εργαλειοθήκη">
-<!ENTITY showintoolbar.accesskey "θ">
-<!ENTITY showinstatusbar.label "Εμφάνιση στην γραμμή κατάστασης">
-<!ENTITY showinstatusbar.accesskey "κ">
-<!ENTITY objecttabs.label "Εμφάνιση ετικέτας σε αντικείμενα Flash και Java">
-<!ENTITY objecttabs.accesskey "α">
-<!ENTITY collapse.label "Σύμπτυξη φιλτραρισμένων στοιχείων">
-<!ENTITY collapse.accesskey "Σ">
-<!ENTITY help.label "Βοήθεια">
-<!ENTITY help.accesskey "Β">
-<!ENTITY gettingStarted.label "Γρήγορη εκκίνηση">
-<!ENTITY gettingStarted.accesskey "γ">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Συχνές ερωτήσεις">
-<!ENTITY faq.accesskey "ε">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Συγγραφή φίλτρων">
-<!ENTITY filterdoc.accesskey "Σ">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Περί">
-<!ENTITY about.accesskey "Π">
-<!ENTITY description "Τα παρακάτω φίλτρα καθορίζουν το ποιες διευθύνσεις θα φιλτράρονται και ποιες όχι:">
-<!ENTITY filter.column "Κανόνας φίλτρου">
-<!ENTITY filter.accesskey "φ">
-<!ENTITY slow.column "Εμφάνιση φίλτρων">
-<!ENTITY slow.accesskey "Ε">
-<!ENTITY enabled.column "Ενεργοποιημένο">
-<!ENTITY enabled.accesskey "ν">
-<!ENTITY hitcount.column "Επιτυχίες">
-<!ENTITY hitcount.accesskey "χ">
-<!ENTITY lasthit.column "Τελευταία επιτυχία">
-<!ENTITY lasthit.accesskey "λ">
-<!ENTITY context.edit.label "Επεξεργασία φίλτρου">
-<!ENTITY context.resethitcount.label "Μηδενισμός στατιστικών επιτυχιών για το φίλτρο">
-<!ENTITY context.synchsubscription.label "Ενημέρωση συνδρομής τώρα">
-<!ENTITY context.editsubscription.label "Επεξεργασία συνδρομής">
-<!ENTITY context.moveup.label "Μετακίνηση επάνω">
-<!ENTITY context.movedown.label "Μετακίνηση κάτω">
-<!ENTITY context.movegroupup.label "Μετακίνηση ομάδας επάνω">
-<!ENTITY context.movegroupdown.label "Μετακίνηση ομάδας κάτω">
-<!ENTITY context.enable.label "Ενεργοποίηση">
-<!ENTITY context.disable.label "Απενεργοποίηση">
-<!ENTITY apply.label "Εφαρμογή">
-<!ENTITY apply.accesskey "ρ">

=== removed file 'chrome/locale/el-GR/sidebar.dtd'
--- chrome/locale/el-GR/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/el-GR/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Στοιχεία προς φραγή">
-<!ENTITY detach.label "Αποκόλληση">
-<!ENTITY reattach.label "Προσάρτηση">
-<!ENTITY search.label "Αναζήτηση:">
-<!ENTITY search.accesskey "ζ">
-<!ENTITY type.label "Τύπος">
-<!ENTITY address.label "Διεύθυνση">
-<!ENTITY filter.label "Φίλτρο">
-<!ENTITY state.label "Κατάσταση">
-<!ENTITY size.label "Μέγεθος">
-<!ENTITY docDomain.label "Πηγή εγγράφου">
-<!ENTITY noitems.label "Δεν υπάρχουν στοιχεία προς φιλτράρισμα">
-<!ENTITY whitelisted.label "Η σελίδα ανήκει στην άσπρη λίστα">
-<!ENTITY tooltip.address.label "Διεύθυνση:">
-<!ENTITY tooltip.type.label "Τύπος:">
-<!ENTITY tooltip.type.blocked "(φιλτραρισμένο)">
-<!ENTITY tooltip.type.whitelisted "(στην άσπρη λίστα)">
-<!ENTITY tooltip.size.label "Μέγεθος:">
-<!ENTITY tooltip.docDomain.label "Πηγή εγγράφου:">
-<!ENTITY tooltip.filter.label "Φίλτρο εν δράση:">
-<!ENTITY tooltip.filterSource.label "Πηγή φίλτρου:">
-<!ENTITY context.block.label "Φραγή του στοιχείου">
-<!ENTITY context.editfilter.label "Επεξεργασία του φίλτρου εν δράση">
-<!ENTITY context.whitelist.label "Προσθήκη κανόνα εξαίρεσης για το στοιχείο">
-<!ENTITY context.disablefilter.label "Απενεργοποίηση φίλτρου --">
-<!ENTITY context.enablefilter.label "Ενεργοποίηση φίλτρου --">
-<!ENTITY context.disablefilteronsite.label "Απενεργοποίηση του φίλτρου στο --">
-<!ENTITY context.open.label "Άνοιγμα σε νέα καρτέλα">
-<!ENTITY context.flash.label "Πλαίσιο στοιχείου Flash">
-<!ENTITY context.copy.label "Αντιγραφή τοποθεσίας του στοιχείου">
-<!ENTITY context.copyFilter.label "Αντιγραφή φίλτρου">
-<!ENTITY context.selectAll.label "Επιλογή όλων">

=== removed file 'chrome/locale/el-GR/subscription.dtd'
--- chrome/locale/el-GR/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/el-GR/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-<!ENTITY dialog.title "Επεξεργασία συνδρομής">
-<!ENTITY dialog.newtitle "Προσθήκη νέας συνδρομής">
-<!ENTITY new.description "Εισάγετε την διεύθυνση ή αρχείο το οποίο περιέχει
-	λίστα με φίλτρα του Adblock Plus.">
-<!ENTITY edit.description "Η λίστα με τα φίλτρα θα μεταφορτωθεί
-	από την διεύθυνση την οποία εισάγατε.">
-<!ENTITY external.description "Αυτή είναι μια εξωτερική συνδρομή. Η λίστα των φίλτρων
-	θα ενημερώνεται από την επέκταση που δημιούργησε αυτή τη συνδρομή.">
-<!ENTITY autodownload.description "Αν επιλέξετε &apos;Αυτόματη ενημέρωση&apos; αυτή η τοποθεσία θα
-	ελέγχεται για ενημερώσεις καθημερινά. Με αυτή την επιλογή ανενεργή μπορείτε
-	να ενημερώσετε την λίστα από το μενού περιεχομένου της συνδρομής.">
-<!ENTITY location.label "Τοποθεσία λίστας φίλτρων:">
-<!ENTITY location.accesskey "Τ">
-<!ENTITY title.label "Τίτλος συνδρομής:">
-<!ENTITY title.accesskey "σ">
-<!ENTITY autodownload.label "Αυτόματη ενημέρωση">
-<!ENTITY autodownload.accesskey "Α">
-<!ENTITY enabled.label "Ενεργοποίηση φίλτρων">
-<!ENTITY enabled.accesskey "Ε">

=== removed file 'chrome/locale/el-GR/tip_subscriptions.dtd'
--- chrome/locale/el-GR/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/el-GR/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,39 +0,0 @@
-<!ENTITY dialog.title "Συνδρομές φίλτρων του Add Adblock Plus">
-<!ENTITY description.par1 "
-	Σας ευχαριστούμε που εγκαταστήσατε το Adblock Plus. Αυτή η επέκταση μπορεί να
-	εξαφανίσει 99&#37; των διαφημίσεων που εμφανίζονται στις ιστοσελίδες. Όμως,
-	για αποτελεσματική φραγή των διαφημίσεων απαιτείται από εσάς ο ορισμός καλών
-	φίλτρων. Μπορείτε να δημιουργήσετε τα φίλτρα μόνοι σας ή απλά να γίνετε συνδρομητές
-	σε λίστες φίλτρων που διατηρούν τρίτοι. Η προσθήκη δικών σας φίλτρων είναι πάντα
-	δυνατή όπως και να ενεργοποιήσετε/απενεργοποιήσετε και άλλες συνδρομές όποτε
-	χρειαστεί.
-">
-<!ENTITY description.par2 "
-	Μπορείτε να επιλέξετε μια συνδρομή από τις
-	προτινόμενες λίστες φίλτρων παρακάτω (περισσότερες συνδρομές μπορούν
-	να προστεθούν στις Προτιμήσεις του AdBlock Plus αργότερα, αλλά συνήθως δεν είναι
-	απαραίτητο):
-">
-<!ENTITY note "Σημείωση: Τυπικά, μια λίστα φίλτρων είναι αποτελεσματικότερη όταν εφαρμόζεται
-	σε ιστοσελίδες που προέρχονται από την ίδια περιοχή για την οποία δημιουργήθηκε η λίστα.">
-<!ENTITY adblock.warning "
-	Το Adblock Plus ανίχνευσε πως το Adblock ή μια παλαιότερη έκδοση του Adblock Plus είναι 
-	εγκατεστημένο. Η παράλληλη χρήση του Adblock και του Adblock Plus μπορεί να προκαλέσει 
-	προβλήματα και έτσι πρέπει να αποφεύγεται. Προτείνεται η απεγκατάσταση του Adblock.
-">
-<!ENTITY adblock.uninstall "Απεγκατάσταση του Adblock">
-<!ENTITY filterset.g.warning "
-	Χρησιμοποιείτε την Filterset.G. Αυτή η λίστα φίλτρων συντηρείται ελάχιστα
-	τα τελευταία χρόνια και είναι συχνή αιτία σε προβλήματα που εμφανίζονται σε
-	ιστοσελίδες. Προτείνεται να απεγκαταστήσετε την λίστα Filterset.G.
-">
-<!ENTITY filterset.g.moreinfo "Περισσότερες πληροφορίες">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Απεγκατάσταση της Filterset.G">
-<!ENTITY homepage.label "Ιστοσελίδα">
-<!ENTITY subscribe.label "Εγγραφή">
-<!ENTITY subscribe.accesskey "Ε">
-<!ENTITY other.label "Προσθήκη άλλης συνδρομής">
-<!ENTITY other.accesskey "Π">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Προβολή όλων των συνδρομών">

=== added file 'chrome/locale/el/about.dtd'
--- chrome/locale/el/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/el/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,14 @@
+<!ENTITY dialog.title "Σχετικά με το Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Έκδοση">
+<!ENTITY description "Με το Adblock Plus σας δίνεται η δυνατότητα να αποφασίζετε εσείς τι θέλετε να βλέπετε και τι όχι στις ιστοσελίδες.
+	Δεν χρειάζεται να βλέπετε διαφημίσεις πλέον αν δεν το θέλετε!
+	Απλά ενημερώστε το Adblock Plus!">
+<!ENTITY homepage.label "Ιστοσελίδα:">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "Δημιουργός:">
+<!ENTITY contributors.label "Συντελεστές:">
+<!ENTITY developers.label "Προγραμματιστές:">
+<!ENTITY designers.label "Σχεδιαστές γραφικών:">
+<!ENTITY subscriptionAuthors.label "Συγγραφείς κανόνων φίλτρων:">
+<!ENTITY translators.label "Μεταφραστές:">

=== added file 'chrome/locale/el/composer.dtd'
--- chrome/locale/el/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/el/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Προσθήκη κανόνα φίλτρου του Adblock Plus">
+<!ENTITY accept.label "Προσθήκη φίλτρου">
+<!ENTITY advanced.label "Για προχωρημένους">
+<!ENTITY basic.label "Βασική προβολή">
+<!ENTITY disabled.warning "Το Adblock Plus είναι απενεργοποιημένο. Μπορείτε να προσθέσετε φίλτρα αλλά αυτά θα εφαρμοστούν μόλις [link]ενεργοποιήσετε το Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Η ομάδα φίλτρων &quot;?1?&quot; στην οποία το φίλτρο θα πρέπει να προστεθεί είναι απενεργοποιημένη. Μπορείτε να προσθέσετε το φίλτρο, αλλά δεν θα εφαρμοστεί εκτός και αν [link]ενεργοποιήσετε την ομάδα φίλτρων[/link].">
+<!ENTITY filter.label "Νέο φίλτρο:">
+<!ENTITY filter.accesskey "φ">
+<!ENTITY preferences.label "Προβολή υπαρχόντων φίλτρων...">
+<!ENTITY preferences.accesskey "Π">
+<!ENTITY type.filter.label "Φίλτρο φραγής">
+<!ENTITY type.filter.accesskey "ρ">
+<!ENTITY type.whitelist.label "Κανόνας εξαίρεσης">
+<!ENTITY type.whitelist.accesskey "ξ">
+<!ENTITY pattern.label "Αναζήτηση μοτίβου">
+<!ENTITY pattern.explanation "Το μοτίβο μπορεί να είναι οποιοδήποτε μέρος της διεύθυνσης, το σύμβολο * δρα ως wildcard. Το φίλτρο θα εφαρμοστεί μόνο στις διευθύνσεις που ταιριάζουν στο μοτίβο.">
+<!ENTITY regexp.warning "Το μοτίβο που εισάγατε θα ερμηνευτεί σαν regular expression. Πολλά regular expressions μπορεί να μειώσουν την ταχύτητα πλοήγησης. Αν σκοπός σας δεν ήταν να χρησιμοποιήσετε regular expressions, προσθέστε το σύμβολο * στο τέλος του μοτίβου.">
+<!ENTITY shortpattern.warning "Το μοτίβο που εισάγατε είναι πολύ κοντό για να βελτιστοποιηθεί· πολλά τέτοια μοτίβα μπορεί να μειώσουν την ταχύτητα πλοήγησης. Προτείνεται να επιλέξετε ένα μακρύτερο μοτίβο για το φίλτρο.">
+<!ENTITY custom.pattern.label "Προσαρμογή:">
+<!ENTITY custom.pattern.accesskey "σ">
+<!ENTITY anchors.label "Αποδοχή του μοτίβου μόνο:">
+<!ENTITY anchor.start.label "στην αρχή της διεύθυνσης">
+<!ENTITY anchor.start.accesskey "α">
+<!ENTITY anchor.start.flexible.label "στην αρχή του ονόματος τομέα">
+<!ENTITY anchor.start.flexible.accesskey "α">
+<!ENTITY anchor.end.label "στο τέλος της διεύθυνσης">
+<!ENTITY anchor.end.accesskey "λ">
+<!ENTITY options.label "Επιλογές">
+<!ENTITY domainRestriction.label "Περιορισμός στον τομέα:">
+<!ENTITY domainRestriction.accesskey "μ">
+<!ENTITY domainRestriction.help "Δηλώστε έναν ή περισσότερους τομείς (domain) διαχωρισμένους με το σύμβολο &quot;|&quot;, και το φίλτρο θα εφαρμοστεί μόνο σε αυτούς. Το σύμβολο &quot;~&quot; πριν από τον τομέα σημαίνει πως το φίλτρο δεν θα εφαρμοστεί στο συγκεκριμένο τομέα.">
+<!ENTITY firstParty.label "Εκτός από τρίτους">
+<!ENTITY firstParty.accesskey "Ε">
+<!ENTITY thirdParty.label "Από τρίτους μόνο">
+<!ENTITY thirdParty.accesskey "τ">
+<!ENTITY matchCase.label "Ταίριασμα μικρών-κεφαλαίων">
+<!ENTITY matchCase.accesskey "κ">
+<!ENTITY types.label "Εφαρμογή στους τύπους:">
+<!ENTITY selectAllTypes.label "Επιλογή όλων">
+<!ENTITY unselectAllTypes.label "Επιλογή κανενός">
+<!ENTITY collapse.label "Σύμπτυξη στοιχείων:">
+<!ENTITY collapse.accesskey "χ">
+<!ENTITY collapse.default.yes.label "Χρήση προκαθορισμένου (ναι)">
+<!ENTITY collapse.default.no.label "Χρήση προκαθορισμένου (όχι)">
+<!ENTITY collapse.yes.label "Ναι">
+<!ENTITY collapse.no.label "Όχι">

=== added file 'chrome/locale/el/global.properties'
--- chrome/locale/el/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/el/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Κλικ για το μενού περιεχομένου, μεσαίο κλικ για ενεργοποίηση/απενεργοποίηση.
+action1_tooltip=Κλικ για να ανοίξετε/κλείσετε τα στοιχεία προς φραγή, μεσαίο κλικ για ενεργοποίηση/απενεργοποίηση.
+action2_tooltip=Κλικ για τις επιλογές, μεσαίο κλικ για ενεργοποίηση/απενεργοποίηση.
+action3_tooltip=Κλικ για ενεργοποίηση/απενεργοποίηση.
+disabled_tooltip=Το Adblock Plus είναι ανενεργό.
+active_tooltip=Το Adblock Plus είναι ενεργό, ?1? συνδρομή(ές) φίλτρων και ?2? προσαρμοσμένο(α) φίλτρο(α) σε χρήση.
+whitelisted_tooltip=Το Adblock Plus είναι ενεργό αλλά απενεργοποιημένο για την τρέχουσα σελίδα.
+blocked_count_tooltip=?1? από τα ?2?
+blocked_count_addendum=(λευκή λίστα: ?1?, κρυφά: ?2?)
+no_blocking_suggestions=Δεν υπάρχουν αντικείμενα προς φραγή σε αυτή τη σελίδα
+whitelisted_page=Το Adblock Plus απενεργοποιήθηκε για την τρέχουσα σελίδα
+whitelist_description=Εξαιρέσεις
+filterlist_description=Φίλτρα διαφημίσεων
+invalid_description=Μη έγκυρα φίλτρα
+elemhide_description=Κανόνες απόκρυψης στοιχείων
+subscription_description=Συνδρομή:
+subscription_wrong_version=Μερικά φίλτρα αυτής της συνδρομής απαιτούν το Adblock Plus ?1? για να λειτουργήσουν!
+subscription_source=Πηγή:
+subscription_status=Κατάσταση:
+subscription_status_autodownload=Ενημερώθηκε αυτόματα
+subscription_status_manualdownload=Ενημερώθηκε χειροκίνητα
+subscription_status_externaldownload=Ενημερώθηκε από άλλη επέκταση
+subscription_status_lastdownload=Τελευταία ενημέρωση:
+subscription_status_lastdownload_inprogress=Σε εξέλιξη...
+subscription_status_lastdownload_unknown=Μ/Δ
+remove_subscription_warning=Θέλετε να απομακρύνετε αυτή τη συνδρομή;
+import_filters_wrong_version=Προειδοποίηση: μερικά από τα φίλτρα σε αυτή τη λίστα απαιτούν το Adblock Plus ?1? για να λειτουργήσουν. Προτείνεται η εγκατάσταση της τελευταίας έκδοσης του Adblock Plus πριν την εισαγωγή της λίστας.
+import_filters_warning=Θέλετε να αντικαταστήσετε τα υπάρχοντα φίλτρα ή να τα προσθέσετε στο τέλος της λίστας;
+import_filters_title=Εισαγωγή φίλτρων
+export_filters_title=Εξαγωγή φίλτρων
+invalid_filters_file=Μη έγκυρο αρχείο λίστας φίλτρων του Adblock Plus.
+filters_write_error=Σφάλμα κατά την εγγραφή των φίλτρων στο αρχείο. Βεβαιωθείτε πως το αρχείο δεν είναι προστατευμένο ή χρησιμοποιείται από άλλη εφαρμογή.
+clearall_warning=Θέλετε πραγματικά να απομακρύνετε όλα τα φίλτρα από τη λίστα;
+resethitcounts_warning=Θέλετε πραγματικά να μηδενίσετε τα στατιστικά επιτυχιών για όλα τα φίλτρα; Η ενέργεια αυτή είναι μη αναστρέψιμη!
+resethitcounts_selected_warning=Θέλετε πραγματικά να μηδενίσετε τα στατιστικά επιτυχιών για τα επιλεγμένα φίλτρα; Η ενέργεια αυτή είναι μη αναστρέψιμη!
+filter_regexp_tooltip=Αυτό το φίλτρο είναι ένα regular expression ή είναι πολύ κοντό ώστε να βελτιστοποιηθεί. Πολλά από αυτά τα φίλτρα μπορεί να μειώσουν την ταχύτητα πλοήγησης.
+filter_elemhide_duplicate_id=Μόνο μια ταυτότητα του στοιχείου προς απόκρυψη πρέπει να καθοριστεί
+filter_elemhide_nocriteria=Δεν καθορίστηκαν κριτήρια ώστε να αναγνωριστεί το στοιχείο που θα φιλτραριστεί
+subscription_notAdded_warning=Δεν προσθέσατε μια συνδρομή φίλτρων. Αν δεν το κάνετε, θα πρέπει να προσθέσετε στο Adblock Plus κάποια φίλτρα χειροκίνητα.
+subscription_notAdded_warning_addendum=Θέλετε να συνεχίσετε;
+subscription_invalid_location=Η τοποθεσία της λίστας φίλτρων δεν είναι έγκυρη URL ούτε και όνομα αρχείου.
+synchronize_invalid_url=Απέτυχε, μη έγκυρη διεύθυνση
+synchronize_connection_error=Απέτυχε, σφάλμα κατά τη λήψη
+synchronize_invalid_data=Απέτυχε, μη έγκυρη λίστα φίλτρων
+synchronize_checksum_mismatch=Απέτυχε, απόκλιση στον έλεγχο checksum
+synchronize_ok=Επιτυχής
+overwrite=Αντικατάσταση
+append=Προσθήκη στο τέλος
+new_filter_group_title=Νέο φίλτρο
+type_label_other=άλλο
+type_label_script=σενάριο εντολών
+type_label_image=εικόνα
+type_label_stylesheet=stylesheet
+type_label_object=αντικείμενο
+type_label_subdocument=πλαίσιο
+type_label_document=κείμενο
+type_label_background=παρασκήνιο
+type_label_elemhide=κρυφό
+type_label_xbl=XBL binding
+type_label_ping=link ping
+type_label_xmlhttprequest=XML request
+type_label_object_subrequest=object subrequest
+type_label_dtd=DTD
+type_label_media=ήχος/βίντεο
+type_label_font=γραμματοσειρά
+fennec_status_enabled=Το Adblock Plus είναι ενεργοποιημένο.
+fennec_status_disabled=Το Adblock Plus είναι απενεργοποιημένο.
+fennec_status_enabled_site=Το Adblock Plus είναι ενεργοποιημένο στο ?1?.
+fennec_status_disabled_site=Το Adblock Plus είναι απενεργοποιημένο στο ?1?.

=== added file 'chrome/locale/el/meta.properties'
--- chrome/locale/el/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/el/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=rookie
+name=Adblock Plus
+description=Αφήστε τις διαφημίσεις στο χθες!
+description.short=Ενοχλημένοι από τις διαφημίσεις; Προβληματισμένοι από την καταγραφή των κινήσεών σας; Σας εμποδίζουν τα banners; Εγκαταστήστε το Adblock Plus και αποκτήστε τον έλεγχο του διαδικτύου. Αλλάξτε τον τρόπο που βλέπετε τις σελίδες.
+description.long=Το Adblock Plus σας δίνει την δυνατότητα να αποκτήσετε τον έλεγχο του διαδικτύου και να βλέπετε τις σελίδες όπως εσείς θέλετε. Η επέκταση αυτή, υποστηρίζεται με παραπάνω από σαράντα συνδρομές φίλτρων σε δεκάδες γλώσσες. Χρησιμοποιώντας τις συνδρομές, το Adblock Plus μπορεί να ρυθμιστεί ώστε να σας προστατεύει από τις ανεπιθύμητες διαφημίσεις μέχρι και να μπλοκάρει τις κακόβουλες σελίδες. Επίσης μπορείτε να προσαρμόζετε τα φίλτρα με την βοήθεια των χρήσιμων λειτουργιών που περιλαμβάνουν την φραγή εικόνων, αντικείμενα Flash και Java και μια λίστα με τα όλα τα αντικείμενα της σελίδας ώστε η φραγή των scripts και των stylesheets να γίνεται παιχνίδι.

=== added file 'chrome/locale/el/overlay.dtd'
--- chrome/locale/el/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/el/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Κατάσταση:">
+<!ENTITY blocked.tooltip "Στοιχεία που έχουν φραχθεί σε αυτή τη σελίδα:">
+<!ENTITY filters.tooltip "Φίλτρα με τις περισσότερες επιτυχίες:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Φιλτραρισμένα στοιχεία">
+<!ENTITY context.image.label "Adblock Plus: φραγή εικόνας">
+<!ENTITY context.object.label "Adblock Plus: φραγή αντικειμένου">
+<!ENTITY context.frame.label "Adblock Plus: φραγή πλαισίου">
+<!ENTITY context.media.label "Adblock Plus: φραγή ήχου/βίντεο">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Ενεργοποίηση σ' αυτή την σελίδα">
+<!ENTITY sidebar.title "Στοιχεία προς φιλτράρισμα στην τρέχουσα σελίδα">
+<!ENTITY settings.label "Προτιμήσεις">
+<!ENTITY settings.accesskey "Π">
+<!ENTITY opensidebar.label "Άνοιγμα των φιλτραρισμένων στοιχείων">
+<!ENTITY opensidebar.accesskey "α">
+<!ENTITY closesidebar.label "Κλείσιμο των φιλτραρισμένων στοιχείων">
+<!ENTITY closesidebar.accesskey "α">
+<!ENTITY whitelist.site.label "Απενεργοποίηση στο ?1?">
+<!ENTITY whitelist.page.label "Απενεργοποίηση σε αυτή τη σελίδα μόνο">
+<!ENTITY objecttab.title "Φραγή">
+<!ENTITY objecttab.tooltip "Κλικ εδώ για να φιλτράρετε αυτό το αντικείμενο με το Adblock Plus">

=== added file 'chrome/locale/el/settings.dtd'
--- chrome/locale/el/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/el/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Προτιμήσεις του Adblock Plus">
+<!ENTITY filters.label "Φίλτρα">
+<!ENTITY filters.accesskey "Φ">
+<!ENTITY add.label "Προσθήκη φίλτρου">
+<!ENTITY add.accesskey "Π">
+<!ENTITY addsubscription.label "Προσθήκη συνδρομής">
+<!ENTITY addsubscription.accesskey "σ">
+<!ENTITY synchsubscriptions.label "Ενημέρωση όλων των συνδρομών">
+<!ENTITY synchsubscriptions.accesskey "Ε">
+<!ENTITY import.label "Εισαγωγή φίλτρων">
+<!ENTITY import.accesskey "ι">
+<!ENTITY export.label "Εξαγωγή φίλτρων">
+<!ENTITY export.accesskey "ξ">
+<!ENTITY clearall.label "Απομάκρυνση όλων των φίλτρων">
+<!ENTITY clearall.accesskey "Α">
+<!ENTITY resethitcounts.label "Μηδενισμός στατιστικών">
+<!ENTITY resethitcounts.accesskey "Μ">
+<!ENTITY edit.label "Επεξεργασία">
+<!ENTITY edit.accesskey "Ε">
+<!ENTITY cut.label "Αποκοπή">
+<!ENTITY cut.accesskey "κ">
+<!ENTITY copy.label "Αντιγραφή">
+<!ENTITY copy.accesskey "γ">
+<!ENTITY paste.label "Επικόλληση">
+<!ENTITY paste.accesskey "π">
+<!ENTITY remove.label "Διαγραφή">
+<!ENTITY remove.accesskey "Δ">
+<!ENTITY menu.find.label "Αναζήτηση">
+<!ENTITY menu.find.accesskey "ζ">
+<!ENTITY menu.findagain.label "Εύρεση ξανά">
+<!ENTITY menu.findagain.accesskey "ξ">
+<!ENTITY view.label "Προβολή">
+<!ENTITY view.accesskey "ο">
+<!ENTITY sort.label "Ταξινόμηση κατά">
+<!ENTITY sort.accesskey "Τ">
+<!ENTITY sort.none.label "Χωρίς ταξινόμηση">
+<!ENTITY sort.none.accesskey "ω">
+<!ENTITY sort.ascending.label "Αύξουσα">
+<!ENTITY sort.ascending.accesskey "Α">
+<!ENTITY sort.descending.label "Φθίνουσα">
+<!ENTITY sort.descending.accesskey "θ">
+<!ENTITY options.label "Επιλογές">
+<!ENTITY options.accesskey "λ">
+<!ENTITY enable.label "Ενεργοποίηση του Adblock Plus">
+<!ENTITY enable.accesskey "Ε">
+<!ENTITY showintoolbar.label "Εμφάνιση στην εργαλειοθήκη">
+<!ENTITY showintoolbar.accesskey "θ">
+<!ENTITY showinstatusbar.label "Εμφάνιση στην γραμμή κατάστασης">
+<!ENTITY showinstatusbar.accesskey "κ">
+<!ENTITY objecttabs.label "Εμφάνιση ετικέτας σε αντικείμενα Flash και Java">
+<!ENTITY objecttabs.accesskey "α">
+<!ENTITY collapse.label "Σύμπτυξη φιλτραρισμένων στοιχείων">
+<!ENTITY collapse.accesskey "Σ">
+<!ENTITY help.label "Βοήθεια">
+<!ENTITY help.accesskey "Β">
+<!ENTITY gettingStarted.label "Γρήγορη εκκίνηση">
+<!ENTITY gettingStarted.accesskey "γ">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Συχνές ερωτήσεις">
+<!ENTITY faq.accesskey "ε">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Συγγραφή φίλτρων">
+<!ENTITY filterdoc.accesskey "Σ">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Περί">
+<!ENTITY about.accesskey "Π">
+<!ENTITY description "Τα παρακάτω φίλτρα καθορίζουν το ποιες διευθύνσεις θα φιλτράρονται και ποιες όχι:">
+<!ENTITY filter.column "Κανόνας φίλτρου">
+<!ENTITY filter.accesskey "φ">
+<!ENTITY slow.column "Εμφάνιση φίλτρων">
+<!ENTITY slow.accesskey "Ε">
+<!ENTITY enabled.column "Ενεργοποιημένο">
+<!ENTITY enabled.accesskey "ν">
+<!ENTITY hitcount.column "Επιτυχίες">
+<!ENTITY hitcount.accesskey "χ">
+<!ENTITY lasthit.column "Τελευταία επιτυχία">
+<!ENTITY lasthit.accesskey "λ">
+<!ENTITY context.edit.label "Επεξεργασία φίλτρου">
+<!ENTITY context.resethitcount.label "Μηδενισμός στατιστικών επιτυχιών για το φίλτρο">
+<!ENTITY context.synchsubscription.label "Ενημέρωση συνδρομής τώρα">
+<!ENTITY context.editsubscription.label "Επεξεργασία συνδρομής">
+<!ENTITY context.moveup.label "Μετακίνηση επάνω">
+<!ENTITY context.movedown.label "Μετακίνηση κάτω">
+<!ENTITY context.movegroupup.label "Μετακίνηση ομάδας επάνω">
+<!ENTITY context.movegroupdown.label "Μετακίνηση ομάδας κάτω">
+<!ENTITY context.enable.label "Ενεργοποίηση">
+<!ENTITY context.disable.label "Απενεργοποίηση">
+<!ENTITY apply.label "Εφαρμογή">
+<!ENTITY apply.accesskey "ρ">
+<!ENTITY fennec.subscription.label "Συνδρομή φίλτρων">

=== added file 'chrome/locale/el/sidebar.dtd'
--- chrome/locale/el/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/el/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Στοιχεία προς φραγή">
+<!ENTITY detach.label "Αποκόλληση">
+<!ENTITY reattach.label "Προσάρτηση">
+<!ENTITY search.label "Αναζήτηση:">
+<!ENTITY search.accesskey "ζ">
+<!ENTITY type.label "Τύπος">
+<!ENTITY address.label "Διεύθυνση">
+<!ENTITY filter.label "Φίλτρο">
+<!ENTITY state.label "Κατάσταση">
+<!ENTITY size.label "Μέγεθος">
+<!ENTITY docDomain.label "Πηγή εγγράφου">
+<!ENTITY noitems.label "Δεν υπάρχουν στοιχεία προς φιλτράρισμα">
+<!ENTITY whitelisted.label "Η σελίδα ανήκει στην άσπρη λίστα">
+<!ENTITY tooltip.address.label "Διεύθυνση:">
+<!ENTITY tooltip.type.label "Τύπος:">
+<!ENTITY tooltip.type.blocked "(φιλτραρισμένο)">
+<!ENTITY tooltip.type.whitelisted "(στην άσπρη λίστα)">
+<!ENTITY tooltip.size.label "Μέγεθος:">
+<!ENTITY tooltip.docDomain.label "Πηγή εγγράφου:">
+<!ENTITY tooltip.filter.label "Φίλτρο εν δράση:">
+<!ENTITY tooltip.filterSource.label "Πηγή φίλτρου:">
+<!ENTITY context.block.label "Φραγή του στοιχείου">
+<!ENTITY context.editfilter.label "Επεξεργασία του φίλτρου εν δράση">
+<!ENTITY context.whitelist.label "Προσθήκη κανόνα εξαίρεσης για το στοιχείο">
+<!ENTITY context.disablefilter.label "Απενεργοποίηση φίλτρου ?1?">
+<!ENTITY context.enablefilter.label "Ενεργοποίηση φίλτρου ?1?">
+<!ENTITY context.disablefilteronsite.label "Απενεργοποίηση του φίλτρου στο ?1?">
+<!ENTITY context.open.label "Άνοιγμα σε νέα καρτέλα">
+<!ENTITY context.flash.label "Πλαίσιο στοιχείου Flash">
+<!ENTITY context.copy.label "Αντιγραφή τοποθεσίας του στοιχείου">
+<!ENTITY context.copyFilter.label "Αντιγραφή φίλτρου">
+<!ENTITY context.selectAll.label "Επιλογή όλων">

=== added file 'chrome/locale/el/subscriptionSelection.dtd'
--- chrome/locale/el/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/el/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,38 @@
+<!ENTITY dialog.title "Συνδρομές φίλτρων του Adblock Plus">
+<!ENTITY dialog.title.edit "Επεξεργασία συνδρομής">
+<!ENTITY description.newInstall "Το Adblock Plus θα είναι πιο αποτελεσματικό αν γίνετε συνδρομητής σε μια λίστα φίλτρων.
+	Οι λίστες φίλτρων παρέχονται από χρήστες του Adblock Plus χωρίς κόστος.
+	Η καταλληλότερη συνδρομή για την γλώσσα σας έχει ήδη επιλεγεί.">
+<!ENTITY adblock.warning "Το Adblock Plus ανίχνευσε πως το Adblock ή μια παλαιότερη έκδοση του Adblock Plus είναι 
+	εγκατεστημένο. Η παράλληλη χρήση του Adblock και του Adblock Plus μπορεί να προκαλέσει 
+	προβλήματα και έτσι πρέπει να αποφεύγεται. Προτείνεται η απεγκατάσταση του Adblock.">
+<!ENTITY adblock.uninstall "Απεγκατάσταση του Adblock">
+<!ENTITY filterset.g.warning "Χρησιμοποιείτε την Filterset.G. Αυτή η λίστα φίλτρων συντηρείται ελάχιστα
+	τα τελευταία χρόνια και είναι συχνή αιτία σε προβλήματα που εμφανίζονται σε
+	ιστοσελίδες. Προτείνεται να απεγκαταστήσετε την λίστα Filterset.G.">
+<!ENTITY filterset.g.moreinfo "Περισσότερες πληροφορίες">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Απεγκατάσταση της Filterset.G">
+<!ENTITY subscriptionSelector.label "Παρακαλώ επιλέξτε μια συνδρομή σε φίλτρα από την λίστα:">
+<!ENTITY viewList.label "Προβολή φίλτρων">
+<!ENTITY visitHomepage.label "Ιστοσελίδα της συνδρομής">
+<!ENTITY addSubscription.label "Προσθήκη συνδρομής">
+<!ENTITY saveSubscription.label "Αποθήκευση συνδρομής">
+<!ENTITY other.label "Προσθήκη άλλης συνδρομής">
+<!ENTITY other.accesskey "Π">
+<!ENTITY list.download.failed "Το Adblock Plus απέτυχε να λάβει την λίστα με τις συνδρομές.">
+<!ENTITY list.download.retry "Προσπαθήστε ξανά">
+<!ENTITY list.download.website "Προβολή της ιστοσελίδας">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Παρακαλώ επιβεβαιώστε ότι θέλετε να προσθέσετε αυτή την λίστα φίλτρων. Μπορείτε να τροποποιήσετε τον τίτλο ή την τοποθεσία πριν την προσθήκη.">
+<!ENTITY edit.description "Μπορείτε ν' αλλάξετε τον τίτλο της συνδρομής ή την τοποθεσία όπως σας βολεύει.">
+<!ENTITY external.description "Αυτή η λίστα φίλτρων προέρχεται από τρίτους· θα ενημερωθεί από το πρόσθετο που την δημιούργησε.">
+<!ENTITY title.label "Τίτλος συνδρομής:">
+<!ENTITY title.accesskey "σ">
+<!ENTITY location.label "Τοποθεσία λίστας φίλτρων:">
+<!ENTITY location.accesskey "Τ">
+<!ENTITY autodownload.label "Αυτόματη ενημέρωση">
+<!ENTITY autodownload.accesskey "Α">
+<!ENTITY supplementMessage "Αυτή η συνδρομή φίλτρων μπορεί να χρησιμοποιηθεί μαζί με την συνδρομή &quot;?1?&quot; την οποία δεν χρησιμοποιείτε.">
+<!ENTITY addMain.label "Προσθήκη και της συνδρομής φίλτρων &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "σ">

=== modified file 'chrome/locale/en-GB/about.dtd'
--- chrome/locale/en-GB/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-GB/about.dtd	2010-05-04 14:45:07 +0000
@@ -1,8 +1,12 @@
 <!ENTITY dialog.title "About Adblock Plus">
 <!ENTITY caption.title "Adblock Plus">
 <!ENTITY version.title "Version">
-<!ENTITY description "Adblock Plus allows you to decide what you don&apos;t want to see on the web. 	You don&apos;t need to download all the ads and banners any more. If you don&apos;t want them - tell Adblock Plus!">
+<!ENTITY description "Adblock Plus allows you to decide what you want to see on the web. You don't need to download adverts and banners any more; if you don't want them - remove them with Adblock Plus!">
 <!ENTITY homepage.label "Adblock Plus homepage:">
 <!ENTITY homepage.url "http://adblockplus.org/en/">
 <!ENTITY author.label "Author:">
 <!ENTITY contributors.label "Contributors:">
+<!ENTITY developers.label "Developers:">
+<!ENTITY designers.label "Graphic designers:">
+<!ENTITY subscriptionAuthors.label "Filter subscription authors:">
+<!ENTITY translators.label "Translators:">

=== modified file 'chrome/locale/en-GB/composer.dtd'
--- chrome/locale/en-GB/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-GB/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "Add filter">
 <!ENTITY advanced.label "Advanced view">
 <!ENTITY basic.label "Basic view">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus is currently disabled. You can still add filters but those will not be applied unless you">
-<!ENTITY disabled.warning.link "enable Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "The filter group &quot;&#37;S&quot; that this filter should be added to is currently disabled. You can still add the filter but it will not be applied unless you">
-<!ENTITY groupDisabled.warning.link "enable the filter group">
-<!ENTITY groupDisabled.warning.afterLink ".">
+<!ENTITY disabled.warning "Adblock Plus is currently disabled. You can still add filters but they will not be applied unless you [link]enable Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "The filter group &quot;?1?&quot; that this filter should be added to is currently disabled. You can still add the filter but it will not be applied unless you [link]enable the filter group[/link].">
 <!ENTITY filter.label "New filter:">
 <!ENTITY filter.accesskey "f">
 <!ENTITY preferences.label "Show existing filters...">
@@ -17,9 +13,9 @@
 <!ENTITY type.whitelist.label "Exception rule">
 <!ENTITY type.whitelist.accesskey "x">
 <!ENTITY pattern.label "Look for pattern">
-<!ENTITY pattern.explanation "The pattern can be any part of the address; the * symbol acts as a wildcard. The filter will only be applied to addresses matching the pattern.">
-<!ENTITY regexp.warning "The pattern you entered will be interpreted as a regular expression. Many regular expressions might slow down your browsing. If you didn&apos;t intend to use a regular expression, add a * symbol at the end of the pattern.">
-<!ENTITY shortpattern.warning "The pattern you entered is too short to be optimised; many such patterns might slow down your browsing. It is recommended that you choose a longer string for this filter.">
+<!ENTITY pattern.explanation "The pattern can be any part of the address; asterisks (*) act as wildcards. The filter will only be applied to addresses matching the pattern provided.">
+<!ENTITY regexp.warning "The pattern you entered will be interpreted as a regular expression; this cannot be efficiently processed by Adblock Plus and may slow down your browsing experience. If you didn't intend to use a regular expression, add an asterisk (*) to the end of the pattern.">
+<!ENTITY shortpattern.warning "The pattern you entered is too short to be optimised; this may slow down your browsing experience. It is recommended that you choose a longer string for this filter to allow Adblock Plus to process the filter more efficiently.">
 <!ENTITY custom.pattern.label "Custom:">
 <!ENTITY custom.pattern.accesskey "C">
 <!ENTITY anchors.label "Accept pattern only:">
@@ -32,7 +28,7 @@
 <!ENTITY options.label "Options">
 <!ENTITY domainRestriction.label "Restrict to domain:">
 <!ENTITY domainRestriction.accesskey "d">
-<!ENTITY domainRestriction.help "Specify one or more domains separated by the symbol &quot;|&quot;; the filter will only be applied on those domains. The symbol &quot;~&quot; before a domain name means that the filter should not be applied on that domain.">
+<!ENTITY domainRestriction.help "Use this option to specify one or more domains separated by a bar line (|). The filter will only be applied on the domain(s) selected. A tilde (~) before a domain name indicates that the filter will not be applied on that domain.">
 <!ENTITY firstParty.label "First-party only">
 <!ENTITY firstParty.accesskey "r">
 <!ENTITY thirdParty.label "Third-party only">

=== modified file 'chrome/locale/en-GB/global.properties'
--- chrome/locale/en-GB/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-GB/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,13 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Ads were yesterday!
-status_active_label=Adblock
-status_disabled_label=Disabled
+default_dialog_title=Adblock Plus
 action0_tooltip=Click to bring up context menu; middle-click to enable/disable.
 action1_tooltip=Click to open/close blockable items; middle-click to enable/disable.
 action2_tooltip=Click to open preferences; middle-click to enable/disable.
 action3_tooltip=Click to enable/disable Adblock Plus.
-active_tooltip=Adblock Plus is enabled.
 disabled_tooltip=Adblock Plus is disabled.
+active_tooltip=Adblock Plus is enabled, ?1? filter subscription(s) and ?2? custom filter(s) in use.
 whitelisted_tooltip=Adblock Plus is active but disabled on current page.
-blocked_count_tooltip=-- out of --
+blocked_count_tooltip=?1? out of ?2?
+blocked_count_addendum=(also whitelisted: ?1?, hidden: ?2?)
 no_blocking_suggestions=No blockable items on the current page
 whitelisted_page=Adblock Plus has been disabled for the current page
 whitelist_description=My Exception Rules
@@ -16,7 +15,7 @@
 invalid_description=My Invalid Rules
 elemhide_description=My Element Hiding Rules
 subscription_description=Filter subscription:
-subscription_wrong_version=Some filters in this subscription require Adblock Plus -- to work properly!
+subscription_wrong_version=Some filters in this subscription require Adblock Plus ?1? to work properly.
 subscription_source=Source:
 subscription_status=Status:
 subscription_status_autodownload=Updated automatically
@@ -25,22 +24,22 @@
 subscription_status_lastdownload=Last download:
 subscription_status_lastdownload_inprogress=Downloading...
 subscription_status_lastdownload_unknown=N/A
-remove_subscription_warning=Do you really wish to remove this subscription?
-import_filters_wrong_version=Warning: some of the filters in this list require Adblock Plus -- to work properly. You should probably upgrade to the latest Adblock Plus release before importing this list.
-import_filters_warning=Do you wish to replace your current filters or append the new filters at the end of the list?
+remove_subscription_warning=Do you really want to remove this subscription?
+import_filters_wrong_version=Warning: some of the filters in this list require Adblock Plus ?1? to work properly. You should probably upgrade to the latest Adblock Plus release before importing this list.
+import_filters_warning=Do you want to replace your current filters or append the new filters at the end of the list?
 import_filters_title=Import filters
 export_filters_title=Export filters
 invalid_filters_file=Not a valid Adblock Plus filters file.
-filters_write_error=There was an error writing filters to the file. Make sure the file is not write protected or open in another program.
+filters_write_error=There was an error writing filters to the file. Make sure the file isn't write protected or open in another application.
 clearall_warning=Do you really want to remove all filters from the list?
-resethitcounts_warning=Do you really wish to reset hit counts for all filters? This operation cannot be undone.
-resethitcounts_selected_warning=Do you really wish to reset hit counts for the selected filters? This operation cannot be undone.
+resethitcounts_warning=Do you really want to reset hit counts for all filters? This operation cannot be undone.
+resethitcounts_selected_warning=Do you really want to reset hit counts for the selected filters? This operation cannot be undone.
 filter_regexp_tooltip=This filter is either a regular expression or too short to be optimised. Too many of these filters might slow down your browsing.
 filter_elemhide_duplicate_id=Only one ID of the element to be hidden can be specified
 filter_elemhide_nocriteria=No criteria specified to recognise the element to be hidden
-subscription_no_location=Please enter a location to download filters from.
+subscription_notAdded_warning=You didn't add a filter subscription. Without a filter subscription you will need to add Adblock Plus filters manually.
+subscription_notAdded_warning_addendum=Do you want to proceed?
 subscription_invalid_location=Filter list location is neither a valid URL nor a valid file name.
-subscription_location_exists=You are already subscribed to this filter list.
 synchronize_invalid_url=Failed: not a valid address
 synchronize_connection_error=Failed: download failure
 synchronize_invalid_data=Failed: not a valid filters list
@@ -65,3 +64,7 @@
 type_label_dtd=DTD
 type_label_media=audio/video
 type_label_font=font
+fennec_status_enabled=Adblock Plus is enabled.
+fennec_status_disabled=Adblock Plus is disabled.
+fennec_status_enabled_site=Adblock Plus is enabled on ?1?.
+fennec_status_disabled_site=Adblock Plus is disabled on ?1?.

=== added file 'chrome/locale/en-GB/meta.properties'
--- chrome/locale/en-GB/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/en-GB/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Mark Tyndall
+name=Adblock Plus
+description=Ads were yesterday!
+description.short=Annoyed by adverts? Troubled by tracking? Bothered by banners? Install Adblock Plus now to regain control of the internet and change the way that you view the web.\n\nA short video overview is available at http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus allows you to regain control of the internet and view the web the way you want to. The add-on is supported by over forty filter subscriptions in dozens of languages which automatically configure it for purposes ranging from removing online advertising to blocking all known malware domains. Adblock Plus also allows you to customise your filters with the assistance of a variety of useful features, including a context option for images, a block tab for Flash and Java objects, and a list of blockable items to remove scripts and stylesheets.

=== modified file 'chrome/locale/en-GB/overlay.dtd'
--- chrome/locale/en-GB/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-GB/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -5,18 +5,19 @@
 <!ENTITY menuitem.accesskey "B">
 <!ENTITY toolbarbutton.label "Adblock Plus">
 <!ENTITY view.blockableItems.label "Adblock Plus: Blockable Items">
-<!ENTITY context.image.label "Adblock Image">
-<!ENTITY context.object.label "Adblock Object">
-<!ENTITY context.frame.label "Adblock Frame">
+<!ENTITY context.image.label "Adblock Plus: Block image">
+<!ENTITY context.object.label "Adblock Plus: Block object">
+<!ENTITY context.frame.label "Adblock Plus: Block frame">
+<!ENTITY context.media.label "Adblock Plus: Block audio/video">
 <!ENTITY context.removeWhitelist.label "Adblock Plus: Re-enable on this page">
 <!ENTITY sidebar.title "Blockable items on current page">
 <!ENTITY settings.label "Preferences">
-<!ENTITY settings.accesskey "F">
+<!ENTITY settings.accesskey "f">
 <!ENTITY opensidebar.label "Open blockable items">
 <!ENTITY opensidebar.accesskey "b">
 <!ENTITY closesidebar.label "Close blockable items">
 <!ENTITY closesidebar.accesskey "b">
-<!ENTITY whitelist.site.label "Disable on --">
+<!ENTITY whitelist.site.label "Disable on ?1?">
 <!ENTITY whitelist.page.label "Disable on this page only">
 <!ENTITY objecttab.title "Block">
 <!ENTITY objecttab.tooltip "Block this object with Adblock Plus">

=== modified file 'chrome/locale/en-GB/settings.dtd'
--- chrome/locale/en-GB/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-GB/settings.dtd	2010-05-04 14:45:07 +0000
@@ -87,3 +87,4 @@
 <!ENTITY context.disable.label "Disable">
 <!ENTITY apply.label "Apply">
 <!ENTITY apply.accesskey "p">
+<!ENTITY fennec.subscription.label "Filter subscription">

=== modified file 'chrome/locale/en-GB/sidebar.dtd'
--- chrome/locale/en-GB/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-GB/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "Block this item">
 <!ENTITY context.editfilter.label "Edit filter in effect">
 <!ENTITY context.whitelist.label "Add exception rule for item">
-<!ENTITY context.disablefilter.label "Disable filter --">
-<!ENTITY context.enablefilter.label "Re-enable filter --">
-<!ENTITY context.disablefilteronsite.label "Disable this filter on --">
+<!ENTITY context.disablefilter.label "Disable filter ?1?">
+<!ENTITY context.enablefilter.label "Re-enable filter ?1?">
+<!ENTITY context.disablefilteronsite.label "Disable this filter on ?1?">
 <!ENTITY context.open.label "Open in New Tab">
 <!ENTITY context.flash.label "Flash item&apos;s borders">
 <!ENTITY context.copy.label "Copy item&apos;s address">

=== removed file 'chrome/locale/en-GB/subscription.dtd'
--- chrome/locale/en-GB/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-GB/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Edit filter subscription">
-<!ENTITY dialog.newtitle "Add filter subscription">
-<!ENTITY new.description "Please enter the web address or file containing a list of Adblock Plus filters.">
-<!ENTITY edit.description "The filter list for this subscription will be downloaded from the location given.">
-<!ENTITY external.description "This is an external filter subscription; its filter list will be kept up-to-date by the extension that created this subscription.">
-<!ENTITY autodownload.description "If you choose &apos;Update automatically&apos; this location will be checked for updates daily. With this option disabled you can still trigger an update manually from the subscription&apos;s context menu.">
-<!ENTITY location.label "Filter list location:">
-<!ENTITY location.accesskey "l">
-<!ENTITY title.label "Subscription title:">
-<!ENTITY title.accesskey "t">
-<!ENTITY autodownload.label "Update automatically">
-<!ENTITY autodownload.accesskey "p">
-<!ENTITY enabled.label "Enable filters">
-<!ENTITY enabled.accesskey "n">

=== added file 'chrome/locale/en-GB/subscriptionSelection.dtd'
--- chrome/locale/en-GB/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/en-GB/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Add Adblock Plus filter subscription">
+<!ENTITY dialog.title.edit "Edit filter subscription">
+<!ENTITY description.newInstall "Adblock Plus will be most effective if you add a filter subscription. Filter subscriptions are provided by other Adblock Plus users free of charge. The most suitable subscription for your language is already selected.">
+<!ENTITY adblock.warning "Adblock Plus has detected that Adblock or an old version of Adblock Plus is installed. Running both Adblock and Adblock Plus in parallel can cause problems and should be avoided. It is recommended that you uninstall Adblock now.">
+<!ENTITY adblock.uninstall "Uninstall Adblock">
+<!ENTITY filterset.g.warning "Adblock Plus has detected that you use Filterset.G. This filter list has been barely maintained in the last few years and is a common cause of problems with web sites. It is recommended that you uninstall Filterset.G now.">
+<!ENTITY filterset.g.moreinfo "More information">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Uninstall Filterset.G">
+<!ENTITY subscriptionSelector.label "Please choose a filter subscription from the list:">
+<!ENTITY viewList.label "View filters">
+<!ENTITY visitHomepage.label "Visit home page">
+<!ENTITY addSubscription.label "Add subscription">
+<!ENTITY saveSubscription.label "Save subscription">
+<!ENTITY other.label "Add a different subscription">
+<!ENTITY other.accesskey "f">
+<!ENTITY list.download.failed "Adblock Plus failed to retrieve the list of subscriptions.">
+<!ENTITY list.download.retry "Try again">
+<!ENTITY list.download.website "View website">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Please confirm that you want to add this filter subscription. You can change the subscription title or location before adding it.">
+<!ENTITY edit.description "You can change the subscription title or location as necessary.">
+<!ENTITY external.description "This is an external filter subscription; it will be updated by the extension that created this subscription.">
+<!ENTITY title.label "Subscription title:">
+<!ENTITY title.accesskey "t">
+<!ENTITY location.label "Filter list location:">
+<!ENTITY location.accesskey "l">
+<!ENTITY autodownload.label "Update automatically">
+<!ENTITY autodownload.accesskey "p">
+<!ENTITY supplementMessage "This filter subscription is meant to be used with the filter subscription &quot;?1?&quot; which you are not using yet.">
+<!ENTITY addMain.label "Add filter subscription &quot;?1?&quot; as well">
+<!ENTITY addMain.accesskey "s">

=== removed file 'chrome/locale/en-GB/tip_subscriptions.dtd'
--- chrome/locale/en-GB/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-GB/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Welcome to Adblock Plus">
-<!ENTITY description.par1 "Thank you for installing Adblock Plus. This extension can eliminate 99&#37; of the advertisements you see on the web. However, effective ad filtering requires you to define a good set of filters. You can do it yourself, or you can simply subscribe to filter lists others maintain for you. It will still be possible to add your own filters or deactivate/remove subscriptions whenever necessary.">
-<!ENTITY description.par2 "You can choose one subscription from the list of recommended subscriptions below (more subscriptions can be added in Adblock Plus Preferences later though usually this is not necessary):">
-<!ENTITY note "Note: A filter list is typically most effective when applied to web sites from the region the filter list was created for.">
-<!ENTITY adblock.warning "Adblock Plus has detected that Adblock or an old version of Adblock Plus is installed. Running both Adblock and Adblock Plus in parallel can cause problems and should be avoided. It is recommended that you uninstall Adblock now.">
-<!ENTITY adblock.uninstall "Uninstall Adblock">
-<!ENTITY filterset.g.warning "Adblock Plus has detected that you use Filterset.G. This filter list has been barely maintained in the last few years and is a common cause of problems with web sites. It is recommended that you uninstall Filterset.G now.">
-<!ENTITY filterset.g.moreinfo "More information">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Uninstall Filterset.G">
-<!ENTITY homepage.label "Home page">
-<!ENTITY subscribe.label "Subscribe">
-<!ENTITY subscribe.accesskey "r">
-<!ENTITY other.label "Add a different subscription">
-<!ENTITY other.accesskey "f">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "View all subscriptions">

=== modified file 'chrome/locale/en-US/about.dtd'
--- chrome/locale/en-US/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-US/about.dtd	2010-05-04 14:45:07 +0000
@@ -3,12 +3,17 @@
 <!ENTITY caption.title      "Adblock Plus">
 <!ENTITY version.title      "Version">
 <!ENTITY description        "
-  Adblock Plus allows you to decide what you don't want to see on the web.
-  You don't need to download all the ads and banners any more, if you
-  don't want them - tell Adblock Plus!
+  Adblock Plus allows you to decide what you want to see on the web.
+  You don't need to download adverts and banners any more; if you
+  don't want them - remove them with Adblock Plus!
 ">
 
 <!ENTITY homepage.label     "Adblock Plus homepage:">
 <!ENTITY homepage.url       "http://adblockplus.org/en/">
 <!ENTITY author.label       "Author:">
 <!ENTITY contributors.label "Contributors:">
+
+<!ENTITY developers.label   "Developers:">
+<!ENTITY designers.label    "Graphic designers:">
+<!ENTITY subscriptionAuthors.label    "Filter subscription authors:">
+<!ENTITY translators.label  "Translators:">

=== modified file 'chrome/locale/en-US/composer.dtd'
--- chrome/locale/en-US/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-US/composer.dtd	2010-05-04 14:45:07 +0000
@@ -3,13 +3,10 @@
 <!ENTITY advanced.label           "Advanced view">
 <!ENTITY basic.label              "Basic view">
 
-<!ENTITY disabled.warning.beforeLink  "Adblock Plus is currently disabled. You can still add filters but those will not be applied unless you ">
-<!ENTITY disabled.warning.link    "enable Adblock Plus">
-<!ENTITY disabled.warning.afterLink   ".">
+<!ENTITY disabled.warning         "Adblock Plus is currently disabled. You can still add filters but they will not be applied unless you [link]enable Adblock Plus[/link].">
 
-<!ENTITY groupDisabled.warning.beforeLink  "The filter group &quot;&#x25;S&quot; that this filter should be added to is currently disabled. You can still add the filter but it will not be applied unless you ">
-<!ENTITY groupDisabled.warning.link        "enable the filter group">
-<!ENTITY groupDisabled.warning.afterLink   ".">
+<!-- Note: the placeholder ?1? will be replaced by the name of the disabled filter group -->
+<!ENTITY groupDisabled.warning    "The filter group &quot;?1?&quot; that this filter will be added to is currently disabled. You can still add the filter but it will not be applied unless you [link]enable the filter group[/link].">
 
 <!ENTITY filter.label             "New filter:">
 <!ENTITY filter.accesskey         "f">
@@ -20,9 +17,9 @@
 <!ENTITY type.whitelist.label     "Exception rule">
 <!ENTITY type.whitelist.accesskey "x">
 <!ENTITY pattern.label            "Look for pattern">
-<!ENTITY pattern.explanation      "The pattern can be any part of the address, symbol * acts as a wildcard. The filter will only be applied to addresses matching the pattern.">
-<!ENTITY regexp.warning           "The pattern you entered will be interpreted as a regular expression. Many regular expressions might slow down your browsing. If you didn't intend to use regular expressions, add a * symbol at the end of the pattern.">
-<!ENTITY shortpattern.warning     "The pattern you entered is too short to be optimized, many such patterns might slow down your browsing. It is recommended that you choose a longer string for this filter.">
+<!ENTITY pattern.explanation      "The pattern can be any part of the address; asterisks (*) act as wildcards. The filter will only be applied to addresses matching the pattern provided.">
+<!ENTITY regexp.warning           "The pattern you entered will be interpreted as a regular expression which cannot be efficiently processed by Adblock Plus and may slow down your browsing experience. If you didn't intend to use a regular expression, add an asterisk (*) to the end of the pattern.">
+<!ENTITY shortpattern.warning     "The pattern you entered is too short to be optimized and may slow down your browsing experience. It is recommended that you choose a longer string for this filter to allow Adblock Plus to process the filter more efficiently.">
 <!ENTITY custom.pattern.label     "Custom:">
 <!ENTITY custom.pattern.accesskey "C">
 <!ENTITY anchors.label            "Accept pattern only:">
@@ -37,7 +34,7 @@
 <!ENTITY options.label            "Options">
 <!ENTITY domainRestriction.label      "Restrict to domain:">
 <!ENTITY domainRestriction.accesskey  "d">
-<!ENTITY domainRestriction.help       "Specify one or more domains separated by the symbol &quot;|&quot;, the filter will only be applied on these domains then. The symbol &quot;~&quot; before a domain name means that the filter should not be applied on that domain.">
+<!ENTITY domainRestriction.help       "Use this option to specify one or more domains separated by a bar line (|). The filter will only be applied on the domain(s) selected. A tilde (~) before a domain name indicates that the filter will not be applied on that domain.">
 <!ENTITY firstParty.label         "First-party only">
 <!ENTITY firstParty.accesskey     "r">
 <!ENTITY thirdParty.label         "Third-party only">

=== modified file 'chrome/locale/en-US/global.properties'
--- chrome/locale/en-US/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-US/global.properties	2010-05-04 14:45:07 +0000
@@ -1,18 +1,19 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Ads were yesterday!
-
-status_active_label=Adblock
-status_disabled_label=Disabled
+default_dialog_title=Adblock Plus
 
 action0_tooltip=Click to bring up context menu, middle-click to enable/disable.
 action1_tooltip=Click to open/close blockable items, middle-click to enable/disable.
 action2_tooltip=Click to open preferences, middle-click to enable/disable.
 action3_tooltip=Click to enable/disable Adblock Plus.
 
-active_tooltip=Adblock Plus is active.
 disabled_tooltip=Adblock Plus is disabled.
-whitelisted_tooltip=Adblock Plus is active but disabled on current page.
+# Note: the placeholder ?1? will be replaced by the number of active filter subscriptions, the placeholder ?2? by the number of custom filters
+active_tooltip=Adblock Plus is enabled, ?1? filter subscription(s) and ?2? custom filter(s) in use.
+whitelisted_tooltip=Adblock Plus is disabled on current page.
 
-blocked_count_tooltip=-- out of --
+# Note: the placeholder ?1? will be replaced by the number of blocked items, the placeholder ?2? by the total number of items on current page
+blocked_count_tooltip=?1? out of ?2?
+# Note: the placeholder ?1? will be replaced by the number of whitelisted items, the placeholder ?2? by the number of hidden items on current page
+blocked_count_addendum=(also whitelisted: ?1?, hidden: ?2?)
 
 no_blocking_suggestions=No blockable items on the current page
 whitelisted_page=Adblock Plus has been disabled for the current page
@@ -21,7 +22,8 @@
 invalid_description=My Invalid Rules
 elemhide_description=My Element Hiding Rules
 subscription_description=Filter subscription:
-subscription_wrong_version=Some filters in this subscription require Adblock Plus -- to work properly!
+# Note: the placeholder ?1? will be replaced by the Adblock Plus version number required
+subscription_wrong_version=Some filters in this subscription require Adblock Plus ?1? to work properly.
 subscription_source=Source:
 subscription_status=Status:
 subscription_status_autodownload=Updated automatically
@@ -30,24 +32,25 @@
 subscription_status_lastdownload=Last download:
 subscription_status_lastdownload_inprogress=Downloading...
 subscription_status_lastdownload_unknown=N/A
-remove_subscription_warning=Do you really wish to remove this subscription?
-import_filters_wrong_version=Warning: some of the filters in this list require Adblock Plus -- to work properly. You should probably upgrade to the latest Adblock Plus release before importing this list.
-import_filters_warning=Do you wish to replace your current filters or append the new filters at the end of the list?
+remove_subscription_warning=Do you really want to remove this subscription?
+# Note: the placeholder ?1? will be replaced by the Adblock Plus version number required
+import_filters_wrong_version=Warning: some of the filters in this list require Adblock Plus ?1? to work properly. You should probably upgrade to the latest Adblock Plus release before importing this list.
+import_filters_warning=Do you want to replace your current filters or append the new filters at the end of the list?
 import_filters_title=Import filters
 export_filters_title=Export filters
 invalid_filters_file=Not a valid Adblock Plus filters file.
-filters_write_error=There was an error writing filters to the file. Make sure the file isn't write protected or hold by another program.
-clearall_warning=Do you really wish to remove all filters from the list?
-resethitcounts_warning=Do you really wish to reset hit counts for all filters back to zero? This operation can't be undone!
-resethitcounts_selected_warning=Do you really wish to reset hit counts for selected filters back to zero? This operation can't be undone!
+filters_write_error=There was an error writing filters to the file. Make sure the file isn't write protected or open in another application.
+clearall_warning=Do you really want to remove all filters from the list?
+resethitcounts_warning=Do you really want to reset hit counts for all filters back to zero? Note: this operation can't be undone.
+resethitcounts_selected_warning=Do you really want to reset hit counts for selected filters back to zero? Note: this operation can't be undone.
 
 filter_regexp_tooltip=This filter is either a regular expression or too short to be optimized. Too many of these filters might slow down your browsing.
 filter_elemhide_duplicate_id=Only one ID of the element to be hidden can be specified
 filter_elemhide_nocriteria=No criteria specified to recognize the element to be hidden
 
-subscription_no_location=Please enter a location to download filters from.
+subscription_notAdded_warning=You didn't add a filter subscription. Without a filter subscription you will need to add Adblock Plus filters manually.
+subscription_notAdded_warning_addendum=Do you want to proceed?
 subscription_invalid_location=Filter list location is neither a valid URL nor a valid file name.
-subscription_location_exists=You are already subscribed to this filter list.
 synchronize_invalid_url=Failed, not a valid address
 synchronize_connection_error=Failed, download failure
 synchronize_invalid_data=Failed, not a valid filters list
@@ -76,3 +79,10 @@
 type_label_dtd=DTD
 type_label_media=audio/video
 type_label_font=font
+
+fennec_status_enabled=Adblock Plus is enabled.
+fennec_status_disabled=Adblock Plus is disabled.
+# Note: the placeholder ?1? will be replaced by the site name
+fennec_status_enabled_site=Adblock Plus is enabled on ?1?.
+# Note: the placeholder ?1? will be replaced by the site name
+fennec_status_disabled_site=Adblock Plus is disabled on ?1?.

=== added file 'chrome/locale/en-US/meta.properties'
--- chrome/locale/en-US/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/en-US/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,10 @@
+# Translator of this locale, separate by commas if multiple
+translator=Wladimir Palant
+# Extension title, usually it shouldn't be translated
+name=Adblock Plus
+# Extension description, to be displayed in the add-on manager
+description=Ads were yesterday!
+# Short description for addons.mozilla.org (250 characters limit!). Leave out the link to English-language video if it isn't useful for users speaking your language.
+description.short=Annoyed by adverts? Troubled by tracking? Bothered by banners? Install Adblock Plus now to regain control of the internet and change the way that you view the web.\n\nA short video overview is available at http://www.youtube.com/watch?v=oNvb2SjVjjI
+# Long description for addons.mozilla.org
+description.long=Adblock Plus allows you to regain control of the internet and view the web the way you want to. The add-on is supported by over forty filter subscriptions in dozens of languages which automatically configure it for purposes ranging from removing online advertising to blocking all known malware domains. Adblock Plus also allows you to customize your filters with the assistance of a variety of useful features, including a context option for images, a block tab for Flash and Java objects, and a list of blockable items to remove scripts and stylesheets.

=== modified file 'chrome/locale/en-US/overlay.dtd'
--- chrome/locale/en-US/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-US/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -3,7 +3,7 @@
 <!ENTITY filters.tooltip        "Most active filters:">
 
 <!ENTITY menuitem.label         "Adblock Plus Preferences">
-<!ENTITY menuitem.accesskey     "B">
+<!ENTITY menuitem.accesskey     "b">
 <!ENTITY toolbarbutton.label    "Adblock Plus">
 
 <!ENTITY view.blockableItems.label  "Adblock Plus: Blockable Items">
@@ -11,19 +11,21 @@
 <!ENTITY context.image.label    "Adblock Plus: Block image">
 <!ENTITY context.object.label   "Adblock Plus: Block object">
 <!ENTITY context.frame.label    "Adblock Plus: Block frame">
+<!ENTITY context.media.label    "Adblock Plus: Block audio/video">
 <!ENTITY context.removeWhitelist.label  "Adblock Plus: Re-enable on this page">
 
 <!ENTITY sidebar.title          "Blockable items on current page">
 
 <!ENTITY settings.label         "Preferences">
-<!ENTITY settings.accesskey     "F">
+<!ENTITY settings.accesskey     "f">
 <!ENTITY opensidebar.label      "Open blockable items">
 <!-- Note: This access key should usually be the same as closesidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open.-->
-<!ENTITY opensidebar.accesskey  "B">
+<!ENTITY opensidebar.accesskey  "b">
 <!ENTITY closesidebar.label     "Close blockable items">
 <!-- Note: This access key should usually be the same as opensidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open.-->
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label   "Disable on --">
+<!ENTITY closesidebar.accesskey "b">
+<!-- Note: the placeholder ?1? will be replaced by the domain name of the current page -->
+<!ENTITY whitelist.site.label   "Disable on ?1?">
 <!ENTITY whitelist.page.label   "Disable on this page only">
 
 <!ENTITY objecttab.title        "Block">

=== modified file 'chrome/locale/en-US/settings.dtd'
--- chrome/locale/en-US/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-US/settings.dtd	2010-05-04 14:45:07 +0000
@@ -6,15 +6,15 @@
 <!ENTITY add.label                  "Add filter">
 <!ENTITY add.accesskey              "A">
 <!ENTITY addsubscription.label      "Add filter subscription">
-<!ENTITY addsubscription.accesskey  "S">
+<!ENTITY addsubscription.accesskey  "s">
 <!ENTITY synchsubscriptions.label       "Update all subscriptions">
-<!ENTITY synchsubscriptions.accesskey   "D">
+<!ENTITY synchsubscriptions.accesskey   "d">
 <!ENTITY import.label               "Import filters">
-<!ENTITY import.accesskey           "M">
+<!ENTITY import.accesskey           "m">
 <!ENTITY export.label               "Export custom filters">
-<!ENTITY export.accesskey           "X">
+<!ENTITY export.accesskey           "x">
 <!ENTITY clearall.label             "Remove all custom filters">
-<!ENTITY clearall.accesskey         "L">
+<!ENTITY clearall.accesskey         "l">
 <!ENTITY resethitcounts.label       "Reset hit statistics">
 <!ENTITY resethitcounts.accesskey   "R">
 
@@ -22,7 +22,7 @@
 <!ENTITY edit.accesskey             "E">
 
 <!ENTITY cut.label                  "Cut">
-<!ENTITY cut.accesskey              "T">
+<!ENTITY cut.accesskey              "t">
 <!ENTITY copy.label                 "Copy">
 <!ENTITY copy.accesskey             "C">
 <!ENTITY paste.label                "Paste">
@@ -32,7 +32,7 @@
 <!ENTITY menu.find.label            "Find">
 <!ENTITY menu.find.accesskey        "F">
 <!ENTITY menu.findagain.label       "Find Again">
-<!ENTITY menu.findagain.accesskey   "G">
+<!ENTITY menu.findagain.accesskey   "g">
 
 <!ENTITY view.label                 "View">
 <!ENTITY view.accesskey             "V">
@@ -50,15 +50,15 @@
 <!ENTITY options.accesskey          "O">
 
 <!ENTITY enable.label               "Enable Adblock Plus">
-<!ENTITY enable.accesskey           "N">
+<!ENTITY enable.accesskey           "n">
 <!ENTITY showintoolbar.label        "Show in toolbar">
-<!ENTITY showintoolbar.accesskey    "B">
+<!ENTITY showintoolbar.accesskey    "b">
 <!ENTITY showinstatusbar.label      "Show in status bar">
-<!ENTITY showinstatusbar.accesskey  "S">
+<!ENTITY showinstatusbar.accesskey  "s">
 <!ENTITY objecttabs.label           "Show tabs on Flash and Java">
-<!ENTITY objecttabs.accesskey       "T">
+<!ENTITY objecttabs.accesskey       "t">
 <!ENTITY collapse.label             "Collapse blocked elements">
-<!ENTITY collapse.accesskey         "L">
+<!ENTITY collapse.accesskey         "l">
 
 <!ENTITY help.label                 "Help">
 <!ENTITY help.accesskey             "H">
@@ -70,10 +70,10 @@
 <!ENTITY faq.accesskey              "F">
 <!ENTITY faq.url                    "http://adblockplus.org/en/faq">
 <!ENTITY filterdoc.label            "Writing Adblock Plus filters">
-<!ENTITY filterdoc.accesskey        "R">
+<!ENTITY filterdoc.accesskey        "r">
 <!ENTITY filterdoc.url              "http://adblockplus.org/en/filters">
 <!ENTITY about.label                "About Adblock Plus">
-<!ENTITY about.accesskey            "B">
+<!ENTITY about.accesskey            "b">
 
 <!ENTITY description                "The following filters determine which addresses should be blocked and which ones should be allowed:">
 
@@ -100,4 +100,6 @@
 <!ENTITY context.disable.label      "Disable">
 
 <!ENTITY apply.label                "Apply">
-<!ENTITY apply.accesskey            "P">
+<!ENTITY apply.accesskey            "p">
+
+<!ENTITY fennec.subscription.label  "Filter subscription">

=== modified file 'chrome/locale/en-US/sidebar.dtd'
--- chrome/locale/en-US/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-US/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -28,9 +28,12 @@
 <!ENTITY context.block.label      "Block this item">
 <!ENTITY context.editfilter.label "Edit filter in effect">
 <!ENTITY context.whitelist.label  "Add exception rule for item">
-<!ENTITY context.disablefilter.label  "Disable filter --">
-<!ENTITY context.enablefilter.label   "Re-enable filter --">
-<!ENTITY context.disablefilteronsite.label  "Disable this filter on --">
+<!-- Note: the placeholder ?1? will be replaced by the filter text -->
+<!ENTITY context.disablefilter.label  "Disable filter ?1?">
+<!-- Note: the placeholder ?1? will be replaced by the filter text -->
+<!ENTITY context.enablefilter.label   "Re-enable filter ?1?">
+<!-- Note: the placeholder ?1? will be replaced by the domain name of the current page -->
+<!ENTITY context.disablefilteronsite.label  "Disable this filter on ?1?">
 <!ENTITY context.open.label       "Open in New Tab">
 <!ENTITY context.flash.label      "Flash item's borders">
 <!ENTITY context.copy.label       "Copy item's address">

=== removed file 'chrome/locale/en-US/subscription.dtd'
--- chrome/locale/en-US/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-US/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,34 +0,0 @@
-<!ENTITY dialog.title               "Edit filter subscription">
-<!ENTITY dialog.newtitle            "Add filter subscription">
-
-<!ENTITY new.description            "
-  Please enter the web address or file containing a list of
-  Adblock Plus filters.
-">
-
-<!ENTITY edit.description           "
-  The filter list for this subscription will be downloaded
-  from the location given.
-">
-
-<!ENTITY external.description       "
-  This is an external filter subscription, its filter list
-  will be kept up-to-date by the extension that created this
-  subscription.
-">
-
-<!ENTITY autodownload.description   "
-  If you choose 'Update automatically' this location will be
-  checked for updates daily. With this option disabled you still
-  can trigger an update manually from the subscription's context
-  menu.
-">
-
-<!ENTITY location.label             "Filter list location:">
-<!ENTITY location.accesskey         "L">
-<!ENTITY title.label                "Subscription title:">
-<!ENTITY title.accesskey            "T">
-<!ENTITY autodownload.label         "Update automatically">
-<!ENTITY autodownload.accesskey     "P">
-<!ENTITY enabled.label              "Enable filters">
-<!ENTITY enabled.accesskey          "N">

=== added file 'chrome/locale/en-US/subscriptionSelection.dtd'
--- chrome/locale/en-US/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/en-US/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,58 @@
+<!ENTITY dialog.title               "Add Adblock Plus filter subscription">
+<!ENTITY dialog.title.edit          "Edit filter subscription">
+
+<!ENTITY description.newInstall     "
+  Adblock Plus will be most effective if you add a filter subscription.
+  Filter subscriptions are provided by other Adblock Plus users free of
+  charge. The most suitable subscription for your language is already
+  selected.
+">
+
+<!ENTITY adblock.warning            "
+  Adblock Plus has detected that Adblock or an old version of Adblock Plus is
+  installed. Running both Adblock and Adblock Plus in parallel can cause
+  problems and should be avoided. It is recommended that you uninstall Adblock now.
+">
+<!ENTITY adblock.uninstall          "Uninstall Adblock">
+
+<!ENTITY filterset.g.warning        "
+  It seems that you use Filterset.G. This filter list has been barely
+  maintained in the last few years and is a common cause of problems with web
+  sites. It is recommended that you uninstall Filterset.G now.
+">
+<!ENTITY filterset.g.moreinfo       "More information">
+<!ENTITY filterset.g.moreinfo.url   "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall      "Uninstall Filterset.G">
+
+<!ENTITY subscriptionSelector.label "Please choose a filter subscription from the list:">
+
+<!ENTITY viewList.label             "View filters">
+<!ENTITY visitHomepage.label        "Visit home page">
+
+<!ENTITY addSubscription.label      "Add subscription">
+<!ENTITY saveSubscription.label     "Save subscription">
+
+<!ENTITY other.label                "Add a different subscription">
+<!ENTITY other.accesskey            "f">
+
+<!ENTITY list.download.failed       "Adblock Plus failed to retrieve the list of subscriptions.">
+<!ENTITY list.download.retry        "Try again">
+<!ENTITY list.download.website      "View website">
+<!ENTITY list.website.url           "http://adblockplus.org/en/subscriptions">
+
+<!ENTITY fromWeb.description        "Please confirm that you want to add this filter subscription. You can change the subscription title or location before adding it.">
+<!ENTITY edit.description           "You can change the subscription title or location as necessary.">
+<!ENTITY external.description       "This is an external filter subscription; it will be updated by the extension that created this subscription.">
+
+<!ENTITY title.label                "Subscription title:">
+<!ENTITY title.accesskey            "t">
+<!ENTITY location.label             "Filter list location:">
+<!ENTITY location.accesskey         "l">
+<!ENTITY autodownload.label         "Update filters automatically">
+<!ENTITY autodownload.accesskey     "p">
+
+<!-- Note: the placeholder (?1?) will be replaced by the name of the filter subscription required -->
+<!ENTITY supplementMessage          "This filter subscription is meant to be used with the filter subscription &quot;?1?&quot; which you are not using yet.">
+<!-- Note: the placeholder (?1?) will be replaced by the name of the filter subscription required -->
+<!ENTITY addMain.label              "Add filter subscription &quot;?1?&quot; as well">
+<!ENTITY addMain.accesskey          "s">

=== removed file 'chrome/locale/en-US/tip_subscriptions.dtd'
--- chrome/locale/en-US/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/en-US/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,49 +0,0 @@
-<!ENTITY dialog.title               "Add Adblock Plus filter subscription">
-
-<!ENTITY description.par1           "
-  Thank you for installing Adblock Plus. This extension can
-  eliminate 99&#x25; of the advertisements you see on the web. However,
-  effective ad filtering requires you to define a good set of
-  filters. You can do it yourself, or you can simply subscribe
-  to filter lists others maintain for you. It will still be possible
-  to add your own filters or deactivate/remove subscriptions
-  whenever necessary.
-">
-
-<!ENTITY description.par2           "
-  You can choose one subscription from the
-  list of recommended subscriptions below (more subscriptions can be
-  added in Adblock Plus Preferences later though usually this is not
-  necessary):
-">
-
-<!ENTITY note                       "
-  Note: A filter list is typically most effective when applied
-  to web sites from the region this filter list was created for.
-">
-
-<!ENTITY adblock.warning            "
-  Adblock Plus has detected that Adblock or an old version of Adblock Plus is
-  installed. Running both Adblock and Adblock Plus in parallel can cause
-  problems and should be avoided. It is recommended that you uninstall Adblock now.
-">
-<!ENTITY adblock.uninstall          "Uninstall Adblock">
-
-<!ENTITY filterset.g.warning        "
-  It seems that you use Filterset.G. This filter list has been barely
-  maintained in the last few years and is a common cause of problems with web
-  sites. It is recommended that you uninstall Filterset.G now.
-">
-<!ENTITY filterset.g.moreinfo       "More information">
-<!ENTITY filterset.g.moreinfo.url   "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall      "Uninstall Filterset.G">
-
-<!ENTITY homepage.label             "Home page">
-
-<!ENTITY subscribe.label            "Subscribe">
-<!ENTITY subscribe.accesskey        "R">
-<!ENTITY other.label                "Add a different subscription">
-<!ENTITY other.accesskey            "f">
-
-<!ENTITY full-list.url              "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label            "View all subscriptions">

=== added directory 'chrome/locale/es-AR'
=== added file 'chrome/locale/es-AR/about.dtd'
--- chrome/locale/es-AR/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/es-AR/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Acerca de Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versión">
+<!ENTITY description "Adblock Plus te deja a vos que decidas qué querés ver en la web, y qué no. Basta de soportar esa molesta publicidad. Si no la querés, ¡decíselo a Adblock Plus!">
+<!ENTITY homepage.label "Sitio web oficial de Adblock Plus (en inglés):">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "Autor:">
+<!ENTITY contributors.label "Contribuyentes:">
+<!ENTITY developers.label "Desarrolladores:">
+<!ENTITY designers.label "Diseñadores gráficos:">
+<!ENTITY subscriptionAuthors.label "Autores de los filtros de suscripción:">
+<!ENTITY translators.label "Traductores:">

=== added file 'chrome/locale/es-AR/composer.dtd'
--- chrome/locale/es-AR/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/es-AR/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Agregar regla de filtro">
+<!ENTITY accept.label "Agregar filtro">
+<!ENTITY advanced.label "Vista avanzada">
+<!ENTITY basic.label "Vista básica">
+<!ENTITY disabled.warning "Adblock Plus está deshabilitado. Podés seguir agregando filtros, pero no se aplicarán hasta que no actives los [link]filtros de Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "El grupo del filtro &quot;?1?&quot; al que éste debería ser agregado, está deshabilitado. Podés agregar el filtro, pero no se aplicará hasta que no actives el [link]grupo de filtro[/link].">
+<!ENTITY filter.label "Nuevo filtro:">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "Mostrar filtros existentes...">
+<!ENTITY preferences.accesskey "M">
+<!ENTITY type.filter.label "Filtros de bloqueo">
+<!ENTITY type.filter.accesskey "b">
+<!ENTITY type.whitelist.label "Regla de excepción">
+<!ENTITY type.whitelist.accesskey "x">
+<!ENTITY pattern.label "Buscar patrón">
+<!ENTITY pattern.explanation "El patrón puede ser cualquier parte de la dirección. El asterisco (&quot;*&quot;) funciona como un comodín. El filtro sólo será aplicado a aquellas direcciones que que coincidan con el patrón.">
+<!ENTITY regexp.warning "El patrón que ingresés será interpretado como una expresión constante. Demasiadas expresiones constantes podrían ralentizar tu navegación web. Si no preferís usar expresiones constantes, agregá un asterisco (&quot;*&quot;) al final del patrón.">
+<!ENTITY shortpattern.warning "El patrón que ingresaste es demasiado corto para poder ser optimizado. Varios patrones similares podrían ralentizar tu navegación web. Te recomendamos que elijas una cadena más larga para este filtro.">
+<!ENTITY custom.pattern.label "Personalizado:">
+<!ENTITY custom.pattern.accesskey "P">
+<!ENTITY anchors.label "Aceptar solamente patrón:">
+<!ENTITY anchor.start.label "al comienzo de la dirección">
+<!ENTITY anchor.start.accesskey "c">
+<!ENTITY anchor.start.flexible.label "al comienzo del nombre de dominio">
+<!ENTITY anchor.start.flexible.accesskey "c">
+<!ENTITY anchor.end.label "al final de la dirección">
+<!ENTITY anchor.end.accesskey "f">
+<!ENTITY options.label "Opciones">
+<!ENTITY domainRestriction.label "Restringir al dominio:">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "Especificá uno o más dominios, separados por el símbolo tubería &quot;|&quot;, así el filtro se aplica solamente sobre estos dominios. El símbolo ñuflo &quot;~&quot; antes de un nombre de dominio significa que el filtro no se aplicaría sobre ese dominio.">
+<!ENTITY firstParty.label "Solamente personal">
+<!ENTITY firstParty.accesskey "p">
+<!ENTITY thirdParty.label "Solamente de terceros">
+<!ENTITY thirdParty.accesskey "t">
+<!ENTITY matchCase.label "Coincidir mayúsculas">
+<!ENTITY matchCase.accesskey "m">
+<!ENTITY types.label "Aplicar a tipos:">
+<!ENTITY selectAllTypes.label "Seleccionar todo">
+<!ENTITY unselectAllTypes.label "No seleccionar nada">
+<!ENTITY collapse.label "Colapsar los bloqueados:">
+<!ENTITY collapse.accesskey "l">
+<!ENTITY collapse.default.yes.label "Usar predeterminado (sí)">
+<!ENTITY collapse.default.no.label "Usar predeterminado (no)">
+<!ENTITY collapse.yes.label "Sí">
+<!ENTITY collapse.no.label "No">

=== added file 'chrome/locale/es-AR/global.properties'
--- chrome/locale/es-AR/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/es-AR/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Clic para ver el menú contextual, clic con el botón del medio para habilitarlo/deshabilitarlo.
+action1_tooltip=Clic para abrir/cerrar los elementos bloqueables, clic con el botón del medio para habilitarlos/deshabilitarlos.
+action2_tooltip=Clic para abrir el menú de Preferencias, clic con el botón del medio para habilitarlo/deshabilitarlo.
+action3_tooltip=Clic para habilitar/deshabilitar Adblock Plus.
+disabled_tooltip=Adblock Plus está deshabilitado.
+active_tooltip=Adblock Plus está activo. En uso: ?1? suscripción/es de filtros y ?2? filtros personalizados.
+whitelisted_tooltip=Adblock Plus se encuentra activo, pero deshabilitado en la página actual.
+blocked_count_tooltip=?1? de un total de ?2?
+blocked_count_addendum=(también en la lista segura: ?1?, oculta: ?2?)
+no_blocking_suggestions=No hay elementos bloqueables en la página actual
+whitelisted_page=Adblock Plus fue deshabilitado para la página actual
+whitelist_description=Mis reglas de excepción
+filterlist_description=Mis reglas de bloqueo de publicidad
+invalid_description=Mis reglas inválidas
+elemhide_description=Mis reglas de ocultamiento de elementos
+subscription_description=Suscripción de filtro:
+subscription_wrong_version=Algunos filtros en esta suscripción requieren que Adblock Plus ?1? ¡funcione bien!
+subscription_source=Fuente:
+subscription_status=Estado:
+subscription_status_autodownload=Actualizado automáticamente
+subscription_status_manualdownload=Actualizado manualmente
+subscription_status_externaldownload=Actualizado externamente (otra extensión)
+subscription_status_lastdownload=Última descarga:
+subscription_status_lastdownload_inprogress=Descargando...
+subscription_status_lastdownload_unknown=No disponible
+remove_subscription_warning=¿Estás seguro de querer quitar esta suscripción?
+import_filters_wrong_version=Advertencia: algunos filtros en esta lista requieren que Adblock Plus ?1? ¡funcione bien! Quizás deberías actualizarte al último lanzamiento de Adblock Plus antes de importar esta lista.
+import_filters_warning=¿Querés reemplazar tus filtros actuales o sumar los nuevos filtros al final de la lista?
+import_filters_title=Importar filtros
+export_filters_title=Exportar filtros
+invalid_filters_file=Este no es un archivo válido de filtros de Adblock Plus.
+filters_write_error=Hubo un error al escribir filtros al archivo. Asegurate de que el archivo no esté protegido contra escrituras, o que no esté siendo utilizado por otro programa.
+clearall_warning=¿Estás seguro de querer quitar todos los filtros de la lista?
+resethitcounts_warning=¿Estás seguro de querer restablecer los contadores a cero para todos los filtros? ¡Esta operación no se puede deshacer!
+resethitcounts_selected_warning=¿Estás seguro de querer restablecer los contadores a cero para los filtros seleccionados? ¡Esta operación no se puede deshacer!
+filter_regexp_tooltip=Este filtro o bien es una expresión constante, o bien es demasiado corto para ser optimizado. Demasiados filtros similares podrían ralentizar tu navegación web.
+filter_elemhide_duplicate_id=Se puede especificar solamente un identificador del elemento a ser ocultado.
+filter_elemhide_nocriteria=No se especificó el criterio para reconocer el elemento a ser ocultado
+subscription_notAdded_warning=No agregaste una suscripción de filtros. Sin una suscripción de filtros vas a tener que ingresar los filtros a Adblock Plus manualmente.
+subscription_notAdded_warning_addendum=¿Querés continuar?
+subscription_invalid_location=La ubicación de lista de filtros no es válida, o no es válido el nombre de archivo.
+synchronize_invalid_url=Falló, no es una dirección válida
+synchronize_connection_error=Falló, error en la descarga
+synchronize_invalid_data=Falló, no es una lista de filtros válida
+synchronize_checksum_mismatch=Falló, el archivo checksum no coincide
+synchronize_ok=Se realizó exitosamente
+overwrite=Sobreescribir
+append=Sumar
+new_filter_group_title=Nuevo filtro
+type_label_other=otro
+type_label_script=script
+type_label_image=imagen
+type_label_stylesheet=hoja de estilo
+type_label_object=objeto
+type_label_subdocument=marco
+type_label_document=documento
+type_label_background=fondo
+type_label_elemhide=oculto
+type_label_xbl=solicitud XML
+type_label_ping=rebote de enlace
+type_label_xmlhttprequest=petición XML
+type_label_object_subrequest=subpetición de objeto
+type_label_dtd=DTD
+type_label_media=audio/video
+type_label_font=fuente
+fennec_status_enabled=Adblock Plus está habilitado.
+fennec_status_disabled=Adblock Plus está deshabilitado.
+fennec_status_enabled_site=Adblock Plus está habilitado en ?1?.
+fennec_status_disabled_site=Adblock Plus está deshabilitado en ?1?.

=== added file 'chrome/locale/es-AR/meta.properties'
--- chrome/locale/es-AR/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/es-AR/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=KNTRO
+name=Adblock Plus
+description=¡La publicidad es cosa del pasado!
+description.short=¿Te molestan las publicidades? ¿Te fastidian los báners? Instalá Adblock Plus ahora para recuperar el control de Internet y cambiar la forma en que ves la web.\n\nPodés ver un pantallazo, en video, en http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus te permite recuperar el control de Internet y cambiar la forma en que ves la web. La extensión incluye soporte para más de cuarenta suscripciones de filtros, en docenas de idiomas, cuyos propósitos van desde quitar publicidad en línea hasta bloquear todos los dominios maliciosos conocidos. Adblock Plus también te permite configurar tus filtros con la asistencia de una variedad de funciones muy útiles, incluyendo una opción contextual para imágenes, una pestaña de bloqueos para objetos Flash y Java, y una lista de elementos susceptibles de ser bloqueados, para quitar así scripts y hojas de estilo.

=== added file 'chrome/locale/es-AR/overlay.dtd'
--- chrome/locale/es-AR/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/es-AR/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Estado:">
+<!ENTITY blocked.tooltip "Elementos bloqueados en esta página:">
+<!ENTITY filters.tooltip "Filtros más activos:">
+<!ENTITY menuitem.label "Preferencias de Adblock Plus">
+<!ENTITY menuitem.accesskey "P">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: elementos bloqueables">
+<!ENTITY context.image.label "Adblock Plus: bloquear imagen">
+<!ENTITY context.object.label "Adblock Plus: bloquear objeto">
+<!ENTITY context.frame.label "Adblock Plus: bloquear marco">
+<!ENTITY context.media.label "Adblock Plus: Bloquear audio/video">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: rehabilitar en esta página">
+<!ENTITY sidebar.title "Elementos bloqueables en la página actual">
+<!ENTITY settings.label "Preferencias">
+<!ENTITY settings.accesskey "P">
+<!ENTITY opensidebar.label "Abrir elementos bloqueables">
+<!ENTITY opensidebar.accesskey "b">
+<!ENTITY closesidebar.label "Cerrar elementos bloqueables">
+<!ENTITY closesidebar.accesskey "b">
+<!ENTITY whitelist.site.label "Deshabilitar en ?1?">
+<!ENTITY whitelist.page.label "Deshabilitar solamente en esta página">
+<!ENTITY objecttab.title "Bloquear">
+<!ENTITY objecttab.tooltip "Clic acá para bloquear este objeto con Adblock Plus">

=== added file 'chrome/locale/es-AR/settings.dtd'
--- chrome/locale/es-AR/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/es-AR/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Preferencias de Adblock Plus">
+<!ENTITY filters.label "Filtros">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Agregar filtro">
+<!ENTITY add.accesskey "A">
+<!ENTITY addsubscription.label "Agregar suscripción de filtros">
+<!ENTITY addsubscription.accesskey "s">
+<!ENTITY synchsubscriptions.label "Actualizar todas las suscripciones">
+<!ENTITY synchsubscriptions.accesskey "c">
+<!ENTITY import.label "Importar filtros">
+<!ENTITY import.accesskey "m">
+<!ENTITY export.label "Exportar filtros personalizados">
+<!ENTITY export.accesskey "x">
+<!ENTITY clearall.label "Quitar todos los filtros personalizados">
+<!ENTITY clearall.accesskey "Q">
+<!ENTITY resethitcounts.label "Restablecer estadísticas de uso">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "Editar">
+<!ENTITY edit.accesskey "E">
+<!ENTITY cut.label "Cortar">
+<!ENTITY cut.accesskey "t">
+<!ENTITY copy.label "Copy">
+<!ENTITY copy.accesskey "C">
+<!ENTITY paste.label "Pegar">
+<!ENTITY paste.accesskey "P">
+<!ENTITY remove.label "Eliminar">
+<!ENTITY remove.accesskey "l">
+<!ENTITY menu.find.label "Buscar">
+<!ENTITY menu.find.accesskey "B">
+<!ENTITY menu.findagain.label "Buscar de nuevo">
+<!ENTITY menu.findagain.accesskey "n">
+<!ENTITY view.label "Ver">
+<!ENTITY view.accesskey "V">
+<!ENTITY sort.label "Ordenar por">
+<!ENTITY sort.accesskey "O">
+<!ENTITY sort.none.label "Desordenar">
+<!ENTITY sort.none.accesskey "D">
+<!ENTITY sort.ascending.label "Ordenar de la &quot;A&quot; a la &quot;Z&quot;">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Ordenar de la &quot;Z&quot; a la &quot;A&quot;">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Opciones">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Habilitar Adblock Plus">
+<!ENTITY enable.accesskey "H">
+<!ENTITY showintoolbar.label "Mostrar en la barra de herramientas">
+<!ENTITY showintoolbar.accesskey "h">
+<!ENTITY showinstatusbar.label "Mostrar en la barra de estado">
+<!ENTITY showinstatusbar.accesskey "e">
+<!ENTITY objecttabs.label "Mostrar pestañas en Flash y Java">
+<!ENTITY objecttabs.accesskey "p">
+<!ENTITY collapse.label "Colapsar elementos bloqueados">
+<!ENTITY collapse.accesskey "l">
+<!ENTITY help.label "Ayuda">
+<!ENTITY help.accesskey "y">
+<!ENTITY gettingStarted.label "Cómo comenzar (en inglés)">
+<!ENTITY gettingStarted.accesskey "C">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Preguntas frecuentes (en inglés)">
+<!ENTITY faq.accesskey "P">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Escribir filtros de Adblock Plus (en inglés)">
+<!ENTITY filterdoc.accesskey "E">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Acerca de Adblock Plus">
+<!ENTITY about.accesskey "A">
+<!ENTITY description "Los siguientes filtros determinan qué direcciones deberían bloquearse y cuáles deberían permitirse:">
+<!ENTITY filter.column "Regla de filtro">
+<!ENTITY filter.accesskey "f">
+<!ENTITY slow.column "Filtros lentos">
+<!ENTITY slow.accesskey "n">
+<!ENTITY enabled.column "Habilitado">
+<!ENTITY enabled.accesskey "H">
+<!ENTITY hitcount.column "Veces usado">
+<!ENTITY hitcount.accesskey "u">
+<!ENTITY lasthit.column "Última vez usado">
+<!ENTITY lasthit.accesskey "l">
+<!ENTITY context.edit.label "Editar filtro">
+<!ENTITY context.resethitcount.label "Restablecer estadísticas de uso del filtro">
+<!ENTITY context.synchsubscription.label "Actualizar suscripción ahora">
+<!ENTITY context.editsubscription.label "Editar suscripción">
+<!ENTITY context.moveup.label "Subir filtro">
+<!ENTITY context.movedown.label "Bajar filtro">
+<!ENTITY context.movegroupup.label "Subir grupo">
+<!ENTITY context.movegroupdown.label "Bajar grupo">
+<!ENTITY context.enable.label "Habilitar">
+<!ENTITY context.disable.label "Deshabilitar">
+<!ENTITY apply.label "Aplicar">
+<!ENTITY apply.accesskey "p">
+<!ENTITY fennec.subscription.label "Suscripción de filtros">

=== added file 'chrome/locale/es-AR/sidebar.dtd'
--- chrome/locale/es-AR/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/es-AR/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: elementos bloqueables (separados)">
+<!ENTITY detach.label "Separar">
+<!ENTITY reattach.label "Rejuntar">
+<!ENTITY search.label "Buscar:">
+<!ENTITY search.accesskey "B">
+<!ENTITY type.label "Tipo">
+<!ENTITY address.label "Dirección">
+<!ENTITY filter.label "Filtro">
+<!ENTITY state.label "Estado">
+<!ENTITY size.label "Tamaño">
+<!ENTITY docDomain.label "Fuente del documento">
+<!ENTITY noitems.label "Sin elementos bloqueables">
+<!ENTITY whitelisted.label "Página aceptada">
+<!ENTITY tooltip.address.label "Dirección:">
+<!ENTITY tooltip.type.label "Tipo:">
+<!ENTITY tooltip.type.blocked "(bloqueada)">
+<!ENTITY tooltip.type.whitelisted "(aceptada)">
+<!ENTITY tooltip.size.label "Tamaño:">
+<!ENTITY tooltip.docDomain.label "Fuente del documento:">
+<!ENTITY tooltip.filter.label "Filtro en efecto:">
+<!ENTITY tooltip.filterSource.label "Fuente del filtro">
+<!ENTITY context.block.label "Bloquear este elemento">
+<!ENTITY context.editfilter.label "Editar filtro en efecto">
+<!ENTITY context.whitelist.label "Agregar regla de excepción a este elemento">
+<!ENTITY context.disablefilter.label "Deshabilitar filtro ?1?">
+<!ENTITY context.enablefilter.label "Rehabilitar filtro ?1?">
+<!ENTITY context.disablefilteronsite.label "Deshabilitar este filtro en ?1?">
+<!ENTITY context.open.label "Abrir en nueva pestaña">
+<!ENTITY context.flash.label "Bordes de los elementos flash">
+<!ENTITY context.copy.label "Copiar dirección del elemento">
+<!ENTITY context.copyFilter.label "Copiar filtro">
+<!ENTITY context.selectAll.label "Seleccionar todo">

=== added file 'chrome/locale/es-AR/subscriptionSelection.dtd'
--- chrome/locale/es-AR/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/es-AR/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Agregar suscripción de filtro de Adblock Plus">
+<!ENTITY dialog.title.edit "Editar suscripción de filtro">
+<!ENTITY description.newInstall "Para que Adblock Plus sea más efectivo, tendrías que agregar una suscripción de filtros. Estas suscripciones son ofrecidas por otros usuarios de Adblock Plus, gratuitamente. Las suscripciones más adecuadas para tu idioma ya fueron seleccionadas.">
+<!ENTITY adblock.warning "Adblock Plus ha detectado que Adblock, o una versión vieja de Adblock Plus, está instalada. Tener funcionando simultáneamente Adblock y Adblock Plus puede causar problemas y se aconseja evitar esto. Te recomendamos desinstalar el viejo Adblock ahora.">
+<!ENTITY adblock.uninstall "Desinstalar Adblock">
+<!ENTITY filterset.g.warning "Parece que estás usando Filterset.G. Esta lista de filtros ha sido pobremente mantenida en los últimos años y es un constante causante de problemas con los sitios web. Te recomendamos que desinstalés Filterset.G ahora.">
+<!ENTITY filterset.g.moreinfo "Más información (en inglés)">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Desinstalar Filterset.G">
+<!ENTITY subscriptionSelector.label "Por favor, seleccioná una suscripción de la lista:">
+<!ENTITY viewList.label "Ver filtros">
+<!ENTITY visitHomepage.label "Visitar la página oficial">
+<!ENTITY addSubscription.label "Agregar suscripción">
+<!ENTITY saveSubscription.label "Guardar suscripción">
+<!ENTITY other.label "Agregar un filtro de suscripción">
+<!ENTITY other.accesskey "f">
+<!ENTITY list.download.failed "Hubo un error al recuperar la lista de suscripciones.">
+<!ENTITY list.download.retry "Intentá otra vez">
+<!ENTITY list.download.website "Ver sitio web">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Por favor, confirmá que querés agregar esta suscripción de filtros. Podés cambiar el título de la suscripción o la ubicación antes de agregarla.">
+<!ENTITY edit.description "Podés cambiar el título de la suscripción o la ubicación, de ser necesario.">
+<!ENTITY external.description "Esta es una suscripción externa de filtros. La lista de filtros será actualizada por la extensión que creó esta suscripción.">
+<!ENTITY title.label "Título de suscripción:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Ubicación de la lista de filtros:">
+<!ENTITY location.accesskey "U">
+<!ENTITY autodownload.label "Actualizar automáticamente">
+<!ENTITY autodownload.accesskey "A">
+<!ENTITY supplementMessage "Esta suscripción está diseñada para ser usada conjuntamente con la suscripción de filtros &quot;?1?&quot;, que aún no agregaste.">
+<!ENTITY addMain.label "Agregá también la suscripción de filtros &quot;?1?&quot;.">
+<!ENTITY addMain.accesskey "s">

=== modified file 'chrome/locale/es-ES/about.dtd'
--- chrome/locale/es-ES/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/es-ES/about.dtd	2010-05-04 14:45:07 +0000
@@ -8,3 +8,7 @@
 <!ENTITY homepage.url "http://adblockplus.org/">
 <!ENTITY author.label "Autor:">
 <!ENTITY contributors.label "Colaboradores:">
+<!ENTITY developers.label "Desarrolladores:">
+<!ENTITY designers.label "Diseñadores gráficos:">
+<!ENTITY subscriptionAuthors.label "Autores de suscripciones de filtros:">
+<!ENTITY translators.label "Traductores:">

=== modified file 'chrome/locale/es-ES/composer.dtd'
--- chrome/locale/es-ES/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/es-ES/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "Añadir filtro">
 <!ENTITY advanced.label "Vista avanzada">
 <!ENTITY basic.label "Vista básica">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus está desactivado. Puede añadir filtros, pero no se aplicarán a menos que">
-<!ENTITY disabled.warning.link "active Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "El grupo de filtros &quot;&#37;S&quot; al que se va añadir este filtro está desactivado. Puede añadir el filtro, pero éste no se aplicará a menos que">
-<!ENTITY groupDisabled.warning.link "active el grupo de filtros">
-<!ENTITY groupDisabled.warning.afterLink ".">
+<!ENTITY disabled.warning "Adblock Plus está desactivado. Puede añadir filtros, pero no se aplicarán a menos que [link]active Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "El grupo de filtros &quot;?1?&quot; al que se va añadir este filtro está desactivado. Puede añadir el filtro, pero éste no se aplicará a menos que [link]active el grupo de filtros[/link].">
 <!ENTITY filter.label "Nuevo filtro:">
 <!ENTITY filter.accesskey "N">
 <!ENTITY preferences.label "Mostrar filtros existentes...">

=== modified file 'chrome/locale/es-ES/global.properties'
--- chrome/locale/es-ES/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/es-ES/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,13 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=La publicidad es cosa del ayer
-status_active_label=Adblock
-status_disabled_label=Desactivado
+default_dialog_title=Adblock Plus
 action0_tooltip=Pulse para abrir el menú contextual, botón central para activar/desactivar.
 action1_tooltip=Pulse para abrir/cerrar elementos para bloquear, botón central para activar/desactivar.
 action2_tooltip=Pulse para abrir las preferencias, botón central para activar/desactivar.
 action3_tooltip=Pulse para activar/desactivar Adblock Plus.
-active_tooltip=Adblock Plus está activado.
 disabled_tooltip=Adblock Plus está desactivado.
+active_tooltip=Adblock Plus activado, ?1? suscripciones de filtros y ?2? filtros personalizados en uso.
 whitelisted_tooltip=Adblock Plus activado pero deshabilitado en la página actual.
-blocked_count_tooltip=-- de un total de --
+blocked_count_tooltip=?1? de un total de ?2?
+blocked_count_addendum=(en lista blanca: ?1?, ocultos: ?2?)
 no_blocking_suggestions=No hay elementos que se puedan bloquear en la página actual
 whitelisted_page=Se ha deshabilitado Adblock Plus para la página actual
 whitelist_description=Mis reglas de excepción
@@ -16,7 +15,7 @@
 invalid_description=Mis filtros no válidos
 elemhide_description=Mis reglas de ocultación de elementos
 subscription_description=Suscripción de filtros:
-subscription_wrong_version=Algunos filtros de esta suscripción requieren Adblock Plus -- para funcionar correctamente.
+subscription_wrong_version=Algunos filtros de esta suscripción requieren Adblock Plus ?1? para funcionar correctamente.
 subscription_source=Fuente:
 subscription_status=Estado:
 subscription_status_autodownload=Actualizado automáticamente
@@ -26,7 +25,7 @@
 subscription_status_lastdownload_inprogress=Descargando...
 subscription_status_lastdownload_unknown=N/D
 remove_subscription_warning=¿Está seguro de querer eliminar esta suscripción?
-import_filters_wrong_version=Advertencia: algunos de estos filtros de esta lista requieren Adblock Plus -- para funcionar correctamente. Probablemente debería actualizar a la última versión de Adblock Plus antes de importar esta lista.
+import_filters_wrong_version=Advertencia: algunos de estos filtros de esta lista requieren Adblock Plus ?1? para funcionar correctamente. Probablemente debería actualizar a la última versión de Adblock Plus antes de importar esta lista.
 import_filters_warning=¿Desea reemplazar sus filtros actuales, o añadir los nuevos filtros al final de la lista?
 import_filters_title=Importar filtros
 export_filters_title=Exportar filtros
@@ -38,9 +37,9 @@
 filter_regexp_tooltip=Este filtro es una expresión regular o demasiado corto para ser optimizado. Demasiados filtros de este tipo podrían hacer más lenta su navegación.
 filter_elemhide_duplicate_id=Sólo puede especificarse una ID del elemento a ocultar
 filter_elemhide_nocriteria=No se especificó ningún criterio para identificar el elemento a ocultar
-subscription_no_location=Por favor, introduzca una ruta desde donde descargar los filtros.
+subscription_notAdded_warning=No ha añadido ninguna suscripción de filtros. Sin ellas tendrá que ser usted el que añada manualmente filtros a Adblock Plus
+subscription_notAdded_warning_addendum=¿Quiere continuar?
 subscription_invalid_location=La dirección de la lista de filtros no es una URL ni una ruta de archivo válida.
-subscription_location_exists=Ya está suscrito a esta lista de filtros.
 synchronize_invalid_url=Error: no es una dirección válida
 synchronize_connection_error=Error: error de descarga
 synchronize_invalid_data=Error: lista de filtros no válida
@@ -65,3 +64,7 @@
 type_label_dtd=DTD
 type_label_media=audio/vídeo
 type_label_font=fuente
+fennec_status_enabled=Adblock Plus está activado.
+fennec_status_disabled=Adblock Plus está desactivado.
+fennec_status_enabled_site=Adblock Plus está activado en ?1?.
+fennec_status_disabled_site=Adblock Plus está desactivado en ?1?.

=== added file 'chrome/locale/es-ES/meta.properties'
--- chrome/locale/es-ES/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/es-ES/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Urko
+name=Adblock Plus
+description=La publicidad es cosa del ayer
+description.short=¿Le molestan los anuncios, los banners, que espíen su navegación? Instale Adblock Plus para recuperar el control de Internet y cambie la forma en la que ve la web.\n\nVea un vídeo explicativo (en inglés) en http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus le permite recuperar el control de Internet y ver la web como usted quiera. Esta extensión está apoyada por más de cuarenta suscripciones de filtros en docenas de idiomas que la configuran automáticamente para poder desde eliminar la publicidad online hasta bloquear todos los dominios de malware conocidos. Adblock Plus también le permite personalizar sus filtros con la ayuda de varias funciones útiles, como la opción del menú contextual para imágenes, la pestaña de bloqueo de objetos Flash y Java, y una lista de elementos bloqueables para eliminar scripts y hojas de estilo.

=== modified file 'chrome/locale/es-ES/overlay.dtd'
--- chrome/locale/es-ES/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/es-ES/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -8,6 +8,7 @@
 <!ENTITY context.image.label "ABP - Bloquear imagen">
 <!ENTITY context.object.label "ABP - Bloquear objeto">
 <!ENTITY context.frame.label "ABP - Bloquear marco">
+<!ENTITY context.media.label "ABP - Bloquear vídeo/audio">
 <!ENTITY context.removeWhitelist.label "ABP - Reactivar en esta página">
 <!ENTITY sidebar.title "Elementos bloqueables en la página actual">
 <!ENTITY settings.label "Preferencias">
@@ -16,7 +17,7 @@
 <!ENTITY opensidebar.accesskey "v">
 <!ENTITY closesidebar.label "Cerrar ventana elementos bloqueables">
 <!ENTITY closesidebar.accesskey "v">
-<!ENTITY whitelist.site.label "Desactivar en --">
+<!ENTITY whitelist.site.label "Desactivar en ?1?">
 <!ENTITY whitelist.page.label "Deshabilitar sólo en esta página">
 <!ENTITY objecttab.title "Bloquear">
 <!ENTITY objecttab.tooltip "Pulse aquí para bloquear este objeto con Adblock Plus">

=== modified file 'chrome/locale/es-ES/settings.dtd'
--- chrome/locale/es-ES/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/es-ES/settings.dtd	2010-05-04 14:45:07 +0000
@@ -87,3 +87,4 @@
 <!ENTITY context.disable.label "Desactivar">
 <!ENTITY apply.label "Aplicar">
 <!ENTITY apply.accesskey "p">
+<!ENTITY fennec.subscription.label "Suscripción de filtros">

=== modified file 'chrome/locale/es-ES/sidebar.dtd'
--- chrome/locale/es-ES/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/es-ES/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "Bloquear este elemento">
 <!ENTITY context.editfilter.label "Editar el filtro en uso">
 <!ENTITY context.whitelist.label "Añadir regla de excepción para el elemento">
-<!ENTITY context.disablefilter.label "Desactivar filtro --">
-<!ENTITY context.enablefilter.label "Reactivar filtro --">
-<!ENTITY context.disablefilteronsite.label "Desactivar este filtro en --">
+<!ENTITY context.disablefilter.label "Desactivar filtro ?1?">
+<!ENTITY context.enablefilter.label "Reactivar filtro ?1?">
+<!ENTITY context.disablefilteronsite.label "Desactivar este filtro en ?1?">
 <!ENTITY context.open.label "Abrir en nueva pestaña">
 <!ENTITY context.flash.label "Resaltar los bordes del elemento">
 <!ENTITY context.copy.label "Copiar la dirección del elemento">

=== removed file 'chrome/locale/es-ES/subscription.dtd'
--- chrome/locale/es-ES/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/es-ES/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,20 +0,0 @@
-<!ENTITY dialog.title "Editar suscripción de filtros">
-<!ENTITY dialog.newtitle "Añadir suscripción de filtros">
-<!ENTITY new.description "Por favor, introduzca la dirección web o el archivo que 
-	contenga la lista de filtros de AdblockPlus.">
-<!ENTITY edit.description "La lista de filtros para esta suscripción se descargará 
-	desde esa dirección.">
-<!ENTITY external.description "Esta es una suscripción de filtros externa. Su lista de filtros 
-	será actualizada por la misma extensión que la creó.">
-<!ENTITY autodownload.description "Si elige &apos;Actualizar automáticamente&apos; se comprobarán a diario 
-	las actualizaciones en esa dirección. Si desactiva la opción, 
-	aún puede realizar actualizaciones manuales desde el menú 
-	contextual de suscripciones.">
-<!ENTITY location.label "Ubicación de lista de filtros:">
-<!ENTITY location.accesskey "U">
-<!ENTITY title.label "Título de la suscripción:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Actualizar automáticamente">
-<!ENTITY autodownload.accesskey "z">
-<!ENTITY enabled.label "Activar filtros">
-<!ENTITY enabled.accesskey "A">

=== added file 'chrome/locale/es-ES/subscriptionSelection.dtd'
--- chrome/locale/es-ES/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/es-ES/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,36 @@
+<!ENTITY dialog.title "Añadir suscripción de filtros para Adblock Plus">
+<!ENTITY dialog.title.edit "Editar suscripción de filtros">
+<!ENTITY description.newInstall "Para conseguir la máxima eficacia de Adblock Plus debería añadir una suscripción de filtros. Estas suscripciones son elaboradas por usuarios de Adblock Plus sin ninguna contraprestación económica. Se han resaltado las suscripciones que puedan ser más adecuadas para su idioma.">
+<!ENTITY adblock.warning "Adblock Plus ha detectado que está instalado Adblock o una versión antigua de 
+Adblock Plus. Utilizar Adblock y Adblock Plus de forma simultánea puede causar
+problemas y está totalmente desaconsejado. Le recomendamos que desinstale Adblock ahora.">
+<!ENTITY adblock.uninstall "Desinstalar Adblock">
+<!ENTITY filterset.g.warning "Parece que usted utiliza Filterset.G. Esta lista de filtros apenas ha 
+tenido mantenimiento en los últimos años y suele causar problemas con
+diversos sitios web. Le recomendamos que desinstale Filterset.G ahora.">
+<!ENTITY filterset.g.moreinfo "Más información">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Desinstalar Filterset.G">
+<!ENTITY subscriptionSelector.label "Por favor elija una suscripción de filtros de la lista:">
+<!ENTITY viewList.label "Ver filtros">
+<!ENTITY visitHomepage.label "Visitar su página web">
+<!ENTITY addSubscription.label "Añadir suscripción">
+<!ENTITY saveSubscription.label "Guardar suscripción">
+<!ENTITY other.label "Añadir otra suscripción">
+<!ENTITY other.accesskey "o">
+<!ENTITY list.download.failed "Error al recuperar la lista de suscripciones.">
+<!ENTITY list.download.retry "Intentar de nuevo">
+<!ENTITY list.download.website "Ver página web">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Por favor, confirme que quiere añadir está suscripción de filtros. Puede cambiar su título o ubicación antes de añadirla.">
+<!ENTITY edit.description "Puede cambiar el título o ubicación de la suscripción si lo necesita.">
+<!ENTITY external.description "Se trata de una suscripción externa, la lista de filtros será actualizada por la extensión que creó la suscripción.">
+<!ENTITY title.label "Título de la suscripción:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Ubicación de la lista de filtros:">
+<!ENTITY location.accesskey "U">
+<!ENTITY autodownload.label "Actualizar automáticamente">
+<!ENTITY autodownload.accesskey "z">
+<!ENTITY supplementMessage "Esta suscripción de filtros está pensada para usarse junto a la suscripción &quot;?1?&quot; que usted aún no ha instalado.">
+<!ENTITY addMain.label "Añadir también la suscripción &quot;?1?&quot;.">
+<!ENTITY addMain.accesskey "ñ">

=== removed file 'chrome/locale/es-ES/tip_subscriptions.dtd'
--- chrome/locale/es-ES/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/es-ES/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY dialog.title "Añadir suscripción de filtros para Adblock Plus">
-<!ENTITY description.par1 "Gracias por instalar Adblock Plus. Este complemento puede
-	eliminar el 99&#37; de los anuncios que ve en la web. Sin 
-	embargo, para filtrar eficazmente los anuncios tiene que
-	definir unos buenos filtros. Puede hacerlo usted mismo, 
-	o puede suscribirse simplemente a las listas de filtros 
-	que otros mantienen para usted. Y seguirá pudiendo añadir 
-	sus propios filtros o desactivar/eliminar las suscripciones 
-	siempre que lo desee.">
-<!ENTITY description.par2 "Puede elegir una suscripción de la lista de suscripciones 
-	recomendadas más abajo (puede añadir posteriormente otras 
-	suscripciones en la ventana de Preferencias de Adblock Plus, 
-	aunque no suele ser necesario):">
-<!ENTITY note "Nota: Una lista de filtros suele ser más eficaz cuando se aplica 
-	a sitios web de la región para la que ha sido desarrollada.">
-<!ENTITY adblock.warning "Adblock Plus ha detectado que está instalado Adblock o una versión antigua de 
-Adblock Plus. Utilizar Adblock y Adblock Plus de forma simultánea puede causar
-problemas y está totalmente desaconsejado. Le recomendamos que desinstale Adblock ahora.">
-<!ENTITY adblock.uninstall "Desinstalar Adblock">
-<!ENTITY filterset.g.warning "Parece que usted utiliza Filterset.G. Esta lista de filtros apenas ha 
-tenido mantenimiento en los últimos años y suele causar problemas con
-diversos sitios web. Le recomendamos que desinstale Filterset.G ahora.">
-<!ENTITY filterset.g.moreinfo "Más información">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Desinstalar Filterset.G">
-<!ENTITY homepage.label "Página de inicio">
-<!ENTITY subscribe.label "Suscribir">
-<!ENTITY subscribe.accesskey "S">
-<!ENTITY other.label "Añadir otra suscripción">
-<!ENTITY other.accesskey "A">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Ver todas las suscripciones">

=== added directory 'chrome/locale/et'
=== removed directory 'chrome/locale/et-EE'
=== removed file 'chrome/locale/et-EE/about.dtd'
--- chrome/locale/et-EE/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/et-EE/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-<!ENTITY dialog.title "Adblock Plusist">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Versioon">
-<!ENTITY description "Adblock Plus lubab sul otsustada, mida sa tahad internetis näha ning 
-kui soovid Internetis liigelda reklaamivabalt, siis räägi sellest Adblock Plusile!">
-<!ENTITY homepage.label "Adblock Plusi koduleht:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Autor:">
-<!ENTITY contributors.label "Kaastöötajad:">

=== removed file 'chrome/locale/et-EE/composer.dtd'
--- chrome/locale/et-EE/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/et-EE/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,23 +0,0 @@
-<!ENTITY dialog.title "Lisa Ablock Plusi filtri reeglel">
-<!ENTITY accept.label "Lisa filter">
-<!ENTITY advanced.label "Arenenud vaade">
-<!ENTITY basic.label "Põhivaade">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus on hetkel keelatud, kuid siiski on võimalik lisada filtreid, kuid need ei jõustu kuni Sa">
-<!ENTITY disabled.warning.link "Lubad Adblock Plusi">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Filtrite grupp &quot;&#37;S&quot; that this filter should be added to is currently disabled. You can still add the filter but it will not be applied unless you">
-<!ENTITY groupDisabled.warning.link "luba filtrid">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Uus filter">
-<!ENTITY filter.accesskey "f">
-<!ENTITY preferences.label "Näita olemasolevaid filtreid...">
-<!ENTITY preferences.accesskey "N">
-<!ENTITY type.filter.label "Keela filtri">
-<!ENTITY type.filter.accesskey "K">
-<!ENTITY type.whitelist.label "Erandlik reegel">
-<!ENTITY type.whitelist.accesskey "E">
-<!ENTITY pattern.label "Otsi mustreid">
-<!ENTITY selectAllTypes.label "Vali kõik">
-<!ENTITY unselectAllTypes.label "Vali 0">
-<!ENTITY collapse.yes.label "Jah">
-<!ENTITY collapse.no.label "Ei">

=== removed file 'chrome/locale/et-EE/global.properties'
--- chrome/locale/et-EE/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/et-EE/global.properties	1970-01-01 00:00:00 +0000
@@ -1,59 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Reklaamid on minevik!
-status_active_label=Adblock
-status_disabled_label=Eemaldatud
-action0_tooltip=Vajuta et tuue esile konteksti menüüd, vajuta keskmist hiireklõpsu, et lubada/keelata
-action1_tooltip=Kliki et avada/sulgeda blokeeritavaid objekte, klõpsa keskmist hiirenuppu, et lubada/keelata.
-action2_tooltip=Kliki et avada seaded, klõpsa keskmist hiirenuppu, et lubada/keelata.
-action3_tooltip=Kliki et lubada/keelata Adblock Plusi.
-active_tooltip=Adblock Plus on aktiivne.
-disabled_tooltip=Adblock Plus on kinni.
-whitelisted_tooltip=Adblock plus on aktiivne, kuid kinni praegusel lehel
-blocked_count_tooltip=-
-no_blocking_suggestions=Praegusel lehel pole blokeeritavaid objekte
-whitelisted_page=Adblock Plus on kinni praegusel lehel
-whitelist_description=Erandite reeglid
-filterlist_description=Reklaamide filtrid
-invalid_description=Valed filtrid
-elemhide_description=Elemendi peitmise reeglid
-subscription_description=Filtri tellimus:
-subscription_wrong_version=Mõned filtrid selles tellimuses vajavad Adblock Plussi et töötada korralikult!
-subscription_source=Allikas:
-subscription_status=Staatus:
-subscription_status_autodownload=Automaatselt uuendatud
-subscription_status_manualdownload=Manuaalselt uuendatud
-subscription_status_externaldownload=Väliselt uundatud
-subscription_status_lastdownload=Viimane allalaadimine:
-subscription_status_lastdownload_inprogress=Laeb alla...
-subscription_status_lastdownload_unknown=Pole teada
-remove_subscription_warning=Kas sa tõesti tahad eemaldada selle tellimuse?
-import_filters_wrong_version=Hoiatus. Mõned filtrid, mis on nimekirjas vajavad töötamiseks Adblock Plusi. Sa peaksid Adblock Plusi uuemaks versiooniks uuendama enne selle nimekirja importimist.
-import_filters_warning=Kas sa tahad asendada praegused filtrid või lisada uusi filtreid nimekirja lõppu?
-import_filters_title=Impordi filtreid
-export_filters_title=Ekspordi filtreid
-invalid_filters_file=Vale Adblock Plusi filtri fail.
-filters_write_error=Toimus viga kui kirjutati filtreid faili. Ole kindel et see fail ei ole ainult lugemiseks või ei ole avatud teise programmi poolt.
-clearall_warning=Kas sa tõesti soovid eemaldada kõik filtrid nimekirjast?
-resethitcounts_warning=Kas sa tõesti soovid nullida kõigi filtrite tabamused? Seda ei saa teha olematuks!
-resethitcounts_selected_warning=Kas sa tõesti tahad nullida tabamused valitud filtritel?
-filter_elemhide_duplicate_id=Ainult üks peidetud element võib olla määratud
-subscription_no_location=Palun sisestage asukoha kust filtreid tõmmata.
-subscription_invalid_location=Filtri nimekirja asukoht, URL või failinimi pole õige.
-subscription_location_exists=Sa oled juba tellinud selle filtrite nimekirja
-synchronize_invalid_url=Vale aadress
-synchronize_connection_error=Allalaadimine ebaõnnestus
-synchronize_invalid_data=Viga, pole õige filtrite nimekiri
-synchronize_ok=Edukas
-overwrite=Kirjuta üle
-append=Lisa
-new_filter_group_title=Uus filter
-type_label_other=muu
-type_label_script=skript
-type_label_image=pilt
-type_label_stylesheet=stiilileht
-type_label_object=objekt
-type_label_subdocument=kaader
-type_label_document=dokument
-type_label_background=taust
-type_label_elemhide=peidus
-type_label_dtd=DTD
-type_label_media=heli/video

=== removed file 'chrome/locale/et-EE/overlay.dtd'
--- chrome/locale/et-EE/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/et-EE/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY status.tooltip "Olek:">
-<!ENTITY blocked.tooltip "Blokeeritud objektid sellel lehel:">
-<!ENTITY filters.tooltip "Kõige aktiivsemad filtrid:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "c">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Blokeeritavad objektid">
-<!ENTITY context.image.label "Adblocki Pilt">
-<!ENTITY context.object.label "Adblocki Objekt">
-<!ENTITY context.frame.label "Adblocki Kaader">
-<!ENTITY sidebar.title "Blokeeritavad objektid sellel lehel">
-<!ENTITY settings.label "Seaded">
-<!ENTITY settings.accesskey "S">
-<!ENTITY opensidebar.label "Ava blokeeritavad objektid">
-<!ENTITY opensidebar.accesskey "O">
-<!ENTITY closesidebar.label "Sulge blokeeritavad objektid">
-<!ENTITY closesidebar.accesskey "O">
-<!ENTITY whitelist.site.label "Sulge --">
-<!ENTITY whitelist.page.label "Sulge ainult sellel lehel">
-<!ENTITY objecttab.title "Blokeeri">
-<!ENTITY objecttab.tooltip "Vajuta siia, et blokeerida selle objekti Adblock Plusiga">

=== removed file 'chrome/locale/et-EE/settings.dtd'
--- chrome/locale/et-EE/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/et-EE/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plusi Seaded">
-<!ENTITY filters.label "Filtrid">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Lisa filter">
-<!ENTITY add.accesskey "L">
-<!ENTITY addsubscription.label "Lisa filtri tellimuse">
-<!ENTITY addsubscription.accesskey "t">
-<!ENTITY synchsubscriptions.label "Uuenda kõik tellimused">
-<!ENTITY synchsubscriptions.accesskey "d">
-<!ENTITY import.label "Impordi filtreid">
-<!ENTITY import.accesskey "I">
-<!ENTITY export.label "Ekspordi filreid">
-<!ENTITY export.accesskey "s">
-<!ENTITY clearall.label "Eemalda kõik filtrid">
-<!ENTITY clearall.accesskey "m">
-<!ENTITY resethitcounts.label "Nulli tabamuste statistika">
-<!ENTITY resethitcounts.accesskey "N">
-<!ENTITY edit.label "Muuda">
-<!ENTITY edit.accesskey "d">
-<!ENTITY cut.label "Lõika">
-<!ENTITY cut.accesskey "i">
-<!ENTITY copy.label "Kopeeri">
-<!ENTITY copy.accesskey "r">
-<!ENTITY paste.label "Kleebi">
-<!ENTITY paste.accesskey "b">
-<!ENTITY remove.label "Kustuta">
-<!ENTITY remove.accesskey "t">
-<!ENTITY menu.find.label "Otsi">
-<!ENTITY menu.find.accesskey "O">
-<!ENTITY menu.findagain.label "Otsi uuesti">
-<!ENTITY menu.findagain.accesskey "S">
-<!ENTITY view.label "Vaata">
-<!ENTITY view.accesskey "V">
-<!ENTITY sort.label "Sorteeri">
-<!ENTITY sort.accesskey "S">
-<!ENTITY sort.none.label "Sorteerimata">
-<!ENTITY sort.none.accesskey "e">
-<!ENTITY sort.ascending.label "Sorteeri A-st Z-ni">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Sorteeri Z-st A-ni">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Valikud">
-<!ENTITY options.accesskey "k">
-<!ENTITY enable.label "Võimalda Adblock Plusi">
-<!ENTITY enable.accesskey "P">
-<!ENTITY showintoolbar.label "Näita tööristaribas">
-<!ENTITY showintoolbar.accesskey "ä">
-<!ENTITY showinstatusbar.label "Näita seisundi ribas">
-<!ENTITY showinstatusbar.accesskey "r">
-<!ENTITY objecttabs.label "Näita tabbe Flashis ja Javas">
-<!ENTITY objecttabs.accesskey "J">
-<!ENTITY collapse.label "Sulge blokeeritud elemendid">
-<!ENTITY collapse.accesskey "e">
-<!ENTITY help.label "Abi">
-<!ENTITY help.accesskey "A">
-<!ENTITY gettingStarted.label "info Adblock Plusist">
-<!ENTITY gettingStarted.accesskey "i">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Korduma Kippuvad Küsimused">
-<!ENTITY faq.accesskey "K">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Kirjutamas Adblock Plusi filtreid">
-<!ENTITY filterdoc.accesskey "m">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Teavet">
-<!ENTITY about.accesskey "v">
-<!ENTITY description "Lisa aadresse mida sa soovid blokeerida, soovituseks vaata nimekirja.
-Sa saad kasutada * et luua rohkem üldiseid filtreid. Edasijõudnud kasutajad saavad
-kasutada regulaarseid väljendeid.">
-<!ENTITY filter.column "Filtri reegel">
-<!ENTITY filter.accesskey "F">
-<!ENTITY enabled.column "Lubatud">
-<!ENTITY enabled.accesskey "d">
-<!ENTITY hitcount.column "Tabamusi">
-<!ENTITY hitcount.accesskey "m">
-<!ENTITY lasthit.column "Viimane tabamus">
-<!ENTITY lasthit.accesskey "u">
-<!ENTITY context.edit.label "Muuda filtrit">
-<!ENTITY context.resethitcount.label "Nulli">
-<!ENTITY context.synchsubscription.label "Uuenda tellimust nüüd">
-<!ENTITY context.editsubscription.label "Muuda tellimust">
-<!ENTITY context.moveup.label "Liiguta üles">
-<!ENTITY context.movedown.label "Liiguta alla">
-<!ENTITY context.movegroupup.label "Liiguta grupp üles">
-<!ENTITY context.movegroupdown.label "Liiguta grupp alla">
-<!ENTITY context.enable.label "Luba">
-<!ENTITY context.disable.label "Keela">
-<!ENTITY apply.label "Rakenda">
-<!ENTITY apply.accesskey "R">

=== removed file 'chrome/locale/et-EE/sidebar.dtd'
--- chrome/locale/et-EE/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/et-EE/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,30 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Blokeeritavad objektid (lahtised)">
-<!ENTITY detach.label "Ava">
-<!ENTITY reattach.label "Kinnita">
-<!ENTITY search.label "Otsi:">
-<!ENTITY search.accesskey "S">
-<!ENTITY type.label "Tüüp">
-<!ENTITY address.label "Address">
-<!ENTITY filter.label "Filter">
-<!ENTITY state.label "Seisukord">
-<!ENTITY size.label "Suurus">
-<!ENTITY noitems.label "Blokeeritavaid objekte pole">
-<!ENTITY whitelisted.label "Hea nimekiri">
-<!ENTITY tooltip.address.label "Aadress:">
-<!ENTITY tooltip.type.label "Tüüp:">
-<!ENTITY tooltip.type.blocked "(blokeeritud)">
-<!ENTITY tooltip.type.whitelisted "(valges nimekirjas)">
-<!ENTITY tooltip.size.label "Suurus:">
-<!ENTITY tooltip.filter.label "Filtreid effektis:">
-<!ENTITY tooltip.filterSource.label "Filtri päritolu:">
-<!ENTITY context.block.label "Blokeeri selle objekti">
-<!ENTITY context.editfilter.label "Muuda filtrit efektis">
-<!ENTITY context.whitelist.label "Lisa objektile erandliku reegeli">
-<!ENTITY context.disablefilter.label "Keela filetr">
-<!ENTITY context.enablefilter.label "Luba filter">
-<!ENTITY context.disablefilteronsite.label "Keela filter">
-<!ENTITY context.open.label "Ava uues tabis">
-<!ENTITY context.flash.label "Flashi objekti ääred">
-<!ENTITY context.copy.label "Kopeeri objekti aadress">
-<!ENTITY context.copyFilter.label "Kopeeri filter">
-<!ENTITY context.selectAll.label "Vali kõik">

=== removed file 'chrome/locale/et-EE/subscription.dtd'
--- chrome/locale/et-EE/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/et-EE/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,20 +0,0 @@
-<!ENTITY dialog.title "Muuda filtri tellimust">
-<!ENTITY dialog.newtitle "Lisa filtri tellimust">
-<!ENTITY new.description "Palun sisestage veebiaddress või fail mis sisaldab nimekirja
-Adblock Plusi filtritest.">
-<!ENTITY edit.description "Filtrite nimekiri selle tellimuseks jaoks hakkab alla laadima
-määratud asukohast.">
-<!ENTITY external.description "See on väline filtri tellimus, selle filtrite nimekiri
-hakkab olema uuendatud laienduse tegija poolt kes tegi selle
-tellimuse.">
-<!ENTITY autodownload.description "Kui sa valid &apos;Uuenda automaatselt&apos; siis hakatakse otsima
-uuendusi iga päev. Kui see on kinni, siis sa saad uuendada 
-manuaalselt tellimuse konteksti menüüst.">
-<!ENTITY location.label "Flitri nimekirja asukoht:">
-<!ENTITY location.accesskey "F">
-<!ENTITY title.label "Tellimuse pealkiri:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Uuenda automaatselt">
-<!ENTITY autodownload.accesskey "U">
-<!ENTITY enabled.label "Luba filtreid">
-<!ENTITY enabled.accesskey "L">

=== removed file 'chrome/locale/et-EE/tip_subscriptions.dtd'
--- chrome/locale/et-EE/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/et-EE/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,30 +0,0 @@
-<!ENTITY dialog.title "Lisa reklaamifiltri tellimuse">
-<!ENTITY description.par1 "Täname teid, et installeerisite Adblock Plusi. See laiendus võimaldab 
-eemaldada enamiku reklaamidest, mida Te internetis näete. Kuid
-efektiivne reklaami filtreerimine nõuab hea filtrite
-komplekti olemasolu. Sa võid neid ise valmistada, 
-või valida juba olemasolevatest.
-Ning isegi siis on võimalik lisada enda filtreid või 
-vajadusel deaktiveerida/eemaldada tellimusi.">
-<!ENTITY description.par2 "Sa võid valida ühe tellimuse
-eelistatud tellimuste nimekirjast (rohkem tellimusi on võimalik lisada
-Adblock Plusi Seadetest hiljem, kuid tavaliselt pole see vajalik):">
-<!ENTITY note "Märge: Filtrite nimekiri on tavaliselt kõige efektiivsem, kui see on rakendatud
-internetilehekülgedele, mille regiooni jaoks see filter oli loodud.">
-<!ENTITY adblock.warning "On tuvastatud, et vanem versioon (Adblock) on eelnevalt paigaldatud.
-Kasutades nii Adblock Plusi kui ka Adblocki korraga võib põhjustada probleeme 
-ning Adblocki tuleks eemaldada.">
-<!ENTITY adblock.uninstall "Eemalda Adblock">
-<!ENTITY filterset.g.warning "On tuvastatud, et Te kasutate Filterset.G-d. Kuna seda on viimastel aastatel 
-vähe uuendatud ning on teada, et see põhjustab probleeme internetilehekülgedel, 
-siis on soovitatav selle koheselt eemaldada.">
-<!ENTITY filterset.g.moreinfo "Lisainformatsioon">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Eemalda Filterset.G">
-<!ENTITY homepage.label "Koduleht">
-<!ENTITY subscribe.label "Telli">
-<!ENTITY subscribe.accesskey "T">
-<!ENTITY other.label "Lisa uus tellimus">
-<!ENTITY other.accesskey "L">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Vaata kõiki tellimusi">

=== added file 'chrome/locale/et/.incomplete'
=== added file 'chrome/locale/et/about.dtd'
--- chrome/locale/et/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/et/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,9 @@
+<!ENTITY dialog.title "Adblock Plusist">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versioon">
+<!ENTITY description "Adblock Plus lubab sul otsustada, mida sa tahad internetis näha ning 
+kui soovid Internetis liigelda reklaamivabalt, siis räägi sellest Adblock Plusile!">
+<!ENTITY homepage.label "Adblock Plusi koduleht:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Autor:">
+<!ENTITY contributors.label "Kaastöötajad:">

=== added file 'chrome/locale/et/composer.dtd'
--- chrome/locale/et/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/et/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,19 @@
+<!ENTITY dialog.title "Lisa Ablock Plusi filtri reeglel">
+<!ENTITY accept.label "Lisa filter">
+<!ENTITY advanced.label "Arenenud vaade">
+<!ENTITY basic.label "Põhivaade">
+<!ENTITY disabled.warning "Adblock Plus on hetkel keelatud, kuid siiski on võimalik lisada filtreid, kuid need ei jõustu kuni Sa [link]Lubad Adblock Plusi[/link].">
+<!ENTITY groupDisabled.warning "Filtrite grupp &quot;?1?&quot; that this filter should be added to is currently disabled. You can still add the filter but it will not be applied unless you [link]luba filtrid[/link].">
+<!ENTITY filter.label "Uus filter">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "Näita olemasolevaid filtreid...">
+<!ENTITY preferences.accesskey "N">
+<!ENTITY type.filter.label "Keela filtri">
+<!ENTITY type.filter.accesskey "K">
+<!ENTITY type.whitelist.label "Erandlik reegel">
+<!ENTITY type.whitelist.accesskey "E">
+<!ENTITY pattern.label "Otsi mustreid">
+<!ENTITY selectAllTypes.label "Vali kõik">
+<!ENTITY unselectAllTypes.label "Vali 0">
+<!ENTITY collapse.yes.label "Jah">
+<!ENTITY collapse.no.label "Ei">

=== added file 'chrome/locale/et/global.properties'
--- chrome/locale/et/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/et/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,50 @@
+action0_tooltip=Vajuta et tuue esile konteksti menüüd, vajuta keskmist hiireklõpsu, et lubada/keelata
+action1_tooltip=Kliki et avada/sulgeda blokeeritavaid objekte, klõpsa keskmist hiirenuppu, et lubada/keelata.
+action2_tooltip=Kliki et avada seaded, klõpsa keskmist hiirenuppu, et lubada/keelata.
+action3_tooltip=Kliki et lubada/keelata Adblock Plusi.
+disabled_tooltip=Adblock Plus on kinni.
+whitelisted_tooltip=Adblock plus on aktiivne, kuid kinni praegusel lehel
+no_blocking_suggestions=Praegusel lehel pole blokeeritavaid objekte
+whitelisted_page=Adblock Plus on kinni praegusel lehel
+whitelist_description=Erandite reeglid
+filterlist_description=Reklaamide filtrid
+invalid_description=Valed filtrid
+elemhide_description=Elemendi peitmise reeglid
+subscription_description=Filtri tellimus:
+subscription_source=Allikas:
+subscription_status=Staatus:
+subscription_status_autodownload=Automaatselt uuendatud
+subscription_status_manualdownload=Manuaalselt uuendatud
+subscription_status_externaldownload=Väliselt uundatud
+subscription_status_lastdownload=Viimane allalaadimine:
+subscription_status_lastdownload_inprogress=Laeb alla...
+subscription_status_lastdownload_unknown=Pole teada
+remove_subscription_warning=Kas sa tõesti tahad eemaldada selle tellimuse?
+import_filters_warning=Kas sa tahad asendada praegused filtrid või lisada uusi filtreid nimekirja lõppu?
+import_filters_title=Impordi filtreid
+export_filters_title=Ekspordi filtreid
+invalid_filters_file=Vale Adblock Plusi filtri fail.
+filters_write_error=Toimus viga kui kirjutati filtreid faili. Ole kindel et see fail ei ole ainult lugemiseks või ei ole avatud teise programmi poolt.
+clearall_warning=Kas sa tõesti soovid eemaldada kõik filtrid nimekirjast?
+resethitcounts_warning=Kas sa tõesti soovid nullida kõigi filtrite tabamused? Seda ei saa teha olematuks!
+resethitcounts_selected_warning=Kas sa tõesti tahad nullida tabamused valitud filtritel?
+filter_elemhide_duplicate_id=Ainult üks peidetud element võib olla määratud
+subscription_invalid_location=Filtri nimekirja asukoht, URL või failinimi pole õige.
+synchronize_invalid_url=Vale aadress
+synchronize_connection_error=Allalaadimine ebaõnnestus
+synchronize_invalid_data=Viga, pole õige filtrite nimekiri
+synchronize_ok=Edukas
+overwrite=Kirjuta üle
+append=Lisa
+new_filter_group_title=Uus filter
+type_label_other=muu
+type_label_script=skript
+type_label_image=pilt
+type_label_stylesheet=stiilileht
+type_label_object=objekt
+type_label_subdocument=kaader
+type_label_document=dokument
+type_label_background=taust
+type_label_elemhide=peidus
+type_label_dtd=DTD
+type_label_media=heli/video

=== added file 'chrome/locale/et/meta.properties'
--- chrome/locale/et/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/et/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=Reklaamid on minevik!

=== added file 'chrome/locale/et/overlay.dtd'
--- chrome/locale/et/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/et/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,21 @@
+<!ENTITY status.tooltip "Olek:">
+<!ENTITY blocked.tooltip "Blokeeritud objektid sellel lehel:">
+<!ENTITY filters.tooltip "Kõige aktiivsemad filtrid:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "c">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Blokeeritavad objektid">
+<!ENTITY context.image.label "Adblocki Pilt">
+<!ENTITY context.object.label "Adblocki Objekt">
+<!ENTITY context.frame.label "Adblocki Kaader">
+<!ENTITY sidebar.title "Blokeeritavad objektid sellel lehel">
+<!ENTITY settings.label "Seaded">
+<!ENTITY settings.accesskey "S">
+<!ENTITY opensidebar.label "Ava blokeeritavad objektid">
+<!ENTITY opensidebar.accesskey "O">
+<!ENTITY closesidebar.label "Sulge blokeeritavad objektid">
+<!ENTITY closesidebar.accesskey "O">
+<!ENTITY whitelist.site.label "Sulge ?1?">
+<!ENTITY whitelist.page.label "Sulge ainult sellel lehel">
+<!ENTITY objecttab.title "Blokeeri">
+<!ENTITY objecttab.tooltip "Vajuta siia, et blokeerida selle objekti Adblock Plusiga">

=== added file 'chrome/locale/et/settings.dtd'
--- chrome/locale/et/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/et/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,89 @@
+<!ENTITY dialog.title "Adblock Plusi Seaded">
+<!ENTITY filters.label "Filtrid">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Lisa filter">
+<!ENTITY add.accesskey "L">
+<!ENTITY addsubscription.label "Lisa filtri tellimuse">
+<!ENTITY addsubscription.accesskey "t">
+<!ENTITY synchsubscriptions.label "Uuenda kõik tellimused">
+<!ENTITY synchsubscriptions.accesskey "d">
+<!ENTITY import.label "Impordi filtreid">
+<!ENTITY import.accesskey "I">
+<!ENTITY export.label "Ekspordi filreid">
+<!ENTITY export.accesskey "s">
+<!ENTITY clearall.label "Eemalda kõik filtrid">
+<!ENTITY clearall.accesskey "m">
+<!ENTITY resethitcounts.label "Nulli tabamuste statistika">
+<!ENTITY resethitcounts.accesskey "N">
+<!ENTITY edit.label "Muuda">
+<!ENTITY edit.accesskey "d">
+<!ENTITY cut.label "Lõika">
+<!ENTITY cut.accesskey "i">
+<!ENTITY copy.label "Kopeeri">
+<!ENTITY copy.accesskey "r">
+<!ENTITY paste.label "Kleebi">
+<!ENTITY paste.accesskey "b">
+<!ENTITY remove.label "Kustuta">
+<!ENTITY remove.accesskey "t">
+<!ENTITY menu.find.label "Otsi">
+<!ENTITY menu.find.accesskey "O">
+<!ENTITY menu.findagain.label "Otsi uuesti">
+<!ENTITY menu.findagain.accesskey "S">
+<!ENTITY view.label "Vaata">
+<!ENTITY view.accesskey "V">
+<!ENTITY sort.label "Sorteeri">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "Sorteerimata">
+<!ENTITY sort.none.accesskey "e">
+<!ENTITY sort.ascending.label "Sorteeri A-st Z-ni">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Sorteeri Z-st A-ni">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Valikud">
+<!ENTITY options.accesskey "k">
+<!ENTITY enable.label "Võimalda Adblock Plusi">
+<!ENTITY enable.accesskey "P">
+<!ENTITY showintoolbar.label "Näita tööristaribas">
+<!ENTITY showintoolbar.accesskey "ä">
+<!ENTITY showinstatusbar.label "Näita seisundi ribas">
+<!ENTITY showinstatusbar.accesskey "r">
+<!ENTITY objecttabs.label "Näita tabbe Flashis ja Javas">
+<!ENTITY objecttabs.accesskey "J">
+<!ENTITY collapse.label "Sulge blokeeritud elemendid">
+<!ENTITY collapse.accesskey "e">
+<!ENTITY help.label "Abi">
+<!ENTITY help.accesskey "A">
+<!ENTITY gettingStarted.label "info Adblock Plusist">
+<!ENTITY gettingStarted.accesskey "i">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Korduma Kippuvad Küsimused">
+<!ENTITY faq.accesskey "K">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Kirjutamas Adblock Plusi filtreid">
+<!ENTITY filterdoc.accesskey "m">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Teavet">
+<!ENTITY about.accesskey "v">
+<!ENTITY description "Lisa aadresse mida sa soovid blokeerida, soovituseks vaata nimekirja.
+Sa saad kasutada * et luua rohkem üldiseid filtreid. Edasijõudnud kasutajad saavad
+kasutada regulaarseid väljendeid.">
+<!ENTITY filter.column "Filtri reegel">
+<!ENTITY filter.accesskey "F">
+<!ENTITY enabled.column "Lubatud">
+<!ENTITY enabled.accesskey "d">
+<!ENTITY hitcount.column "Tabamusi">
+<!ENTITY hitcount.accesskey "m">
+<!ENTITY lasthit.column "Viimane tabamus">
+<!ENTITY lasthit.accesskey "u">
+<!ENTITY context.edit.label "Muuda filtrit">
+<!ENTITY context.resethitcount.label "Nulli">
+<!ENTITY context.synchsubscription.label "Uuenda tellimust nüüd">
+<!ENTITY context.editsubscription.label "Muuda tellimust">
+<!ENTITY context.moveup.label "Liiguta üles">
+<!ENTITY context.movedown.label "Liiguta alla">
+<!ENTITY context.movegroupup.label "Liiguta grupp üles">
+<!ENTITY context.movegroupdown.label "Liiguta grupp alla">
+<!ENTITY context.enable.label "Luba">
+<!ENTITY context.disable.label "Keela">
+<!ENTITY apply.label "Rakenda">
+<!ENTITY apply.accesskey "R">

=== added file 'chrome/locale/et/sidebar.dtd'
--- chrome/locale/et/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/et/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,27 @@
+<!ENTITY detached.title "Adblock Plus: Blokeeritavad objektid (lahtised)">
+<!ENTITY detach.label "Ava">
+<!ENTITY reattach.label "Kinnita">
+<!ENTITY search.label "Otsi:">
+<!ENTITY search.accesskey "S">
+<!ENTITY type.label "Tüüp">
+<!ENTITY address.label "Address">
+<!ENTITY filter.label "Filter">
+<!ENTITY state.label "Seisukord">
+<!ENTITY size.label "Suurus">
+<!ENTITY noitems.label "Blokeeritavaid objekte pole">
+<!ENTITY whitelisted.label "Hea nimekiri">
+<!ENTITY tooltip.address.label "Aadress:">
+<!ENTITY tooltip.type.label "Tüüp:">
+<!ENTITY tooltip.type.blocked "(blokeeritud)">
+<!ENTITY tooltip.type.whitelisted "(valges nimekirjas)">
+<!ENTITY tooltip.size.label "Suurus:">
+<!ENTITY tooltip.filter.label "Filtreid effektis:">
+<!ENTITY tooltip.filterSource.label "Filtri päritolu:">
+<!ENTITY context.block.label "Blokeeri selle objekti">
+<!ENTITY context.editfilter.label "Muuda filtrit efektis">
+<!ENTITY context.whitelist.label "Lisa objektile erandliku reegeli">
+<!ENTITY context.open.label "Ava uues tabis">
+<!ENTITY context.flash.label "Flashi objekti ääred">
+<!ENTITY context.copy.label "Kopeeri objekti aadress">
+<!ENTITY context.copyFilter.label "Kopeeri filter">
+<!ENTITY context.selectAll.label "Vali kõik">

=== added file 'chrome/locale/et/subscriptionSelection.dtd'
--- chrome/locale/et/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/et/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,20 @@
+<!ENTITY dialog.title "Lisa reklaamifiltri tellimuse">
+<!ENTITY dialog.title.edit "Muuda filtri tellimust">
+<!ENTITY adblock.warning "On tuvastatud, et vanem versioon (Adblock) on eelnevalt paigaldatud.
+Kasutades nii Adblock Plusi kui ka Adblocki korraga võib põhjustada probleeme 
+ning Adblocki tuleks eemaldada.">
+<!ENTITY adblock.uninstall "Eemalda Adblock">
+<!ENTITY filterset.g.warning "On tuvastatud, et Te kasutate Filterset.G-d. Kuna seda on viimastel aastatel 
+vähe uuendatud ning on teada, et see põhjustab probleeme internetilehekülgedel, 
+siis on soovitatav selle koheselt eemaldada.">
+<!ENTITY filterset.g.moreinfo "Lisainformatsioon">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Eemalda Filterset.G">
+<!ENTITY other.label "Lisa uus tellimus">
+<!ENTITY other.accesskey "L">
+<!ENTITY title.label "Tellimuse pealkiri:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Flitri nimekirja asukoht:">
+<!ENTITY location.accesskey "F">
+<!ENTITY autodownload.label "Uuenda automaatselt">
+<!ENTITY autodownload.accesskey "U">

=== added directory 'chrome/locale/eu'
=== removed directory 'chrome/locale/eu-ES'
=== removed file 'chrome/locale/eu-ES/.incomplete'
=== removed file 'chrome/locale/eu-ES/about.dtd'
--- chrome/locale/eu-ES/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/eu-ES/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,7 +0,0 @@
-<!ENTITY dialog.title "Adblock Plusi buruz">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Bertsioa">
-<!ENTITY description "Adblock Plusek uzten dizu erabakitez zer ikusi nahi ez duzuna web-ean. Ez daukazu behera kargatu beharko iragarki gehiagorik, baldin eta ez nahi badituzu - esaiozu Adblock Plus-i!">
-<!ENTITY homepage.label "Adblock Plus-aren web orria:">
-<!ENTITY author.label "Egilea:">
-<!ENTITY contributors.label "Partaideak:">

=== removed file 'chrome/locale/eu-ES/composer.dtd'
=== removed file 'chrome/locale/eu-ES/global.properties'
--- chrome/locale/eu-ES/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/eu-ES/global.properties	1970-01-01 00:00:00 +0000
@@ -1,25 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Iragarkiak atzoko gauza dira!
-status_active_label=Adblock
-status_disabled_label=Ezgaituta
-no_blocking_suggestions=Ez daude elementu blokeagarririk uneko orrian
-whitelisted_page=Adblock Plus ezgaitu egin da uneko orrirako
-whitelist_description=Salbuespen arauak
-filterlist_description=Iragarki iragazakiak
-invalid_description=Baliogabeko iragazkiak
-elemhide_description=Elementuak ezkutatzeko arauak
-subscription_description=Iragazki harpidetza:
-subscription_source=Jatorria:
-subscription_status=Egoera:
-subscription_status_autodownload=Eguneratu automatikoki
-subscription_status_manualdownload=Eskuz eguneratua
-subscription_status_externaldownload=Kanpotik eguneratua (beste gehigarri batek)
-subscription_status_lastdownload=Azkeneko behera kargatzea:
-subscription_status_lastdownload_inprogress=Behera kargatzen...
-remove_subscription_warning=Ziur al zaude harpidetza hau ezabatu nahi duzula?
-import_filters_warning=Uneko iragazkiak ordeztu edo iragazki berriak zerrendaren bukaeran erantsi nahi dituzu?
-import_filters_title=Inportatu iragazkiak
-export_filters_title=Esportatu iragazkiak
-invalid_filters_file=Ez da Adblock Plus iragazki fitxategi baliogarria.
-filters_write_error=Errore bat egon da iragazkiak fitxategian idazterakoan. Ziurtatu fitxategia ez daukala idazketaren kontrako babesik edo beste programa batek hartuta ez daukala.
-clearall_warning=Ziur al zaude iragazki guztiak kendu nahi dituzula zerrendatik?
-type_label_object=objektua

=== removed file 'chrome/locale/eu-ES/overlay.dtd'
--- chrome/locale/eu-ES/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/eu-ES/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,10 +0,0 @@
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY context.image.label "Adblock Irudia">
-<!ENTITY context.object.label "Adblock Objektu">
-<!ENTITY context.frame.label "Adblock Markoa">
-<!ENTITY sidebar.title "Elementu blokeagarriak uneko orrialdean">
-<!ENTITY settings.label "Lehentasunak">
-<!ENTITY opensidebar.label "Ireki elementu blokeagarriak">
-<!ENTITY closesidebar.label "Itxi elementu blokeagarriak">
-<!ENTITY whitelist.site.label "Ezgaitu --">
-<!ENTITY whitelist.page.label "Ezgaitu orri honetan soilik">

=== removed file 'chrome/locale/eu-ES/settings.dtd'
--- chrome/locale/eu-ES/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/eu-ES/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,37 +0,0 @@
-<!ENTITY filters.label "Iragazkiak">
-<!ENTITY filters.accesskey "I">
-<!ENTITY add.label "Gehitu iragazkia">
-<!ENTITY import.label "Iragazkiak inportatu">
-<!ENTITY import.accesskey "n">
-<!ENTITY clearall.label "Kendu iragazki guztiak">
-<!ENTITY clearall.accesskey "K">
-<!ENTITY cut.label "Moztu">
-<!ENTITY cut.accesskey "M">
-<!ENTITY copy.label "Kopiatu">
-<!ENTITY copy.accesskey "K">
-<!ENTITY paste.label "Itsatsi">
-<!ENTITY paste.accesskey "I">
-<!ENTITY remove.label "Ezabatu">
-<!ENTITY remove.accesskey "E">
-<!ENTITY menu.find.label "Bilatu">
-<!ENTITY menu.find.accesskey "B">
-<!ENTITY menu.findagain.label "Berriro Bilatu">
-<!ENTITY options.label "Aukerak">
-<!ENTITY options.accesskey "A">
-<!ENTITY enable.label "Gaitu Adblock Plus">
-<!ENTITY showintoolbar.label "Erakutsi tresna-barran">
-<!ENTITY showintoolbar.accesskey "T">
-<!ENTITY showinstatusbar.label "Erakutsi egoera-barran">
-<!ENTITY objecttabs.label "Erakutsi fitxak Flash eta Javan">
-<!ENTITY collapse.label "Tolestu blokeatutako elementuak">
-<!ENTITY help.label "Laguntza">
-<!ENTITY help.accesskey "L">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY enabled.column "Gaituta">
-<!ENTITY context.edit.label "Editatu iragazkia">
-<!ENTITY context.synchsubscription.label "Eguneratu harpidetza orain">
-<!ENTITY context.editsubscription.label "Editatu harpidetza">
-<!ENTITY context.moveup.label "Eraman gora">
-<!ENTITY context.movedown.label "Eraman behera">
-<!ENTITY context.movegroupup.label "Mugitu taldea gora">
-<!ENTITY context.movegroupdown.label "Mugitu taldea behera">

=== removed file 'chrome/locale/eu-ES/sidebar.dtd'
--- chrome/locale/eu-ES/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/eu-ES/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,13 +0,0 @@
-<!ENTITY search.label "Bilatu:">
-<!ENTITY search.accesskey "B">
-<!ENTITY type.label "Mota">
-<!ENTITY address.label "Helbidea">
-<!ENTITY filter.label "Iragazki">
-<!ENTITY tooltip.address.label "Helbidea:">
-<!ENTITY tooltip.type.label "Mota:">
-<!ENTITY tooltip.type.blocked "(blokeatuta)">
-<!ENTITY context.block.label "Blokeatu elementu hau">
-<!ENTITY context.editfilter.label "Editatu martxan dabilen iragazkia">
-<!ENTITY context.open.label "Fitxa Berrian Ireki">
-<!ENTITY context.flash.label "Flash elementuaren ertzak">
-<!ENTITY context.copy.label "Elementuaren helbidea kopiatu">

=== removed file 'chrome/locale/eu-ES/subscription.dtd'
--- chrome/locale/eu-ES/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/eu-ES/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Editatu iragazki harpidetza">
-<!ENTITY dialog.newtitle "Gehitu iragazki harpidetza">
-<!ENTITY new.description "Mesedez idatzi web-aren helbidea edo Adblock Plus iragazki zerrenda daukan fitxategia.">
-<!ENTITY edit.description "Harpidetza honetarako iragazki-zerrenda behera deskargatuko da emandako kokalekutik.">
-<!ENTITY external.description "Hau urruneko iragazki harpidetza da, bere iragazki zerrenda eguneratua mantenduko da harpideta sortu zuen gehigarriagatik.">
-<!ENTITY title.label "Harpidetza titulua:">
-<!ENTITY autodownload.label "Eguneratu automatikoki">
-<!ENTITY enabled.label "Iragazkiak gaitu">

=== removed file 'chrome/locale/eu-ES/tip_subscriptions.dtd'
=== added file 'chrome/locale/eu/.incomplete'
=== added file 'chrome/locale/eu/about.dtd'
--- chrome/locale/eu/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/eu/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,7 @@
+<!ENTITY dialog.title "Adblock Plusi buruz">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Bertsioa">
+<!ENTITY description "Adblock Plusek uzten dizu erabakitez zer ikusi nahi ez duzuna web-ean. Ez daukazu behera kargatu beharko iragarki gehiagorik, baldin eta ez nahi badituzu - esaiozu Adblock Plus-i!">
+<!ENTITY homepage.label "Adblock Plus-aren web orria:">
+<!ENTITY author.label "Egilea:">
+<!ENTITY contributors.label "Partaideak:">

=== added file 'chrome/locale/eu/global.properties'
--- chrome/locale/eu/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/eu/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,22 @@
+no_blocking_suggestions=Ez daude elementu blokeagarririk uneko orrian
+whitelisted_page=Adblock Plus ezgaitu egin da uneko orrirako
+whitelist_description=Salbuespen arauak
+filterlist_description=Iragarki iragazakiak
+invalid_description=Baliogabeko iragazkiak
+elemhide_description=Elementuak ezkutatzeko arauak
+subscription_description=Iragazki harpidetza:
+subscription_source=Jatorria:
+subscription_status=Egoera:
+subscription_status_autodownload=Eguneratu automatikoki
+subscription_status_manualdownload=Eskuz eguneratua
+subscription_status_externaldownload=Kanpotik eguneratua (beste gehigarri batek)
+subscription_status_lastdownload=Azkeneko behera kargatzea:
+subscription_status_lastdownload_inprogress=Behera kargatzen...
+remove_subscription_warning=Ziur al zaude harpidetza hau ezabatu nahi duzula?
+import_filters_warning=Uneko iragazkiak ordeztu edo iragazki berriak zerrendaren bukaeran erantsi nahi dituzu?
+import_filters_title=Inportatu iragazkiak
+export_filters_title=Esportatu iragazkiak
+invalid_filters_file=Ez da Adblock Plus iragazki fitxategi baliogarria.
+filters_write_error=Errore bat egon da iragazkiak fitxategian idazterakoan. Ziurtatu fitxategia ez daukala idazketaren kontrako babesik edo beste programa batek hartuta ez daukala.
+clearall_warning=Ziur al zaude iragazki guztiak kendu nahi dituzula zerrendatik?
+type_label_object=objektua

=== added file 'chrome/locale/eu/meta.properties'
--- chrome/locale/eu/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/eu/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=Iragarkiak atzoko gauza dira!

=== added file 'chrome/locale/eu/overlay.dtd'
--- chrome/locale/eu/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/eu/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,10 @@
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY context.image.label "Adblock Irudia">
+<!ENTITY context.object.label "Adblock Objektu">
+<!ENTITY context.frame.label "Adblock Markoa">
+<!ENTITY sidebar.title "Elementu blokeagarriak uneko orrialdean">
+<!ENTITY settings.label "Lehentasunak">
+<!ENTITY opensidebar.label "Ireki elementu blokeagarriak">
+<!ENTITY closesidebar.label "Itxi elementu blokeagarriak">
+<!ENTITY whitelist.site.label "Ezgaitu ?1?">
+<!ENTITY whitelist.page.label "Ezgaitu orri honetan soilik">

=== added file 'chrome/locale/eu/settings.dtd'
--- chrome/locale/eu/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/eu/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,37 @@
+<!ENTITY filters.label "Iragazkiak">
+<!ENTITY filters.accesskey "I">
+<!ENTITY add.label "Gehitu iragazkia">
+<!ENTITY import.label "Iragazkiak inportatu">
+<!ENTITY import.accesskey "n">
+<!ENTITY clearall.label "Kendu iragazki guztiak">
+<!ENTITY clearall.accesskey "K">
+<!ENTITY cut.label "Moztu">
+<!ENTITY cut.accesskey "M">
+<!ENTITY copy.label "Kopiatu">
+<!ENTITY copy.accesskey "K">
+<!ENTITY paste.label "Itsatsi">
+<!ENTITY paste.accesskey "I">
+<!ENTITY remove.label "Ezabatu">
+<!ENTITY remove.accesskey "E">
+<!ENTITY menu.find.label "Bilatu">
+<!ENTITY menu.find.accesskey "B">
+<!ENTITY menu.findagain.label "Berriro Bilatu">
+<!ENTITY options.label "Aukerak">
+<!ENTITY options.accesskey "A">
+<!ENTITY enable.label "Gaitu Adblock Plus">
+<!ENTITY showintoolbar.label "Erakutsi tresna-barran">
+<!ENTITY showintoolbar.accesskey "T">
+<!ENTITY showinstatusbar.label "Erakutsi egoera-barran">
+<!ENTITY objecttabs.label "Erakutsi fitxak Flash eta Javan">
+<!ENTITY collapse.label "Tolestu blokeatutako elementuak">
+<!ENTITY help.label "Laguntza">
+<!ENTITY help.accesskey "L">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY enabled.column "Gaituta">
+<!ENTITY context.edit.label "Editatu iragazkia">
+<!ENTITY context.synchsubscription.label "Eguneratu harpidetza orain">
+<!ENTITY context.editsubscription.label "Editatu harpidetza">
+<!ENTITY context.moveup.label "Eraman gora">
+<!ENTITY context.movedown.label "Eraman behera">
+<!ENTITY context.movegroupup.label "Mugitu taldea gora">
+<!ENTITY context.movegroupdown.label "Mugitu taldea behera">

=== added file 'chrome/locale/eu/sidebar.dtd'
--- chrome/locale/eu/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/eu/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,13 @@
+<!ENTITY search.label "Bilatu:">
+<!ENTITY search.accesskey "B">
+<!ENTITY type.label "Mota">
+<!ENTITY address.label "Helbidea">
+<!ENTITY filter.label "Iragazki">
+<!ENTITY tooltip.address.label "Helbidea:">
+<!ENTITY tooltip.type.label "Mota:">
+<!ENTITY tooltip.type.blocked "(blokeatuta)">
+<!ENTITY context.block.label "Blokeatu elementu hau">
+<!ENTITY context.editfilter.label "Editatu martxan dabilen iragazkia">
+<!ENTITY context.open.label "Fitxa Berrian Ireki">
+<!ENTITY context.flash.label "Flash elementuaren ertzak">
+<!ENTITY context.copy.label "Elementuaren helbidea kopiatu">

=== added file 'chrome/locale/eu/subscriptionSelection.dtd'
--- chrome/locale/eu/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/eu/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,3 @@
+<!ENTITY dialog.title.edit "Editatu iragazki harpidetza">
+<!ENTITY title.label "Harpidetza titulua:">
+<!ENTITY autodownload.label "Eguneratu automatikoki">

=== added directory 'chrome/locale/fa'
=== removed directory 'chrome/locale/fa-IR'
=== removed file 'chrome/locale/fa-IR/about.dtd'
--- chrome/locale/fa-IR/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fa-IR/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus درباره">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "نسخه">
-<!ENTITY description "Adblock Plus به شما اجازه برای تصمیم‌گیری در موارد قابل مشاهده در وب را می‌دهد.
-	دیگر لازم نیست که تمام تصویرها و موارد تبلیغاتی را بر خلاف میل شما دریافت شوند٬ این امر را به Adblock Plus واگزار کنید!">
-<!ENTITY homepage.label "صفحه خانگی Adblock Plus:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "نويسنده:">
-<!ENTITY contributors.label "همکاران:">

=== removed file 'chrome/locale/fa-IR/composer.dtd'
=== removed file 'chrome/locale/fa-IR/global.properties'
--- chrome/locale/fa-IR/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/fa-IR/global.properties	1970-01-01 00:00:00 +0000
@@ -1,55 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=تبليغات ديروز بود!
-status_active_label=Adblock
-status_disabled_label=غيرفعال
-action0_tooltip=برای نمایش منو فشار دهید. کلید میانی برای فعال یا غیرفعال کردن.
-action1_tooltip=برای گشودن یا بستن موارد مسدودی را کلیک کنید. کلید میانی برای فعال یا غیرفعال کردن.
-action2_tooltip=برای گشودن تنظیمات کلیک کنید. کلید میانی برای فعال یا غیرفعال کردن.
-action3_tooltip=برای فعال یا غیرفعال‌کردن Adblock Plus کلیک کنید.
-active_tooltip=Adblock Plus فعال است.
-disabled_tooltip=Adblock Plus غيرفعال است.
-whitelisted_tooltip=Adblock Plus فعال است و برای این صفحه غیرفعال شده است.
-blocked_count_tooltip=-- از میان --
-no_blocking_suggestions=موارد مسدودی در این صفحه موجود نیست
-whitelisted_page=Adblock Plus برای صفحه جاری غیرفعال شده است.
-whitelist_description=دستورهای استثنائی
-filterlist_description=فیلترهای تبلیغاتی
-invalid_description=فیلترهای غیرمعتبر
-elemhide_description=دستورهای پنهان‌کننده عنصر
-subscription_description=اشتراک فیلتر:
-subscription_wrong_version=بعضی از فیلترهای این اشتراک برای کارکردن صحیح به Adblock Plus احتیاج دارند!
-subscription_source=منبع:
-subscription_status=وضعيت:
-subscription_status_autodownload=به‌روزرسانی خودکار
-subscription_status_manualdownload=به‌روزرسانی دستی
-subscription_status_externaldownload=به‌روزرسانی غیره (توسط پسوند دیگر)
-subscription_status_lastdownload=آخرین دریافت:
-subscription_status_lastdownload_inprogress=درحال دريافت...
-subscription_status_lastdownload_unknown=نامعین
-remove_subscription_warning=آیا برای حذف اشتراک مطمئن هستید؟
-import_filters_wrong_version=تذکر:بعضی از فیلترهای این اشتراک برای کارکردن صحیح به Adblock Plus احتیاج دارند! شما باید آخرین نسخه Adblock Plus را نصب کنید.
-import_filters_warning=آیا شما مایل به جای‌گذاری فهرست فیلتر هستید یا این فهرست به فهرست کنونی شما اضافه شود؟
-import_filters_title=واردکردن فیلترها
-export_filters_title=خروجی فیلترها
-invalid_filters_file=پرونده مورد نظر برای فهرست فیلترهای Adblock Plus معتبر نیست.
-filters_write_error=در هنگام نوشتن پرونده فیلترها اشکال بوجود آمد. اطمینان خاطر کنید که پرونده مورد نظر توسط برنامه دیگر استفاده نشده و قابل نوشتن باشد.
-clearall_warning=آیا برای حذف تمام فیلترها در این فهرست مطمئن هستید؟
-resethitcounts_warning=آیا شما مایل به بازگشت آمار استفاده فیلتر به صفر هستید؟ این عمل بازگشت‌پذیر نیست.
-resethitcounts_selected_warning=آیا شما مایل به بازگشت آمار استفاده از فیلترهای انتحاب شده به صفر هستید؟ این عمل بازگشت‌پذیر نیست
-subscription_no_location=لطفا مکان واردکردن فیلترها را مشخص کنید.
-subscription_invalid_location=مکان وارد شده برای فهرست فیلترها نامعتبر است.
-subscription_location_exists=شما برای این لیست قبلا مشترک شده‌اید
-synchronize_invalid_url=نشانی نامعتبر بود
-synchronize_connection_error=اشکال در دریافت‌کردن
-synchronize_invalid_data=اشکال در فهرست فیلترها
-synchronize_ok=با موفقيت
-overwrite=جای گذاری
-append=افزودن
-type_label_other=ديگر
-type_label_script=دست‌نوشت
-type_label_image=تصوير
-type_label_stylesheet=استایل‌شیت
-type_label_object=شیء
-type_label_subdocument=قابک
-type_label_document=نوشتار
-type_label_background=زمينه
-type_label_elemhide=پنهان

=== removed file 'chrome/locale/fa-IR/overlay.dtd'
--- chrome/locale/fa-IR/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fa-IR/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-<!ENTITY status.tooltip "وضعيت:">
-<!ENTITY blocked.tooltip "موارد ردشده در اين صفحه:">
-<!ENTITY filters.tooltip "فعالترين فيلترها:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY context.image.label "Adblock تصوير">
-<!ENTITY context.object.label "Adblock Object">
-<!ENTITY context.frame.label "Adblock قابک">
-<!ENTITY sidebar.title "موارد قابل ردکردن در صفحه جاری">
-<!ENTITY settings.label "تنظيمات">
-<!ENTITY settings.accesskey "ن">
-<!ENTITY opensidebar.label "بازکردن موارد قابل ردکردن">
-<!ENTITY opensidebar.accesskey "ق">
-<!ENTITY closesidebar.label "بستن موارد قابل ردکردن">
-<!ENTITY closesidebar.accesskey "ق">
-<!ENTITY whitelist.site.label "غيرفعال در --">
-<!ENTITY whitelist.page.label "غيرفعال فقط در اين صفحه">
-<!ENTITY objecttab.title "مسدود کردن">
-<!ENTITY objecttab.tooltip "جهت مسدود کردن با Adblock Plus اینجا کلیک کنید">

=== removed file 'chrome/locale/fa-IR/settings.dtd'
--- chrome/locale/fa-IR/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fa-IR/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,70 +0,0 @@
-<!ENTITY dialog.title "تنظيمات Adblock Plus">
-<!ENTITY filters.label "فيلترها">
-<!ENTITY filters.accesskey "ه">
-<!ENTITY add.label "افزودن فيلتر">
-<!ENTITY add.accesskey "ز">
-<!ENTITY addsubscription.label "اشتراک فيلتر">
-<!ENTITY addsubscription.accesskey "ش">
-<!ENTITY synchsubscriptions.label "به‌روزرساني اشتراک‌ها">
-<!ENTITY synchsubscriptions.accesskey "ک">
-<!ENTITY import.label "واردکردن فيلترها">
-<!ENTITY import.accesskey "د">
-<!ENTITY export.label "صادرکردن فيلترها">
-<!ENTITY export.accesskey "ف">
-<!ENTITY clearall.label "حذف فيلترها">
-<!ENTITY clearall.accesskey "ح">
-<!ENTITY resethitcounts.label "بازگشت آمار استفاده">
-<!ENTITY resethitcounts.accesskey "س">
-<!ENTITY edit.label "ويرايش">
-<!ENTITY edit.accesskey "ش">
-<!ENTITY cut.label "برش">
-<!ENTITY cut.accesskey "ر">
-<!ENTITY copy.label "رونوشت">
-<!ENTITY copy.accesskey "ش">
-<!ENTITY paste.label "جای گذاری">
-<!ENTITY paste.accesskey "گ">
-<!ENTITY remove.label "حذف">
-<!ENTITY remove.accesskey "ذ">
-<!ENTITY menu.find.label "يافتن">
-<!ENTITY menu.find.accesskey "ف">
-<!ENTITY menu.findagain.label "يافتن مجدد">
-<!ENTITY menu.findagain.accesskey "م">
-<!ENTITY options.label "تنظيمات">
-<!ENTITY options.accesskey "ظ">
-<!ENTITY enable.label "فعال‌کردن Adblock Plus">
-<!ENTITY enable.accesskey "ع">
-<!ENTITY showintoolbar.label "نمايش در نوارابزار">
-<!ENTITY showintoolbar.accesskey "ب">
-<!ENTITY showinstatusbar.label "نمايش در نواروضعيت">
-<!ENTITY showinstatusbar.accesskey "و">
-<!ENTITY objecttabs.label "نمایش برگه در موارد Flash و Java">
-<!ENTITY objecttabs.accesskey "J">
-<!ENTITY collapse.label "نمایش موارد ردشده">
-<!ENTITY collapse.accesskey "م">
-<!ENTITY help.label "راهنما">
-<!ENTITY help.accesskey "ن">
-<!ENTITY faq.label "سوالات طرح شده">
-<!ENTITY faq.accesskey "ش">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "نوشتن فیلترهای Adblock Plus">
-<!ENTITY filterdoc.accesskey "P">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "درباره Adblock Plus">
-<!ENTITY about.accesskey "د">
-<!ENTITY description "برای رد کردن نشانی‌ها٬ آنها را به این فهرست اضافه کنید.
-		برای استفاده از لیست‌های عمومی از ستاره استفاده کنید.
-کاربران پیشرفته می‌توانند از عبارات مرتب استفاده کنند٬ مانند:
-		/banner\d+\.gif$/">
-<!ENTITY enabled.column "فعال‌">
-<!ENTITY hitcount.column "استفاده شده">
-<!ENTITY lasthit.column "آخرين استفاده">
-<!ENTITY context.edit.label "ويرايش فيلتر">
-<!ENTITY context.resethitcount.label "برگشت آمار استفاده">
-<!ENTITY context.synchsubscription.label "به‌روزرساني اشتراک">
-<!ENTITY context.editsubscription.label "ويريش اشتراک">
-<!ENTITY context.moveup.label "بالا‌بردن">
-<!ENTITY context.movedown.label "پائين‌بردن">
-<!ENTITY context.movegroupup.label "بالا‌بردن گروه">
-<!ENTITY context.movegroupdown.label "پائين‌بردن گروه">
-<!ENTITY apply.label "انجام دادن">
-<!ENTITY apply.accesskey "ج">

=== removed file 'chrome/locale/fa-IR/sidebar.dtd'
--- chrome/locale/fa-IR/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fa-IR/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: موارد قابل ردکردن (قطع)">
-<!ENTITY detach.label "قطع کردن">
-<!ENTITY reattach.label "وصل کردن">
-<!ENTITY search.label "يافتن:">
-<!ENTITY search.accesskey "ف">
-<!ENTITY type.label "نوع">
-<!ENTITY address.label "نشانی">
-<!ENTITY filter.label "فيلتر">
-<!ENTITY state.label "وصعيت">
-<!ENTITY noitems.label "موارد قابل ردکردن پيدا نشد">
-<!ENTITY whitelisted.label "صفحه در فهرست سفيد">
-<!ENTITY tooltip.address.label "نشاني:">
-<!ENTITY tooltip.type.label "نوع:">
-<!ENTITY tooltip.type.blocked "(ردشده)">
-<!ENTITY tooltip.type.whitelisted "(در فهرست سفيد)">
-<!ENTITY tooltip.filter.label "فيلتر فعال:">
-<!ENTITY context.block.label "ردکردن اين مورد">
-<!ENTITY context.editfilter.label "ويرايش فيلتر فعال">
-<!ENTITY context.whitelist.label "افزودن قانون استثناء برای اين مورد">
-<!ENTITY context.open.label "گشودن در برگه نو">
-<!ENTITY context.flash.label "قاب مورد فلاش">
-<!ENTITY context.copy.label "رونوشت نشانی مورد">

=== removed file 'chrome/locale/fa-IR/subscription.dtd'
--- chrome/locale/fa-IR/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fa-IR/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,15 +0,0 @@
-<!ENTITY dialog.title "ويرايش آبونه فيلتر">
-<!ENTITY dialog.newtitle "اشتراک آبونه فيلتر">
-<!ENTITY new.description "لطفا نشانی وب یا پرونده حاوی فهرست فیلترهای Adblock Plus را وارد کنید.">
-<!ENTITY edit.description "فهرست فیلترهای اشتراکی از نشانی وارد شده٬ دریافت خواهند‌شد.">
-<!ENTITY external.description "این اشتراک بیرونی فیلتر است و فهرست آن بوسیله پسوند سازنده آن به‌روزرسانی خواهد شد.">
-<!ENTITY autodownload.description "اگر شما گزینه به‌روزرسانی حودگار را انتخاب کنید٬ این نشانی هرروز بررسی خواهد شد.
-در غیر این صورت شما می‌توانید از طرف منوی اشتراک آن را به صورت دستی به‌روزرسانی کنید.">
-<!ENTITY location.label "نشانی فهرست فیلتر:">
-<!ENTITY location.accesskey "ف">
-<!ENTITY title.label "عنوان اشتراک:">
-<!ENTITY title.accesskey "ش">
-<!ENTITY autodownload.label "به‌روزرسانی خودکار">
-<!ENTITY autodownload.accesskey "خ">
-<!ENTITY enabled.label "فعال‌کردن فیلترها">
-<!ENTITY enabled.accesskey "ع">

=== removed file 'chrome/locale/fa-IR/tip_subscriptions.dtd'
--- chrome/locale/fa-IR/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fa-IR/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,15 +0,0 @@
-<!ENTITY dialog.title "به Adblock Plus خوش آمديد">
-<!ENTITY description.par1 "با تشکر از نصب‌کردن Adblock Plus.
-	این پسوند قابلیت حذف ۹۹&#37; تبلیغات موجود در وب را دارا می‌باشد.
-	ولی فیلترکردن موثر نیاز به تعریف یک مجموعه فیلتر از طرف شما است.
-	شما می‌توانید این مجموعه را خودتان تعریف کنید٬ یا برای لیستهای دیگران مشترک شوید.
-	شما حتی در این صورت می‌توانید فیلترهای خود را به فهرست اضافه کنید٬ یا اشتراکهای خود را هر لحظه پایان دهید.">
-<!ENTITY description.par2 "شما می‌توانید از موارد پیشنهادی زیر یکی را جهت اشتراک انتخاب کنید.
-(شما می‌توانید بعدا در بخش تنطیمات اشتراکهای دیگری انتخاب کنید٬ با وجوداینکه این مورد معمولا لازم نمی‌باشد):">
-<!ENTITY note "تذکر: یک فهرست از منطقه درست شده برای این فیلترها معمولا به بهترین نحو مورد استفاده می‌تواند باشد.">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY homepage.label "صفحه خانگی">
-<!ENTITY subscribe.label "اشتراک">
-<!ENTITY subscribe.accesskey "ش">
-<!ENTITY other.label "اشتراک ديگر">
-<!ENTITY other.accesskey "گ">

=== added file 'chrome/locale/fa/.incomplete'
=== added file 'chrome/locale/fa/about.dtd'
--- chrome/locale/fa/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fa/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,9 @@
+<!ENTITY dialog.title "Adblock Plus درباره">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "نسخه">
+<!ENTITY description "Adblock Plus به شما اجازه برای تصمیم‌گیری در موارد قابل مشاهده در وب را می‌دهد.
+	دیگر لازم نیست که تمام تصویرها و موارد تبلیغاتی را بر خلاف میل شما دریافت شوند٬ این امر را به Adblock Plus واگزار کنید!">
+<!ENTITY homepage.label "صفحه خانگی Adblock Plus:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "نويسنده:">
+<!ENTITY contributors.label "همکاران:">

=== added file 'chrome/locale/fa/global.properties'
--- chrome/locale/fa/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/fa/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,49 @@
+action0_tooltip=برای نمایش منو فشار دهید. کلید میانی برای فعال یا غیرفعال کردن.
+action1_tooltip=برای گشودن یا بستن موارد مسدودی را کلیک کنید. کلید میانی برای فعال یا غیرفعال کردن.
+action2_tooltip=برای گشودن تنظیمات کلیک کنید. کلید میانی برای فعال یا غیرفعال کردن.
+action3_tooltip=برای فعال یا غیرفعال‌کردن Adblock Plus کلیک کنید.
+disabled_tooltip=Adblock Plus غيرفعال است.
+whitelisted_tooltip=Adblock Plus فعال است و برای این صفحه غیرفعال شده است.
+blocked_count_tooltip=?1? از میان ?2?
+no_blocking_suggestions=موارد مسدودی در این صفحه موجود نیست
+whitelisted_page=Adblock Plus برای صفحه جاری غیرفعال شده است.
+whitelist_description=دستورهای استثنائی
+filterlist_description=فیلترهای تبلیغاتی
+invalid_description=فیلترهای غیرمعتبر
+elemhide_description=دستورهای پنهان‌کننده عنصر
+subscription_description=اشتراک فیلتر:
+subscription_wrong_version=بعضی از فیلترهای این اشتراک برای کارکردن صحیح به Adblock Plus احتیاج دارند!
+subscription_source=منبع:
+subscription_status=وضعيت:
+subscription_status_autodownload=به‌روزرسانی خودکار
+subscription_status_manualdownload=به‌روزرسانی دستی
+subscription_status_externaldownload=به‌روزرسانی غیره (توسط پسوند دیگر)
+subscription_status_lastdownload=آخرین دریافت:
+subscription_status_lastdownload_inprogress=درحال دريافت...
+subscription_status_lastdownload_unknown=نامعین
+remove_subscription_warning=آیا برای حذف اشتراک مطمئن هستید؟
+import_filters_wrong_version=تذکر:بعضی از فیلترهای این اشتراک برای کارکردن صحیح به Adblock Plus احتیاج دارند! شما باید آخرین نسخه Adblock Plus را نصب کنید.
+import_filters_warning=آیا شما مایل به جای‌گذاری فهرست فیلتر هستید یا این فهرست به فهرست کنونی شما اضافه شود؟
+import_filters_title=واردکردن فیلترها
+export_filters_title=خروجی فیلترها
+invalid_filters_file=پرونده مورد نظر برای فهرست فیلترهای Adblock Plus معتبر نیست.
+filters_write_error=در هنگام نوشتن پرونده فیلترها اشکال بوجود آمد. اطمینان خاطر کنید که پرونده مورد نظر توسط برنامه دیگر استفاده نشده و قابل نوشتن باشد.
+clearall_warning=آیا برای حذف تمام فیلترها در این فهرست مطمئن هستید؟
+resethitcounts_warning=آیا شما مایل به بازگشت آمار استفاده فیلتر به صفر هستید؟ این عمل بازگشت‌پذیر نیست.
+resethitcounts_selected_warning=آیا شما مایل به بازگشت آمار استفاده از فیلترهای انتحاب شده به صفر هستید؟ این عمل بازگشت‌پذیر نیست
+subscription_invalid_location=مکان وارد شده برای فهرست فیلترها نامعتبر است.
+synchronize_invalid_url=نشانی نامعتبر بود
+synchronize_connection_error=اشکال در دریافت‌کردن
+synchronize_invalid_data=اشکال در فهرست فیلترها
+synchronize_ok=با موفقيت
+overwrite=جای گذاری
+append=افزودن
+type_label_other=ديگر
+type_label_script=دست‌نوشت
+type_label_image=تصوير
+type_label_stylesheet=استایل‌شیت
+type_label_object=شیء
+type_label_subdocument=قابک
+type_label_document=نوشتار
+type_label_background=زمينه
+type_label_elemhide=پنهان

=== added file 'chrome/locale/fa/meta.properties'
--- chrome/locale/fa/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/fa/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=تبليغات ديروز بود!

=== added file 'chrome/locale/fa/overlay.dtd'
--- chrome/locale/fa/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fa/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,19 @@
+<!ENTITY status.tooltip "وضعيت:">
+<!ENTITY blocked.tooltip "موارد ردشده در اين صفحه:">
+<!ENTITY filters.tooltip "فعالترين فيلترها:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY context.image.label "Adblock تصوير">
+<!ENTITY context.object.label "Adblock Object">
+<!ENTITY context.frame.label "Adblock قابک">
+<!ENTITY sidebar.title "موارد قابل ردکردن در صفحه جاری">
+<!ENTITY settings.label "تنظيمات">
+<!ENTITY settings.accesskey "ن">
+<!ENTITY opensidebar.label "بازکردن موارد قابل ردکردن">
+<!ENTITY opensidebar.accesskey "ق">
+<!ENTITY closesidebar.label "بستن موارد قابل ردکردن">
+<!ENTITY closesidebar.accesskey "ق">
+<!ENTITY whitelist.site.label "غيرفعال در ?1?">
+<!ENTITY whitelist.page.label "غيرفعال فقط در اين صفحه">
+<!ENTITY objecttab.title "مسدود کردن">
+<!ENTITY objecttab.tooltip "جهت مسدود کردن با Adblock Plus اینجا کلیک کنید">

=== added file 'chrome/locale/fa/settings.dtd'
--- chrome/locale/fa/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fa/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+<!ENTITY dialog.title "تنظيمات Adblock Plus">
+<!ENTITY filters.label "فيلترها">
+<!ENTITY filters.accesskey "ه">
+<!ENTITY add.label "افزودن فيلتر">
+<!ENTITY add.accesskey "ز">
+<!ENTITY addsubscription.label "اشتراک فيلتر">
+<!ENTITY addsubscription.accesskey "ش">
+<!ENTITY synchsubscriptions.label "به‌روزرساني اشتراک‌ها">
+<!ENTITY synchsubscriptions.accesskey "ک">
+<!ENTITY import.label "واردکردن فيلترها">
+<!ENTITY import.accesskey "د">
+<!ENTITY export.label "صادرکردن فيلترها">
+<!ENTITY export.accesskey "ف">
+<!ENTITY clearall.label "حذف فيلترها">
+<!ENTITY clearall.accesskey "ح">
+<!ENTITY resethitcounts.label "بازگشت آمار استفاده">
+<!ENTITY resethitcounts.accesskey "س">
+<!ENTITY edit.label "ويرايش">
+<!ENTITY edit.accesskey "ش">
+<!ENTITY cut.label "برش">
+<!ENTITY cut.accesskey "ر">
+<!ENTITY copy.label "رونوشت">
+<!ENTITY copy.accesskey "ش">
+<!ENTITY paste.label "جای گذاری">
+<!ENTITY paste.accesskey "گ">
+<!ENTITY remove.label "حذف">
+<!ENTITY remove.accesskey "ذ">
+<!ENTITY menu.find.label "يافتن">
+<!ENTITY menu.find.accesskey "ف">
+<!ENTITY menu.findagain.label "يافتن مجدد">
+<!ENTITY menu.findagain.accesskey "م">
+<!ENTITY options.label "تنظيمات">
+<!ENTITY options.accesskey "ظ">
+<!ENTITY enable.label "فعال‌کردن Adblock Plus">
+<!ENTITY enable.accesskey "ع">
+<!ENTITY showintoolbar.label "نمايش در نوارابزار">
+<!ENTITY showintoolbar.accesskey "ب">
+<!ENTITY showinstatusbar.label "نمايش در نواروضعيت">
+<!ENTITY showinstatusbar.accesskey "و">
+<!ENTITY objecttabs.label "نمایش برگه در موارد Flash و Java">
+<!ENTITY objecttabs.accesskey "J">
+<!ENTITY collapse.label "نمایش موارد ردشده">
+<!ENTITY collapse.accesskey "م">
+<!ENTITY help.label "راهنما">
+<!ENTITY help.accesskey "ن">
+<!ENTITY faq.label "سوالات طرح شده">
+<!ENTITY faq.accesskey "ش">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "نوشتن فیلترهای Adblock Plus">
+<!ENTITY filterdoc.accesskey "P">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "درباره Adblock Plus">
+<!ENTITY about.accesskey "د">
+<!ENTITY description "برای رد کردن نشانی‌ها٬ آنها را به این فهرست اضافه کنید.
+		برای استفاده از لیست‌های عمومی از ستاره استفاده کنید.
+کاربران پیشرفته می‌توانند از عبارات مرتب استفاده کنند٬ مانند:
+		/banner\d+\.gif$/">
+<!ENTITY enabled.column "فعال‌">
+<!ENTITY hitcount.column "استفاده شده">
+<!ENTITY lasthit.column "آخرين استفاده">
+<!ENTITY context.edit.label "ويرايش فيلتر">
+<!ENTITY context.resethitcount.label "برگشت آمار استفاده">
+<!ENTITY context.synchsubscription.label "به‌روزرساني اشتراک">
+<!ENTITY context.editsubscription.label "ويريش اشتراک">
+<!ENTITY context.moveup.label "بالا‌بردن">
+<!ENTITY context.movedown.label "پائين‌بردن">
+<!ENTITY context.movegroupup.label "بالا‌بردن گروه">
+<!ENTITY context.movegroupdown.label "پائين‌بردن گروه">
+<!ENTITY apply.label "انجام دادن">
+<!ENTITY apply.accesskey "ج">

=== added file 'chrome/locale/fa/sidebar.dtd'
--- chrome/locale/fa/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fa/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,22 @@
+<!ENTITY detached.title "Adblock Plus: موارد قابل ردکردن (قطع)">
+<!ENTITY detach.label "قطع کردن">
+<!ENTITY reattach.label "وصل کردن">
+<!ENTITY search.label "يافتن:">
+<!ENTITY search.accesskey "ف">
+<!ENTITY type.label "نوع">
+<!ENTITY address.label "نشانی">
+<!ENTITY filter.label "فيلتر">
+<!ENTITY state.label "وصعيت">
+<!ENTITY noitems.label "موارد قابل ردکردن پيدا نشد">
+<!ENTITY whitelisted.label "صفحه در فهرست سفيد">
+<!ENTITY tooltip.address.label "نشاني:">
+<!ENTITY tooltip.type.label "نوع:">
+<!ENTITY tooltip.type.blocked "(ردشده)">
+<!ENTITY tooltip.type.whitelisted "(در فهرست سفيد)">
+<!ENTITY tooltip.filter.label "فيلتر فعال:">
+<!ENTITY context.block.label "ردکردن اين مورد">
+<!ENTITY context.editfilter.label "ويرايش فيلتر فعال">
+<!ENTITY context.whitelist.label "افزودن قانون استثناء برای اين مورد">
+<!ENTITY context.open.label "گشودن در برگه نو">
+<!ENTITY context.flash.label "قاب مورد فلاش">
+<!ENTITY context.copy.label "رونوشت نشانی مورد">

=== added file 'chrome/locale/fa/subscriptionSelection.dtd'
--- chrome/locale/fa/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fa/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,10 @@
+<!ENTITY dialog.title.edit "ويرايش آبونه فيلتر">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY other.label "اشتراک ديگر">
+<!ENTITY other.accesskey "گ">
+<!ENTITY title.label "عنوان اشتراک:">
+<!ENTITY title.accesskey "ش">
+<!ENTITY location.label "نشانی فهرست فیلتر:">
+<!ENTITY location.accesskey "ف">
+<!ENTITY autodownload.label "به‌روزرسانی خودکار">
+<!ENTITY autodownload.accesskey "خ">

=== added directory 'chrome/locale/fi'
=== removed directory 'chrome/locale/fi-FI'
=== removed file 'chrome/locale/fi-FI/about.dtd'
--- chrome/locale/fi-FI/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fi-FI/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus - Tietoja">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Versio">
-<!ENTITY description "Adblock Plussan avulla voit päättää, mitkä osat verkkosivuista näkyvät sinulle. Jos sinua ei kiinnosta nähdä mainoksia ja bannereita, Adblock Plussan avulla on kuin niitä ei ikinä olisi ollutkaan!">
-<!ENTITY homepage.label "Adblock Plussan kotisivu:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Tekijä:">
-<!ENTITY contributors.label "Avustajat:">

=== removed file 'chrome/locale/fi-FI/composer.dtd'
--- chrome/locale/fi-FI/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fi-FI/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Lisää Adblock-suodatusehto">
-<!ENTITY accept.label "Lisää suodatin">
-<!ENTITY advanced.label "Näytä lisää">
-<!ENTITY basic.label "Näytä vähemmän">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus on tällä hetkellä poistettu käytöstä. Voit silti lisätä suodattimia mutta ne otetaan käyttöön vasta kun,">
-<!ENTITY disabled.warning.link "otat Adblockin Plussan käyttöön">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Suodatinryhmä &quot;&#37;S&quot;, johon tämä suodatin tulisi lisätä on poistettu käytöstä. Voit silti lisätä tämän suodattimen mutta sitä ei oteta käyttöön ellet">
-<!ENTITY groupDisabled.warning.link "ota suodatinryhmää käyttöön">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Uusi suodatin:">
-<!ENTITY filter.accesskey "U">
-<!ENTITY preferences.label "Näytä nykyiset suodattimet...">
-<!ENTITY preferences.accesskey "N">
-<!ENTITY type.filter.label "Estävä suodatin">
-<!ENTITY type.filter.accesskey "E">
-<!ENTITY type.whitelist.label "Sallimisehto">
-<!ENTITY type.whitelist.accesskey "S">
-<!ENTITY pattern.label "Etsi merkkijonoa">
-<!ENTITY pattern.explanation "Merkkijono voi olla mikä tahansa osoitteen osa. Merkki * toimii jokerimerkkinä. Suodatin toimii vain osoitteissa, joita merkkijono vastaa.">
-<!ENTITY regexp.warning "Syöttämäsi merkkijono tulkitaan säännölliseksi lausekkeeksi. Monet säännölliset lausekkeet saattavat hidastaa selailua. Jos tarkoituksena ei ollut käyttää säännöllistä lauseketta, lisää merkki * lauseen loppuun.">
-<!ENTITY shortpattern.warning "Syöttämäsi merkkijono on liian lyhyt optimoitavaksi. Useat tällaiset merkkijonot saattavat hidastaa selailua. On suositeltavaa, että valitset tälle suodattimelle pidemmän merkkijonon.">
-<!ENTITY custom.pattern.label "Oma muokkaus:">
-<!ENTITY custom.pattern.accesskey "O">
-<!ENTITY anchors.label "Hyväksy merkkijono vain:">
-<!ENTITY anchor.start.label "osoitteen alussa">
-<!ENTITY anchor.start.accesskey "t">
-<!ENTITY anchor.start.flexible.label "verkkotunnuksen alussa.">
-<!ENTITY anchor.start.flexible.accesskey "t">
-<!ENTITY anchor.end.label "osoitteen lopussa">
-<!ENTITY anchor.end.accesskey "l">
-<!ENTITY options.label "Valinnat">
-<!ENTITY domainRestriction.label "Rajoita verkkotunnukseen:">
-<!ENTITY domainRestriction.accesskey "a">
-<!ENTITY domainRestriction.help "Määrittele yksi tai useampia verkkotunnuksia &quot;|&quot;-merkilla eroteltuna. Suodatin on käytössä vain näissä verkkotunnuksissa. Suodatinta ei käytetä verkkotunnuksella, jos sen edessä on &quot;~&quot;-merkki.">
-<!ENTITY firstParty.label "Vain sivun ylläpitäjän">
-<!ENTITY firstParty.accesskey "i">
-<!ENTITY thirdParty.label "Vain muiden kuin sivun ylläpitäjän">
-<!ENTITY thirdParty.accesskey "m">
-<!ENTITY matchCase.label "Huomioi kirjainkoko">
-<!ENTITY matchCase.accesskey "H">
-<!ENTITY types.label "Käytä tyypeissä:">
-<!ENTITY selectAllTypes.label "Valitse kaikki">
-<!ENTITY unselectAllTypes.label "Älä valitse mitään">
-<!ENTITY collapse.label "Romahduta estetyt:">
-<!ENTITY collapse.accesskey "R">
-<!ENTITY collapse.default.yes.label "Käytä oletusta (kyllä)">
-<!ENTITY collapse.default.no.label "Käytä oletusta (ei)">
-<!ENTITY collapse.yes.label "Kyllä">
-<!ENTITY collapse.no.label "Ei">

=== removed file 'chrome/locale/fi-FI/global.properties'
--- chrome/locale/fi-FI/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/fi-FI/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Mainokset ovat menneisyyttä!
-status_active_label=Adblock
-status_disabled_label=Ei käytössä
-action0_tooltip=Napsautus avaa ponnahdusvalikon. Keskinapsautus ottaa käyttöön/poistaa käytöstä.
-action1_tooltip=Napsautus avaa/sulkee elementtilistan. Keskinapsautus ottaa käyttöön/poistaa käytöstä.
-action2_tooltip=Napsautus avaa asetukset. Keskinapsautus ottaa käyttöön/poistaa käytöstä.
-action3_tooltip=Napsauttamalla Adblock Plus otetaan käyttöön/poistetaan käytöstä.
-active_tooltip=Adblock Plus on aktiivinen.
-disabled_tooltip=Adblock Plus ei ole käytössä.
-whitelisted_tooltip=Adblock Plus on aktiivinen mutta poistettu käytöstä tämänhetkisellä sivustolla.
-blocked_count_tooltip=-- / --
-no_blocking_suggestions=Ei estettäviä elementtejä avoimella sivulla
-whitelisted_page=Adblock Plus on poistettu käytöstä avoimella sivulla
-whitelist_description=Sallivat suodattimet
-filterlist_description=Estävät suodattimet
-invalid_description=Virheelliset suodattimet
-elemhide_description=Elementtien piilottamisehdot
-subscription_description=Tilatut suodattimet:
-subscription_wrong_version=Jotkin tämän tilauksen suodattimista vaativat Adblock Plussan  -- toimiakseen oikein!
-subscription_source=Osoite:
-subscription_status=Tila:
-subscription_status_autodownload=Automaattisesti päivittyvä
-subscription_status_manualdownload=Päivitettävä käsin
-subscription_status_externaldownload=Päivittyy ulkoisesti (toinen laajennus)
-subscription_status_lastdownload=Viimeisin lataus:
-subscription_status_lastdownload_inprogress=Lataa...
-subscription_status_lastdownload_unknown=N/A
-remove_subscription_warning=Haluatko varmasti poistaa tämän tilauksen?
-import_filters_wrong_version=Varoitus: jotkin tämän tilauksen suodattimista vaativat Adblock Plussan  -- toimiakseen oikein. Sinun tulisi luultavasti päivittää Adblock Plussan viimeisimpään versioon ennen tämän listan tuomista.
-import_filters_warning=Haluatko korvata nykyiset suodattimet vai lisätä uudet listan loppuun?
-import_filters_title=Tuo suodattimia
-export_filters_title=Vie suodattimia
-invalid_filters_file=Virheellinen Adblock Plus -suodatintiedosto.
-filters_write_error=Tapahtui virhe kirjoitettaessa suodattimia tiedostoon. Varmista, ettei tiedosto ole kirjoitussuojattu tai ei ole jonkin muun ohjelman käytössä.
-clearall_warning=Haluatko varmasti poistaa kaikki listan suodattimet?
-resethitcounts_warning=Haluatko varmasti nollata kaikkien suodattimien osumamäärät? Tätä toimintoa ei voida peruuttaa jälkikäteen!
-resethitcounts_selected_warning=Haluatko varmasti nollata valittujen suodattimien osumamäärät? Tätä toimintoa ei voida peruuttaa jälkikäteen!
-filter_regexp_tooltip=Tämä suodatin on joko säännöllinen lauseke tai liian lyhyt optimoitavaksi. Liian monta tällaista suodatinta saattaa hidastaa selailuasi.
-filter_elemhide_duplicate_id=Piilotettavalle elementille voidaan määritellä vain yksi tunniste (ID)
-filter_elemhide_nocriteria=Piilotettavaa elementtiä määrittelevää tunnistetta ei annettu
-subscription_no_location=Ole hyvä ja valitse sijainti, josta suodattimet ladataan.
-subscription_invalid_location=Suodatinlistan sijainti on joko kelvoton osoite tai tiedoston nimi.
-subscription_location_exists=Olet jo tilannut tämän suodatinlistan.
-synchronize_invalid_url=Epäonnistui, kelvoton osoite
-synchronize_connection_error=Epäonnistui, latausvirhe
-synchronize_invalid_data=Epäonnistui, kelvoton suodatinlista
-synchronize_checksum_mismatch=Epäonnistui, tarkistussumma ei täsmää
-synchronize_ok=Onnistui
-overwrite=Korvaa
-append=Lisää loppuun
-new_filter_group_title=Uusi suodatin
-type_label_other=muu
-type_label_script=komento
-type_label_image=kuva
-type_label_stylesheet=tyyliohje
-type_label_object=objekti
-type_label_subdocument=kehys
-type_label_document=dokumentti
-type_label_background=taustakuva
-type_label_elemhide=piilotettu
-type_label_xbl=XBL-liitos
-type_label_ping=ping-link
-type_label_xmlhttprequest=XML-pyyntö
-type_label_object_subrequest=objektin alipyyntö
-type_label_dtd=DTD
-type_label_media=ääni/video
-type_label_font=kirjaisin

=== removed file 'chrome/locale/fi-FI/overlay.dtd'
--- chrome/locale/fi-FI/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fi-FI/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Tila:">
-<!ENTITY blocked.tooltip "Tämän sivun estetyt elementit:">
-<!ENTITY filters.tooltip "Aktiivisimmat suodattimet:">
-<!ENTITY menuitem.label "Adblock Plus - Asetukset">
-<!ENTITY menuitem.accesskey "d">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Estettävät elementit">
-<!ENTITY context.image.label "Estä kuva Adblockilla">
-<!ENTITY context.object.label "Estä kohde Adblockilla">
-<!ENTITY context.frame.label "Estä kehys Adblockilla">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Ota tämä sivu uudestaan käyttöön">
-<!ENTITY sidebar.title "Estettävät elementit avoimella sivulla">
-<!ENTITY settings.label "Asetukset">
-<!ENTITY settings.accesskey "A">
-<!ENTITY opensidebar.label "Näytä elementit">
-<!ENTITY opensidebar.accesskey "e">
-<!ENTITY closesidebar.label "Sulje elementit">
-<!ENTITY closesidebar.accesskey "e">
-<!ENTITY whitelist.site.label "Ei käytössä osoitteessa --">
-<!ENTITY whitelist.page.label "Ei käytössä tällä sivulla">
-<!ENTITY objecttab.title "Estä">
-<!ENTITY objecttab.tooltip "Estä tämä objekti Adblock Plussalla">

=== removed file 'chrome/locale/fi-FI/settings.dtd'
--- chrome/locale/fi-FI/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fi-FI/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus - Asetukset">
-<!ENTITY filters.label "Suodattimet">
-<!ENTITY filters.accesskey "S">
-<!ENTITY add.label "Lisää suodatin">
-<!ENTITY add.accesskey "L">
-<!ENTITY addsubscription.label "Lisää suodatintilaus">
-<!ENTITY addsubscription.accesskey "i">
-<!ENTITY synchsubscriptions.label "Päivitä kaikki tilaukset">
-<!ENTITY synchsubscriptions.accesskey "k">
-<!ENTITY import.label "Tuo suodattimia">
-<!ENTITY import.accesskey "T">
-<!ENTITY export.label "Vie omia suodattimia">
-<!ENTITY export.accesskey "V">
-<!ENTITY clearall.label "Poista kaikki omat suodattimet">
-<!ENTITY clearall.accesskey "P">
-<!ENTITY resethitcounts.label "Nollaa osumatilastot">
-<!ENTITY resethitcounts.accesskey "N">
-<!ENTITY edit.label "Muokkaa">
-<!ENTITY edit.accesskey "M">
-<!ENTITY cut.label "Leikkaa">
-<!ENTITY cut.accesskey "L">
-<!ENTITY copy.label "Kopioi">
-<!ENTITY copy.accesskey "K">
-<!ENTITY paste.label "Liitä">
-<!ENTITY paste.accesskey "i">
-<!ENTITY remove.label "Poista">
-<!ENTITY remove.accesskey "P">
-<!ENTITY menu.find.label "Etsi">
-<!ENTITY menu.find.accesskey "E">
-<!ENTITY menu.findagain.label "Etsi seuraava">
-<!ENTITY menu.findagain.accesskey "t">
-<!ENTITY view.label "Näytä">
-<!ENTITY view.accesskey "N">
-<!ENTITY sort.label "Lajitteluperuste">
-<!ENTITY sort.accesskey "E">
-<!ENTITY sort.none.label "Ei lajiteltu">
-<!ENTITY sort.none.accesskey "L">
-<!ENTITY sort.ascending.label "A &gt; Z lajittelu">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Z &gt; A lajittelu">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Valinnat">
-<!ENTITY options.accesskey "V">
-<!ENTITY enable.label "Adblock Plus käytössä">
-<!ENTITY enable.accesskey "d">
-<!ENTITY showintoolbar.label "Näytä työkalupalkilla">
-<!ENTITY showintoolbar.accesskey "y">
-<!ENTITY showinstatusbar.label "Näytä tilarivillä">
-<!ENTITY showinstatusbar.accesskey "N">
-<!ENTITY objecttabs.label "Korvake Flashin ja Javan yhteydessä">
-<!ENTITY objecttabs.accesskey "K">
-<!ENTITY collapse.label "Romahduta estetyt elementit">
-<!ENTITY collapse.accesskey "R">
-<!ENTITY help.label "Ohje">
-<!ENTITY help.accesskey "O">
-<!ENTITY gettingStarted.label "Alkuun pääseminen">
-<!ENTITY gettingStarted.accesskey "l">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Usein kysytyt kysymykset (FAQ)">
-<!ENTITY faq.accesskey "U">
-<!ENTITY faq.url "http://www.mozilla.fi/wiki/Adblock_Plus">
-<!ENTITY filterdoc.label "Adblock Plus -suodattimien kirjoittamisesta">
-<!ENTITY filterdoc.accesskey "A">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Tietoja Adblock Plussasta">
-<!ENTITY about.accesskey "T">
-<!ENTITY description "Seuraavat suodattimet määrittelevät sen, mitkä osoitteet estetään ja mitkä sallitaan:">
-<!ENTITY filter.column "Suodatusehto">
-<!ENTITY filter.accesskey "S">
-<!ENTITY slow.column "Hitaat suodattimet">
-<!ENTITY slow.accesskey "H">
-<!ENTITY enabled.column "Käytössä">
-<!ENTITY enabled.accesskey "y">
-<!ENTITY hitcount.column "Osumat">
-<!ENTITY hitcount.accesskey "O">
-<!ENTITY lasthit.column "Viimeisin osuma">
-<!ENTITY lasthit.accesskey "V">
-<!ENTITY context.edit.label "Muokkaa suodatinta">
-<!ENTITY context.resethitcount.label "Nollaa suodattimen osumatilastot">
-<!ENTITY context.synchsubscription.label "Päivitä tilaus nyt">
-<!ENTITY context.editsubscription.label "Muokkaa tilausta">
-<!ENTITY context.moveup.label "Siirrä suodatin ylöspäin">
-<!ENTITY context.movedown.label "Siirrä suodatin alaspäin">
-<!ENTITY context.movegroupup.label "Siirrä ryhmä ylöspäin">
-<!ENTITY context.movegroupdown.label "Siirrä ryhmä alaspäin">
-<!ENTITY context.enable.label "Ota käyttöön">
-<!ENTITY context.disable.label "Poista käytöstä">
-<!ENTITY apply.label "Käytä">
-<!ENTITY apply.accesskey "K">

=== removed file 'chrome/locale/fi-FI/sidebar.dtd'
--- chrome/locale/fi-FI/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fi-FI/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Estettävien elementtien lista (irrotettu)">
-<!ENTITY detach.label "Irrota">
-<!ENTITY reattach.label "Kiinnitä">
-<!ENTITY search.label "Etsi:">
-<!ENTITY search.accesskey "E">
-<!ENTITY type.label "Tyyppi">
-<!ENTITY address.label "Osoite">
-<!ENTITY filter.label "Suodatin">
-<!ENTITY state.label "Tila">
-<!ENTITY size.label "Koko">
-<!ENTITY docDomain.label "Dokumentin lähde">
-<!ENTITY noitems.label "Ei estettäviä elementtejä">
-<!ENTITY whitelisted.label "Sallittu sivu">
-<!ENTITY tooltip.address.label "Osoite:">
-<!ENTITY tooltip.type.label "Tyyppi:">
-<!ENTITY tooltip.type.blocked "(estetty)">
-<!ENTITY tooltip.type.whitelisted "(sallittu)">
-<!ENTITY tooltip.size.label "Koko:">
-<!ENTITY tooltip.docDomain.label "Dokumentin lähde:">
-<!ENTITY tooltip.filter.label "Vaikuttava suodatin:">
-<!ENTITY tooltip.filterSource.label "Suodattimen lähde:">
-<!ENTITY context.block.label "Estä elementti">
-<!ENTITY context.editfilter.label "Muokkaa suodatinta">
-<!ENTITY context.whitelist.label "Lisää poikkeusehto">
-<!ENTITY context.disablefilter.label "Poista käytöstä suodatin: --">
-<!ENTITY context.enablefilter.label "Palauta suodatin: --">
-<!ENTITY context.disablefilteronsite.label "Poista tämä suodatin käytöstä osoiteessa --">
-<!ENTITY context.open.label "Avaa uuteen välilehteen">
-<!ENTITY context.flash.label "Välkytä reunoja">
-<!ENTITY context.copy.label "Kopioi osoite">
-<!ENTITY context.copyFilter.label "Kopioi suodatin">
-<!ENTITY context.selectAll.label "Valitse kaikki">

=== removed file 'chrome/locale/fi-FI/subscription.dtd'
--- chrome/locale/fi-FI/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fi-FI/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY dialog.title "Muokkaa suodatintilausta">
-<!ENTITY dialog.newtitle "Lisää suodatintilaus">
-<!ENTITY new.description "Syötä verkko-osoite tai tiedosto, joka sisältää listan 
-	Adblock Plus -suodattimia.">
-<!ENTITY edit.description "Tämän tilauksen suodatinlista ladataan annetusta
-	sijainnista.">
-<!ENTITY external.description "Tämä on ulkoinen suodatintilaus, sen suodatinlista
-	pidetään ajan tasalla laajennuksella, joka on luotu tätä 
-	tilausta varten.">
-<!ENTITY autodownload.description "Jos valitset &quot;Päivitä automaattisesti&quot;, tämä sijainti
-	tarkistetaan päivittäin päivitysten varalta. Vaikka tämä asetus on poissa 
-	käytöstä voit silti suorittaa päivittämisen käsin  valitsemalla
-	&quot;Päivitä tilaus nyt&quot; tilauksen ponnahdusvalikosta.">
-<!ENTITY location.label "Listan sijainti:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Tilauksen nimi:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Päivitä automaattisesti">
-<!ENTITY autodownload.accesskey "a">
-<!ENTITY enabled.label "Käytä suodattimia">
-<!ENTITY enabled.accesskey "K">

=== removed file 'chrome/locale/fi-FI/tip_subscriptions.dtd'
--- chrome/locale/fi-FI/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fi-FI/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY dialog.title "Lisää Adblock Plus -suodatintilaus">
-<!ENTITY description.par1 "Kiitos, että asensit Adblock Plussan. Tällä laajennuksella on mahdollista estää 99&#37; verkkomainoksista. Tehokkaaseen suodattamiseen tarvitaan kuitenkin hyvä kokoelma suodattimia. Voit luoda suodattimesi itse tai voit yksinkertaisesti tilata toisten ylläpitämiä suodatinlistoja. Mitä päätätkin, voit aina lisätä ja poistaa omia suodattimia, tilata uusia tai poistaa vanhoja tilauksia, sekä poistaa käytöstä yksittäisiä tai useita suodattimia.">
-<!ENTITY description.par2 "Voit valita yhden tilauksen
-	suositeltujen tilausten listasta alapuolelta
-	(lisää tilauksia voi lisätä Adblock Plussan 
-	asetuksista myöhemmin, vaikka tämä ei ole usein tarpeellista):">
-<!ENTITY note "Huomio: Suodatinlista on yleensä tehokkain, kun sitä käytetään
-	sivustoilla, joita varten se on alueellisesti luotu.">
-<!ENTITY adblock.warning "Adblock Plus on huomannut, että Adblockista tai Adblock Plussasta on vanha versio asennettuna. Adblockin ja Adblock Plussan yhtäaikainen käyttäminen saattaa aiheuttaa ongelmia ja tulisi välttää. Suosittelemme Adblockin poistamista välittömästi.">
-<!ENTITY adblock.uninstall "Poista Adblock">
-<!ENTITY filterset.g.warning "Näyttää siltä, että käytät Filterset.G:tä. Tätä suodatinlistaa ei ole ylläpidetty viime vuosina ja yleinen syy ongelmiin verkkosivujen kanssa. Suosittelemme Filterset.G:n poistamista välittömästi.">
-<!ENTITY filterset.g.moreinfo "Lisätietoa">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Poista Filterset.G">
-<!ENTITY homepage.label "Kotisivu">
-<!ENTITY subscribe.label "Tilaa">
-<!ENTITY subscribe.accesskey "T">
-<!ENTITY other.label "Lisää jokin muu tilaus">
-<!ENTITY other.accesskey "L">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Näytä kaikki tilaukset">

=== added file 'chrome/locale/fi/about.dtd'
--- chrome/locale/fi/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fi/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Adblock Plus - Tietoja">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versio">
+<!ENTITY description "Adblock Plussan avulla voit päättää, mitkä osat verkkosivuista näkyvät sinulle. Jos sinua ei kiinnosta nähdä mainoksia ja bannereita, Adblock Plussan avulla on kuin niitä ei ikinä olisi ollutkaan!">
+<!ENTITY homepage.label "Adblock Plussan kotisivu:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Tekijä:">
+<!ENTITY contributors.label "Avustajat:">
+<!ENTITY developers.label "Kehittäjät:">
+<!ENTITY designers.label "Graafiset suunnitelijat:">
+<!ENTITY subscriptionAuthors.label "Suodatintilausten tekijät:">
+<!ENTITY translators.label "Kääntäjät:">

=== added file 'chrome/locale/fi/composer.dtd'
--- chrome/locale/fi/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fi/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Lisää Adblock-suodatusehto">
+<!ENTITY accept.label "Lisää suodatin">
+<!ENTITY advanced.label "Näytä lisää">
+<!ENTITY basic.label "Näytä vähemmän">
+<!ENTITY disabled.warning "Adblock Plus on tällä hetkellä poistettu käytöstä. Voit silti lisätä suodattimia mutta ne otetaan käyttöön vasta kun, [link]otat Adblockin Plussan käyttöön[/link].">
+<!ENTITY groupDisabled.warning "Suodatinryhmä &quot;?1?&quot;, johon tämä suodatin tulisi lisätä on poistettu käytöstä. Voit silti lisätä tämän suodattimen mutta sitä ei oteta käyttöön ellet [link]ota suodatinryhmää käyttöön[/link].">
+<!ENTITY filter.label "Uusi suodatin:">
+<!ENTITY filter.accesskey "U">
+<!ENTITY preferences.label "Näytä nykyiset suodattimet...">
+<!ENTITY preferences.accesskey "N">
+<!ENTITY type.filter.label "Estävä suodatin">
+<!ENTITY type.filter.accesskey "E">
+<!ENTITY type.whitelist.label "Sallimisehto">
+<!ENTITY type.whitelist.accesskey "S">
+<!ENTITY pattern.label "Merkkijonon löytäminen">
+<!ENTITY pattern.explanation "Merkkijono voi olla mikä tahansa osoitteen osa. Merkki * toimii jokerimerkkinä. Suodatin toimii vain osoitteissa, joita merkkijono vastaa.">
+<!ENTITY regexp.warning "Syöttämäsi merkkijono tulkitaan säännölliseksi lausekkeeksi. Monet säännölliset lausekkeet saattavat hidastaa selailua. Jos tarkoituksena ei ollut käyttää säännöllistä lauseketta, lisää merkki * lauseen loppuun.">
+<!ENTITY shortpattern.warning "Syöttämäsi merkkijono on liian lyhyt optimoitavaksi. Useat tällaiset merkkijonot saattavat hidastaa selailua. On suositeltavaa, että valitset tälle suodattimelle pidemmän merkkijonon.">
+<!ENTITY custom.pattern.label "Oma muokkaus:">
+<!ENTITY custom.pattern.accesskey "O">
+<!ENTITY anchors.label "Hyväksy merkkijono vain:">
+<!ENTITY anchor.start.label "osoitteen alussa">
+<!ENTITY anchor.start.accesskey "t">
+<!ENTITY anchor.start.flexible.label "verkkotunnuksen alussa.">
+<!ENTITY anchor.start.flexible.accesskey "t">
+<!ENTITY anchor.end.label "osoitteen lopussa">
+<!ENTITY anchor.end.accesskey "l">
+<!ENTITY options.label "Valinnat">
+<!ENTITY domainRestriction.label "Rajoita verkkotunnukseen:">
+<!ENTITY domainRestriction.accesskey "a">
+<!ENTITY domainRestriction.help "Määrittele yksi tai useampia verkkotunnuksia &quot;|&quot;-merkilla eroteltuna. Suodatin on käytössä vain näissä verkkotunnuksissa. Suodatinta ei käytetä verkkotunnuksella, jos sen edessä on &quot;~&quot;-merkki.">
+<!ENTITY firstParty.label "Vain sivun ylläpitäjän">
+<!ENTITY firstParty.accesskey "i">
+<!ENTITY thirdParty.label "Vain muiden kuin sivun ylläpitäjän">
+<!ENTITY thirdParty.accesskey "m">
+<!ENTITY matchCase.label "Huomioi kirjainkoko">
+<!ENTITY matchCase.accesskey "H">
+<!ENTITY types.label "Käytä tyypeissä:">
+<!ENTITY selectAllTypes.label "Valitse kaikki">
+<!ENTITY unselectAllTypes.label "Älä valitse mitään">
+<!ENTITY collapse.label "Romahduta estetyt:">
+<!ENTITY collapse.accesskey "R">
+<!ENTITY collapse.default.yes.label "Käytä oletusta (kyllä)">
+<!ENTITY collapse.default.no.label "Käytä oletusta (ei)">
+<!ENTITY collapse.yes.label "Kyllä">
+<!ENTITY collapse.no.label "Ei">

=== added file 'chrome/locale/fi/global.properties'
--- chrome/locale/fi/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/fi/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Napsautus avaa ponnahdusvalikon. Keskinapsautus ottaa käyttöön/poistaa käytöstä.
+action1_tooltip=Napsautus avaa/sulkee elementtilistan. Keskinapsautus ottaa käyttöön/poistaa käytöstä.
+action2_tooltip=Napsautus avaa asetukset. Keskinapsautus ottaa käyttöön/poistaa käytöstä.
+action3_tooltip=Napsauttamalla Adblock Plus otetaan käyttöön/poistetaan käytöstä.
+disabled_tooltip=Adblock Plus ei ole käytössä.
+active_tooltip=Adblock Plus on aktiivinen, ?1? kpl suodatintilauksia ja ?2? kpl omia suodattimia käytössä.
+whitelisted_tooltip=Adblock Plus on poistettu käytöstä tämänhetkisellä sivustolla.
+blocked_count_tooltip=?1? / ?2?
+blocked_count_addendum=(sallituja: ?1?, piilotettuja: ?2?)
+no_blocking_suggestions=Ei estettäviä elementtejä avoimella sivulla
+whitelisted_page=Adblock Plus on poistettu käytöstä avoimella sivulla
+whitelist_description=Sallivat suodattimet
+filterlist_description=Estävät suodattimet
+invalid_description=Virheelliset suodattimet
+elemhide_description=Elementtien piilottamisehdot
+subscription_description=Tilatut suodattimet:
+subscription_wrong_version=Jotkin tämän tilauksen suodattimista vaativat Adblock Plus ?1?:n toimiakseen oikein!
+subscription_source=Osoite:
+subscription_status=Tila:
+subscription_status_autodownload=Automaattisesti päivittyvä
+subscription_status_manualdownload=Päivitettävä käsin
+subscription_status_externaldownload=Päivittyy ulkoisesti (toinen laajennus)
+subscription_status_lastdownload=Viimeisin lataus:
+subscription_status_lastdownload_inprogress=Lataa...
+subscription_status_lastdownload_unknown=N/A
+remove_subscription_warning=Haluatko varmasti poistaa tämän tilauksen?
+import_filters_wrong_version=Varoitus: jotkin tämän tilauksen suodattimista vaativat Adblock Plussan  ?1? toimiakseen oikein. Sinun tulisi luultavasti päivittää Adblock Plussan viimeisimpään versioon ennen tämän listan tuomista.
+import_filters_warning=Haluatko korvata nykyiset suodattimet vai lisätä uudet listan loppuun?
+import_filters_title=Tuo suodattimia
+export_filters_title=Vie suodattimia
+invalid_filters_file=Virheellinen Adblock Plus -suodatintiedosto.
+filters_write_error=Tapahtui virhe kirjoitettaessa suodattimia tiedostoon. Varmista, ettei tiedosto ole kirjoitussuojattu tai ei ole jonkin muun ohjelman käytössä.
+clearall_warning=Haluatko varmasti poistaa kaikki listan suodattimet?
+resethitcounts_warning=Haluatko varmasti nollata kaikkien suodattimien osumamäärät? Tätä toimintoa ei voida peruuttaa jälkikäteen!
+resethitcounts_selected_warning=Haluatko varmasti nollata valittujen suodattimien osumamäärät? Tätä toimintoa ei voida peruuttaa jälkikäteen!
+filter_regexp_tooltip=Tämä suodatin on joko säännöllinen lauseke tai liian lyhyt optimoitavaksi. Liian monta tällaista suodatinta saattaa hidastaa selailuasi.
+filter_elemhide_duplicate_id=Piilotettavalle elementille voidaan määritellä vain yksi tunniste (ID)
+filter_elemhide_nocriteria=Piilotettavaa elementtiä määrittelevää tunnistetta ei annettu
+subscription_notAdded_warning=Et lisännyt suodatintilausta. Ilman sauodatintilausta joudut lisäämään Adblock Plussan suodattimet käsin.
+subscription_notAdded_warning_addendum=Jatketaanko?
+subscription_invalid_location=Suodatinlistan sijainti on joko kelvoton osoite tai tiedoston nimi.
+synchronize_invalid_url=Epäonnistui, kelvoton osoite
+synchronize_connection_error=Epäonnistui, latausvirhe
+synchronize_invalid_data=Epäonnistui, kelvoton suodatinlista
+synchronize_checksum_mismatch=Epäonnistui, tarkistussumma ei täsmää
+synchronize_ok=Onnistui
+overwrite=Korvaa
+append=Lisää loppuun
+new_filter_group_title=Uusi suodatin
+type_label_other=muu
+type_label_script=komento
+type_label_image=kuva
+type_label_stylesheet=tyyliohje
+type_label_object=objekti
+type_label_subdocument=kehys
+type_label_document=dokumentti
+type_label_background=taustakuva
+type_label_elemhide=piilotettu
+type_label_xbl=XBL-liitos
+type_label_ping=ping-link
+type_label_xmlhttprequest=XML-pyyntö
+type_label_object_subrequest=objektin alipyyntö
+type_label_dtd=DTD
+type_label_media=ääni/video
+type_label_font=kirjaisin
+fennec_status_enabled=Adblock Plus on käytössä.
+fennec_status_disabled=Adblock Plus ei ole käytössä.
+fennec_status_enabled_site=Adblock Plus on käytössä sivustolla ?1?.
+fennec_status_disabled_site=Adblock Plus poistettu käytöstä sivustolla ?1?.

=== added file 'chrome/locale/fi/meta.properties'
--- chrome/locale/fi/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/fi/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Joni Heinonen
+name=Adblock Plus
+description=Mainokset ovat menneisyyttä!
+description.short=Ärsyttävätkö mainokset? Huolestutko jäljittämisestä? Asenna Adblock Plus saadaksesi Internetin ohjat takaisin ja muuttaaksesi tapaa, jolla näet verkon.\n\nLyhyt yleiskuvan antava video osoitteessa http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus antaa Internetin ohjat takaisin ja näet verkon sellaisena kuin haluat. Lisäosaa tukee yli neljäkymmentä kymmenillä kielillä olevaa tilattavaa suodatinlistaa, jotka automaattisesti asettavat asetukset eri tilanteisiin sopiviksi vaihdellen mainosten estämisestä haitallisia ohjelmia sisältävien sivustojen estämiseen. Adblock Plus sallii suodattimien muokkaamisen moninaisten hyödyllisten toimintojen avustuksella. Näihin lukeutuvat mm. kuvien estämisen valikkokohta, estokorvake Java -ja Flash-elementtien kanssa ja lista estettävistä komentosarjoista ja tyyliohjeista.

=== added file 'chrome/locale/fi/overlay.dtd'
--- chrome/locale/fi/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fi/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Tila:">
+<!ENTITY blocked.tooltip "Tämän sivun estetyt elementit:">
+<!ENTITY filters.tooltip "Aktiivisimmat suodattimet:">
+<!ENTITY menuitem.label "Adblock Plus - Asetukset">
+<!ENTITY menuitem.accesskey "d">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Estettävät elementit">
+<!ENTITY context.image.label "Adblock Plus: Estä kuva">
+<!ENTITY context.object.label "Adblock Plus: Estä kohde">
+<!ENTITY context.frame.label "Adblock Plus: Estä kehys">
+<!ENTITY context.media.label "Adblock Plus: Estä ääni/kuva">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Ota tämä sivu uudestaan käyttöön">
+<!ENTITY sidebar.title "Estettävät elementit avoimella sivulla">
+<!ENTITY settings.label "Asetukset">
+<!ENTITY settings.accesskey "A">
+<!ENTITY opensidebar.label "Näytä elementit">
+<!ENTITY opensidebar.accesskey "e">
+<!ENTITY closesidebar.label "Sulje elementit">
+<!ENTITY closesidebar.accesskey "e">
+<!ENTITY whitelist.site.label "Ei käytössä osoitteessa ?1?">
+<!ENTITY whitelist.page.label "Ei käytössä tällä sivulla">
+<!ENTITY objecttab.title "Estä">
+<!ENTITY objecttab.tooltip "Estä tämä objekti Adblock Plussalla">

=== added file 'chrome/locale/fi/settings.dtd'
--- chrome/locale/fi/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fi/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus - Asetukset">
+<!ENTITY filters.label "Suodattimet">
+<!ENTITY filters.accesskey "S">
+<!ENTITY add.label "Lisää suodatin">
+<!ENTITY add.accesskey "L">
+<!ENTITY addsubscription.label "Lisää suodatintilaus">
+<!ENTITY addsubscription.accesskey "i">
+<!ENTITY synchsubscriptions.label "Päivitä kaikki tilaukset">
+<!ENTITY synchsubscriptions.accesskey "k">
+<!ENTITY import.label "Tuo suodattimia">
+<!ENTITY import.accesskey "T">
+<!ENTITY export.label "Vie omia suodattimia">
+<!ENTITY export.accesskey "V">
+<!ENTITY clearall.label "Poista kaikki omat suodattimet">
+<!ENTITY clearall.accesskey "P">
+<!ENTITY resethitcounts.label "Nollaa osumatilastot">
+<!ENTITY resethitcounts.accesskey "N">
+<!ENTITY edit.label "Muokkaa">
+<!ENTITY edit.accesskey "M">
+<!ENTITY cut.label "Leikkaa">
+<!ENTITY cut.accesskey "L">
+<!ENTITY copy.label "Kopioi">
+<!ENTITY copy.accesskey "K">
+<!ENTITY paste.label "Liitä">
+<!ENTITY paste.accesskey "i">
+<!ENTITY remove.label "Poista">
+<!ENTITY remove.accesskey "P">
+<!ENTITY menu.find.label "Etsi">
+<!ENTITY menu.find.accesskey "E">
+<!ENTITY menu.findagain.label "Etsi seuraava">
+<!ENTITY menu.findagain.accesskey "t">
+<!ENTITY view.label "Näytä">
+<!ENTITY view.accesskey "N">
+<!ENTITY sort.label "Lajitteluperuste">
+<!ENTITY sort.accesskey "E">
+<!ENTITY sort.none.label "Ei lajiteltu">
+<!ENTITY sort.none.accesskey "L">
+<!ENTITY sort.ascending.label "A &gt; Z lajittelu">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Z &gt; A lajittelu">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Valinnat">
+<!ENTITY options.accesskey "V">
+<!ENTITY enable.label "Adblock Plus käytössä">
+<!ENTITY enable.accesskey "d">
+<!ENTITY showintoolbar.label "Näytä työkalupalkilla">
+<!ENTITY showintoolbar.accesskey "y">
+<!ENTITY showinstatusbar.label "Näytä tilarivillä">
+<!ENTITY showinstatusbar.accesskey "N">
+<!ENTITY objecttabs.label "Korvake Flashin ja Javan yhteydessä">
+<!ENTITY objecttabs.accesskey "K">
+<!ENTITY collapse.label "Romahduta estetyt elementit">
+<!ENTITY collapse.accesskey "R">
+<!ENTITY help.label "Ohje">
+<!ENTITY help.accesskey "O">
+<!ENTITY gettingStarted.label "Alkuun pääseminen">
+<!ENTITY gettingStarted.accesskey "l">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Usein kysytyt kysymykset (FAQ)">
+<!ENTITY faq.accesskey "U">
+<!ENTITY faq.url "http://www.mozilla.fi/wiki/Adblock_Plus">
+<!ENTITY filterdoc.label "Adblock Plus -suodattimien kirjoittamisesta">
+<!ENTITY filterdoc.accesskey "A">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Tietoja Adblock Plussasta">
+<!ENTITY about.accesskey "T">
+<!ENTITY description "Seuraavat suodattimet määrittelevät sen, mitkä osoitteet estetään ja mitkä sallitaan:">
+<!ENTITY filter.column "Suodatusehto">
+<!ENTITY filter.accesskey "S">
+<!ENTITY slow.column "Hitaat suodattimet">
+<!ENTITY slow.accesskey "H">
+<!ENTITY enabled.column "Käytössä">
+<!ENTITY enabled.accesskey "y">
+<!ENTITY hitcount.column "Osumat">
+<!ENTITY hitcount.accesskey "O">
+<!ENTITY lasthit.column "Viimeisin osuma">
+<!ENTITY lasthit.accesskey "V">
+<!ENTITY context.edit.label "Muokkaa suodatinta">
+<!ENTITY context.resethitcount.label "Nollaa suodattimen osumatilastot">
+<!ENTITY context.synchsubscription.label "Päivitä tilaus nyt">
+<!ENTITY context.editsubscription.label "Muokkaa tilausta">
+<!ENTITY context.moveup.label "Siirrä suodatin ylöspäin">
+<!ENTITY context.movedown.label "Siirrä suodatin alaspäin">
+<!ENTITY context.movegroupup.label "Siirrä ryhmä ylöspäin">
+<!ENTITY context.movegroupdown.label "Siirrä ryhmä alaspäin">
+<!ENTITY context.enable.label "Ota käyttöön">
+<!ENTITY context.disable.label "Poista käytöstä">
+<!ENTITY apply.label "Käytä">
+<!ENTITY apply.accesskey "K">
+<!ENTITY fennec.subscription.label "Suodatintilaus">

=== added file 'chrome/locale/fi/sidebar.dtd'
--- chrome/locale/fi/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fi/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Estettävien elementtien lista (irrotettu)">
+<!ENTITY detach.label "Irrota">
+<!ENTITY reattach.label "Kiinnitä">
+<!ENTITY search.label "Etsi:">
+<!ENTITY search.accesskey "E">
+<!ENTITY type.label "Tyyppi">
+<!ENTITY address.label "Osoite">
+<!ENTITY filter.label "Suodatin">
+<!ENTITY state.label "Tila">
+<!ENTITY size.label "Koko">
+<!ENTITY docDomain.label "Dokumentin lähde">
+<!ENTITY noitems.label "Ei estettäviä elementtejä">
+<!ENTITY whitelisted.label "Sallittu sivu">
+<!ENTITY tooltip.address.label "Osoite:">
+<!ENTITY tooltip.type.label "Tyyppi:">
+<!ENTITY tooltip.type.blocked "(estetty)">
+<!ENTITY tooltip.type.whitelisted "(sallittu)">
+<!ENTITY tooltip.size.label "Koko:">
+<!ENTITY tooltip.docDomain.label "Dokumentin lähde:">
+<!ENTITY tooltip.filter.label "Vaikuttava suodatin:">
+<!ENTITY tooltip.filterSource.label "Suodattimen lähde:">
+<!ENTITY context.block.label "Estä elementti">
+<!ENTITY context.editfilter.label "Muokkaa suodatinta">
+<!ENTITY context.whitelist.label "Lisää poikkeusehto">
+<!ENTITY context.disablefilter.label "Poista käytöstä suodatin: ?1?">
+<!ENTITY context.enablefilter.label "Palauta suodatin: ?1?">
+<!ENTITY context.disablefilteronsite.label "Poista tämä suodatin käytöstä osoiteessa ?1?">
+<!ENTITY context.open.label "Avaa uuteen välilehteen">
+<!ENTITY context.flash.label "Välkytä reunoja">
+<!ENTITY context.copy.label "Kopioi osoite">
+<!ENTITY context.copyFilter.label "Kopioi suodatin">
+<!ENTITY context.selectAll.label "Valitse kaikki">

=== added file 'chrome/locale/fi/subscriptionSelection.dtd'
--- chrome/locale/fi/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fi/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Lisää Adblock Plus -suodatintilaus">
+<!ENTITY dialog.title.edit "Muokkaa suodatintilausta">
+<!ENTITY description.newInstall "Adblock Plus on tehokkaimmillan, jos lisäät suodatintilauksen. Muut Adblock Plussan käyttäjät tarjoavat suodatintilaukset ilmaiseksi. Kielellesi kaikkein sopivin tilaus on jo valittu.">
+<!ENTITY adblock.warning "Adblock Plus on huomannut, että Adblockista tai Adblock Plussasta on vanha versio asennettuna. Adblockin ja Adblock Plussan yhtäaikainen käyttäminen saattaa aiheuttaa ongelmia ja tulisi välttää. Suosittelemme Adblockin poistamista välittömästi.">
+<!ENTITY adblock.uninstall "Poista Adblock">
+<!ENTITY filterset.g.warning "Näyttää siltä, että käytät Filterset.G:tä. Tätä suodatinlistaa ei ole ylläpidetty viime vuosina ja yleinen syy ongelmiin verkkosivujen kanssa. Suosittelemme Filterset.G:n poistamista välittömästi.">
+<!ENTITY filterset.g.moreinfo "Lisätietoa">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Poista Filterset.G">
+<!ENTITY subscriptionSelector.label "Valitse suodatintilaus listasta:">
+<!ENTITY viewList.label "Näytä suodattimet">
+<!ENTITY visitHomepage.label "Vieraile kotisivulla">
+<!ENTITY addSubscription.label "Lisää suodatintilaus">
+<!ENTITY saveSubscription.label "Tallenna suodatintilaus">
+<!ENTITY other.label "Lisää jokin muu tilaus">
+<!ENTITY other.accesskey "L">
+<!ENTITY list.download.failed "Adblock Plus ei kyennyt hakemaan suodatinlistaa.">
+<!ENTITY list.download.retry "Kokeile uudestaan">
+<!ENTITY list.download.website "Näytä verkkosivu">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Varmista tämän suodatintilauksen lisääminen. Ennnen tilauksen lisäämistä voit muuttaa tilauksen nimen ja sijainnin.">
+<!ENTITY edit.description "Voit muuttaa tilauksen nimen ja sijainnin, jos tarpeellista.">
+<!ENTITY external.description "Tämä on ulkoinen suodatintilaus; sitä päivittää tilauksen tekijän laajennus.">
+<!ENTITY title.label "Tilauksen nimi:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Listan sijainti:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Päivitä automaattisesti">
+<!ENTITY autodownload.accesskey "a">
+<!ENTITY supplementMessage "Tätä suodatintilausta on tarkoitus käyttää suodatintilauksen &quot;?1?&quot; kanssa, jota et vielä käytä.">
+<!ENTITY addMain.label "Lisäa myös suodatintilaus &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "L">

=== added directory 'chrome/locale/fr'
=== removed directory 'chrome/locale/fr-FR'
=== removed file 'chrome/locale/fr-FR/about.dtd'
--- chrome/locale/fr-FR/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fr-FR/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "À propos d&apos;Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Version">
-<!ENTITY description "Adblock Plus vous permet de décider de ne voir que ce que vous souhaitez voir sur le Web. Vous n&apos;êtes plus obligé de laisser s&apos;afficher des publicités et autres bannières. Si vous n&apos;en voulez plus, activez Adblock Plus !">
-<!ENTITY homepage.label "Page Web :">
-<!ENTITY homepage.url "http://adblockplus.org/fr/">
-<!ENTITY author.label "Auteur :">
-<!ENTITY contributors.label "Contributeurs :">

=== removed file 'chrome/locale/fr-FR/composer.dtd'
--- chrome/locale/fr-FR/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fr-FR/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Ajouter une règle de filtrage Adblock Plus">
-<!ENTITY accept.label "Ajouter le filtre">
-<!ENTITY advanced.label "Affichage avancé">
-<!ENTITY basic.label "Affichage standard">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus est actuellement désactivée. Vous pouvez continuer à ajouter des filtres mais ils ne seront pas appliqués tant que vous n&apos;aurez pas">
-<!ENTITY disabled.warning.link "activé Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Le groupe de filtres &quot;&#37;S&quot; auquel le filtre devrait être ajouté est actuellement désactivé. Vous pouvez l&apos;ajouter tout de même mais il ne sera pas appliqué tant que vous n&apos;aurez pas">
-<!ENTITY groupDisabled.warning.link "activé le groupe de filtres">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Nouveau filtre :">
-<!ENTITY filter.accesskey "f">
-<!ENTITY preferences.label "Afficher les filtres existants…">
-<!ENTITY preferences.accesskey "A">
-<!ENTITY type.filter.label "Filtre bloquant">
-<!ENTITY type.filter.accesskey "b">
-<!ENTITY type.whitelist.label "Règle d&apos;exception">
-<!ENTITY type.whitelist.accesskey "x">
-<!ENTITY pattern.label "Proposition de motifs">
-<!ENTITY pattern.explanation "Le motif peut être une partie de l&apos;adresse, le symbole * jouant le rôle de joker. Le filtre ne sera appliqué qu&apos;aux adresses coïncidant avec le motif.">
-<!ENTITY regexp.warning "Le motif que vous avez indiqué sera interprété comme une expression régulière. Un grand nombre d&apos;expressions régulières ralentira votre navigation. Si vous ne souhaitiez pas utiliser des expressions régulières, veuillez ajouter un * à la fin du motif.">
-<!ENTITY shortpattern.warning "Le motif que vous avez indiqué est trop court pour être optimisé, un grand nombre de ce genre de motifs ralentira votre navigation. Nous vous recommandons de choisir une chaîne de caractères plus longue pour ce filtre.">
-<!ENTITY custom.pattern.label "Personnaliser :">
-<!ENTITY custom.pattern.accesskey "P">
-<!ENTITY anchors.label "Accepter le motif uniquement :">
-<!ENTITY anchor.start.label "en début d&apos;adresse">
-<!ENTITY anchor.start.accesskey "u">
-<!ENTITY anchor.start.flexible.label "au début du nom de domaine">
-<!ENTITY anchor.start.flexible.accesskey "u">
-<!ENTITY anchor.end.label "en fin d&apos;adresse">
-<!ENTITY anchor.end.accesskey "n">
-<!ENTITY options.label "Options">
-<!ENTITY domainRestriction.label "Restreindre au domaine :">
-<!ENTITY domainRestriction.accesskey "d">
-<!ENTITY domainRestriction.help "Spécifiez un ou plusieurs domaines séparés par le symbole « | », le filtre ne s&apos;appliquera alors qu&apos;aux domaines indiqués. Le symbole « ~ » précédant un nom de domaine signifie que le filtre ne devra pas être appliqué sur ce domaine.">
-<!ENTITY firstParty.label "Provenant uniquement du même domaine">
-<!ENTITY firstParty.accesskey "m">
-<!ENTITY thirdParty.label "Provenant uniquement d&apos;autres domaines">
-<!ENTITY thirdParty.accesskey "t">
-<!ENTITY matchCase.label "Sensible à la casse">
-<!ENTITY matchCase.accesskey "c">
-<!ENTITY types.label "Appliquer aux types suivants :">
-<!ENTITY selectAllTypes.label "Tout sélectionner">
-<!ENTITY unselectAllTypes.label "Ne rien sélectionner">
-<!ENTITY collapse.label "Réutiliser l&apos;espace de l&apos;élément filtré :">
-<!ENTITY collapse.accesskey "R">
-<!ENTITY collapse.default.yes.label "Utiliser le comportement par défaut (oui)">
-<!ENTITY collapse.default.no.label "Utiliser le comportement par défaut (non)">
-<!ENTITY collapse.yes.label "Oui">
-<!ENTITY collapse.no.label "Non">

=== removed file 'chrome/locale/fr-FR/global.properties'
--- chrome/locale/fr-FR/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/fr-FR/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Les publicités, c'est du passé !
-status_active_label=Adblock
-status_disabled_label=Désactivée
-action0_tooltip=Clic pour afficher le menu contextuel, clic du milieu pour activer / désactiver.
-action1_tooltip=Clic pour ouvrir / fermer la liste des éléments filtrables, clic du milieu pour activer / désactiver.
-action2_tooltip=Clic pour ouvrir les préférences, clic du milieu pour activer / désactiver.
-action3_tooltip=Clic pour activer / désactiver Adblock Plus.
-active_tooltip=Adblock Plus est active.
-disabled_tooltip=Adblock Plus est désactivée.
-whitelisted_tooltip=Adblock Plus est active mais désactivée pour cette page.
-blocked_count_tooltip=-- bloqués sur --
-no_blocking_suggestions=Aucun élément filtrable sur cette page
-whitelisted_page=Adblock Plus a été désactivée pour cette page
-whitelist_description=Mes règles d'exceptions (liste blanche)
-filterlist_description=Mes filtres de publicités
-invalid_description=Mes filtres invalides
-elemhide_description=Mes filtres masquant les éléments
-subscription_description=Abonnement :
-subscription_wrong_version=Quelques filtres de cet abonnement requièrent Adblock Plus -- pour fonctionner correctement !
-subscription_source=Source :
-subscription_status=État :
-subscription_status_autodownload=Mise à jour automatiquement
-subscription_status_manualdownload=Mise à jour manuellement
-subscription_status_externaldownload=Mise à jour externe (par une autre extension)
-subscription_status_lastdownload=Dernière mise à jour :
-subscription_status_lastdownload_inprogress=Téléchargement en cours…
-subscription_status_lastdownload_unknown=Inconnu
-remove_subscription_warning=Souhaitez-vous vraiment vous désabonner ?
-import_filters_wrong_version=Avertissement : Quelques filtres dans cette liste requièrent Adblock Plus -- pour fonctionner correctement. Vous devriez mettre à jour Adblock Plus avant d'importer cette liste.
-import_filters_warning=Souhaitez-vous remplacer vos filtres actuels ou ajouter les nouveaux filtres à la fin de la liste ?
-import_filters_title=Importation de filtres
-export_filters_title=Exportation de filtres
-invalid_filters_file=Ceci n'est pas un fichier de filtres Adblock Plus valide.
-filters_write_error=Une erreur s'est produite lors de l'enregistrement des filtres dans le fichier. Assurez-vous que le fichier n'est pas protégé en écriture ou utilisé par un autre programme.
-clearall_warning=Souhaitez-vous vraiment supprimer tous les filtres de la liste ?
-resethitcounts_warning=Souhaitez-vous vraiment remettre le compteur de fréquence d'utilisation à zéro pour tous les filtres ? Cette opération est irréversible !
-resethitcounts_selected_warning=Souhaitez-vous vraiment remettre le compteur de fréquence d'utilisation à zéro pour les filtres sélectionnés ? Cette opération est irréversible !
-filter_regexp_tooltip=Ce filtre est soit une expression régulière soit trop court pour être optimisé. Un excès de ce genre de filtres pourra ralentir votre navigation.
-filter_elemhide_duplicate_id=Il n'est possible de spécifier qu'une ID de l'élément à masquer
-filter_elemhide_nocriteria=Aucun critère spécifié pour reconnaître l'élément à masquer
-subscription_no_location=Veuillez indiquer l'emplacement des filtres à télécharger.
-subscription_invalid_location=L'adresse indiquant l'emplacement de la liste de filtres n'est ni une URL valide, ni un nom de fichier valide.
-subscription_location_exists=Vous avez déjà souscrit à cet abonnement.
-synchronize_invalid_url=Échec, ceci n'est pas une adresse valide !
-synchronize_connection_error=Échec, erreur lors du téléchargement !
-synchronize_invalid_data=Échec, ceci n'est pas une liste de filtres valide !
-synchronize_checksum_mismatch=Échec, le checksum ne correspond pas !
-synchronize_ok=Réussie
-overwrite=Remplacer
-append=Ajouter
-new_filter_group_title=Nouveau filtre
-type_label_other=autre
-type_label_script=script
-type_label_image=image
-type_label_stylesheet=feuille de style
-type_label_object=objet
-type_label_subdocument=cadre
-type_label_document=document
-type_label_background=Arrière-plan
-type_label_elemhide=masqué
-type_label_xbl=liaison XBL
-type_label_ping=ping de lien
-type_label_xmlhttprequest=requête XML
-type_label_object_subrequest=sous-requête objet
-type_label_dtd=DTD
-type_label_media=audio/vidéo
-type_label_font=police

=== removed file 'chrome/locale/fr-FR/overlay.dtd'
--- chrome/locale/fr-FR/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fr-FR/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "État :">
-<!ENTITY blocked.tooltip "Éléments bloqués sur cette page :">
-<!ENTITY filters.tooltip "Filtres les plus utilisés :">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "b">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus : éléments filtrables">
-<!ENTITY context.image.label "Bloquer l&apos;image avec Adblock">
-<!ENTITY context.object.label "Bloquer l&apos;objet avec Adblock">
-<!ENTITY context.frame.label "Bloquer le cadre avec Adblock">
-<!ENTITY context.removeWhitelist.label "Adblock Plus : activer à nouveau pour cette page">
-<!ENTITY sidebar.title "Éléments filtrables dans la page courante">
-<!ENTITY settings.label "Préférences">
-<!ENTITY settings.accesskey "P">
-<!ENTITY opensidebar.label "Ouvrir la liste des éléments filtrables">
-<!ENTITY opensidebar.accesskey "m">
-<!ENTITY closesidebar.label "Fermer la liste des éléments filtrables">
-<!ENTITY closesidebar.accesskey "m">
-<!ENTITY whitelist.site.label "Désactiver pour --">
-<!ENTITY whitelist.page.label "Désactiver pour cette page uniquement">
-<!ENTITY objecttab.title "Bloquer">
-<!ENTITY objecttab.tooltip "Cliquer ici afin qu&apos;Adblock Plus bloque cet objet">

=== removed file 'chrome/locale/fr-FR/settings.dtd'
--- chrome/locale/fr-FR/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fr-FR/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Préférences d&apos;Adblock Plus">
-<!ENTITY filters.label "Filtres">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Ajouter un filtre">
-<!ENTITY add.accesskey "j">
-<!ENTITY addsubscription.label "S&apos;abonner à la liste de filtres">
-<!ENTITY addsubscription.accesskey "l">
-<!ENTITY synchsubscriptions.label "Mettre à jour tous les abonnements">
-<!ENTITY synchsubscriptions.accesskey "t">
-<!ENTITY import.label "Importer des filtres">
-<!ENTITY import.accesskey "I">
-<!ENTITY export.label "Exporter les filtres personnalisés">
-<!ENTITY export.accesskey "E">
-<!ENTITY clearall.label "Supprimer tous les filtres personnalisés">
-<!ENTITY clearall.accesskey "S">
-<!ENTITY resethitcounts.label "Remettre le compteur à zéro">
-<!ENTITY resethitcounts.accesskey "z">
-<!ENTITY edit.label "Édition">
-<!ENTITY edit.accesskey "d">
-<!ENTITY cut.label "Couper">
-<!ENTITY cut.accesskey "u">
-<!ENTITY copy.label "Copier">
-<!ENTITY copy.accesskey "p">
-<!ENTITY paste.label "Coller">
-<!ENTITY paste.accesskey "o">
-<!ENTITY remove.label "Supprimer">
-<!ENTITY remove.accesskey "m">
-<!ENTITY menu.find.label "Rechercher">
-<!ENTITY menu.find.accesskey "h">
-<!ENTITY menu.findagain.label "Rechercher à nouveau">
-<!ENTITY menu.findagain.accesskey "v">
-<!ENTITY view.label "Affichage">
-<!ENTITY view.accesskey "h">
-<!ENTITY sort.label "Trier par">
-<!ENTITY sort.accesskey "T">
-<!ENTITY sort.none.label "Non trié">
-<!ENTITY sort.none.accesskey "N">
-<!ENTITY sort.ascending.label "Ordre de A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Ordre de Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Options">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Activer Adblock Plus">
-<!ENTITY enable.accesskey "A">
-<!ENTITY showintoolbar.label "Afficher dans la barre d&apos;outils">
-<!ENTITY showintoolbar.accesskey "o">
-<!ENTITY showinstatusbar.label "Afficher dans la barre d&apos;état">
-<!ENTITY showinstatusbar.accesskey "n">
-<!ENTITY objecttabs.label "Afficher une étiquette pour Flash et Java">
-<!ENTITY objecttabs.accesskey "J">
-<!ENTITY collapse.label "Utiliser l&apos;espace libéré par les éléments bloqués">
-<!ENTITY collapse.accesskey "u">
-<!ENTITY help.label "Aide">
-<!ENTITY help.accesskey "A">
-<!ENTITY gettingStarted.label "Pour commencer">
-<!ENTITY gettingStarted.accesskey "m">
-<!ENTITY gettingStarted.url "http://adblockplus.org/fr/getting_started">
-<!ENTITY faq.label "Foire Aux Questions">
-<!ENTITY faq.accesskey "F">
-<!ENTITY faq.url "http://adblockplus.org/fr/faq">
-<!ENTITY filterdoc.label "Créer des filtres Adblock Plus">
-<!ENTITY filterdoc.accesskey "C">
-<!ENTITY filterdoc.url "http://adblockplus.org/fr/filters">
-<!ENTITY about.label "À propos d&apos;Adblock Plus">
-<!ENTITY about.accesskey "A">
-<!ENTITY description "Les filtres suivants indiquent les adresses qui devront être bloquées et celles qui devront être autorisées :">
-<!ENTITY filter.column "Règle de filtrage">
-<!ENTITY filter.accesskey "F">
-<!ENTITY slow.column "Afficher les filtres">
-<!ENTITY slow.accesskey "h">
-<!ENTITY enabled.column "Activé">
-<!ENTITY enabled.accesskey "c">
-<!ENTITY hitcount.column "Compteur">
-<!ENTITY hitcount.accesskey "m">
-<!ENTITY lasthit.column "Dernière utilisation">
-<!ENTITY lasthit.accesskey "D">
-<!ENTITY context.edit.label "Modifier le filtre">
-<!ENTITY context.resethitcount.label "Remettre le compteur à zéro">
-<!ENTITY context.synchsubscription.label "Mettre à jour maintenant">
-<!ENTITY context.editsubscription.label "Éditer l&apos;abonnement">
-<!ENTITY context.moveup.label "Monter">
-<!ENTITY context.movedown.label "Descendre">
-<!ENTITY context.movegroupup.label "Monter la sélection">
-<!ENTITY context.movegroupdown.label "Descendre la sélection">
-<!ENTITY context.enable.label "Activer">
-<!ENTITY context.disable.label "Désactiver">
-<!ENTITY apply.label "Appliquer">
-<!ENTITY apply.accesskey "p">

=== removed file 'chrome/locale/fr-FR/sidebar.dtd'
--- chrome/locale/fr-FR/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fr-FR/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus : éléments filtrables (détaché)">
-<!ENTITY detach.label "Détacher">
-<!ENTITY reattach.label "Rattacher">
-<!ENTITY search.label "Chercher :">
-<!ENTITY search.accesskey "C">
-<!ENTITY type.label "Type">
-<!ENTITY address.label "Adresse">
-<!ENTITY filter.label "Filtre">
-<!ENTITY state.label "État">
-<!ENTITY size.label "Taille">
-<!ENTITY docDomain.label "Source du document">
-<!ENTITY noitems.label "Aucun élément filtrable">
-<!ENTITY whitelisted.label "Page dans la liste blanche">
-<!ENTITY tooltip.address.label "Adresse :">
-<!ENTITY tooltip.type.label "Type :">
-<!ENTITY tooltip.type.blocked "(bloqué)">
-<!ENTITY tooltip.type.whitelisted "(autorisé)">
-<!ENTITY tooltip.size.label "Taille :">
-<!ENTITY tooltip.docDomain.label "Source du document :">
-<!ENTITY tooltip.filter.label "Filtre utilisé :">
-<!ENTITY tooltip.filterSource.label "Source du filtre :">
-<!ENTITY context.block.label "Bloquer cet élément">
-<!ENTITY context.editfilter.label "Modifier le filtre actif">
-<!ENTITY context.whitelist.label "Ajouter à la liste blanche">
-<!ENTITY context.disablefilter.label "Désactiver le filtre --">
-<!ENTITY context.enablefilter.label "Réactiver le filtre --">
-<!ENTITY context.disablefilteronsite.label "Désactiver ce filtre pour --">
-<!ENTITY context.open.label "Ouvrir dans un nouvel onglet">
-<!ENTITY context.flash.label "Faire clignoter les bordures de l&apos;élément">
-<!ENTITY context.copy.label "Copier l&apos;adresse de l&apos;élément">
-<!ENTITY context.copyFilter.label "Copier le filtre">
-<!ENTITY context.selectAll.label "Tout sélectionner">

=== removed file 'chrome/locale/fr-FR/subscription.dtd'
--- chrome/locale/fr-FR/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fr-FR/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Modifier l&apos;abonnement">
-<!ENTITY dialog.newtitle "S&apos;abonner à une liste de filtres">
-<!ENTITY new.description "Veuillez indiquer l&apos;adresse Web ou le fichier contenant une liste de filtres Adblock Plus.">
-<!ENTITY edit.description "La liste de filtres souscrite sera téléchargée à partir de l&apos;emplacement indiqué.">
-<!ENTITY external.description "Ceci est un abonnement externe à une liste de filtres qui sera maintenu à jour par l&apos;extension s&apos;étant chargée de l&apos;abonnement.">
-<!ENTITY autodownload.description "Si vous choisissez l&apos;option « Mettre à jour automatiquement », la mise à jour sera recherchée et vérifiée quotidiennement à l&apos;emplacement indiqué ci-dessous. Si vous désactivez cette option, vous pouvez tout de même effectuer une mise à jour manuelle à partir du menu contextuel (clic droit sur le nom de l&apos;abonnement dans la fenêtre de la liste des filtres).">
-<!ENTITY location.label "Emplacement de la liste :">
-<!ENTITY location.accesskey "E">
-<!ENTITY title.label "Nom de l&apos;abonnement :">
-<!ENTITY title.accesskey "N">
-<!ENTITY autodownload.label "Mettre à jour automatiquement">
-<!ENTITY autodownload.accesskey "M">
-<!ENTITY enabled.label "Activer les filtres">
-<!ENTITY enabled.accesskey "A">

=== removed file 'chrome/locale/fr-FR/tip_subscriptions.dtd'
--- chrome/locale/fr-FR/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fr-FR/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Bienvenue sur Adblock Plus">
-<!ENTITY description.par1 "Merci d&apos;avoir installé Adblock Plus. Cette extension peut éliminer 99&#37; des publicités que vous rencontrez sur le Web. Cependant, pour obtenir un filtrage de publicités efficace vous devez définir un bon jeu de filtres. Vous pouvez le composer vous-même ou simplement vous abonner à des listes de filtres que d&apos;autres utilisateurs mettent à disposition et à jour pour vous. Dans ce dernier cas, il sera toujours possible d&apos;ajouter vos propres filtres ou de désactiver/supprimer l&apos;abonnement quand le besoin s&apos;en fait sentir.">
-<!ENTITY description.par2 "Vous pouvez choisir un des abonnements recommandés listés ci-dessous (il sera possible de vous abonner à d&apos;autres listes dans les préférences d&apos;Adblock Plus plus tard, mais cela n&apos;est généralement pas nécessaire) :">
-<!ENTITY note "Remarque : Une liste de filtres sera d&apos;autant plus efficace qu&apos;elle aura été créée pour la région des pages Web consultées.">
-<!ENTITY adblock.warning "Adblock Plus a détecté qu&apos;Adblock ou une ancienne version d&apos;Adblock Plus est installée. Faire fonctionner les deux Adblock en parallèle peut engendrer des problèmes et doit être évité. Il est recommandé de désinstaller Adblock immédiatement.">
-<!ENTITY adblock.uninstall "Désinstaller Adblock">
-<!ENTITY filterset.g.warning "Il semblerait que vous utilisiez Filterset.G. Cette liste de filtre a été maintenue de manière aléatoire ces dernières années et est la cause de problèmes avec des sites Web. Il est recommandé de désinstaller Filterset.G immédiatement.">
-<!ENTITY filterset.g.moreinfo "Davantage d&apos;informations">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/fr/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Désinstaller Filterset.G">
-<!ENTITY homepage.label "Page Web">
-<!ENTITY subscribe.label "S&apos;abonner">
-<!ENTITY subscribe.accesskey "b">
-<!ENTITY other.label "Ajouter un autre abonnement">
-<!ENTITY other.accesskey "t">
-<!ENTITY full-list.url "http://adblockplus.org/fr/subscriptions">
-<!ENTITY full-list.label "Voir tous les abonnements">

=== added file 'chrome/locale/fr/about.dtd'
--- chrome/locale/fr/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fr/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "À propos d'Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Version">
+<!ENTITY description "Adblock Plus vous permet de décider de ne voir que ce que vous souhaitez voir sur le Web. Vous n'êtes plus obligé de laisser s'afficher des publicités et autres bannières. Si vous n'en voulez plus, activez Adblock Plus !">
+<!ENTITY homepage.label "Page Web :">
+<!ENTITY homepage.url "http://adblockplus.org/fr/">
+<!ENTITY author.label "Auteur :">
+<!ENTITY contributors.label "Contributeurs :">
+<!ENTITY developers.label "Développeurs :">
+<!ENTITY designers.label "Graphistes :">
+<!ENTITY subscriptionAuthors.label "Auteurs des abonnements aux filtres :">
+<!ENTITY translators.label "Traducteurs :">

=== added file 'chrome/locale/fr/composer.dtd'
--- chrome/locale/fr/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fr/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Ajouter une règle de filtrage Adblock Plus">
+<!ENTITY accept.label "Ajouter le filtre">
+<!ENTITY advanced.label "Affichage avancé">
+<!ENTITY basic.label "Affichage standard">
+<!ENTITY disabled.warning "Adblock Plus est actuellement désactivée. Vous pouvez continuer à ajouter des filtres mais ils ne seront pas appliqués tant que vous n&apos;aurez pas [link]activé Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Le groupe de filtres &quot;?1?&quot; auquel le filtre devrait être ajouté est actuellement désactivé. Vous pouvez l&apos;ajouter tout de même mais il ne sera pas appliqué tant que vous n&apos;aurez pas [link]activé le groupe de filtres[/link].">
+<!ENTITY filter.label "Nouveau filtre :">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "Afficher les filtres existants…">
+<!ENTITY preferences.accesskey "A">
+<!ENTITY type.filter.label "Filtre bloquant">
+<!ENTITY type.filter.accesskey "b">
+<!ENTITY type.whitelist.label "Règle d&apos;exception">
+<!ENTITY type.whitelist.accesskey "x">
+<!ENTITY pattern.label "Proposition de motifs">
+<!ENTITY pattern.explanation "Le motif peut être une partie de l&apos;adresse, le symbole * jouant le rôle de joker. Le filtre ne sera appliqué qu&apos;aux adresses coïncidant avec le motif.">
+<!ENTITY regexp.warning "Le motif que vous avez indiqué sera interprété comme une expression régulière. Un grand nombre d&apos;expressions régulières ralentira votre navigation. Si vous ne souhaitiez pas utiliser des expressions régulières, veuillez ajouter un * à la fin du motif.">
+<!ENTITY shortpattern.warning "Le motif que vous avez indiqué est trop court pour être optimisé, un grand nombre de ce genre de motifs ralentira votre navigation. Nous vous recommandons de choisir une chaîne de caractères plus longue pour ce filtre.">
+<!ENTITY custom.pattern.label "Personnaliser :">
+<!ENTITY custom.pattern.accesskey "P">
+<!ENTITY anchors.label "Accepter le motif uniquement :">
+<!ENTITY anchor.start.label "en début d&apos;adresse">
+<!ENTITY anchor.start.accesskey "u">
+<!ENTITY anchor.start.flexible.label "au début du nom de domaine">
+<!ENTITY anchor.start.flexible.accesskey "u">
+<!ENTITY anchor.end.label "en fin d&apos;adresse">
+<!ENTITY anchor.end.accesskey "n">
+<!ENTITY options.label "Options">
+<!ENTITY domainRestriction.label "Restreindre au domaine :">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "Spécifiez un ou plusieurs domaines séparés par le symbole « | », le filtre ne s&apos;appliquera alors qu&apos;aux domaines indiqués. Le symbole « ~ » précédant un nom de domaine signifie que le filtre ne devra pas être appliqué sur ce domaine.">
+<!ENTITY firstParty.label "Provenant uniquement du même domaine">
+<!ENTITY firstParty.accesskey "m">
+<!ENTITY thirdParty.label "Provenant uniquement d&apos;autres domaines">
+<!ENTITY thirdParty.accesskey "t">
+<!ENTITY matchCase.label "Sensible à la casse">
+<!ENTITY matchCase.accesskey "c">
+<!ENTITY types.label "Appliquer aux types suivants :">
+<!ENTITY selectAllTypes.label "Tout sélectionner">
+<!ENTITY unselectAllTypes.label "Ne rien sélectionner">
+<!ENTITY collapse.label "Réutiliser l&apos;espace de l&apos;élément filtré :">
+<!ENTITY collapse.accesskey "R">
+<!ENTITY collapse.default.yes.label "Utiliser le comportement par défaut (oui)">
+<!ENTITY collapse.default.no.label "Utiliser le comportement par défaut (non)">
+<!ENTITY collapse.yes.label "Oui">
+<!ENTITY collapse.no.label "Non">

=== added file 'chrome/locale/fr/global.properties'
--- chrome/locale/fr/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/fr/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Clic pour afficher le menu contextuel, clic du milieu pour activer / désactiver.
+action1_tooltip=Clic pour ouvrir / fermer la liste des éléments filtrables, clic du milieu pour activer / désactiver.
+action2_tooltip=Clic pour ouvrir les préférences, clic du milieu pour activer / désactiver.
+action3_tooltip=Clic pour activer / désactiver Adblock Plus.
+disabled_tooltip=Adblock Plus est désactivée.
+active_tooltip=Adblock Plus est active, ?1? abonnement(s) et ?2? filtre(s) personnels utilisé(s).
+whitelisted_tooltip=Adblock Plus est active mais désactivée pour cette page.
+blocked_count_tooltip=?1? bloqués sur ?2?
+blocked_count_addendum=(également en liste blanche : ?1?, masqué(s) : ?2?)
+no_blocking_suggestions=Aucun élément filtrable sur cette page
+whitelisted_page=Adblock Plus a été désactivée pour cette page
+whitelist_description=Mes règles d'exceptions (liste blanche)
+filterlist_description=Mes filtres de publicités
+invalid_description=Mes filtres invalides
+elemhide_description=Mes filtres masquant les éléments
+subscription_description=Abonnement :
+subscription_wrong_version=Quelques filtres de cet abonnement requièrent Adblock Plus ?1? pour fonctionner correctement !
+subscription_source=Source :
+subscription_status=État :
+subscription_status_autodownload=Mise à jour automatiquement
+subscription_status_manualdownload=Mise à jour manuellement
+subscription_status_externaldownload=Mise à jour externe (par une autre extension)
+subscription_status_lastdownload=Dernière mise à jour :
+subscription_status_lastdownload_inprogress=Téléchargement en cours…
+subscription_status_lastdownload_unknown=Inconnu
+remove_subscription_warning=Souhaitez-vous vraiment vous désabonner ?
+import_filters_wrong_version=Avertissement : Quelques filtres dans cette liste requièrent Adblock Plus ?1? pour fonctionner correctement. Vous devriez mettre à jour Adblock Plus avant d'importer cette liste.
+import_filters_warning=Souhaitez-vous remplacer vos filtres actuels ou ajouter les nouveaux filtres à la fin de la liste ?
+import_filters_title=Importation de filtres
+export_filters_title=Exportation de filtres
+invalid_filters_file=Ceci n'est pas un fichier de filtres Adblock Plus valide.
+filters_write_error=Une erreur s'est produite lors de l'enregistrement des filtres dans le fichier. Assurez-vous que le fichier n'est pas protégé en écriture ou utilisé par un autre programme.
+clearall_warning=Souhaitez-vous vraiment supprimer tous les filtres de la liste ?
+resethitcounts_warning=Souhaitez-vous vraiment remettre le compteur de fréquence d'utilisation à zéro pour tous les filtres ? Cette opération est irréversible !
+resethitcounts_selected_warning=Souhaitez-vous vraiment remettre le compteur de fréquence d'utilisation à zéro pour les filtres sélectionnés ? Cette opération est irréversible !
+filter_regexp_tooltip=Ce filtre est soit une expression régulière soit trop court pour être optimisé. Un excès de ce genre de filtres pourra ralentir votre navigation.
+filter_elemhide_duplicate_id=Il n'est possible de spécifier qu'une ID de l'élément à masquer
+filter_elemhide_nocriteria=Aucun critère spécifié pour reconnaître l'élément à masquer
+subscription_notAdded_warning=Vous n'avez pas ajouté d'abonnement à une liste de filtres. Sans abonnement, vous devrez ajouter des filtres Adblock Plus manuellement.
+subscription_notAdded_warning_addendum=Voulez-vous continuer ?
+subscription_invalid_location=L'adresse indiquant l'emplacement de la liste de filtres n'est ni une URL valide, ni un nom de fichier valide.
+synchronize_invalid_url=Échec, ceci n'est pas une adresse valide !
+synchronize_connection_error=Échec, erreur lors du téléchargement !
+synchronize_invalid_data=Échec, ceci n'est pas une liste de filtres valide !
+synchronize_checksum_mismatch=Échec, le checksum ne correspond pas !
+synchronize_ok=Réussie
+overwrite=Remplacer
+append=Ajouter
+new_filter_group_title=Nouveau filtre
+type_label_other=autre
+type_label_script=script
+type_label_image=image
+type_label_stylesheet=feuille de style
+type_label_object=objet
+type_label_subdocument=cadre
+type_label_document=document
+type_label_background=Arrière-plan
+type_label_elemhide=masqué
+type_label_xbl=liaison XBL
+type_label_ping=ping de lien
+type_label_xmlhttprequest=requête XML
+type_label_object_subrequest=sous-requête objet
+type_label_dtd=DTD
+type_label_media=audio/vidéo
+type_label_font=police
+fennec_status_enabled=Adblock Plus est activé.
+fennec_status_disabled=Adblock Plus est désactivé.
+fennec_status_enabled_site=Adblock Plus est activé pour ?1?.
+fennec_status_disabled_site=Adblock Plus est désactivé pour ?1?.

=== added file 'chrome/locale/fr/meta.properties'
--- chrome/locale/fr/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/fr/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=jojaba, Dagobert_78, pirlouy
+name=Adblock Plus
+description=Les publicités, c'est du passé !
+description.short=Agacé par les publicités ? Préoccupé par le fait d'être pisté ? Installez Adblock Plus maintenant pour reprendre le contrôle de ce que vous voyez sur le Web.\n\nVidéo de démonstration : http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus vous permet de reprendre le contrôle d'Internet et de visualiser le Web de la manière que vous souhaitez. L'extension prend en charge plus de quarante abonnements à des listes de filtres en des dizaines de langues qui la configurent automatiquement afin, entre autres, de supprimer des publicités en ligne et de bloquer tous les domaines malveillants. Adblock Plus vous permet également de personnaliser vos filtres à l'aide d'une variété de fonctionnalités très utiles telles qu'une option contextuelle pour les images, un onglet permettant de bloquer les objets Flash et Java et une liste d'éléments filtrables pour supprimer des scripts et des feuilles de style.

=== added file 'chrome/locale/fr/overlay.dtd'
--- chrome/locale/fr/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fr/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "État :">
+<!ENTITY blocked.tooltip "Éléments bloqués sur cette page :">
+<!ENTITY filters.tooltip "Filtres les plus utilisés :">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "b">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus : éléments filtrables">
+<!ENTITY context.image.label "Bloquer l'image avec Adblock">
+<!ENTITY context.object.label "Bloquer l'objet avec Adblock">
+<!ENTITY context.frame.label "Bloquer le cadre avec Adblock">
+<!ENTITY context.media.label "Bloquer les vidéo/audio avec Adblock">
+<!ENTITY context.removeWhitelist.label "Adblock Plus : activer à nouveau pour cette page">
+<!ENTITY sidebar.title "Éléments filtrables dans la page courante">
+<!ENTITY settings.label "Préférences">
+<!ENTITY settings.accesskey "P">
+<!ENTITY opensidebar.label "Ouvrir la liste des éléments filtrables">
+<!ENTITY opensidebar.accesskey "m">
+<!ENTITY closesidebar.label "Fermer la liste des éléments filtrables">
+<!ENTITY closesidebar.accesskey "m">
+<!ENTITY whitelist.site.label "Désactiver pour ?1?">
+<!ENTITY whitelist.page.label "Désactiver pour cette page uniquement">
+<!ENTITY objecttab.title "Bloquer">
+<!ENTITY objecttab.tooltip "Cliquer ici afin qu'Adblock Plus bloque cet objet">

=== added file 'chrome/locale/fr/settings.dtd'
--- chrome/locale/fr/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fr/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Préférences d&apos;Adblock Plus">
+<!ENTITY filters.label "Filtres">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Ajouter un filtre">
+<!ENTITY add.accesskey "j">
+<!ENTITY addsubscription.label "S&apos;abonner à la liste de filtres">
+<!ENTITY addsubscription.accesskey "l">
+<!ENTITY synchsubscriptions.label "Mettre à jour tous les abonnements">
+<!ENTITY synchsubscriptions.accesskey "t">
+<!ENTITY import.label "Importer des filtres">
+<!ENTITY import.accesskey "I">
+<!ENTITY export.label "Exporter les filtres personnalisés">
+<!ENTITY export.accesskey "E">
+<!ENTITY clearall.label "Supprimer tous les filtres personnalisés">
+<!ENTITY clearall.accesskey "S">
+<!ENTITY resethitcounts.label "Remettre le compteur à zéro">
+<!ENTITY resethitcounts.accesskey "z">
+<!ENTITY edit.label "Édition">
+<!ENTITY edit.accesskey "d">
+<!ENTITY cut.label "Couper">
+<!ENTITY cut.accesskey "u">
+<!ENTITY copy.label "Copier">
+<!ENTITY copy.accesskey "p">
+<!ENTITY paste.label "Coller">
+<!ENTITY paste.accesskey "o">
+<!ENTITY remove.label "Supprimer">
+<!ENTITY remove.accesskey "m">
+<!ENTITY menu.find.label "Rechercher">
+<!ENTITY menu.find.accesskey "h">
+<!ENTITY menu.findagain.label "Rechercher à nouveau">
+<!ENTITY menu.findagain.accesskey "v">
+<!ENTITY view.label "Affichage">
+<!ENTITY view.accesskey "h">
+<!ENTITY sort.label "Trier par">
+<!ENTITY sort.accesskey "T">
+<!ENTITY sort.none.label "Non trié">
+<!ENTITY sort.none.accesskey "N">
+<!ENTITY sort.ascending.label "Ordre de A &gt; Z">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Ordre de Z &gt; A">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Options">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Activer Adblock Plus">
+<!ENTITY enable.accesskey "A">
+<!ENTITY showintoolbar.label "Afficher dans la barre d&apos;outils">
+<!ENTITY showintoolbar.accesskey "o">
+<!ENTITY showinstatusbar.label "Afficher dans la barre d&apos;état">
+<!ENTITY showinstatusbar.accesskey "n">
+<!ENTITY objecttabs.label "Afficher une étiquette pour Flash et Java">
+<!ENTITY objecttabs.accesskey "J">
+<!ENTITY collapse.label "Utiliser l&apos;espace libéré par les éléments bloqués">
+<!ENTITY collapse.accesskey "u">
+<!ENTITY help.label "Aide">
+<!ENTITY help.accesskey "A">
+<!ENTITY gettingStarted.label "Pour commencer">
+<!ENTITY gettingStarted.accesskey "m">
+<!ENTITY gettingStarted.url "http://adblockplus.org/fr/getting_started">
+<!ENTITY faq.label "Foire Aux Questions">
+<!ENTITY faq.accesskey "F">
+<!ENTITY faq.url "http://adblockplus.org/fr/faq">
+<!ENTITY filterdoc.label "Créer des filtres Adblock Plus">
+<!ENTITY filterdoc.accesskey "C">
+<!ENTITY filterdoc.url "http://adblockplus.org/fr/filters">
+<!ENTITY about.label "À propos d&apos;Adblock Plus">
+<!ENTITY about.accesskey "A">
+<!ENTITY description "Les filtres suivants indiquent les adresses qui devront être bloquées et celles qui devront être autorisées :">
+<!ENTITY filter.column "Règle de filtrage">
+<!ENTITY filter.accesskey "F">
+<!ENTITY slow.column "Afficher les filtres">
+<!ENTITY slow.accesskey "h">
+<!ENTITY enabled.column "Activé">
+<!ENTITY enabled.accesskey "c">
+<!ENTITY hitcount.column "Compteur">
+<!ENTITY hitcount.accesskey "m">
+<!ENTITY lasthit.column "Dernière utilisation">
+<!ENTITY lasthit.accesskey "D">
+<!ENTITY context.edit.label "Modifier le filtre">
+<!ENTITY context.resethitcount.label "Remettre le compteur à zéro">
+<!ENTITY context.synchsubscription.label "Mettre à jour maintenant">
+<!ENTITY context.editsubscription.label "Éditer l&apos;abonnement">
+<!ENTITY context.moveup.label "Monter">
+<!ENTITY context.movedown.label "Descendre">
+<!ENTITY context.movegroupup.label "Monter la sélection">
+<!ENTITY context.movegroupdown.label "Descendre la sélection">
+<!ENTITY context.enable.label "Activer">
+<!ENTITY context.disable.label "Désactiver">
+<!ENTITY apply.label "Appliquer">
+<!ENTITY apply.accesskey "p">
+<!ENTITY fennec.subscription.label "Abonnement">

=== added file 'chrome/locale/fr/sidebar.dtd'
--- chrome/locale/fr/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fr/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus : éléments filtrables (détaché)">
+<!ENTITY detach.label "Détacher">
+<!ENTITY reattach.label "Rattacher">
+<!ENTITY search.label "Chercher :">
+<!ENTITY search.accesskey "C">
+<!ENTITY type.label "Type">
+<!ENTITY address.label "Adresse">
+<!ENTITY filter.label "Filtre">
+<!ENTITY state.label "État">
+<!ENTITY size.label "Taille">
+<!ENTITY docDomain.label "Source du document">
+<!ENTITY noitems.label "Aucun élément filtrable">
+<!ENTITY whitelisted.label "Page dans la liste blanche">
+<!ENTITY tooltip.address.label "Adresse :">
+<!ENTITY tooltip.type.label "Type :">
+<!ENTITY tooltip.type.blocked "(bloqué)">
+<!ENTITY tooltip.type.whitelisted "(autorisé)">
+<!ENTITY tooltip.size.label "Taille :">
+<!ENTITY tooltip.docDomain.label "Source du document :">
+<!ENTITY tooltip.filter.label "Filtre utilisé :">
+<!ENTITY tooltip.filterSource.label "Source du filtre :">
+<!ENTITY context.block.label "Bloquer cet élément">
+<!ENTITY context.editfilter.label "Modifier le filtre actif">
+<!ENTITY context.whitelist.label "Ajouter à la liste blanche">
+<!ENTITY context.disablefilter.label "Désactiver le filtre ?1?">
+<!ENTITY context.enablefilter.label "Réactiver le filtre ?1?">
+<!ENTITY context.disablefilteronsite.label "Désactiver ce filtre pour ?1?">
+<!ENTITY context.open.label "Ouvrir dans un nouvel onglet">
+<!ENTITY context.flash.label "Faire clignoter les bordures de l&apos;élément">
+<!ENTITY context.copy.label "Copier l&apos;adresse de l&apos;élément">
+<!ENTITY context.copyFilter.label "Copier le filtre">
+<!ENTITY context.selectAll.label "Tout sélectionner">

=== added file 'chrome/locale/fr/subscriptionSelection.dtd'
--- chrome/locale/fr/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fr/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Ajouter un abonnement à une liste de filtres Adblock Plus">
+<!ENTITY dialog.title.edit "Modifier l'abonnement">
+<!ENTITY description.newInstall "Adblock Plus sera plus efficace si vous vous souscrivez à une liste de filtres. Les abonnements sont fournis gracieusement par d'autres utilisateurs d'Adblock Plus. L'abonnement le plus adapté à votre langue est d'ores et déjà sélectionné.">
+<!ENTITY adblock.warning "Adblock Plus a détecté qu'Adblock ou une ancienne version d'Adblock Plus est installée. Faire fonctionner les deux Adblock en parallèle peut engendrer des problèmes et doit être évité. Il est recommandé de désinstaller Adblock immédiatement.">
+<!ENTITY adblock.uninstall "Désinstaller Adblock">
+<!ENTITY filterset.g.warning "Il semblerait que vous utilisiez Filterset.G. Cette liste de filtre a été maintenue de manière aléatoire ces dernières années et est la cause de problèmes avec des sites Web. Il est recommandé de désinstaller Filterset.G immédiatement.">
+<!ENTITY filterset.g.moreinfo "Davantage d'informations">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/fr/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Désinstaller Filterset.G">
+<!ENTITY subscriptionSelector.label "Veuillez choisir un abonnement dans la liste suivante :">
+<!ENTITY viewList.label "Afficher les filtres">
+<!ENTITY visitHomepage.label "Se rendre au site Web">
+<!ENTITY addSubscription.label "Ajouter l'abonnement">
+<!ENTITY saveSubscription.label "Enregistrer l'abonnement">
+<!ENTITY other.label "Ajouter un autre abonnement">
+<!ENTITY other.accesskey "t">
+<!ENTITY list.download.failed "Adblock Plus n'a pu récupérer la liste des abonnements.">
+<!ENTITY list.download.retry "Essayer à nouveau">
+<!ENTITY list.download.website "Afficher le site Web">
+<!ENTITY list.website.url "http://adblockplus.org/fr/subscriptions">
+<!ENTITY fromWeb.description "Veuillez confirmer que vous souhaitez ajouter cet abonnement. Vous pouvez modifier le titre et l'emplacement de l'abonnement avant de l'ajouter.">
+<!ENTITY edit.description "Vous pouvez modifier le titre et l'emplacement à votre convenance.">
+<!ENTITY external.description "Ceci est un abonnement externe ; il sera mis à jour par l'extension qui a créé cet abonnement.">
+<!ENTITY title.label "Nom de l'abonnement :">
+<!ENTITY title.accesskey "N">
+<!ENTITY location.label "Emplacement de la liste :">
+<!ENTITY location.accesskey "E">
+<!ENTITY autodownload.label "Mettre à jour automatiquement">
+<!ENTITY autodownload.accesskey "M">
+<!ENTITY supplementMessage "Cet abonnement est prévu pour être utilisé avec l'abonnement &quot;?1?&quot; que vous n'utilisez pas encore.">
+<!ENTITY addMain.label "Ajouter également l'abonnement &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "a">

=== modified file 'chrome/locale/fy-NL/about.dtd'
--- chrome/locale/fy-NL/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fy-NL/about.dtd	2010-05-04 14:45:07 +0000
@@ -1,8 +1,12 @@
 <!ENTITY dialog.title "Oer Adblock Plus">
 <!ENTITY caption.title "Adblock Plus">
 <!ENTITY version.title "Ferzje">
-<!ENTITY description "Adblock Plus lit jo sels beslisse wat jo net sjen wolle op it ynternet. Fan ôf no hoege jo net mear alle reklames yn te laden dy&apos;t jo dochs net sjen wolle - jou se gewoan troch oan Adblock Plus!">
+<!ENTITY description "Adblock Plus lit jo sels beslisse wat jo net sjen wolle op it ynternet. Fan ôf no hoege jo net mear alle reklames yn te laden dy't jo dochs net sjen wolle - jou se gewoan troch oan Adblock Plus!">
 <!ENTITY homepage.label "Adblock Plus webstee:">
 <!ENTITY homepage.url "http://adblockplus.org/">
 <!ENTITY author.label "Auteur:">
 <!ENTITY contributors.label "Meiwurkers:">
+<!ENTITY developers.label "Untwikkelers:">
+<!ENTITY designers.label "Grafyske ûntwerpers:">
+<!ENTITY subscriptionAuthors.label "Filter abonnemintauteurs:">
+<!ENTITY translators.label "Oersetters:">

=== modified file 'chrome/locale/fy-NL/composer.dtd'
--- chrome/locale/fy-NL/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fy-NL/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "Filter tafoegje">
 <!ENTITY advanced.label "Avansearre byld">
 <!ENTITY basic.label "Basisbyld">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus is op dit stuit útskeakele. Jo kinne noch hieltyd filters tafoegje, mar dy sille net earder aktyf wêze as jo">
-<!ENTITY disabled.warning.link "Adblock Plus ynskeakelje">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "De filtergroep &quot;&#37;S&quot; wêr&apos;t dit filter oan tafoege wurde soe is op dit stuit útskeakele. Jo kinne it filter noch hieltyd tafoegje, mar it sil net tapast wurde, allinnich as jo">
-<!ENTITY groupDisabled.warning.link "de filtergroep ynskeakelje">
-<!ENTITY groupDisabled.warning.afterLink ".">
+<!ENTITY disabled.warning "Adblock Plus is op dit stuit útskeakele. Jo kinne noch hieltyd filters tafoegje, mar dy sille net earder aktyf wêze as jo [link]Adblock Plus ynskeakelje[/link].">
+<!ENTITY groupDisabled.warning "De filtergroep &quot;?1?&quot; wêr&apos;t dit filter oan tafoege wurde soe is op dit stuit útskeakele. Jo kinne it filter noch hieltyd tafoegje, mar it sil net tapast wurde, allinnich as jo [link]de filtergroep ynskeakelje[/link].">
 <!ENTITY filter.label "Nij filter:">
 <!ENTITY filter.accesskey "f">
 <!ENTITY preferences.label "Toan besteande filters...">

=== modified file 'chrome/locale/fy-NL/global.properties'
--- chrome/locale/fy-NL/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/fy-NL/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,13 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Fan no ôf gjin reklames mear!
-status_active_label=Adblock
-status_disabled_label=Utskeakele
+default_dialog_title=Adblock Plus
 action0_tooltip=Klik om it kontekst-menu te iepenjen, midden-klik om yn/út te skeakeljen.
 action1_tooltip=Klik om blokkearbere ûnderdielen te iepenjen/sluten, midden-klik om yn/út te skeakeljen.
 action2_tooltip=Klik om foarkarren te iepenjen, midden-klik om yn/út te skeakeljen.
 action3_tooltip=Klik om Adblock Plus yn/út te skeakeljen.
-active_tooltip=Adblock Plus is ynskeakele.
 disabled_tooltip=Adblock Plus is útskeakele.
+active_tooltip=Adblock Plus is ynskeakele, ?1? filter abonnemint(en) en ?2? oanpaste filter(s) yn gebrûk.
 whitelisted_tooltip=Adblock Plus is ynskeakele mar stiet út foar dizze side.
-blocked_count_tooltip=-- fan de --
+blocked_count_tooltip=?1? fan de ?2?
+blocked_count_addendum=(ek wytliste: ?1?, ferstoppe: ?2?)
 no_blocking_suggestions=Gjin blokkearbere ûnderdielen op dizze side
 whitelisted_page=Adblock Plus is útskeakele foar dizze side
 whitelist_description=Utsûnderingsrigels
@@ -16,7 +15,7 @@
 invalid_description=Unjildige filters
 elemhide_description=Ferstoprigels
 subscription_description=Filterabonnemint:
-subscription_wrong_version=Sommige filters yn dit abonnemint fereaskje Adblock Plus -- om goed te wurkjen!
+subscription_wrong_version=Sommige filters yn dit abonnemint fereaskje Adblock Plus ?1? om goed te wurkjen!
 subscription_source=Boarne:
 subscription_status=Steat:
 subscription_status_autodownload=Automatysk bywurke
@@ -26,7 +25,7 @@
 subscription_status_lastdownload_inprogress=Ynlade...
 subscription_status_lastdownload_unknown=n.f.t.
 remove_subscription_warning=Witte jo seker dat jo dit abonnemint fuortsmite wolle?
-import_filters_wrong_version=Warskôging: sommige filters yn dit abonnemint fereaskje Adblock Plus -- om goed te wurkjen! Jo kinne it bêste in nije ferzje fan Adblock Plus ynstallearje eardat jo dizze list ymportearje.
+import_filters_wrong_version=Warskôging: sommige filters yn dit abonnemint fereaskje Adblock Plus ?1? om goed te wurkjen! Jo kinne it bêste in nije ferzje fan Adblock Plus ynstallearje eardat jo dizze list ymportearje.
 import_filters_warning=Wolle jo jo aktuele filters ferfange of de nije filters oan it ein fan de list tafoegje?
 import_filters_title=Filters ymportearje
 export_filters_title=Filters eksportearje
@@ -38,9 +37,9 @@
 filter_regexp_tooltip=Dit filter is of in reguliere ekspresje of te koart om optimalisearre te wurden. Te folle fan dizze filters kinne it sneupjen fertrage.
 filter_elemhide_duplicate_id=Der kin allinnich ien ID fan it te ferstoppen elemint spesifisearre wurde
 filter_elemhide_nocriteria=Gjin kritearia spesifisearre om it te ferstoppen elemint te ûntdekken
-subscription_no_location=Jou asjebleaft in lokaasje op om filters fan yn te laden.
+subscription_notAdded_warning=Jo hawwe net in filterabonnemint tafoege. Sûnder in filterabonnemint moatte jo sels Adblock Plus filters tafoegje.
+subscription_notAdded_warning_addendum=Wolle jo trochgean?
 subscription_invalid_location=Dizze lokaasje foar in filterlist is gjin jildige URL of gjin jildige bestânsnamme.
-subscription_location_exists=Jo binne al abonnearre op dizze filterlist.
 synchronize_invalid_url=Mislearre, gjin jildich adres
 synchronize_connection_error=Mislearre, ynlaadprobleem
 synchronize_invalid_data=Mislearre, gjin jildige filterlist
@@ -65,3 +64,7 @@
 type_label_dtd=DTD
 type_label_media=audio/fideo
 type_label_font=lettertype
+fennec_status_enabled=Adblock Plus is ynskeakele.
+fennec_status_disabled=Adblock Plus is útskeakele.
+fennec_status_enabled_site=Adblock Plus is ynskeakele op ?1?.
+fennec_status_disabled_site=Adblock Plus is ynskeakele op ?1?.

=== added file 'chrome/locale/fy-NL/meta.properties'
--- chrome/locale/fy-NL/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/fy-NL/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Wim Benes
+name=Adblock Plus
+description=Fan no ôf gjin reklames mear!
+description.short=Argewaasje oer advertinsjes? Soargen oer achterfolgjen? Steurd troch banners? Ynstallearje Adblock Plus om kontrole te krijen oer it ynternet en hoe't jo ynternet besjogge.\n\nIn koarte fideo is te sjen op http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus jout jo de mooglikheid om de kontrole werom te krijen oer it ynternet en besjen sa as jo dat wolle. De tafoeging is stipe troch oer de fjirtich filterabonnemminten yn ferskate talen dy't it automatysk konfigurearje foar doeleinen fan it fuortsmiten fan online advertinsjes oant it blokkearkjen fan alle bekende malwaredomeinen. Adblock Plus out ek de mooglikheid om jo filters oan te passen mei de help fan in ferskaat oan brûkbere opsjes, ynklusyf in kontekst opsje foar ôfbyldings, in blokkearljepblêd foar Flash en Java objekten en in list mei blokkearbere items om scripts en stylesheets fuort te smiten.

=== modified file 'chrome/locale/fy-NL/overlay.dtd'
--- chrome/locale/fy-NL/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fy-NL/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -8,6 +8,7 @@
 <!ENTITY context.image.label "Ofbylding blokkearje">
 <!ENTITY context.object.label "Objekt blokkearje">
 <!ENTITY context.frame.label "Dielfinster blokkearje">
+<!ENTITY context.media.label "Adblock Plus: Blokkearje audio/fideo">
 <!ENTITY context.removeWhitelist.label "Adblock Plus: opnij ynskeakelje op dizze side">
 <!ENTITY sidebar.title "Blokkearbere ûnderdelen op dizze side">
 <!ENTITY settings.label "Foarkarren">
@@ -16,7 +17,7 @@
 <!ENTITY opensidebar.accesskey "B">
 <!ENTITY closesidebar.label "Blokkearbere ûnderdielen slute">
 <!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Utskeakelje op --">
+<!ENTITY whitelist.site.label "Utskeakelje op ?1?">
 <!ENTITY whitelist.page.label "Allinnich op dizze side útskeakelje">
 <!ENTITY objecttab.title "Blokkearje">
 <!ENTITY objecttab.tooltip "Klik hjir om dit objekt te blokkearjen mei Adblock Plus">

=== modified file 'chrome/locale/fy-NL/settings.dtd'
--- chrome/locale/fy-NL/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fy-NL/settings.dtd	2010-05-04 14:45:07 +0000
@@ -7,9 +7,9 @@
 <!ENTITY addsubscription.accesskey "A">
 <!ENTITY synchsubscriptions.label "Alle abonneminten bywurkje">
 <!ENTITY synchsubscriptions.accesskey "l">
-<!ENTITY import.label "Filters Ymportearje">
+<!ENTITY import.label "Filters ymportearje">
 <!ENTITY import.accesskey "Y">
-<!ENTITY export.label "Filters Eksportearje">
+<!ENTITY export.label "Filters eksportearje">
 <!ENTITY export.accesskey "E">
 <!ENTITY clearall.label "Alle filters fuortsmite">
 <!ENTITY clearall.accesskey "f">
@@ -27,7 +27,7 @@
 <!ENTITY remove.accesskey "F">
 <!ENTITY menu.find.label "Sykje">
 <!ENTITY menu.find.accesskey "S">
-<!ENTITY menu.findagain.label "Op &apos;e nij sykje">
+<!ENTITY menu.findagain.label "Op 'e nij sykje">
 <!ENTITY menu.findagain.accesskey "O">
 <!ENTITY view.label "Byld">
 <!ENTITY view.accesskey "B">
@@ -43,11 +43,11 @@
 <!ENTITY options.accesskey "O">
 <!ENTITY enable.label "Adblock Plus ynskeakelje">
 <!ENTITY enable.accesskey "y">
-<!ENTITY showintoolbar.label "Lit sjen yn arkbalke">
+<!ENTITY showintoolbar.label "Toane yn arkbalke">
 <!ENTITY showintoolbar.accesskey "a">
-<!ENTITY showinstatusbar.label "Lit sjen yn steatbalke">
+<!ENTITY showinstatusbar.label "Toane yn steatbalke">
 <!ENTITY showinstatusbar.accesskey "s">
-<!ENTITY objecttabs.label "Tabs sjen litte op Flash en Java">
+<!ENTITY objecttabs.label "Ljepblêden sjen litte op Flash en Java">
 <!ENTITY objecttabs.accesskey "T">
 <!ENTITY collapse.label "Blokkearre eleminten ynklappe">
 <!ENTITY collapse.accesskey "B">
@@ -64,7 +64,7 @@
 <!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
 <!ENTITY about.label "Oer Adblock Plus">
 <!ENTITY about.accesskey "A">
-<!ENTITY description "Foech it adres ta dat jo blokkearje wolle, sjoch de karlist foar foarstellen. Jo kinne in * as jokerteken brûke foar mear algemiene filters. Erfaren brûkers kinne reguliere ekspresjes brûke, lykas /banner\d+\.gif$/.">
+<!ENTITY description "Foech it adres ta dat jo blokkearje wolle, sjoch de karlist foar foarstellen. Jo kinne in * as jokerteken brûke foar mear algemiene filters. Betûfte brûkers kinne reguliere ekspresjes brûke, lykas /banner\d+\.gif$/.">
 <!ENTITY filter.column "Filterrigel">
 <!ENTITY filter.accesskey "F">
 <!ENTITY slow.column "Langsame filters">
@@ -87,3 +87,4 @@
 <!ENTITY context.disable.label "Utskeakelje">
 <!ENTITY apply.label "Tapasse">
 <!ENTITY apply.accesskey "T">
+<!ENTITY fennec.subscription.label "Filterabonnemint">

=== modified file 'chrome/locale/fy-NL/sidebar.dtd'
--- chrome/locale/fy-NL/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fy-NL/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "Blokkearje dit item">
 <!ENTITY context.editfilter.label "Bewurkje tapaste filter">
 <!ENTITY context.whitelist.label "Meitsje in útsûnderingsrigel foar dit ûnderdiel">
-<!ENTITY context.disablefilter.label "Filter útskeakelje --">
-<!ENTITY context.enablefilter.label "Filter ynskeakelje --">
-<!ENTITY context.disablefilteronsite.label "Skeakel dit filter út op --">
+<!ENTITY context.disablefilter.label "Filter útskeakelje ?1?">
+<!ENTITY context.enablefilter.label "Filter ynskeakelje ?1?">
+<!ENTITY context.disablefilteronsite.label "Skeakel dit filter út op ?1?">
 <!ENTITY context.open.label "Iepen yn in nij ljepblêd">
 <!ENTITY context.flash.label "Lit rannen knipperje">
 <!ENTITY context.copy.label "Kopiearje">

=== removed file 'chrome/locale/fy-NL/subscription.dtd'
--- chrome/locale/fy-NL/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fy-NL/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY dialog.title "Filter abonnemint wizigje">
-<!ENTITY dialog.newtitle "Filter abonnemint tafoegje">
-<!ENTITY new.description "Jou asjobleaft it ynternetadres of bestân op mei in
-Adblock Plus filterlist.">
-<!ENTITY edit.description "De filterlist fan dit abonnemint sil ynladen wurde
-fan de opjûne lokaasje.">
-<!ENTITY external.description "Dit is in ekstern filterabonnemint, de filterlist
-sil bywurke wurde troch de útwreiding dy&apos;t makke is foar dit
-abonnemint.">
-<!ENTITY autodownload.description "As jo kieze foar ‘Automatysk bywurkje’ sil dizze lokaasje 
-daagliks kontrolearre wurde op nije ferzjes. As jo dizze opsje útskeakelje
-kinne jo noch hieltyd in hânmjittige fernijing útfiere fan út it kontekst
-menu by Filter abonnemint.">
-<!ENTITY location.label "Filterlist lokaasje:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Abonnemintnamme:">
-<!ENTITY title.accesskey "B">
-<!ENTITY autodownload.label "Automatysk bywurkje">
-<!ENTITY autodownload.accesskey "T">
-<!ENTITY enabled.label "Filters ynskeakelje">
-<!ENTITY enabled.accesskey "N">

=== added file 'chrome/locale/fy-NL/subscriptionSelection.dtd'
--- chrome/locale/fy-NL/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/fy-NL/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,38 @@
+<!ENTITY dialog.title "Foegje Adblock Plus filterabonnemint ta">
+<!ENTITY dialog.title.edit "Filter abonnemint wizigje">
+<!ENTITY description.newInstall "Adblock Plus sil it meast effektyf wêze as jo in filterabonnemint tafoegje.
+	Filterabonneminten wurde oanlevere troch oare Adblock Plus brûkers hielendal fergees.
+	It meast fan tapassing achte abonnnemint foar jo taal is al selektearre.">
+<!ENTITY adblock.warning "Adblock Plus hat ûntdekt dat Adblock of in âlde ferzje fan Adblock Plus
+ynstallearre is. Adblock en Adblock Plus lyktidich brûke kin problemen
+feroarsaakje en moat foarkommen wurde. It wurd oanrikkemandearre dat jo Adblock de-ynstallearje.">
+<!ENTITY adblock.uninstall "Adblock de-ynstallearje">
+<!ENTITY filterset.g.warning "It liket derop dat jo Fiterset.G brûke. Dizze filterlist wurdt hast net byhâlden
+yn de lêste jieren en is bekend foar it feroarsaakjen fan problemen
+mei websteeën. It wurd oanret dat jo Filterset.G de-ynstallearje.">
+<!ENTITY filterset.g.moreinfo "Mear ynformaasje">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "De-ynstallearje">
+<!ENTITY subscriptionSelector.label "Kies asjobleaft in filterabonnemint út de list:">
+<!ENTITY viewList.label "Toan filters">
+<!ENTITY visitHomepage.label "Besykje thússide">
+<!ENTITY addSubscription.label "Abonnemint tafoegje">
+<!ENTITY saveSubscription.label "Abonnemint bewarje">
+<!ENTITY other.label "In oar abonnemint tafoegje">
+<!ENTITY other.accesskey "T">
+<!ENTITY list.download.failed "It is Adblock Plus net slagge om de list mei abonneminten te krijen.">
+<!ENTITY list.download.retry "Op 'e nij besykje">
+<!ENTITY list.download.website "Toan webstee">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Befestigje asjobleaft dat jo dit filterabonnemint tafoegje wolle. Jo kinne de abonneminttitel of lokaasje wizigje foardat jo it tafoegje.">
+<!ENTITY edit.description "Jo kinne de abonneminttitel of lokaasje wizigje as jo wolle.">
+<!ENTITY external.description "Dit is een ekstern filterabonnemint; it sil fernijd wurde by de útwreiding dy't dit abonnemint makke hat.">
+<!ENTITY title.label "Abonnemintnamme:">
+<!ENTITY title.accesskey "B">
+<!ENTITY location.label "Filterlist lokaasje:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Automatysk bywurkje">
+<!ENTITY autodownload.accesskey "T">
+<!ENTITY supplementMessage "Dit filterabonnemint is bedoeld om brûkt te wurden mei it filterabonnemint &quot;?1?&quot; dy't jo no noch net brûke.">
+<!ENTITY addMain.label "Filterabonnemint &quot;?1?&quot; ek tafoegje">
+<!ENTITY addMain.accesskey "a">

=== removed file 'chrome/locale/fy-NL/tip_subscriptions.dtd'
--- chrome/locale/fy-NL/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/fy-NL/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY dialog.title "Wolkom by Adblock Plus">
-<!ENTITY description.par1 "Tanke foar it ynstallearjen fan Adblock Plus. Dizze útwreiding kin 99&#37; fan alle reklame fuortsmite dy&apos;t jo sjogge op it web. Mar, om reklame goed te filterjen, hawwe jo in goede set filters nedich. Jo kinne dit sels meitsje, of simpel in abonnemint nimme op in filterlist dy&apos;t oaren foar jo byhâlde. As it nedich is kinne jo hjirnei noch hieltyd jo eigen filters meitsje of abonneminten útskeakelje of fuortsmite.">
-<!ENTITY description.par2 "Jo kinne in abonnemint kieze út de list mei oanrikkemandearre abonneminten hjirûnder (mear abonneminten kinne tafoege wurde yn Adblock Plus Foarkarren, al is dit normaal net nedich):">
-<!ENTITY note "Tip: in filterlist wurket meastentiids it bêste as dy tapast wurdt op websteeën út de regio wêr&apos;t de list foar makke is.">
-<!ENTITY adblock.warning "Adblock Plus hat ûntdekt dat Adblock of in âlde ferzje fan Adblock Plus
-ynstallearre is. Adblock en Adblock Plus lyktidich brûke kin problemen
-feroarsaakje en moat foarkommen wurde. It wurd oanrikkemandearre dat jo Adblock de-ynstallearje.">
-<!ENTITY adblock.uninstall "Adblock de-ynstallearje">
-<!ENTITY filterset.g.warning "It liket derop dat jo Fiterset.G brûke. Dizze filterlist wurdt hast net byhâlden
-yn de lêste jieren en is bekend foar it feroarsaakjen fan problemen
-mei websteeën. It wurd oanret dat jo Filterset.G de-ynstallearje.">
-<!ENTITY filterset.g.moreinfo "Mear ynformaasje">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "De-ynstallearje">
-<!ENTITY homepage.label "Webstee">
-<!ENTITY subscribe.label "Abonnearje">
-<!ENTITY subscribe.accesskey "A">
-<!ENTITY other.label "In oar abonnemint tafoegje">
-<!ENTITY other.accesskey "T">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Toan alle abonneminten">

=== removed file 'chrome/locale/ga-IE/composer.dtd'
=== removed file 'chrome/locale/ga-IE/subscription.dtd'
--- chrome/locale/ga-IE/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ga-IE/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Déan eagarthóireacht ar síntiús an scagaire">
-<!ENTITY dialog.newtitle "Cuir síntiús scagaire nua isteach">
-<!ENTITY new.description "Cuir isteach an seoladh Gréasáin nó comhad ina bhfuil réim de scagairí Adblock Plus.">
-<!ENTITY edit.description "Íosluchtófar réim de scagairí don síntiús seo ón láthair tugtha.">
-<!ENTITY external.description "Is síntiús scagaire eachtrach é seo, coimeádfar a réim scagaire bord ar bhord tríd an breisiú a chruthaigh an síntiús seo.">
-<!ENTITY autodownload.description "Má roghnaíonn tú &apos;Uathnuashonraigh&apos; scrúdófar an láthair seo ar bonn laethúil. Leis an rogha seo díchumasaithe is féidir fós nuashonrú a chur ar siúil de láimh ó roghchlár comhthéacsa an síntiús.">
-<!ENTITY location.label "Láthair réim an scagaire:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Teideal síntiús:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Uathnuashonraigh">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.label "Cumasaigh scagairí">
-<!ENTITY enabled.accesskey "N">

=== added file 'chrome/locale/ga-IE/subscriptionSelection.dtd'
--- chrome/locale/ga-IE/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ga-IE/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,9 @@
+<!ENTITY dialog.title.edit "Déan eagarthóireacht ar síntiús an scagaire">
+<!ENTITY other.label "Cuir síntiús eile leis">
+<!ENTITY other.accesskey "T">
+<!ENTITY title.label "Teideal síntiús:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Láthair réim an scagaire:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Uathnuashonraigh">
+<!ENTITY autodownload.accesskey "P">

=== removed file 'chrome/locale/ga-IE/tip_subscriptions.dtd'
--- chrome/locale/ga-IE/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ga-IE/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,7 +0,0 @@
-<!ENTITY dialog.title "Fáilte go Adblock Plus">
-<!ENTITY note "Fógra: Bíonn réim scagaire níos feidhmiúla de gnáth nuair a chuirtear i bhfeidhm í do láithreáin gréasáin ón chríoch a chruthaíodh an réim scagaire seo do.">
-<!ENTITY homepage.label "Clár cinn">
-<!ENTITY subscribe.label "Glac síntiús">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "Cuir síntiús eile leis">
-<!ENTITY other.accesskey "T">

=== added directory 'chrome/locale/gl'
=== removed directory 'chrome/locale/gl-ES'
=== removed file 'chrome/locale/gl-ES/about.dtd'
--- chrome/locale/gl-ES/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/gl-ES/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,10 +0,0 @@
-<!ENTITY dialog.title "Verbo do Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Versión">
-<!ENTITY description "Adblock Plus permítelle decidir o que vostede desexa ver ou non 
-	 ver na Rede. Non necesita descargar todos os anuncios, cando non 
-	 queira velos - avise a Adblock Plus!">
-<!ENTITY homepage.label "Páxina oficial do Adblock Plus">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Autor:">
-<!ENTITY contributors.label "Colaboradores:">

=== removed file 'chrome/locale/gl-ES/composer.dtd'
--- chrome/locale/gl-ES/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/gl-ES/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Engadir regra de filtrado Adblock Plus">
-<!ENTITY accept.label "Engadir filtro">
-<!ENTITY advanced.label "Vista avanzada">
-<!ENTITY basic.label "Vista básica">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus atópase actualmente desactivado. Aínda pode engadir os filtros, mais non se aplicarán a menos que vostede">
-<!ENTITY disabled.warning.link "active Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "O grupo de filtros &quot;&#37;S&quot; ao que se tiña que engadir este filtro está desactivado. Pode engadir o filtro mais non será aplicado ata que">
-<!ENTITY groupDisabled.warning.link "active o grupo de filtros">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Filtro novo:">
-<!ENTITY filter.accesskey "F">
-<!ENTITY preferences.label "Mostrar filtros existentes ...">
-<!ENTITY preferences.accesskey "S">
-<!ENTITY type.filter.label "Filtro de bloqueo">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "Excepción">
-<!ENTITY type.whitelist.accesskey "x">
-<!ENTITY pattern.label "Buscar unha pauta">
-<!ENTITY pattern.explanation "A pauta pode ser calquera parte da dirección, o símbolo * actúa como comodín. O filtro só se aplicará ás direccións coincidentes coa pauta.">
-<!ENTITY regexp.warning "A pauta que introduciu interprétase como unha expresión regular, e usar moitas podería retardar a navegación. Se non ten a intención de utilizar expresións regulares, engada un símbolo * ao final da pauta.">
-<!ENTITY shortpattern.warning "A pauta que introduciu é demasiado curta para ser optimizada, de haber moitas pautas así podería retardarse a navegación. Recoméndase que vostede elixa unha cadea máis longa para este filtro.">
-<!ENTITY custom.pattern.label "Personalizado:">
-<!ENTITY custom.pattern.accesskey "P">
-<!ENTITY anchors.label "Acepte só a pauta:">
-<!ENTITY anchor.start.label "ao comezo da dirección">
-<!ENTITY anchor.start.accesskey "z">
-<!ENTITY anchor.start.flexible.label "ao comezo do nome do dominio">
-<!ENTITY anchor.start.flexible.accesskey "z">
-<!ENTITY anchor.end.label "ao final da dirección">
-<!ENTITY anchor.end.accesskey "d">
-<!ENTITY options.label "Opcións">
-<!ENTITY domainRestriction.label "Restrición ao dominio:">
-<!ENTITY domainRestriction.accesskey "R">
-<!ENTITY domainRestriction.help "Especifique un ou máis dominios separados polo símbolo &quot;|&quot;, o filtro só se aplicará nestes dominios. O símbolo &quot;~&quot; antes dun nome de dominio significa que o filtro non debe aplicarse sobre el.">
-<!ENTITY firstParty.label "Só de orixe">
-<!ENTITY firstParty.accesskey "i">
-<!ENTITY thirdParty.label "Só de terceiros">
-<!ENTITY thirdParty.accesskey "T">
-<!ENTITY matchCase.label "Caso coincidente">
-<!ENTITY matchCase.accesskey "C">
-<!ENTITY types.label "Aplicar aos tipos:">
-<!ENTITY selectAllTypes.label "Marcar todos">
-<!ENTITY unselectAllTypes.label "Non marcar ningún">
-<!ENTITY collapse.label "Encartar bloqueados:">
-<!ENTITY collapse.accesskey "E">
-<!ENTITY collapse.default.yes.label "Uso por defecto (si)">
-<!ENTITY collapse.default.no.label "Uso por defecto (non)">
-<!ENTITY collapse.yes.label "Si">
-<!ENTITY collapse.no.label "Non">

=== removed file 'chrome/locale/gl-ES/global.properties'
--- chrome/locale/gl-ES/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/gl-ES/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Os anuncios son cousa do pasado!
-status_active_label=Adblock
-status_disabled_label=Desactivado
-action0_tooltip=Prema para abrir o menú contextual, e no medio para activar/desactivar.
-action1_tooltip=Prema para abrir/pechar elementos bloqueables, e no medio para activar/desactivar.
-action2_tooltip=Prema para abrir preferencias, e no medio para activar/desactivar.
-action3_tooltip=Prema para activar/desactivar Adblock Plus.
-active_tooltip=Adblock Plus está activo.
-disabled_tooltip=Adblock Plus está desactivado.
-whitelisted_tooltip=Adblock Plus está activo mais desactivado nesta páxina
-blocked_count_tooltip=-- fora de --
-no_blocking_suggestions=Non hai elementos bloqueables nesta páxina
-whitelisted_page=Adblock Plus foi inhabilitado nesta páxina
-whitelist_description=Regras de excepción
-filterlist_description=Regras de Bloqueo de Publicidade
-invalid_description=Filtros non válidos
-elemhide_description=Regras de ocultación de elementos
-subscription_description=Subscrición de filtro:
-subscription_wrong_version=Algúns filtros nesta subscrición requiren Adblock Plus -- para funcionar correctamente!
-subscription_source=Fonte:
-subscription_status=Estado:
-subscription_status_autodownload=Actualizado automaticamente
-subscription_status_manualdownload=Actualizado manualmente
-subscription_status_externaldownload=Actualizado externamente (outra extensión)
-subscription_status_lastdownload=Última descarga:
-subscription_status_lastdownload_inprogress=Descargando...
-subscription_status_lastdownload_unknown=N/A
-remove_subscription_warning=Está seguro de que desexa eliminar esta subscrición?
-import_filters_wrong_version=Advertencia: algúns filtros da lista requiren Adblock Plus - para funcionar correctamente. Probablemente deba actualizar á última versión liberada de Adblock Plus antes de importar esta lista.
-import_filters_warning=Desexa substituír os seus filtros actuais ou engadir novos filtros ao final da lista?
-import_filters_title=Importar filtros
-export_filters_title=Exportar filtros
-invalid_filters_file=Non é un arquivo de filtros de Adblock Plus válido.
-filters_write_error=Produciuse un erro ao escribir os filtros no arquivo. Asegúrese de que o arquivo non estea protexido contra escritura ou retido por outro programa.
-clearall_warning=Está seguro de que desexa eliminar todos os filtros da lista?
-resethitcounts_warning=Está seguro de que desexa reiniciar en cero os contadores de todos os filtros? Esta operación non se pode desfacer!
-resethitcounts_selected_warning=Está seguro de que desexa reiniciar en cero os contadores dos filtros escollidos? Esta operación non se pode desfacer!
-filter_regexp_tooltip=Este filtro é unha expresión regular ou é demasiado curto para ser optimizado. Moitos filtros así poderían retardar a navegación.
-filter_elemhide_duplicate_id=Só pode especificarse un ID do elemento que se vai ocultar
-filter_elemhide_nocriteria=Non se especificaron criterios para recoñecer o elemento que se vai ocultar
-subscription_no_location=Por favor, introduza unha localización de onde descargar filtros.
-subscription_invalid_location=Esa localización da lista de filtros non é nin unha URL válida nin un nome de arquivo válido.
-subscription_location_exists=Xa está subscrito a esta lista de filtros.
-synchronize_invalid_url=Fallou, non é unha dirección válida
-synchronize_connection_error=Fallou, fracasou a descarga
-synchronize_invalid_data=Fallou, non é unha lista de filtros válida
-synchronize_checksum_mismatch=Fallou, a proba 'checksum' non cadrou
-synchronize_ok=Valeu
-overwrite=Sobreescribir
-append=Anexar
-new_filter_group_title=Filtro novo
-type_label_other=outro
-type_label_script=secuencia de comandos
-type_label_image=imaxe
-type_label_stylesheet=folla de estilo
-type_label_object=obxecto
-type_label_subdocument=marco
-type_label_document=documento
-type_label_background=fondo
-type_label_elemhide=oculto
-type_label_xbl=XBL vinculante
-type_label_ping=ping ao enlace
-type_label_xmlhttprequest=solicitude XML
-type_label_object_subrequest=sub-solicitude de obxecto
-type_label_dtd=DTD
-type_label_media=audio/vídeo
-type_label_font=fonte

=== removed file 'chrome/locale/gl-ES/overlay.dtd'
--- chrome/locale/gl-ES/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/gl-ES/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Estado:">
-<!ENTITY blocked.tooltip "Elementos bloqueados nesta páxina:">
-<!ENTITY filters.tooltip "Filtros máis activos:">
-<!ENTITY menuitem.label "Preferencias Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Temas bloqueables">
-<!ENTITY context.image.label "Imaxe Adblock">
-<!ENTITY context.object.label "Obxecto Adblock">
-<!ENTITY context.frame.label "Marco Adblock">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Re-activado nesta páxina">
-<!ENTITY sidebar.title "Temas bloqueables da páxina actual">
-<!ENTITY settings.label "Preferencias">
-<!ENTITY settings.accesskey "F">
-<!ENTITY opensidebar.label "Abrir temas bloqueables">
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "Pechar temas bloqueables">
-<!ENTITY closesidebar.accesskey "b">
-<!ENTITY whitelist.site.label "Desactivar en --">
-<!ENTITY whitelist.page.label "Desactivar só nesta páxina">
-<!ENTITY objecttab.title "Bloquear">
-<!ENTITY objecttab.tooltip "Prema aquí para bloquear este obxecto con Adblock Plus">

=== removed file 'chrome/locale/gl-ES/settings.dtd'
--- chrome/locale/gl-ES/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/gl-ES/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Preferencias Adblock Plus">
-<!ENTITY filters.label "Filtros">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Engadir filtro">
-<!ENTITY add.accesskey "n">
-<!ENTITY addsubscription.label "Engadir subscrición de filtros">
-<!ENTITY addsubscription.accesskey "S">
-<!ENTITY synchsubscriptions.label "Actualizar todas as subscricións">
-<!ENTITY synchsubscriptions.accesskey "A">
-<!ENTITY import.label "Importar filtros">
-<!ENTITY import.accesskey "M">
-<!ENTITY export.label "Exportar filtros personalizados">
-<!ENTITY export.accesskey "X">
-<!ENTITY clearall.label "Eliminar todos os filtros personalizados">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "Reiniciar as estatísticas">
-<!ENTITY resethitcounts.accesskey "R">
-<!ENTITY edit.label "Editar">
-<!ENTITY edit.accesskey "E">
-<!ENTITY cut.label "Cortar">
-<!ENTITY cut.accesskey "T">
-<!ENTITY copy.label "Copiar">
-<!ENTITY copy.accesskey "C">
-<!ENTITY paste.label "Pegar">
-<!ENTITY paste.accesskey "P">
-<!ENTITY remove.label "Borrar">
-<!ENTITY remove.accesskey "B">
-<!ENTITY menu.find.label "Atopar">
-<!ENTITY menu.find.accesskey "O">
-<!ENTITY menu.findagain.label "Atopar de novo">
-<!ENTITY menu.findagain.accesskey "N">
-<!ENTITY view.label "Ver">
-<!ENTITY view.accesskey "V">
-<!ENTITY sort.label "Ordenar por">
-<!ENTITY sort.accesskey "o">
-<!ENTITY sort.none.label "Sen clasificar">
-<!ENTITY sort.none.accesskey "s">
-<!ENTITY sort.ascending.label "Ordenar A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Ordenar Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Opcións">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Activar Adblock Plus">
-<!ENTITY enable.accesskey "a">
-<!ENTITY showintoolbar.label "Mostrar na barra de ferramentas">
-<!ENTITY showintoolbar.accesskey "f">
-<!ENTITY showinstatusbar.label "Mostrar na barra de estado">
-<!ENTITY showinstatusbar.accesskey "e">
-<!ENTITY objecttabs.label "Mostrar separadores en Flash e Java">
-<!ENTITY objecttabs.accesskey "s">
-<!ENTITY collapse.label "Encartar elementos bloqueados">
-<!ENTITY collapse.accesskey "L">
-<!ENTITY help.label "Axuda">
-<!ENTITY help.accesskey "X">
-<!ENTITY gettingStarted.label "Primeiros pasos">
-<!ENTITY gettingStarted.accesskey "p">
-<!ENTITY gettingStarted.url "primeirosPasos.url">
-<!ENTITY faq.label "Preguntas frecuentes (FAQ)">
-<!ENTITY faq.accesskey "F">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Escribir filtros de Adblock Plus">
-<!ENTITY filterdoc.accesskey "R">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Verbo do Adblock Plus">
-<!ENTITY about.accesskey "B">
-<!ENTITY description "Os seguintes filtros determinan que enderezos débense bloquear e cales débense permitir:">
-<!ENTITY filter.column "Regra de filtro">
-<!ENTITY filter.accesskey "F">
-<!ENTITY slow.column "Filtros lentos">
-<!ENTITY slow.accesskey "n">
-<!ENTITY enabled.column "Activada">
-<!ENTITY enabled.accesskey "c">
-<!ENTITY hitcount.column "Impactos">
-<!ENTITY hitcount.accesskey "I">
-<!ENTITY lasthit.column "Último impacto">
-<!ENTITY lasthit.accesskey "L">
-<!ENTITY context.edit.label "Editar filtro">
-<!ENTITY context.resethitcount.label "Reiniciar a estatística de impactos do filtro">
-<!ENTITY context.synchsubscription.label "Actualizar subscrición">
-<!ENTITY context.editsubscription.label "Editar subscrición">
-<!ENTITY context.moveup.label "Mover filtro arriba">
-<!ENTITY context.movedown.label "Mover filtro abaixo">
-<!ENTITY context.movegroupup.label "Mover grupo arriba">
-<!ENTITY context.movegroupdown.label "Mover grupo abaixo">
-<!ENTITY context.enable.label "Activar">
-<!ENTITY context.disable.label "Desactivar">
-<!ENTITY apply.label "Aplicar">
-<!ENTITY apply.accesskey "P">

=== removed file 'chrome/locale/gl-ES/sidebar.dtd'
--- chrome/locale/gl-ES/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/gl-ES/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Temas bloqueables (separados)">
-<!ENTITY detach.label "Separar">
-<!ENTITY reattach.label "Unir de novo">
-<!ENTITY search.label "Procurar:">
-<!ENTITY search.accesskey "P">
-<!ENTITY type.label "Tipo">
-<!ENTITY address.label "Enderezo">
-<!ENTITY filter.label "Filtro">
-<!ENTITY state.label "Estado">
-<!ENTITY size.label "Tamaño">
-<!ENTITY docDomain.label "Documento fonte">
-<!ENTITY noitems.label "Non hai temas bloqueables">
-<!ENTITY whitelisted.label "Páxina da Lista Branca">
-<!ENTITY tooltip.address.label "Enderezo:">
-<!ENTITY tooltip.type.label "Tipo">
-<!ENTITY tooltip.type.blocked "(bloqueado)">
-<!ENTITY tooltip.type.whitelisted "(engadido á lista branca)">
-<!ENTITY tooltip.size.label "Tamaño:">
-<!ENTITY tooltip.docDomain.label "Documento fonte:">
-<!ENTITY tooltip.filter.label "Filtro en vigor:">
-<!ENTITY tooltip.filterSource.label "Fonte do filtro:">
-<!ENTITY context.block.label "Bloquear este tema">
-<!ENTITY context.editfilter.label "Editar o filtro en vigor">
-<!ENTITY context.whitelist.label "Engadir excepción para o tema">
-<!ENTITY context.disablefilter.label "Desactivar filtro --">
-<!ENTITY context.enablefilter.label "Activar filtro --">
-<!ENTITY context.disablefilteronsite.label "Desactivar este filtro en --">
-<!ENTITY context.open.label "Abrir nun novo separador">
-<!ENTITY context.flash.label "Bordos do tema Flash">
-<!ENTITY context.copy.label "Copiar o enderezo do tema">
-<!ENTITY context.copyFilter.label "Copiar o filtro">
-<!ENTITY context.selectAll.label "Seleccionar todo">

=== removed file 'chrome/locale/gl-ES/subscription.dtd'
--- chrome/locale/gl-ES/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/gl-ES/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY dialog.title "Editar filtro de subscrición">
-<!ENTITY dialog.newtitle "Engadir filtro de subscrición">
-<!ENTITY new.description "Introduza a dirección web ou un arquivo que conteña unha lista de
-	 filtros de Adblock Plus.">
-<!ENTITY edit.description "A lista de filtros para esta subscrición vai
-	 ser descargada dese lugar.">
-<!ENTITY external.description "É unha subscrición externa de filtros, a súa lista de 
-	 filtros manterase ao día pola extensión que creou esta 
-	 subscrición.">
-<!ENTITY autodownload.description "Se escolle &quot;Actualizar automaticamente&quot; buscaranse 
-	 actualizacións diarias. Con esta opción desactivada 
-	 aínda poderá actualizar manualmente a subscrición co 
-	 menú de contexto.">
-<!ENTITY location.label "Localización da lista de Filtros:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Título da subscrición:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Posta ao día automática">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.label "Accionar filtros">
-<!ENTITY enabled.accesskey "A">

=== removed file 'chrome/locale/gl-ES/tip_subscriptions.dtd'
--- chrome/locale/gl-ES/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/gl-ES/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY dialog.title "Engadir subscrición de filtros Adblock Plus">
-<!ENTITY description.par1 "Grazas por instalar Adblock Plus. Esta extensión pode eliminar o 99&#37; dos anuncios que ve na web. Con todo, o filtrado de anuncios eficaz require que se defina un bo conxunto de filtros. Pode facelo vostede mesmo, ou pode subscribirse ás listas de filtros mantidas por outros. Será posible engadir os seus propios filtros ou desactivar/eliminar subscricións sempre que sexa necesario.">
-<!ENTITY description.par2 "Pode elixir unha subscrición da lista 
-de subscricións recomendadas (pódense engadir logo máis 
-subscricións en Preferencias Adblock Plus, aínda que non 
-adoita ser necesario):">
-<!ENTITY note "Nota: Unha lista de filtros adoita ser máis eficaz cando 
-	 se aplica aos sitios da rexión para a que foi creada.">
-<!ENTITY adblock.warning "Adblock Plus detectou que está instalado Adblock ou unha versión antiga de Adblock Plus. Executar Adblock Plus e Adblock en paralelo pode causar problemas e debe evitarse. Recoméndase desinstalar Adblock.">
-<!ENTITY adblock.uninstall "Desinstalar Adblock">
-<!ENTITY filterset.g.warning "Parece que utiliza Filterset.G. Esta lista de filtros apenas se mantivo nos últimos anos e é unha causa de problemas cos sitios da Rede. Recoméndase desinstalar Filterset.G.">
-<!ENTITY filterset.g.moreinfo "Máis información">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Desinstalar Filterset.G">
-<!ENTITY homepage.label "Páxina">
-<!ENTITY subscribe.label "Subscribir">
-<!ENTITY subscribe.accesskey "S">
-<!ENTITY other.label "Engadir outra subscrición">
-<!ENTITY other.accesskey "O">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Ver todas as subscricións">

=== added file 'chrome/locale/gl/about.dtd'
--- chrome/locale/gl/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/gl/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Verbo do Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versión">
+<!ENTITY description "Adblock Plus permítelle decidir o que vostede non desexa ver na Rede. Non necesita descargar todos os anuncios, cando non queira velos - avise a Adblock Plus!">
+<!ENTITY homepage.label "Páxina oficial do Adblock Plus">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Autor:">
+<!ENTITY contributors.label "Colaboradores:">
+<!ENTITY developers.label "Desenvolvedores:">
+<!ENTITY designers.label "Deseñadores gráficos:">
+<!ENTITY subscriptionAuthors.label "Autores das subscricións de filtros:">
+<!ENTITY translators.label "Tradutores:">

=== added file 'chrome/locale/gl/composer.dtd'
--- chrome/locale/gl/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/gl/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Engadir regra de filtrado Adblock Plus">
+<!ENTITY accept.label "Engadir filtro">
+<!ENTITY advanced.label "Vista avanzada">
+<!ENTITY basic.label "Vista básica">
+<!ENTITY disabled.warning "Adblock Plus atópase actualmente desactivado. Aínda pode engadir os filtros, mais non se aplicarán a menos que vostede [link]active Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "O grupo de filtros &quot;?1?&quot; ao que se tiña que engadir este filtro está desactivado. Pode engadir o filtro mais non será aplicado ata que [link]active o grupo de filtros[/link].">
+<!ENTITY filter.label "Filtro novo:">
+<!ENTITY filter.accesskey "F">
+<!ENTITY preferences.label "Mostrar filtros existentes ...">
+<!ENTITY preferences.accesskey "S">
+<!ENTITY type.filter.label "Filtro de bloqueo">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Excepción">
+<!ENTITY type.whitelist.accesskey "x">
+<!ENTITY pattern.label "Buscar unha pauta">
+<!ENTITY pattern.explanation "A pauta pode ser calquera parte da dirección, o símbolo * actúa como comodín. O filtro só se aplicará ás direccións coincidentes coa pauta.">
+<!ENTITY regexp.warning "A pauta que introduciu interprétase como unha expresión regular, e usar moitas podería retardar a navegación. Se non ten a intención de utilizar expresións regulares, engada un símbolo * ao final da pauta.">
+<!ENTITY shortpattern.warning "A pauta que introduciu é demasiado curta para ser optimizada, de haber moitas pautas así podería retardarse a navegación. Recoméndase que vostede elixa unha cadea máis longa para este filtro.">
+<!ENTITY custom.pattern.label "Personalizado:">
+<!ENTITY custom.pattern.accesskey "P">
+<!ENTITY anchors.label "Acepte só a pauta:">
+<!ENTITY anchor.start.label "ao comezo da dirección">
+<!ENTITY anchor.start.accesskey "z">
+<!ENTITY anchor.start.flexible.label "ao comezo do nome do dominio">
+<!ENTITY anchor.start.flexible.accesskey "z">
+<!ENTITY anchor.end.label "ao final da dirección">
+<!ENTITY anchor.end.accesskey "d">
+<!ENTITY options.label "Opcións">
+<!ENTITY domainRestriction.label "Restrición ao dominio:">
+<!ENTITY domainRestriction.accesskey "R">
+<!ENTITY domainRestriction.help "Especifique un ou máis dominios separados polo símbolo &quot;|&quot;, o filtro só se aplicará nestes dominios. O símbolo &quot;~&quot; antes dun nome de dominio significa que o filtro non debe aplicarse sobre el.">
+<!ENTITY firstParty.label "Só de orixe">
+<!ENTITY firstParty.accesskey "i">
+<!ENTITY thirdParty.label "Só de terceiros">
+<!ENTITY thirdParty.accesskey "T">
+<!ENTITY matchCase.label "Caso coincidente">
+<!ENTITY matchCase.accesskey "C">
+<!ENTITY types.label "Aplicar aos tipos:">
+<!ENTITY selectAllTypes.label "Marcar todos">
+<!ENTITY unselectAllTypes.label "Non marcar ningún">
+<!ENTITY collapse.label "Encartar bloqueados:">
+<!ENTITY collapse.accesskey "E">
+<!ENTITY collapse.default.yes.label "Uso por defecto (si)">
+<!ENTITY collapse.default.no.label "Uso por defecto (non)">
+<!ENTITY collapse.yes.label "Si">
+<!ENTITY collapse.no.label "Non">

=== added file 'chrome/locale/gl/global.properties'
--- chrome/locale/gl/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/gl/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Prema para abrir o menú contextual, e no medio para activar/desactivar.
+action1_tooltip=Prema para abrir/pechar elementos bloqueables, e no medio para activar/desactivar.
+action2_tooltip=Prema para abrir preferencias, e no medio para activar/desactivar.
+action3_tooltip=Prema para activar/desactivar Adblock Plus.
+disabled_tooltip=Adblock Plus está desactivado.
+active_tooltip=Adblock Plus está activo, ?1? o filtro de subscrición(s) ?2?  e o(s) filtro(s) personalizado(s) están en uso.
+whitelisted_tooltip=Adblock Plus está activo mais desactivado nesta páxina
+blocked_count_tooltip=?1? de ?2?
+blocked_count_addendum=(tamén na Lista Branca: ?1?, escondidos: ?2?)
+no_blocking_suggestions=Non hai elementos bloqueables nesta páxina
+whitelisted_page=Adblock Plus foi inhabilitado nesta páxina
+whitelist_description=Regras de excepción
+filterlist_description=Regras de Bloqueo de Publicidade
+invalid_description=Filtros non válidos
+elemhide_description=Regras de ocultación de elementos
+subscription_description=Subscrición de filtro:
+subscription_wrong_version=Algúns filtros nesta subscrición requiren Adblock Plus ?1? para funcionar correctamente!
+subscription_source=Fonte:
+subscription_status=Estado:
+subscription_status_autodownload=Actualizado automaticamente
+subscription_status_manualdownload=Actualizado manualmente
+subscription_status_externaldownload=Actualizado externamente (outra extensión)
+subscription_status_lastdownload=Última descarga:
+subscription_status_lastdownload_inprogress=Descargando...
+subscription_status_lastdownload_unknown=N/A
+remove_subscription_warning=Está seguro de que desexa eliminar esta subscrición?
+import_filters_wrong_version=Advertencia: algúns filtros da lista requiren Adblock Plus ?1? para funcionar correctamente. Probablemente deba actualizar á última versión liberada de Adblock Plus antes de importar esta lista.
+import_filters_warning=Desexa substituír os seus filtros actuais ou engadir novos filtros ao final da lista?
+import_filters_title=Importar filtros
+export_filters_title=Exportar filtros
+invalid_filters_file=Non é un arquivo de filtros de Adblock Plus válido.
+filters_write_error=Produciuse un erro ao escribir os filtros no arquivo. Asegúrese de que o arquivo non estea protexido contra escritura ou retido por outro programa.
+clearall_warning=Está seguro de que desexa eliminar todos os filtros da lista?
+resethitcounts_warning=Está seguro de que desexa reiniciar en cero os contadores de todos os filtros? Esta operación non se pode desfacer!
+resethitcounts_selected_warning=Está seguro de que desexa reiniciar en cero os contadores dos filtros escollidos? Esta operación non se pode desfacer!
+filter_regexp_tooltip=Este filtro é unha expresión regular ou é demasiado curto para ser optimizado. Moitos filtros así poderían retardar a navegación.
+filter_elemhide_duplicate_id=Só pode especificarse un ID do elemento que se vai ocultar
+filter_elemhide_nocriteria=Non se especificaron criterios para recoñecer o elemento que se vai ocultar
+subscription_notAdded_warning=Vostede non engadiu unha subscrición de filtros. Sen ela terá que engadir manualmente os filtros de Adblock Plus.
+subscription_notAdded_warning_addendum=Quere continuar?
+subscription_invalid_location=Esa localización da lista de filtros non é nin unha URL válida nin un nome de arquivo válido.
+synchronize_invalid_url=Fallou, non é unha dirección válida
+synchronize_connection_error=Fallou, fracasou a descarga
+synchronize_invalid_data=Fallou, non é unha lista de filtros válida
+synchronize_checksum_mismatch=Fallou, a proba 'checksum' non cadrou
+synchronize_ok=Valeu
+overwrite=Sobreescribir
+append=Anexar
+new_filter_group_title=Filtro novo
+type_label_other=outro
+type_label_script=secuencia de comandos
+type_label_image=imaxe
+type_label_stylesheet=folla de estilo
+type_label_object=obxecto
+type_label_subdocument=marco
+type_label_document=documento
+type_label_background=fondo
+type_label_elemhide=oculto
+type_label_xbl=XBL vinculante
+type_label_ping=ping ao enlace
+type_label_xmlhttprequest=solicitude XML
+type_label_object_subrequest=sub-solicitude de obxecto
+type_label_dtd=DTD
+type_label_media=audio/vídeo
+type_label_font=fonte
+fennec_status_enabled=Adblock Plus está activo.
+fennec_status_disabled=Adblock Plus está desactivado.
+fennec_status_enabled_site=Adblock Plus está activo en ?1?.
+fennec_status_disabled_site=Adblock Plus está desactivado en ?1?.

=== added file 'chrome/locale/gl/meta.properties'
--- chrome/locale/gl/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/gl/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Manuel Meixide
+name=Adblock Plus
+description=Os anuncios son cousa do pasado!
+description.short=Irritado polos anuncios e os banners? Preocupado polos rastreos? Instale Adblock Plus e recupere o control e cambie a súa visión da Internet.\n\nVexa un pequeno vídeo resumo en http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus permítelle recuperar o control de Internet e ver o web da maneira que desexa. O complemento apoiase en máis de corenta subscricións de filtros en decenas de idiomas, que automaticamente configúrano para propósitos que van desde a eliminación de publicidade en liña ao bloqueo de todos os dominios coñecidos de aplicacións maliciosas. Adblock Plus tamén permite personalizar os filtros, coa axuda dunha variedade de características útiles, incluíndo unha opción de contexto para as imaxes, unha pestana de bloqueo de obxectos Flash e Java, e unha lista de elementos a bloquear que eliminan guións executables (scripts) e follas de estilo.

=== added file 'chrome/locale/gl/overlay.dtd'
--- chrome/locale/gl/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/gl/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Estado:">
+<!ENTITY blocked.tooltip "Elementos bloqueados nesta páxina:">
+<!ENTITY filters.tooltip "Filtros máis activos:">
+<!ENTITY menuitem.label "Preferencias Adblock Plus">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Temas bloqueables">
+<!ENTITY context.image.label "Imaxe Adblock">
+<!ENTITY context.object.label "Obxecto Adblock">
+<!ENTITY context.frame.label "Marco Adblock">
+<!ENTITY context.media.label "Adblock Plus: Bloquear vídeo/audio">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Re-activado nesta páxina">
+<!ENTITY sidebar.title "Temas bloqueables da páxina actual">
+<!ENTITY settings.label "Preferencias">
+<!ENTITY settings.accesskey "F">
+<!ENTITY opensidebar.label "Abrir temas bloqueables">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "Pechar temas bloqueables">
+<!ENTITY closesidebar.accesskey "b">
+<!ENTITY whitelist.site.label "Desactivar en ?1?">
+<!ENTITY whitelist.page.label "Desactivar só nesta páxina">
+<!ENTITY objecttab.title "Bloquear">
+<!ENTITY objecttab.tooltip "Prema aquí para bloquear este obxecto con Adblock Plus">

=== added file 'chrome/locale/gl/settings.dtd'
--- chrome/locale/gl/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/gl/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Preferencias Adblock Plus">
+<!ENTITY filters.label "Filtros">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Engadir filtro">
+<!ENTITY add.accesskey "n">
+<!ENTITY addsubscription.label "Engadir subscrición de filtros">
+<!ENTITY addsubscription.accesskey "S">
+<!ENTITY synchsubscriptions.label "Actualizar todas as subscricións">
+<!ENTITY synchsubscriptions.accesskey "A">
+<!ENTITY import.label "Importar filtros">
+<!ENTITY import.accesskey "M">
+<!ENTITY export.label "Exportar filtros personalizados">
+<!ENTITY export.accesskey "X">
+<!ENTITY clearall.label "Eliminar todos os filtros personalizados">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "Reiniciar as estatísticas">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "Editar">
+<!ENTITY edit.accesskey "E">
+<!ENTITY cut.label "Cortar">
+<!ENTITY cut.accesskey "T">
+<!ENTITY copy.label "Copiar">
+<!ENTITY copy.accesskey "C">
+<!ENTITY paste.label "Pegar">
+<!ENTITY paste.accesskey "P">
+<!ENTITY remove.label "Borrar">
+<!ENTITY remove.accesskey "B">
+<!ENTITY menu.find.label "Atopar">
+<!ENTITY menu.find.accesskey "O">
+<!ENTITY menu.findagain.label "Atopar de novo">
+<!ENTITY menu.findagain.accesskey "N">
+<!ENTITY view.label "Ver">
+<!ENTITY view.accesskey "V">
+<!ENTITY sort.label "Ordenar por">
+<!ENTITY sort.accesskey "o">
+<!ENTITY sort.none.label "Sen clasificar">
+<!ENTITY sort.none.accesskey "s">
+<!ENTITY sort.ascending.label "Ordenar A &gt; Z">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Ordenar Z &gt; A">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Opcións">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Activar Adblock Plus">
+<!ENTITY enable.accesskey "a">
+<!ENTITY showintoolbar.label "Mostrar na barra de ferramentas">
+<!ENTITY showintoolbar.accesskey "f">
+<!ENTITY showinstatusbar.label "Mostrar na barra de estado">
+<!ENTITY showinstatusbar.accesskey "e">
+<!ENTITY objecttabs.label "Mostrar separadores en Flash e Java">
+<!ENTITY objecttabs.accesskey "s">
+<!ENTITY collapse.label "Encartar elementos bloqueados">
+<!ENTITY collapse.accesskey "L">
+<!ENTITY help.label "Axuda">
+<!ENTITY help.accesskey "X">
+<!ENTITY gettingStarted.label "Primeiros pasos">
+<!ENTITY gettingStarted.accesskey "p">
+<!ENTITY gettingStarted.url "primeirosPasos.url">
+<!ENTITY faq.label "Preguntas frecuentes (FAQ)">
+<!ENTITY faq.accesskey "F">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Escribir filtros de Adblock Plus">
+<!ENTITY filterdoc.accesskey "R">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Verbo do Adblock Plus">
+<!ENTITY about.accesskey "B">
+<!ENTITY description "Os seguintes filtros determinan que enderezos débense bloquear e cales débense permitir:">
+<!ENTITY filter.column "Regra de filtro">
+<!ENTITY filter.accesskey "F">
+<!ENTITY slow.column "Filtros lentos">
+<!ENTITY slow.accesskey "n">
+<!ENTITY enabled.column "Activada">
+<!ENTITY enabled.accesskey "c">
+<!ENTITY hitcount.column "Impactos">
+<!ENTITY hitcount.accesskey "I">
+<!ENTITY lasthit.column "Último impacto">
+<!ENTITY lasthit.accesskey "L">
+<!ENTITY context.edit.label "Editar filtro">
+<!ENTITY context.resethitcount.label "Reiniciar a estatística de impactos do filtro">
+<!ENTITY context.synchsubscription.label "Actualizar subscrición">
+<!ENTITY context.editsubscription.label "Editar subscrición">
+<!ENTITY context.moveup.label "Mover filtro arriba">
+<!ENTITY context.movedown.label "Mover filtro abaixo">
+<!ENTITY context.movegroupup.label "Mover grupo arriba">
+<!ENTITY context.movegroupdown.label "Mover grupo abaixo">
+<!ENTITY context.enable.label "Activar">
+<!ENTITY context.disable.label "Desactivar">
+<!ENTITY apply.label "Aplicar">
+<!ENTITY apply.accesskey "P">
+<!ENTITY fennec.subscription.label "Subscrición de Filtros">

=== added file 'chrome/locale/gl/sidebar.dtd'
--- chrome/locale/gl/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/gl/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Temas bloqueables (separados)">
+<!ENTITY detach.label "Separar">
+<!ENTITY reattach.label "Unir de novo">
+<!ENTITY search.label "Procurar:">
+<!ENTITY search.accesskey "P">
+<!ENTITY type.label "Tipo">
+<!ENTITY address.label "Enderezo">
+<!ENTITY filter.label "Filtro">
+<!ENTITY state.label "Estado">
+<!ENTITY size.label "Tamaño">
+<!ENTITY docDomain.label "Documento fonte">
+<!ENTITY noitems.label "Non hai temas bloqueables">
+<!ENTITY whitelisted.label "Páxina da Lista Branca">
+<!ENTITY tooltip.address.label "Enderezo:">
+<!ENTITY tooltip.type.label "Tipo">
+<!ENTITY tooltip.type.blocked "(bloqueado)">
+<!ENTITY tooltip.type.whitelisted "(engadido á lista branca)">
+<!ENTITY tooltip.size.label "Tamaño:">
+<!ENTITY tooltip.docDomain.label "Documento fonte:">
+<!ENTITY tooltip.filter.label "Filtro en vigor:">
+<!ENTITY tooltip.filterSource.label "Fonte do filtro:">
+<!ENTITY context.block.label "Bloquear este tema">
+<!ENTITY context.editfilter.label "Editar o filtro en vigor">
+<!ENTITY context.whitelist.label "Engadir excepción para o tema">
+<!ENTITY context.disablefilter.label "Desactivar filtro ?1?">
+<!ENTITY context.enablefilter.label "Activar filtro ?1?">
+<!ENTITY context.disablefilteronsite.label "Desactivar este filtro en ?1?">
+<!ENTITY context.open.label "Abrir nun novo separador">
+<!ENTITY context.flash.label "Bordos do tema Flash">
+<!ENTITY context.copy.label "Copiar o enderezo do tema">
+<!ENTITY context.copyFilter.label "Copiar o filtro">
+<!ENTITY context.selectAll.label "Seleccionar todo">

=== added file 'chrome/locale/gl/subscriptionSelection.dtd'
--- chrome/locale/gl/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/gl/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Engadir subscrición de filtros Adblock Plus">
+<!ENTITY dialog.title.edit "Editar filtro de subscrición">
+<!ENTITY description.newInstall "Para que Adblock Plus sexa máis eficaz ten que engadir unha subscrición de filtro. Estas subscricións de filtro son proporcionadas gratis por outros usuarios de Adblock Plus. As subscricións de filtro máis axeitadas para o seu idioma xa están seleccionadas.">
+<!ENTITY adblock.warning "Adblock Plus detectou que está instalado Adblock ou unha versión antiga de Adblock Plus. Executar Adblock Plus e Adblock en paralelo pode causar problemas e debe evitarse. Recoméndase desinstalar Adblock.">
+<!ENTITY adblock.uninstall "Desinstalar Adblock">
+<!ENTITY filterset.g.warning "Parece que utiliza Filterset.G. Esta lista de filtros apenas se mantivo nos últimos anos e é unha causa de problemas cos sitios da Rede. Recoméndase desinstalar Filterset.G.">
+<!ENTITY filterset.g.moreinfo "Máis información">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Desinstalar Filterset.G">
+<!ENTITY subscriptionSelector.label "Por favor, escolla unha subscrición de filtro da lista:">
+<!ENTITY viewList.label "Ver filtros">
+<!ENTITY visitHomepage.label "Visite a páxina de inicio">
+<!ENTITY addSubscription.label "Engadir subscrición">
+<!ENTITY saveSubscription.label "Engadir subscrición">
+<!ENTITY other.label "Engadir outra subscrición">
+<!ENTITY other.accesskey "O">
+<!ENTITY list.download.failed "Fallo na recuperación da lista de subscricións.">
+<!ENTITY list.download.retry "Ténteo de novo">
+<!ENTITY list.download.website "Ver sitio web">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Por favor, confirme que quere engadir esa subscrición de filtro. Pode cambiar o título ou a situación da subscrición antes de engadila.">
+<!ENTITY edit.description "Pode cambiar o título ou a situación da subscrición se fose necesario.">
+<!ENTITY external.description "Esta é unha subscrición de filtro externa, a lista de filtros será actualizada pola extensión que creou esta subscrición.">
+<!ENTITY title.label "Título da subscrición:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Localización da lista de Filtros:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Posta ao día automática">
+<!ENTITY autodownload.accesskey "P">
+<!ENTITY supplementMessage "Esta subscrición de filtro está feita para ser usada en conxunto coa subscrición de filtro &quot;?1?&quot; que non engadiu aínda.">
+<!ENTITY addMain.label "Engadir tamén subscrición de filtro &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "s">

=== added directory 'chrome/locale/he'
=== removed directory 'chrome/locale/he-IL'
=== removed file 'chrome/locale/he-IL/about.dtd'
--- chrome/locale/he-IL/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/he-IL/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus אודות">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "גירסה">
-<!ENTITY description "Adblock Plus מאפשר להחליט מה רוצים לראות ברשת.
-אין צורך יותר להוריד את כל הפרסומות והבאנרים יותר, אם לא רוצים אותם - ספר ל-Adblock Plus!">
-<!ENTITY homepage.label "עמוד הבית של Adblock Plus">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "מחבר:">
-<!ENTITY contributors.label "תורמים:">

=== removed file 'chrome/locale/he-IL/composer.dtd'
--- chrome/locale/he-IL/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/he-IL/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "הוספת חוק מסנן Adblock Plus">
-<!ENTITY accept.label "הוספת מסנן">
-<!ENTITY advanced.label "תצוגה מתקדמת">
-<!ENTITY basic.label "תצוגה בסיסית">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus מנוטרל. ניתן לערוך את כל המסננים ברשימה, אבל זה לא יהיה מעשי עד שתאפשר אותו מחדש.">
-<!ENTITY disabled.warning.link "מאפשר את Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "סנן זה אשר אמור להיות מצורף לקבוצת הסינון &quot;&#37;S&quot; מנוטרל כרגע. עדיין ניתן להוסיף סנן זה אך הוא לא ייושם אל אם">
-<!ENTITY groupDisabled.warning.link "קבוצת הסינון תאפשר">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "מסנן חדש:">
-<!ENTITY filter.accesskey "מ">
-<!ENTITY preferences.label "מציג מסננים קיימים...">
-<!ENTITY preferences.accesskey "צ">
-<!ENTITY type.filter.label "מסנן חסימה">
-<!ENTITY type.filter.accesskey "ס">
-<!ENTITY type.whitelist.label "חוק חריג">
-<!ENTITY type.whitelist.accesskey "ק">
-<!ENTITY pattern.label "חפש אחר תבנית">
-<!ENTITY pattern.explanation "הדפוס יכול להיות כל חלק מהכתובת, סמל * משמש כתו חופשי שאחריו יכול לבוא כל תו אחר. המסנן יכול להחיל רק על כתובות המתאימות לתבנית.">
-<!ENTITY regexp.warning "הדפוס שהוזן יפורש כביטוי רגיל. ביטויים רגילים רבים עשויים להאט את הגלישה. אם אין כוונה להשתמש בביטויים רגילים, יש להוסיף את הסמל * בסוף התבנית.">
-<!ENTITY shortpattern.warning "הדפוס שהוזן קצר מדי בכדי להיות יעיל, דפוסים רבים מסוג זה עשויים להאט את הגלישה. מומלץ לבחור מחרוזת ארוכה יותר למסנן זה.">
-<!ENTITY custom.pattern.label "מותאם אישית:">
-<!ENTITY custom.pattern.accesskey "א">
-<!ENTITY anchors.label "הסכם לתבנית שרק:">
-<!ENTITY anchor.start.label "בתחילת הכתובת">
-<!ENTITY anchor.start.accesskey "ב">
-<!ENTITY anchor.start.flexible.label "בתחילת שם המתחם">
-<!ENTITY anchor.start.flexible.accesskey "ב">
-<!ENTITY anchor.end.label "בסוף הכתובת">
-<!ENTITY anchor.end.accesskey "ף">
-<!ENTITY options.label "אפשרויות">
-<!ENTITY domainRestriction.label "הגבלה למתחם:">
-<!ENTITY domainRestriction.accesskey "ג">
-<!ENTITY domainRestriction.help "מתחם אחד או יותר מופרדים על ידי הסמל &quot;|&quot;, המסנן יאפשר מתחמים אלו בלבד. הסמל &quot;~&quot; לפני שם המתחם משמעותו שמסנן זה מנוטרל על מתחם זה.">
-<!ENTITY firstParty.label "צד-ראשון (יוצר) בלבד">
-<!ENTITY firstParty.accesskey "ד">
-<!ENTITY thirdParty.label "צד-שלישי בלבד">
-<!ENTITY thirdParty.accesskey "ש">
-<!ENTITY matchCase.label "התאם אותיות גדולות/קטנות">
-<!ENTITY matchCase.accesskey "ט">
-<!ENTITY types.label "החל על סוגים:">
-<!ENTITY selectAllTypes.label "בחר הכל">
-<!ENTITY unselectAllTypes.label "לא לבחור דבר">
-<!ENTITY collapse.label "שמוט חסומים:">
-<!ENTITY collapse.accesskey "ו">
-<!ENTITY collapse.default.yes.label "השתמש בברירת מחדל (כן)">
-<!ENTITY collapse.default.no.label "השתמש בברירת מחדל (לא)">
-<!ENTITY collapse.yes.label "כן">
-<!ENTITY collapse.no.label "לא">

=== removed file 'chrome/locale/he-IL/global.properties'
--- chrome/locale/he-IL/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/he-IL/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=הפרסומות שייכות לעבר!
-status_active_label=Adblock
-status_disabled_label=מנוטרל
-action0_tooltip=לחץ כדי להציג את תפריט ההקשר, לחץ לחיצה אמצעית כדי לאפשר/לנטרל.
-action1_tooltip=לחץ כדי לפתוח/לסגור את רשימת פריטים לחסימה, לחץ לחיצה אמצעית כדי לאפשר/לנטרל.
-action2_tooltip=לחץ כדי לפתוח את המאפיינים, לחץ לחיצה אמצעית כדי לאפשר/לנטרל.
-action3_tooltip=לחץ כדי לאפשר/לנטרל את Adblock Plus.
-active_tooltip=Adblock Plus פועל.
-disabled_tooltip=Adblock Plus מנוטרל.
-whitelisted_tooltip=Adblock Plus עובד אבל הוא מנוטרל בדף הנוכחי.
-blocked_count_tooltip=-- מתוך --
-no_blocking_suggestions=אין פריטים לחסימה בדף הנוכחי
-whitelisted_page=Adblock Plus מנוטרל עבור הדף הנוכחי
-whitelist_description=החוקים החריגים שלי
-filterlist_description=מסנני פרסומות
-invalid_description=מסננים פגומים
-elemhide_description=חוקים להסתרת אלמנטים
-subscription_description=רשום למסננים:
-subscription_wrong_version=לכמה מהמסננים בהרשמה הזאת דרוש Adblock Plus -- כדי לעבוד כיאות.
-subscription_source=מקור:
-subscription_status=מצב:
-subscription_status_autodownload=עדכון אוטומטי
-subscription_status_manualdownload=עדכון ידני
-subscription_status_externaldownload=עדכון חיצוני (בעזרת הרחבה אחרת)
-subscription_status_lastdownload=הורדה אחרונה
-subscription_status_lastdownload_inprogress=מוריד...
-subscription_status_lastdownload_unknown=לא זמין
-remove_subscription_warning=האם בטוח שברצונך להסיר את ההרשמה הזאת?
-import_filters_wrong_version=אזהרה: לכמה מהמסננים ברשימה דרוש Adblock Plus -- כדי לעבוד כיאות. כנראה שצריך לשדרג לגירסא האחרונה של Adblock Plus לפני שתייבא את הרשימה הזאת.
-import_filters_warning=האם ברצונך להחליף את המסננים הנוכחיים או או להוסיף מסננים חדשים בסוף הרשימה?
-import_filters_title=יבוא מסננים
-export_filters_title=יצוא מסננים
-invalid_filters_file=הקובץ אינו קובץ מסננים חוקי.
-filters_write_error=חלה שגיאה בכתיבת מסננים לקובץ. בדוק שהקובץ אינו מוגן מפני כתיבה ואינו בשימוש על ידי תוכנית אחרת.
-clearall_warning=האם ברצונך להסיר את כל המסננים מהרשימה?
-resethitcounts_warning=האם ברצונך לאפס את המונים של כל המסננים? פעולה זו איננה ניתנת לביטול!
-resethitcounts_selected_warning=האם ברצונך לאפס את המונים של המסננים שנבחרו? פעולה זו איננה ניתנת לביטול!
-filter_regexp_tooltip=מסנן זה הוא או ביטוי רגיל או קצר מדי מכדי להיות מיטבי. יותר מדי מסננים מסוג זה יכולים להאט את הגלישה.
-filter_elemhide_duplicate_id=רק זהות אחת של האלמנט שיהיה מוסתר ניצן לציון
-filter_elemhide_nocriteria=לא צוין קריטריון לזיהוי האלמנט שיהיה מוסתר
-subscription_no_location=נא הכנס את המיקום שממנה ברצונך להוריד את המסננים.
-subscription_invalid_location=המיקום שגוי או ששם הקובץ שגוי.
-subscription_location_exists=כבר נרשמת לרשימת המסננים הזו.
-synchronize_invalid_url=נכשל, הכתובת שגויה
-synchronize_connection_error=נכשל, ההורדה נכשלה
-synchronize_invalid_data=נכשל, רשימת המסננים לא חוקית
-synchronize_checksum_mismatch=נכשל, ביקורת הסיכום לתקינות התקבלה לא תואמת
-synchronize_ok=הצליח
-overwrite=כתוב על
-append=הוסף
-new_filter_group_title=מסנן חדש
-type_label_other=אחר
-type_label_script=תסריט
-type_label_image=תמונה
-type_label_stylesheet=סגנון
-type_label_object=אובייקט
-type_label_subdocument=מסגרת
-type_label_document=מסמך
-type_label_background=רקע
-type_label_elemhide=מוסתר
-type_label_xbl=הגבלת XBL
-type_label_ping=פינג לקישור
-type_label_xmlhttprequest=דרוש XML
-type_label_object_subrequest=תת-דרישת אובייקט
-type_label_dtd=DTD
-type_label_media=אודיו\וידאו
-type_label_font=גופן

=== removed file 'chrome/locale/he-IL/overlay.dtd'
--- chrome/locale/he-IL/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/he-IL/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "מצב:">
-<!ENTITY blocked.tooltip "פריטים חסומים בעמוד זה:">
-<!ENTITY filters.tooltip "המסננים הפעילים ביותר:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: פריטים לחסימה">
-<!ENTITY context.image.label "חסום תמונה">
-<!ENTITY context.object.label "חסום פריט">
-<!ENTITY context.frame.label "חסום מסגרת">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: מאופשר מחדש בעמוד זה">
-<!ENTITY sidebar.title "פריטים לחסימה בעמוד הנוכחי">
-<!ENTITY settings.label "מאפיינים">
-<!ENTITY settings.accesskey "מ">
-<!ENTITY opensidebar.label "פתח את רשימת פריטים לחסימה">
-<!ENTITY opensidebar.accesskey "ר">
-<!ENTITY closesidebar.label "סגור את רשימת פריטים לחסימה">
-<!ENTITY closesidebar.accesskey "ר">
-<!ENTITY whitelist.site.label "נטרל ב --">
-<!ENTITY whitelist.page.label "נטרל בעמוד הזה בלבד">
-<!ENTITY objecttab.title "חסום">
-<!ENTITY objecttab.tooltip "לחץ כאן כדי לחסום את הפריט הזה עם Adblock Plus">

=== removed file 'chrome/locale/he-IL/settings.dtd'
--- chrome/locale/he-IL/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/he-IL/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus מאפייני">
-<!ENTITY filters.label "מסננים">
-<!ENTITY filters.accesskey "מ">
-<!ENTITY add.label "הוסף מסנן">
-<!ENTITY add.accesskey "ס">
-<!ENTITY addsubscription.label "הוסף הרשמה למסננים">
-<!ENTITY addsubscription.accesskey "ף">
-<!ENTITY synchsubscriptions.label "עדכן את כל ההרשמות">
-<!ENTITY synchsubscriptions.accesskey "ע">
-<!ENTITY import.label "ייבוא מסננים">
-<!ENTITY import.accesskey "ב">
-<!ENTITY export.label "יצוא מסננים מותאמים אישית">
-<!ENTITY export.accesskey "צ">
-<!ENTITY clearall.label "הסר את כל המסננים המותאמים אישית">
-<!ENTITY clearall.accesskey "ה">
-<!ENTITY resethitcounts.label "אפס את כל מוני הלחיצות">
-<!ENTITY resethitcounts.accesskey "א">
-<!ENTITY edit.label "ערוך">
-<!ENTITY edit.accesskey "ר">
-<!ENTITY cut.label "גזור">
-<!ENTITY cut.accesskey "ג">
-<!ENTITY copy.label "העתק">
-<!ENTITY copy.accesskey "ק">
-<!ENTITY paste.label "הדבק">
-<!ENTITY paste.accesskey "ה">
-<!ENTITY remove.label "מחק">
-<!ENTITY remove.accesskey "ח">
-<!ENTITY menu.find.label "מצא">
-<!ENTITY menu.find.accesskey "מ">
-<!ENTITY menu.findagain.label "מצא שוב">
-<!ENTITY menu.findagain.accesskey "צ">
-<!ENTITY view.label "תצוגה">
-<!ENTITY view.accesskey "ת">
-<!ENTITY sort.label "מיין לפי">
-<!ENTITY sort.accesskey "מ">
-<!ENTITY sort.none.label "לא ממוין">
-<!ENTITY sort.none.accesskey "ן">
-<!ENTITY sort.ascending.label "מיון מ- א &gt; עד ת">
-<!ENTITY sort.ascending.accesskey "מ">
-<!ENTITY sort.descending.label "מיון מ- ת &gt; עד א">
-<!ENTITY sort.descending.accesskey "י">
-<!ENTITY options.label "אפשרויות">
-<!ENTITY options.accesskey "פ">
-<!ENTITY enable.label "אפשר את Adblock Plus">
-<!ENTITY enable.accesskey "א">
-<!ENTITY showintoolbar.label "הצג בסרגל הכלים">
-<!ENTITY showintoolbar.accesskey "ל">
-<!ENTITY showinstatusbar.label "הצג בשורת המצב">
-<!ENTITY showinstatusbar.accesskey "צ">
-<!ENTITY objecttabs.label "הצג לשוניות על ג&apos;אווה ופלאש">
-<!ENTITY objecttabs.accesskey "ג">
-<!ENTITY collapse.label "השמט פריטים חסומים">
-<!ENTITY collapse.accesskey "ה">
-<!ENTITY help.label "עזרה">
-<!ENTITY help.accesskey "ע">
-<!ENTITY gettingStarted.label "התחלה">
-<!ENTITY gettingStarted.accesskey "ת">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "שאלות נפוצות (אנגלית)">
-<!ENTITY faq.accesskey "ש">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "כתיבת מסננים ל-Adblock Plus (אנגלית)">
-<!ENTITY filterdoc.accesskey "מ">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "אודות Adblock Plus">
-<!ENTITY about.accesskey "א">
-<!ENTITY description "המסננים הבאים קובעים איזה כתובות אמורות להיחסם ואיזה להיות מורשות:">
-<!ENTITY filter.column "חוק סינון">
-<!ENTITY filter.accesskey "נ">
-<!ENTITY slow.column "פילטרים אטיים">
-<!ENTITY slow.accesskey "פ">
-<!ENTITY enabled.column "מאופשר">
-<!ENTITY enabled.accesskey "ר">
-<!ENTITY hitcount.column "לחיצות">
-<!ENTITY hitcount.accesskey "ל">
-<!ENTITY lasthit.column "לחיצה אחרונה">
-<!ENTITY lasthit.accesskey "ח">
-<!ENTITY context.edit.label "ערוך מסנן">
-<!ENTITY context.resethitcount.label "אפס את כל מוני הלחיצות עבור מסנן">
-<!ENTITY context.synchsubscription.label "עדכן הרשמה כעת">
-<!ENTITY context.editsubscription.label "ערוך הרשמה">
-<!ENTITY context.moveup.label "הזז מסנן מעלה">
-<!ENTITY context.movedown.label "הזז מסנן מטה">
-<!ENTITY context.movegroupup.label "הזז קבוצה מעלה">
-<!ENTITY context.movegroupdown.label "הזז קבוצה מטה">
-<!ENTITY context.enable.label "אפשר">
-<!ENTITY context.disable.label "נטרל">
-<!ENTITY apply.label "החל">
-<!ENTITY apply.accesskey "ח">

=== removed file 'chrome/locale/he-IL/sidebar.dtd'
--- chrome/locale/he-IL/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/he-IL/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "(פריטים לחסימה (משוחרר :Adblock Plus">
-<!ENTITY detach.label "הפרד">
-<!ENTITY reattach.label "חבר">
-<!ENTITY search.label "חיפוש:">
-<!ENTITY search.accesskey "ח">
-<!ENTITY type.label "סוג">
-<!ENTITY address.label "כתובת">
-<!ENTITY filter.label "מסנן">
-<!ENTITY state.label "מצב">
-<!ENTITY size.label "גודל">
-<!ENTITY docDomain.label "מקור המסמך">
-<!ENTITY noitems.label "אין פריטים הניתנים לחסימה">
-<!ENTITY whitelisted.label "העמוד נמצא ברשימה הלבנה">
-<!ENTITY tooltip.address.label "כתובת:">
-<!ENTITY tooltip.type.label "סוג:">
-<!ENTITY tooltip.type.blocked "(חסום)">
-<!ENTITY tooltip.type.whitelisted "(ברשימה הלבנה)">
-<!ENTITY tooltip.size.label "גודל:">
-<!ENTITY tooltip.docDomain.label "מקור המסמך:">
-<!ENTITY tooltip.filter.label "מסנן משפיע:">
-<!ENTITY tooltip.filterSource.label "מקור מסנן">
-<!ENTITY context.block.label "חסום פריט זה">
-<!ENTITY context.editfilter.label "ערוך מסנן שמשפיע">
-<!ENTITY context.whitelist.label "הוסף כלל חריג עבור פריט">
-<!ENTITY context.disablefilter.label "נטרל מסנן --">
-<!ENTITY context.enablefilter.label "אפשר מסנן מחדש --">
-<!ENTITY context.disablefilteronsite.label "נטרול מסנן זה ב --">
-<!ENTITY context.open.label "פתח בלשונית חדשה">
-<!ENTITY context.flash.label "גבולות של פריט פלאש">
-<!ENTITY context.copy.label "העתק כתובת הפריט">
-<!ENTITY context.copyFilter.label "העתק מסנן">
-<!ENTITY context.selectAll.label "בחר הכל">

=== removed file 'chrome/locale/he-IL/subscription.dtd'
--- chrome/locale/he-IL/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/he-IL/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "ערוך הרשמה למסננים">
-<!ENTITY dialog.newtitle "הוסף הרשמה למסננים">
-<!ENTITY new.description "נא הכנס את כתובת האינטרנט או את הקובץ שמכילים את רשימת המסננים.">
-<!ENTITY edit.description "רשימת המסננים של הרשמה זו תורד מהמיקום שצוין.">
-<!ENTITY external.description "ההרשמה הזו היא לרשימת מסננים חיצונית, רשימת המסננים הזו תשאר מעודכנת בעזרת ההרחבה שיצרה אותה.">
-<!ENTITY autodownload.description "אם תבחר ב&quot;עדכן אוטומטית&quot; המיקום הזה ייבדק לעדכונים מדי יום. גם אם תנטרל את האפשרות הזאת תוכל לעדכן ידנית מתפריט הלחצן הימני של ההרשמה.">
-<!ENTITY location.label "מיקום רשימת מסננים:">
-<!ENTITY location.accesskey "מ">
-<!ENTITY title.label "כותרת הרשמה:">
-<!ENTITY title.accesskey "כ">
-<!ENTITY autodownload.label "עדכון אוטומטי">
-<!ENTITY autodownload.accesskey "ע">
-<!ENTITY enabled.label "אפשר מסננים">
-<!ENTITY enabled.accesskey "א">

=== removed file 'chrome/locale/he-IL/tip_subscriptions.dtd'
--- chrome/locale/he-IL/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/he-IL/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY dialog.title "ברוכים הבאים ל-Adblock Plus">
-<!ENTITY description.par1 "תודה שהתקנתם את Adblock Plus. ההרחבה הזאת יכולה
- לחסל 99&#37; מהפרסומות שרואים ברשת. למרות זאת,
-סינון פרסומות יעיל דורש ממך להגדיר מערכת טובה של
-מסננים. ניתן לעשות זאת לבד, או פשוט להרשם
-לרשימות מסננים שאחרים מתחזקים עבורך. עדיין ניתן להוסיף
-מסננים משלך או לנטרל/להסיר הרשמות בכל זמן שיהיה צורך.">
-<!ENTITY description.par2 "ניתן לבחור הרשמה אחת מהרשימה של ההרשמות המומלצות (אפשר להוסיף עוד הרשמות אחר כך בהגדרות של Adblock Plus, אבל בדרך כלל אין צורך בכך):">
-<!ENTITY note "הערה: בדרך הטבע, רשימת המסננים יותר יעילה כשהיא משמשת לסוג האתרים עבורו היא נכתבה.">
-<!ENTITY adblock.warning "Adblock Plus זיהה שAdblock או גרסה ישנה של Adblock Plus מותקנת. הרצת שתי הגרסאות במקביל יכולה לגרום לבעיות ואמורה להמנע.מומלץ למחוק את Adblock כעת.">
-<!ENTITY adblock.uninstall "הסרת Adblock">
-<!ENTITY filterset.g.warning "נראה שנעשה שימוש בהרחבה Filterset.G. רשימת מסננים זו בקושי תוחזקה בשנים האחרונות ולכן ישנן בעיות עם אתרים. מומלץ להסיר את Filterset.G כעת.">
-<!ENTITY filterset.g.moreinfo "מידע נוסף">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "הסרת Filterset.G">
-<!ENTITY homepage.label "דף הבית">
-<!ENTITY subscribe.label "הרשם">
-<!ENTITY subscribe.accesskey "ר">
-<!ENTITY other.label "הוסף הרשמה אחרת">
-<!ENTITY other.accesskey "ס">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "הצגת כל ההרשמות">

=== added file 'chrome/locale/he/about.dtd'
--- chrome/locale/he/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/he/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,13 @@
+<!ENTITY dialog.title "Adblock Plus אודות">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "גרסה">
+<!ENTITY description "Adblock Plus מאפשר להחליט מה רוצים לראות ברשת.
+אין צורך יותר להוריד את כל הפרסומות והודעות הפרסום יותר, אם לא רוצים אותם - ספר ל-Adblock Plus!">
+<!ENTITY homepage.label "עמוד הבית של Adblock Plus">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "מחבר:">
+<!ENTITY contributors.label "תורמים:">
+<!ENTITY developers.label "מפתחים:">
+<!ENTITY designers.label "מעצבים גרפיים:">
+<!ENTITY subscriptionAuthors.label "מחברי ההרשמה למסננים:">
+<!ENTITY translators.label "מתרגמים:">

=== added file 'chrome/locale/he/composer.dtd'
--- chrome/locale/he/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/he/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "הוספת חוק מסנן Adblock Plus">
+<!ENTITY accept.label "הוספת מסנן">
+<!ENTITY advanced.label "תצוגה מתקדמת">
+<!ENTITY basic.label "תצוגה בסיסית">
+<!ENTITY disabled.warning "Adblock Plus מנוטרל. ניתן לערוך את כל המסננים ברשימה, אבל זה לא יהיה מעשי עד שיאפשר מחדש. [link]מאפשר את Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "מסנן זה אשר אמור להיות מצורף לקבוצת הסינון &quot;?1?&quot; מנוטרל כרגע. עדיין ניתן להוסיף מסנן זה אך הוא לא ייושם אלא אם [link]קבוצת הסינון תאפשר[/link].">
+<!ENTITY filter.label "מסנן חדש:">
+<!ENTITY filter.accesskey "מ">
+<!ENTITY preferences.label "הצגת המסננים הקיימים...">
+<!ENTITY preferences.accesskey "צ">
+<!ENTITY type.filter.label "מסנן חסימה">
+<!ENTITY type.filter.accesskey "ס">
+<!ENTITY type.whitelist.label "חוק חריג">
+<!ENTITY type.whitelist.accesskey "ק">
+<!ENTITY pattern.label "חיפוש אחר תבנית">
+<!ENTITY pattern.explanation "הדפוס יכול להיות כל חלק מהכתובת, סמל * משמש כתו חופשי שאחריו יכול לבוא כל תו אחר. המסנן יכול להחיל רק על כתובות המתאימות לתבנית.">
+<!ENTITY regexp.warning "הדפוס שהוזן יפורש כביטוי רגיל. ביטויים רגילים רבים עשויים להאט את הגלישה. אם אין כוונה להשתמש בביטויים רגילים, יש להוסיף את הסמל * בסוף התבנית.">
+<!ENTITY shortpattern.warning "הדפוס שהוזן קצר מדי בכדי להיות יעיל, דפוסים רבים מסוג זה עשויים להאט את הגלישה. מומלץ לבחור מחרוזת ארוכה יותר למסנן זה.">
+<!ENTITY custom.pattern.label "מותאם:">
+<!ENTITY custom.pattern.accesskey "א">
+<!ENTITY anchors.label "הסכמה לתבנית שרק:">
+<!ENTITY anchor.start.label "בתחילת הכתובת">
+<!ENTITY anchor.start.accesskey "ב">
+<!ENTITY anchor.start.flexible.label "בתחילת שם המתחם">
+<!ENTITY anchor.start.flexible.accesskey "ב">
+<!ENTITY anchor.end.label "בסוף הכתובת">
+<!ENTITY anchor.end.accesskey "ף">
+<!ENTITY options.label "אפשרויות">
+<!ENTITY domainRestriction.label "הגבלה למרחב:">
+<!ENTITY domainRestriction.accesskey "ג">
+<!ENTITY domainRestriction.help "מרחב אחד או יותר מופרדים על ידי הסמל &quot;|&quot;, המסנן יאפשר מרחבים אלו בלבד. הסמל &quot;~&quot; לפני שם המרחב משמעותו שמסנן זה מנוטרל על מרחב זה.">
+<!ENTITY firstParty.label "צד-ראשון (יוצר) בלבד">
+<!ENTITY firstParty.accesskey "ד">
+<!ENTITY thirdParty.label "צד-שלישי בלבד">
+<!ENTITY thirdParty.accesskey "ש">
+<!ENTITY matchCase.label "התאמת אותיות גדולות/קטנות">
+<!ENTITY matchCase.accesskey "ת">
+<!ENTITY types.label "החל על הסוגים:">
+<!ENTITY selectAllTypes.label "בחר הכל">
+<!ENTITY unselectAllTypes.label "לא לבחור דבר">
+<!ENTITY collapse.label "שמוט חסומים:">
+<!ENTITY collapse.accesskey "ו">
+<!ENTITY collapse.default.yes.label "שימוש בברירת מחדל (כן)">
+<!ENTITY collapse.default.no.label "שימוש בברירת מחדל (לא)">
+<!ENTITY collapse.yes.label "כן">
+<!ENTITY collapse.no.label "לא">

=== added file 'chrome/locale/he/global.properties'
--- chrome/locale/he/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/he/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=לחיצה כדי להציג את תפריט הלחצן הימני, לחיצה אמצעית כדי לאפשר\לנטרל.
+action1_tooltip=לחיצה כדי לפתוח\לסגור את רשימת הפריטים לחסימה, לחיצה אמצעית כדי לאפשר\לנטרל.
+action2_tooltip=לחיצה כדי לפתוח את המאפיינים, לחיצה אמצעית כדי לאפשר\לנטרל.
+action3_tooltip=לחיצה כדי לאפשר\לנטרל את Adblock Plus.
+disabled_tooltip=Adblock Plus מנוטרל.
+active_tooltip=Adblock Plus מאפשר, ?1? הרשמת(ות) מסננים ו ?2? מסנן(ים) מותאמים בשימוש.
+whitelisted_tooltip=Adblock Plus עובד אבל הוא מנוטרל בדף הנוכחי.
+blocked_count_tooltip=?1? מתוך ?2?
+blocked_count_addendum=(גם כן ברשימה הלבנה: ?1?, מוסתר: ?2?)
+no_blocking_suggestions=אין פריטים לחסימה בדף הנוכחי
+whitelisted_page=Adblock Plus מנוטרל עבור הדף הנוכחי
+whitelist_description=החוקים החריגים שלי
+filterlist_description=חוקי החסימה שלי
+invalid_description=החוקים הפגומים שלי
+elemhide_description=החוקים להסתרת אלמנטים שלי
+subscription_description=הרשמת מסננים:
+subscription_wrong_version=לכמה מהמסננים בהרשמה הזאת דרוש Adblock Plus ?1? כדי לעבוד כיאות.
+subscription_source=מקור:
+subscription_status=מצב:
+subscription_status_autodownload=עדכון אוטומטי
+subscription_status_manualdownload=עדכון ידני
+subscription_status_externaldownload=עדכון חיצוני (בעזרת הרחבה אחרת)
+subscription_status_lastdownload=הורדה אחרונה:
+subscription_status_lastdownload_inprogress=מוריד...
+subscription_status_lastdownload_unknown=לא זמין
+remove_subscription_warning=האם בטוח שלהסיר את ההרשמה הזאת?
+import_filters_wrong_version=אזהרה: לכמה מהמסננים ברשימה דרוש Adblock Plus ?1? כדי לעבוד כיאות. כנראה שצריך לשדרג לגרסה האחרונה של Adblock Plus לפני שתיובא הרשימה הזאת.
+import_filters_warning=האם להחליף את המסננים הנוכחיים או להוסיף מסננים חדשים בסוף הרשימה?
+import_filters_title=ייבוא מסננים
+export_filters_title=ייצוא מסננים
+invalid_filters_file=הקובץ אינו קובץ מסננים חוקי.
+filters_write_error=חלה שגיאה בכתיבת מסננים לקובץ. יש לבדוק שהקובץ אינו מוגן מפני כתיבה ואינו בשימוש על ידי יישום אחר.
+clearall_warning=האם להסיר את כל המסננים מהרשימה?
+resethitcounts_warning=האם לאפס את המונים של כל המסננים? פעולה זו איננה ניתנת לביטול!
+resethitcounts_selected_warning=האם לאפס את המונים של המסננים שנבחרו? פעולה זו איננה ניתנת לביטול!
+filter_regexp_tooltip=מסנן זה הוא או ביטוי רגיל או קצר מדי מכדי להיות מיטבי. יותר מדי מסננים מסוג זה יכולים להאט את הגלישה.
+filter_elemhide_duplicate_id=רק זהות אחת של האלמנט שיהיה מוסתר ניתן לציון
+filter_elemhide_nocriteria=לא צוין קריטריון לזיהוי האלמנט שיהיה מוסתר
+subscription_notAdded_warning=לא הוספה הרשמת מסנן. ללא הרשמת מסנן יהיה צריך להוסיף ידנית מסנני Adblock Plus.
+subscription_notAdded_warning_addendum=האם להמשיך?
+subscription_invalid_location=המיקום שגוי או ששם הקובץ שגוי.
+synchronize_invalid_url=כשל, הכתובת שגויה
+synchronize_connection_error=כשל, ההורדה נכשלה
+synchronize_invalid_data=כשל, רשימת המסננים לא חוקית
+synchronize_checksum_mismatch=כשל, ביקורת הסיכום לתקינות התאימה בצורה לא טובה
+synchronize_ok=הצליח
+overwrite=כתוב על
+append=הוספת
+new_filter_group_title=מסנן חדש
+type_label_other=אחר
+type_label_script=תסריט
+type_label_image=תמונה
+type_label_stylesheet=סגנון
+type_label_object=אובייקט
+type_label_subdocument=מסגרת
+type_label_document=מסמך
+type_label_background=רקע
+type_label_elemhide=מוסתר
+type_label_xbl=הגבלת XBL
+type_label_ping=פינג לקישור
+type_label_xmlhttprequest=בקשת XML
+type_label_object_subrequest=תת-דרישת אובייקט
+type_label_dtd=DTD
+type_label_media=אודיו\וידאו
+type_label_font=גופן
+fennec_status_enabled=Adblock Plus מאופשר.
+fennec_status_disabled=Adblock Plus מנוטרל.
+fennec_status_enabled_site=Adblock Plus מאופשר על ?1?.
+fennec_status_disabled_site=Adblock Plus מנוטרל על ?1?.

=== added file 'chrome/locale/he/meta.properties'
--- chrome/locale/he/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/he/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=catcat, SiiiE
+name=Adblock Plus
+description=הפרסומות שייכות לעבר!
+description.short=הפרסומות מציקות לך? מוטרד ממעקב אחריך? הבאנרים מפריעים לך? התקן עכשיו את Adblock Plus כדי לקבל חזרה את השליטה באינטרנט וכדי לשנות את הדרך שבה אתה צופה ברשת. \n\nסקירת וידאו קצרה באנגלית זמינה ב־http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus מאפשרת לך לקבל חזרה את השליטה באינטרנט ולצפות ברשת בדרך הרצויה לך. ההרחבה תומכת בלמעלה מארבעים רשימות מסננים בתריסר שפות שמוגדרות אוטומטית לכיסוי מלא של חסימה, מפרסומות ועד אתרים מזיקים. Adblock Plus גם יאפשר לך להתאים מסננים משלך בעזרת מבחר מאפיינים שימושיים, הכוללים תפריט הקשר לתמונות, לשונית לחסימת פלאש וג'אווה ורשימת פריטים לחסימה כדי להסיר תסריטים וסגנונות.

=== added file 'chrome/locale/he/overlay.dtd'
--- chrome/locale/he/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/he/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "מצב:">
+<!ENTITY blocked.tooltip "הפריטים החסומים בעמוד זה:">
+<!ENTITY filters.tooltip "המסננים הפעילים ביותר:">
+<!ENTITY menuitem.label "העדפות Adblock Plus">
+<!ENTITY menuitem.accesskey "b">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: פריטים לחסימה">
+<!ENTITY context.image.label "Adblock Plus: חסימת תמונה">
+<!ENTITY context.object.label "Adblock Plus: חסימת פריט">
+<!ENTITY context.frame.label "Adblock Plus: חסימת מסגרת (פריים)">
+<!ENTITY context.media.label "Adblock Plus: חסימת ווידאו\אודיו">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: מאפשר מחדש בעמוד זה">
+<!ENTITY sidebar.title "פריטים לחסימה בעמוד הנוכחי">
+<!ENTITY settings.label "העדפות">
+<!ENTITY settings.accesskey "ע">
+<!ENTITY opensidebar.label "פתיחת רשימת הפריטים לחסימה">
+<!ENTITY opensidebar.accesskey "ר">
+<!ENTITY closesidebar.label "סגירת הרשימה של הפריטים לחסימה">
+<!ENTITY closesidebar.accesskey "ר">
+<!ENTITY whitelist.site.label "נטרול ב ?1?">
+<!ENTITY whitelist.page.label "נטרול בעמוד הזה בלבד">
+<!ENTITY objecttab.title "חסימה">
+<!ENTITY objecttab.tooltip "לחץ כאן לחסימת פריט זה עם Adblock Plus">

=== added file 'chrome/locale/he/settings.dtd'
--- chrome/locale/he/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/he/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus העדפות">
+<!ENTITY filters.label "מסננים">
+<!ENTITY filters.accesskey "מ">
+<!ENTITY add.label "הוספת מסנן">
+<!ENTITY add.accesskey "ס">
+<!ENTITY addsubscription.label "הוספת הרשמה למסננים">
+<!ENTITY addsubscription.accesskey "פ">
+<!ENTITY synchsubscriptions.label "עדכון כל ההרשמות">
+<!ENTITY synchsubscriptions.accesskey "ע">
+<!ENTITY import.label "ייבוא מסננים">
+<!ENTITY import.accesskey "ב">
+<!ENTITY export.label "ייצוא מסננים מותאמים אישית">
+<!ENTITY export.accesskey "צ">
+<!ENTITY clearall.label "הסרת כל המסננים המותאמים אישית">
+<!ENTITY clearall.accesskey "ה">
+<!ENTITY resethitcounts.label "אפוס כל מוני הלחיצות">
+<!ENTITY resethitcounts.accesskey "א">
+<!ENTITY edit.label "עריכה">
+<!ENTITY edit.accesskey "כ">
+<!ENTITY cut.label "גזור">
+<!ENTITY cut.accesskey "ג">
+<!ENTITY copy.label "העתק">
+<!ENTITY copy.accesskey "ק">
+<!ENTITY paste.label "הדבק">
+<!ENTITY paste.accesskey "ה">
+<!ENTITY remove.label "מחק">
+<!ENTITY remove.accesskey "ח">
+<!ENTITY menu.find.label "מצא">
+<!ENTITY menu.find.accesskey "מ">
+<!ENTITY menu.findagain.label "מצא שוב">
+<!ENTITY menu.findagain.accesskey "צ">
+<!ENTITY view.label "תצוגה">
+<!ENTITY view.accesskey "ת">
+<!ENTITY sort.label "מיין לפי">
+<!ENTITY sort.accesskey "מ">
+<!ENTITY sort.none.label "לא ממוין">
+<!ENTITY sort.none.accesskey "ן">
+<!ENTITY sort.ascending.label "מיון מ- א &gt; עד ת">
+<!ENTITY sort.ascending.accesskey "מ">
+<!ENTITY sort.descending.label "מיון מ- ת &gt; עד א">
+<!ENTITY sort.descending.accesskey "י">
+<!ENTITY options.label "אפשרויות">
+<!ENTITY options.accesskey "פ">
+<!ENTITY enable.label "אפשור  Adblock Plus">
+<!ENTITY enable.accesskey "א">
+<!ENTITY showintoolbar.label "הצגה בסרגל הכלים">
+<!ENTITY showintoolbar.accesskey "ל">
+<!ENTITY showinstatusbar.label "הצגה בשורת המצב">
+<!ENTITY showinstatusbar.accesskey "צ">
+<!ENTITY objecttabs.label "הצגת לשוניות על ג'אווה ופלאש">
+<!ENTITY objecttabs.accesskey "ג">
+<!ENTITY collapse.label "השמטת פריטים חסומים">
+<!ENTITY collapse.accesskey "ה">
+<!ENTITY help.label "עזרה">
+<!ENTITY help.accesskey "ע">
+<!ENTITY gettingStarted.label "התחלה">
+<!ENTITY gettingStarted.accesskey "ת">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "שאלות נפוצות (אנגלית)">
+<!ENTITY faq.accesskey "ש">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "כתיבת מסננים ל-Adblock Plus (אנגלית)">
+<!ENTITY filterdoc.accesskey "מ">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "אודות Adblock Plus">
+<!ENTITY about.accesskey "א">
+<!ENTITY description "המסננים הבאים קובעים איזה כתובות אמורות להיחסם ואיזה להיות מאפשרות:">
+<!ENTITY filter.column "חוק סינון">
+<!ENTITY filter.accesskey "נ">
+<!ENTITY slow.column "מסננים אטיים">
+<!ENTITY slow.accesskey "ס">
+<!ENTITY enabled.column "מאפשר">
+<!ENTITY enabled.accesskey "ר">
+<!ENTITY hitcount.column "לחיצות">
+<!ENTITY hitcount.accesskey "ל">
+<!ENTITY lasthit.column "לחיצה אחרונה">
+<!ENTITY lasthit.accesskey "ח">
+<!ENTITY context.edit.label "עריכת מסנן">
+<!ENTITY context.resethitcount.label "אפוס את כל מוני הלחיצות עבור מסנן">
+<!ENTITY context.synchsubscription.label "עדכון ההרשמה כעת">
+<!ENTITY context.editsubscription.label "עריכת ההרשמה">
+<!ENTITY context.moveup.label "הזזת המסנן מעלה">
+<!ENTITY context.movedown.label "הזזת המסנן מטה">
+<!ENTITY context.movegroupup.label "הזזת הקבוצה מעלה">
+<!ENTITY context.movegroupdown.label "הזזת הקבוצה מטה">
+<!ENTITY context.enable.label "אפשר">
+<!ENTITY context.disable.label "נטרל">
+<!ENTITY apply.label "החל">
+<!ENTITY apply.accesskey "ח">
+<!ENTITY fennec.subscription.label "הרשמת מסננים">

=== added file 'chrome/locale/he/sidebar.dtd'
--- chrome/locale/he/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/he/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "(פריטים לחסימה (מופרד :Adblock Plus">
+<!ENTITY detach.label "הפרדה">
+<!ENTITY reattach.label "חיבור">
+<!ENTITY search.label "חיפוש:">
+<!ENTITY search.accesskey "ח">
+<!ENTITY type.label "סוג">
+<!ENTITY address.label "כתובת">
+<!ENTITY filter.label "מסנן">
+<!ENTITY state.label "מצב">
+<!ENTITY size.label "גודל">
+<!ENTITY docDomain.label "מקור המסמך">
+<!ENTITY noitems.label "אין פריטים הניתנים לחסימה">
+<!ENTITY whitelisted.label "העמוד נמצא ברשימה הלבנה">
+<!ENTITY tooltip.address.label "כתובת:">
+<!ENTITY tooltip.type.label "סוג:">
+<!ENTITY tooltip.type.blocked "(חסום)">
+<!ENTITY tooltip.type.whitelisted "(ברשימה הלבנה)">
+<!ENTITY tooltip.size.label "גודל:">
+<!ENTITY tooltip.docDomain.label "מקור המסמך:">
+<!ENTITY tooltip.filter.label "השפעת המסנן:">
+<!ENTITY tooltip.filterSource.label "מקור מסנן">
+<!ENTITY context.block.label "חסימת פריט זה">
+<!ENTITY context.editfilter.label "עריכת המסנן שמשפיע">
+<!ENTITY context.whitelist.label "הוספת כלל חריג עבור פריט">
+<!ENTITY context.disablefilter.label "נטרול המסנן ?1?">
+<!ENTITY context.enablefilter.label "אפשור המסנן מחדש ?1?">
+<!ENTITY context.disablefilteronsite.label "נטרול מסנן זה ב ?1?">
+<!ENTITY context.open.label "פתיחה בלשונית חדשה">
+<!ENTITY context.flash.label "גבולות פריט הפלאש">
+<!ENTITY context.copy.label "העתקת כתובת הפריט">
+<!ENTITY context.copyFilter.label "העתקת המסנן">
+<!ENTITY context.selectAll.label "בחירת הכל">

=== added file 'chrome/locale/he/subscriptionSelection.dtd'
--- chrome/locale/he/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/he/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "הוספת הרשמות מסננים לAdblock Plus">
+<!ENTITY dialog.title.edit "ערוך הרשמה למסננים">
+<!ENTITY description.newInstall "Adblock Plus יהיה הכי יעיל אם יתווספו לו הרשמות מסננים. הרשמות המסננים מסופקים על ידי משתמשי Adblock Plus אחרים ללא שכר. ההרשמה ההולמת ביותר לשפתך נבחרה כבר.">
+<!ENTITY adblock.warning "Adblock Plus זיהה שAdblock או גרסה ישנה של Adblock Plus מותקנת. הרצת שתי הגרסאות במקביל יכולה לגרום לבעיות ואמורה להימנע.מומלץ למחוק את Adblock כעת.">
+<!ENTITY adblock.uninstall "הסרת Adblock">
+<!ENTITY filterset.g.warning "נראה שנעשה שימוש בהרחבה Filterset.G. רשימת מסננים זו בקושי תוחזקה בשנים האחרונות ולכן ישנן בעיות עם אתרים. מומלץ להסיר את Filterset.G כעת.">
+<!ENTITY filterset.g.moreinfo "מידע נוסף">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "הסרת Filterset.G">
+<!ENTITY subscriptionSelector.label "יש לבחור הרשמת מסנן מהרשימה:">
+<!ENTITY viewList.label "הצגת מסננים">
+<!ENTITY visitHomepage.label "ביקור באתר הבית">
+<!ENTITY addSubscription.label "הוספת הרשמה">
+<!ENTITY saveSubscription.label "שמירת הרשמה">
+<!ENTITY other.label "הוספת הרשמה אחרת">
+<!ENTITY other.accesskey "ס">
+<!ENTITY list.download.failed "Adblock Plus נכשל באיחזור רשימת ההרשמות.">
+<!ENTITY list.download.retry "נסה שנית">
+<!ENTITY list.download.website "הצגת האתר">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "יש לוודא הוספת מסנן הרשמה זה. ניתן לשנות את כותרת או מיקום ההרשמה לפני הוספתה.">
+<!ENTITY edit.description "ניתן לשנות את הכותרת או מיקום ההרשמה כנדרש.">
+<!ENTITY external.description "זה הוא מסנן הרשמה חיצוני; הוא יתעדכן בעזרת ההרחבה אשר ייצרה את ההרשמה.">
+<!ENTITY title.label "כותרת ההרשמה:">
+<!ENTITY title.accesskey "כ">
+<!ENTITY location.label "מיקום רשימת המסננים:">
+<!ENTITY location.accesskey "מ">
+<!ENTITY autodownload.label "עדכון מסננים אוטומטי">
+<!ENTITY autodownload.accesskey "ע">
+<!ENTITY supplementMessage "מסנן הרשמה זה נועד לשימוש עם מסנן ההרשמה ?1? אשר לא נעשה בו שימוש עדיין.">
+<!ENTITY addMain.label "הוספת מסנן ההרשמה ?1? גם כן">
+<!ENTITY addMain.accesskey "ש">

=== added directory 'chrome/locale/hr'
=== removed directory 'chrome/locale/hr-HR'
=== removed file 'chrome/locale/hr-HR/about.dtd'
--- chrome/locale/hr-HR/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hr-HR/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-<!ENTITY dialog.title "O Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Inačica">
-<!ENTITY description "Adblock Plus Vam dozvoljava da odlučite što ne želite vidjeti na webu.
-Više ne morate preuzeti sve oglase i banere, ako ih ne želite - recite Adblock Plus-u!">
-<!ENTITY homepage.label "Adblock Plus početna stranica:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Autor:">
-<!ENTITY contributors.label "Oni koji su pridonijeli:">

=== removed file 'chrome/locale/hr-HR/composer.dtd'
=== removed file 'chrome/locale/hr-HR/global.properties'
--- chrome/locale/hr-HR/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/hr-HR/global.properties	1970-01-01 00:00:00 +0000
@@ -1,55 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Oglasi su prošlost!
-status_active_label=Adblock
-status_disabled_label=Onemogućen
-action0_tooltip=Kliknite da bi se otvorio kontekstni izbornik, srednji klik za omogućavanje/onemogućavanje.
-action1_tooltip=Kliknite da bi se otvorile/zatvorile stavke koje se mogu blokirati, srednji klik za omogućavanje/onemogućavanje.
-action2_tooltip=Kliknite da bi se otvorila svojstva, srednji klik za omogućavanje/onemogućavanje.
-action3_tooltip=Kliknite da bi omogućili/onemogućili Adblock Plus.
-active_tooltip=Adblock Plus je aktivan.
-disabled_tooltip=Adblock Plus je onemogućen.
-whitelisted_tooltip=Adblock Plus je aktivan, ali onemogućen za trenutnu stranicu.
-blocked_count_tooltip=-- od --
-no_blocking_suggestions=Na trenutnoj stranici nema stavki koje se mogu blokirati
-whitelisted_page=Adblock Plus je onemogućen za trenutnu stranicu
-whitelist_description=Pravila izuzimanja
-filterlist_description=Filteri oglašavanja
-invalid_description=Nevažeći filteri
-elemhide_description=Temeljna pravila skrivanja
-subscription_description=Pretplata na filter:
-subscription_wrong_version=Neki filteri u ovoj pretplati zahtijevaju Adblock Plus -- da bi ispravno radili!
-subscription_source=Izvor:
-subscription_status=Status:
-subscription_status_autodownload=Automatsko ažuriranje
-subscription_status_manualdownload=Ručno ažuriranje
-subscription_status_externaldownload=Vanjsko ažuriranje (drugo proširenje)
-subscription_status_lastdownload=Zadnje preuzimanje:
-subscription_status_lastdownload_inprogress=Preuzimanje...
-subscription_status_lastdownload_unknown=N/A
-remove_subscription_warning=Želite li zbilja ukloniti ovu pretplatu?
-import_filters_wrong_version=Upozorenje: neki od filtera u ovom popisu zahtjevaju Adblock Plus -- da bi ispravno radili. Vjerojatno biste trebali nadograditi na zadnju inačicu Adblock Plus prije uvoza ovog popisa.
-import_filters_warning=Želite li zamijeniti Vaše trenutne filtere ili nove filtere želite dodati na kraj popisa?
-import_filters_title=Uvezi filtere
-export_filters_title=Izvezi filtere
-invalid_filters_file=Nevažeća Adblock Plus datoteka filtera.
-filters_write_error=Greška prilikom zapisivanja filtera u datoteku. Provjerite da datoteka nije zaštićena protiv pisanja ili u upotrebi od strane nekog drugog programa.
-clearall_warning=Želite li stvarno ukloniti sve filtere s popisa?
-resethitcounts_warning=Želite li doista ponovno postaviti brojanje pogodaka za sve filtere natrag na nulu? Ova operacija ne može biti opozvana!
-resethitcounts_selected_warning=Želite li doista ponovno postaviti brojanje pogodaka za odabrani filter natrag na nulu? Ova operacija ne može biti opozvana!
-subscription_no_location=Molimo Vas unesete mjesto za preuzimanje filtera.
-subscription_invalid_location=Mjesto popisa filtera nije niti valjana web adresa niti naziv datoteke.
-subscription_location_exists=Već ste pretplaćeni na ovaj popis filtera.
-synchronize_invalid_url=Neuspjeh, neispravna adresa
-synchronize_connection_error=Neuspjeh, neuspjelo preuzimanje
-synchronize_invalid_data=Neuspjeh, neispravan popis filtera
-synchronize_ok=Uspjeh
-overwrite=Prepiši
-append=Dodaj na kraj
-type_label_other=drugi
-type_label_script=skripta
-type_label_image=slika
-type_label_stylesheet=stylesheet
-type_label_object=objekt
-type_label_subdocument=okvir
-type_label_document=dokument
-type_label_background=pozadina
-type_label_elemhide=skriveno

=== removed file 'chrome/locale/hr-HR/overlay.dtd'
--- chrome/locale/hr-HR/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hr-HR/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-<!ENTITY status.tooltip "Status:">
-<!ENTITY blocked.tooltip "Blokirane stavke na ovoj stranici:">
-<!ENTITY filters.tooltip "Najaktivniji filteri:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "b">
-<!ENTITY context.image.label "Blokiraj sliku s Adblock">
-<!ENTITY context.object.label "Blokiraj objekt s Adblock">
-<!ENTITY context.frame.label "Blokiraj okvir s Adblock">
-<!ENTITY sidebar.title "Stavke koje se mogu blokirati na trenutnoj stranici">
-<!ENTITY settings.label "Postavke">
-<!ENTITY settings.accesskey "t">
-<!ENTITY opensidebar.label "Otvori stavke koje se mogu blokirati">
-<!ENTITY opensidebar.accesskey "b">
-<!ENTITY closesidebar.label "Zatvori stavke koje se mogu blokirati">
-<!ENTITY closesidebar.accesskey "b">
-<!ENTITY whitelist.site.label "Onemogući na --">
-<!ENTITY whitelist.page.label "Onemogući samo na ovoj stranici">
-<!ENTITY objecttab.title "Blokiraj">
-<!ENTITY objecttab.tooltip "Kliknite ovdje da biste ovaj objekt blokirali s Adblock Plus">

=== removed file 'chrome/locale/hr-HR/settings.dtd'
--- chrome/locale/hr-HR/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hr-HR/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,68 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus Postavke">
-<!ENTITY filters.label "Filteri">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Dodaj filter">
-<!ENTITY add.accesskey "j">
-<!ENTITY addsubscription.label "Dodaj pretplatu na filter">
-<!ENTITY addsubscription.accesskey "D">
-<!ENTITY synchsubscriptions.label "Ažuriraj sve pretplate">
-<!ENTITY synchsubscriptions.accesskey "ž">
-<!ENTITY import.label "Uvezi filtere">
-<!ENTITY import.accesskey "v">
-<!ENTITY export.label "Izvezi filtere">
-<!ENTITY export.accesskey "z">
-<!ENTITY clearall.label "Ukloni sve filtere">
-<!ENTITY clearall.accesskey "k">
-<!ENTITY resethitcounts.label "Vrati izvornu statistiku pogodaka">
-<!ENTITY resethitcounts.accesskey "r">
-<!ENTITY edit.label "Uredi">
-<!ENTITY edit.accesskey "r">
-<!ENTITY cut.label "Izreži">
-<!ENTITY cut.accesskey "z">
-<!ENTITY copy.label "Kopiraj">
-<!ENTITY copy.accesskey "o">
-<!ENTITY paste.label "Zalijepi">
-<!ENTITY paste.accesskey "l">
-<!ENTITY remove.label "Obriši">
-<!ENTITY remove.accesskey "b">
-<!ENTITY menu.find.label "Traži">
-<!ENTITY menu.find.accesskey "T">
-<!ENTITY menu.findagain.label "Ponovno traži">
-<!ENTITY menu.findagain.accesskey "n">
-<!ENTITY options.label "Opcije">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Omogući Adblock Plus">
-<!ENTITY enable.accesskey "m">
-<!ENTITY showintoolbar.label "Prikaži u alatnoj traci">
-<!ENTITY showintoolbar.accesskey "a">
-<!ENTITY showinstatusbar.label "Prikaži u statusnoj traci">
-<!ENTITY showinstatusbar.accesskey "s">
-<!ENTITY objecttabs.label "Prikaži kartice s Flashom i Javom">
-<!ENTITY objecttabs.accesskey "k">
-<!ENTITY collapse.label "Sažmi blokirane elemente">
-<!ENTITY collapse.accesskey "e">
-<!ENTITY help.label "Pomoć">
-<!ENTITY help.accesskey "ć">
-<!ENTITY faq.label "Često postavljana pitanja">
-<!ENTITY faq.accesskey "t">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Pisanje Adblock Plus filtera">
-<!ENTITY filterdoc.accesskey "i">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "O Adblock Plus">
-<!ENTITY about.accesskey "O">
-<!ENTITY description "Dodajte adrese koje želite blokirati, za prijedloge provjerite padajući popis.
-Možete koristiti * kao joker da bi kreirali još općenitije filtere. Napredni korisnici mogu koristiti regularne izraze kao /banner\d+\.gif$/.">
-<!ENTITY enabled.column "Omogućeno">
-<!ENTITY hitcount.column "Pogoci">
-<!ENTITY lasthit.column "Posljednji pogodak">
-<!ENTITY context.edit.label "Uredi filter">
-<!ENTITY context.resethitcount.label "Vrati izvornu statistiku pogodaka za filter">
-<!ENTITY context.synchsubscription.label "Ažuriraj pretplatu sada">
-<!ENTITY context.editsubscription.label "Uredi pretplatu">
-<!ENTITY context.moveup.label "Pomakni prema gore">
-<!ENTITY context.movedown.label "Pomakni prema dolje">
-<!ENTITY context.movegroupup.label "Pomakni grupu prema gore">
-<!ENTITY context.movegroupdown.label "Pomakni grupu prema dolje">
-<!ENTITY apply.label "Primijeni">
-<!ENTITY apply.accesskey "P">

=== removed file 'chrome/locale/hr-HR/sidebar.dtd'
--- chrome/locale/hr-HR/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hr-HR/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Stavke koje se mogu blokirati (odvojene)">
-<!ENTITY detach.label "Odvoji">
-<!ENTITY reattach.label "Ponovno spoji">
-<!ENTITY search.label "Traži:">
-<!ENTITY search.accesskey "T">
-<!ENTITY type.label "Tip">
-<!ENTITY address.label "Adresa">
-<!ENTITY filter.label "Filter">
-<!ENTITY state.label "Status">
-<!ENTITY noitems.label "Nema stavki koje se mogu blokirati">
-<!ENTITY whitelisted.label "Stranica koja je na dopuštenom popisu">
-<!ENTITY tooltip.address.label "Adresa:">
-<!ENTITY tooltip.type.label "Tip:">
-<!ENTITY tooltip.type.blocked "(blokiran)">
-<!ENTITY tooltip.type.whitelisted "(na dozvoljenom popisu)">
-<!ENTITY tooltip.filter.label "Filter u upotrebi:">
-<!ENTITY context.block.label "Blokiraj ovu stavku">
-<!ENTITY context.editfilter.label "Uredi filter u upotrebi">
-<!ENTITY context.whitelist.label "Dodaj pravilo izuzimanja za stavku">
-<!ENTITY context.open.label "Otvori u novoj kartici">
-<!ENTITY context.flash.label "Osvijetli granice stavke">
-<!ENTITY context.copy.label "Kopiraj adresu stavke">

=== removed file 'chrome/locale/hr-HR/subscription.dtd'
--- chrome/locale/hr-HR/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hr-HR/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Uredi pretplatu na filter">
-<!ENTITY dialog.newtitle "Dodaj pretplatu na filter">
-<!ENTITY new.description "Molimo Vas da unesete web adresu ili datoteku koja sadrži popis	Adblock Plus filtera.">
-<!ENTITY edit.description "Popis filtera za ovu pretplatu će biti preuzet s dane lokacije.">
-<!ENTITY external.description "Ovo je vanjska pretplata na filtere, njezin popis filtera će biti ažuriran od strane proširenja koje je stvorilo ovu pretplatu.">
-<!ENTITY autodownload.description "Ako izaberete &apos;Automatski ažuriraj&apos; ova lokacija će biti dnevno provjeravana za nadogradnje. S ovom opcijom onemogućenom još uvijek ćete moći ručno pokrenuti ažuriranje iz kontekstnog izbornika pretplate.">
-<!ENTITY location.label "Mjesto popisa filtera:">
-<!ENTITY location.accesskey "j">
-<!ENTITY title.label "Naslov pretplate:">
-<!ENTITY title.accesskey "p">
-<!ENTITY autodownload.label "Automatski ažuriraj">
-<!ENTITY autodownload.accesskey "m">
-<!ENTITY enabled.label "Omogući filtere">
-<!ENTITY enabled.accesskey "g">

=== removed file 'chrome/locale/hr-HR/tip_subscriptions.dtd'
--- chrome/locale/hr-HR/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hr-HR/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,10 +0,0 @@
-<!ENTITY dialog.title "Dobrodošli u Adblock Plus">
-<!ENTITY description.par1 "Hvala Vam na istalaciji Adblock Plus. Ovo proširenje može ukloniti 99&#37; oglašavanja koje vidite na webu. Ipak, efikasno filtriranje oglasa zahtijeva da definirate dobar skup filtera. To možete napraviti sami ili se jednostavno možete pretplatiti na listu filtera koje drugi održavaju za Vas. Još uvijek će biti moguće da dodate Vaše vlastite filtere ili da deaktivirate/uklonite pretplate, kad god to bude potrebno.">
-<!ENTITY description.par2 "Možete odabrati pretplatu iz donjeg popisa preporučenih pretplata  (više pretplata može kasnije biti dodano u postavkama Adblock Plus iako to obično nije potrebno):">
-<!ENTITY note "Napomena: Popis filtera je obično najučinkovitiji kada se primjenjuje na web stranice iz regije za koju je kreiran taj popis filtera.">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY homepage.label "Početna stranica">
-<!ENTITY subscribe.label "Pretplatite se">
-<!ENTITY subscribe.accesskey "r">
-<!ENTITY other.label "Dodajte drugu pretplatu">
-<!ENTITY other.accesskey "g">

=== added file 'chrome/locale/hr/about.dtd'
--- chrome/locale/hr/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hr/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,13 @@
+<!ENTITY dialog.title "O Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Inačica">
+<!ENTITY description "Adblock Plus Vam dozvoljava da odlučite što ne želite vidjeti na webu.
+Više ne morate preuzeti sve oglase i banere, ako ih ne želite - recite Adblock Plus-u!">
+<!ENTITY homepage.label "Adblock Plus početna stranica:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Autor:">
+<!ENTITY contributors.label "Oni koji su pridonijeli:">
+<!ENTITY developers.label "Razvojni tim:">
+<!ENTITY designers.label "Grafički dizajneri:">
+<!ENTITY subscriptionAuthors.label "Autori pretplata na filtere:">
+<!ENTITY translators.label "Prevoditelji:">

=== added file 'chrome/locale/hr/composer.dtd'
--- chrome/locale/hr/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hr/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Dodaj Adblock Plus pravilo za filter">
+<!ENTITY accept.label "Dodaj filet">
+<!ENTITY advanced.label "Napredni pregled">
+<!ENTITY basic.label "osnovni pregled">
+<!ENTITY disabled.warning "Adblock Plus je trenutno onemogućen. Možete dodavati filtere ali se oni neće primjenjivati ako ne [link]omogućite Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Grupa filtera &quot;?1?&quot; kojoj će ovaj filter biti dodan je trenutno onemogućena. Sveedno možete dodati filter ali on neće biti primjenjen ako ne  [link]omogućite grupu filtera[/link].">
+<!ENTITY filter.label "Novi filter">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "Prikaži postojeće filtere">
+<!ENTITY preferences.accesskey "S">
+<!ENTITY type.filter.label "Blokirani filter">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Iznimka">
+<!ENTITY type.whitelist.accesskey "m">
+<!ENTITY pattern.label "Traži ponavljajući uzorak">
+<!ENTITY pattern.explanation "uzorak može biti bilo koji dio adrese, asterisk (*) služi kao zamjena. Filter će biti primjenjen na adrese koje se poklapaju sa naznačenim uzorkom.">
+<!ENTITY regexp.warning "Uzorak koji ste unijeli biti će protumačen kao obični izraz kojeg Adblock Plus ne može efikasno obraditi i može usporiti vaše surfanje. Ako niste namjeravali koristiti obični izra, dodajte asterisk (*) na kraju uzorka.">
+<!ENTITY shortpattern.warning "Uneseni uzorak je prekratak za optimizaciju i može usporiti vaše surfanje. Preporučamo da odaberete duži niz za ovaj filter kako biste omogućili da Adblock Plus efikasnije obradi taj filter.">
+<!ENTITY custom.pattern.label "Prilagođeno:">
+<!ENTITY custom.pattern.accesskey "l">
+<!ENTITY anchors.label "Prihvati samo uzorak:">
+<!ENTITY anchor.start.label "na početku adrese">
+<!ENTITY anchor.start.accesskey "p">
+<!ENTITY anchor.start.flexible.label "na početku naziva domene">
+<!ENTITY anchor.start.flexible.accesskey "p">
+<!ENTITY anchor.end.label "na kraju adrese">
+<!ENTITY anchor.end.accesskey "n">
+<!ENTITY options.label "Postavke">
+<!ENTITY domainRestriction.label "Ograničiti na domenu:">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "Koristite ovu opciju da odabir jedne ili više domena odvojenih okomitom linijom (|). Filter će biti primjenjen samo na odabrane domene. Tilda (~) prije naziva domene pokazuje da filter neće biti primjenjen na toj domeni.">
+<!ENTITY firstParty.label "Samo first-party">
+<!ENTITY firstParty.accesskey "r">
+<!ENTITY thirdParty.label "Samo third-party">
+<!ENTITY thirdParty.accesskey "T">
+<!ENTITY matchCase.label "Točan izraz">
+<!ENTITY matchCase.accesskey "z">
+<!ENTITY types.label "Primjeniti na tipove:">
+<!ENTITY selectAllTypes.label "Odabrati sve">
+<!ENTITY unselectAllTypes.label "Nijedan odabrati">
+<!ENTITY collapse.label "Sažeti blokirano:">
+<!ENTITY collapse.accesskey "S">
+<!ENTITY collapse.default.yes.label "Koristiti općenito (da)">
+<!ENTITY collapse.default.no.label "Koriatiti općenito (ne)">
+<!ENTITY collapse.yes.label "Da">
+<!ENTITY collapse.no.label "Ne">

=== added file 'chrome/locale/hr/global.properties'
--- chrome/locale/hr/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/hr/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Kliknite da bi se otvorio kontekstni izbornik, srednji klik za omogućavanje/onemogućavanje.
+action1_tooltip=Kliknite da bi se otvorile/zatvorile stavke koje se mogu blokirati, srednji klik za omogućavanje/onemogućavanje.
+action2_tooltip=Kliknite da bi se otvorila svojstva, srednji klik za omogućavanje/onemogućavanje.
+action3_tooltip=Kliknite da bi omogućili/onemogućili Adblock Plus.
+disabled_tooltip=Adblock Plus je onemogućen.
+active_tooltip=Adblock Plus je aktivan, ?1? pretplata na filtere i ?2? vlastitih filtera u uporabi.
+whitelisted_tooltip=Adblock Plus je aktivan, ali onemogućen za trenutnu stranicu.
+blocked_count_tooltip=?1? od ?2?
+blocked_count_addendum=dopušteni: ?1?, skriveni: ?2?)
+no_blocking_suggestions=Na trenutnoj stranici nema stavki koje se mogu blokirati
+whitelisted_page=Adblock Plus je onemogućen za trenutnu stranicu
+whitelist_description=Pravila izuzimanja
+filterlist_description=Filteri oglašavanja
+invalid_description=Nevažeći filteri
+elemhide_description=Temeljna pravila skrivanja
+subscription_description=Pretplata na filter:
+subscription_wrong_version=Neki filteri u ovoj pretplati zahtijevaju Adblock Plus ?1? da bi ispravno radili!
+subscription_source=Izvor:
+subscription_status=Status:
+subscription_status_autodownload=Automatsko ažuriranje
+subscription_status_manualdownload=Ručno ažuriranje
+subscription_status_externaldownload=Vanjsko ažuriranje (drugo proširenje)
+subscription_status_lastdownload=Zadnje preuzimanje:
+subscription_status_lastdownload_inprogress=Preuzimanje...
+subscription_status_lastdownload_unknown=N/A
+remove_subscription_warning=Želite li zbilja ukloniti ovu pretplatu?
+import_filters_wrong_version=Upozorenje: neki od filtera u ovom popisu zahtjevaju Adblock Plus ?1? da bi ispravno radili. Vjerojatno biste trebali nadograditi na zadnju inačicu Adblock Plus prije uvoza ovog popisa.
+import_filters_warning=Želite li zamijeniti Vaše trenutne filtere ili nove filtere želite dodati na kraj popisa?
+import_filters_title=Uvezi filtere
+export_filters_title=Izvezi filtere
+invalid_filters_file=Nevažeća Adblock Plus datoteka filtera.
+filters_write_error=Greška prilikom zapisivanja filtera u datoteku. Provjerite da datoteka nije zaštićena protiv pisanja ili u upotrebi od strane nekog drugog programa.
+clearall_warning=Želite li stvarno ukloniti sve filtere s popisa?
+resethitcounts_warning=Želite li doista ponovno postaviti brojanje pogodaka za sve filtere natrag na nulu? Ova operacija ne može biti opozvana!
+resethitcounts_selected_warning=Želite li doista ponovno postaviti brojanje pogodaka za odabrani filter natrag na nulu? Ova operacija ne može biti opozvana!
+filter_regexp_tooltip=Ovaj filter je ili regularan izraz ili je prekatak za optimizacju. Previše ovakvih filtera vam može usporiti surfanje.
+filter_elemhide_duplicate_id=Samo jedan ID elementa za skrivanje može biti odabran.
+filter_elemhide_nocriteria=Nijedan kriterij za prepoznavanje elementa koji će biti skriven
+subscription_notAdded_warning=Niste dodali pretplatu za filter. Bez pretplate za filter morate dodavati filtere za Adblock Plus ručno.
+subscription_notAdded_warning_addendum=Želite li nastaviti?
+subscription_invalid_location=Mjesto popisa filtera nije niti valjana web adresa niti naziv datoteke.
+synchronize_invalid_url=Neuspjeh, neispravna adresa
+synchronize_connection_error=Neuspjeh, neuspjelo preuzimanje
+synchronize_invalid_data=Neuspjeh, neispravan popis filtera
+synchronize_checksum_mismatch=Neuspješno, neusklađenost checksum-a.
+synchronize_ok=Uspjeh
+overwrite=Prepiši
+append=Dodaj na kraj
+new_filter_group_title=Novi filter
+type_label_other=drugi
+type_label_script=skripta
+type_label_image=slika
+type_label_stylesheet=stylesheet
+type_label_object=objekt
+type_label_subdocument=okvir
+type_label_document=dokument
+type_label_background=pozadina
+type_label_elemhide=skriveno
+type_label_xbl=XBL vezanje
+type_label_ping=ping linka
+type_label_xmlhttprequest=XML zahtjev
+type_label_object_subrequest=podzahtjev objekta
+type_label_dtd=DTD
+type_label_media=audio/video
+type_label_font=font
+fennec_status_enabled=Adblock Plus je omogućen.
+fennec_status_disabled=Adblock Plus je onemogućen.
+fennec_status_enabled_site=Adblock Plus je omogućen na ?1?.
+fennec_status_disabled_site=Adblock Plus je onemogućen na ?1?.

=== added file 'chrome/locale/hr/meta.properties'
--- chrome/locale/hr/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/hr/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Hrvoje Majer, Leonid
+name=Adblock Plus
+description=Oglasi su prošlost!
+description.short=Oglasi vas živciraju? Praćenje vas zabrinjava? Banneri vam dosađuju? instalirajte Adblock Plus sada i kontrolu nad internetom i promijenite način na koji vidite web.\n\nKratak video pregled je dostupan na http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus vam omogućuje vraćanje kontrole nad Internetom i pregledavanjem weba na način koji vi želite. Dodatak je podržan sa preko 40 pretplata na filtere na desecima jezika koji ga automatski konfiguriraju za namjene od uklanjanja online oglasa do blokiraja svih poznatih štetnih stranica. Adblock Plus vam također omogućuje da sami stvorite vlastite filtere uz pomoć raznih korisnih mogućnosti, uključujući kontekstnu opciju za slike, karticu za blokiranje Flash i Java objekata i liste objekata koje možete blokirati kako biste uklonili skripte i stilove.

=== added file 'chrome/locale/hr/overlay.dtd'
--- chrome/locale/hr/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hr/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Status:">
+<!ENTITY blocked.tooltip "Blokirane stavke na ovoj stranici:">
+<!ENTITY filters.tooltip "Najaktivniji filteri:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "b">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Stavke koje se mogu blokirati">
+<!ENTITY context.image.label "Blokiraj sliku s Adblock">
+<!ENTITY context.object.label "Blokiraj objekt s Adblock">
+<!ENTITY context.frame.label "Blokiraj okvir s Adblock">
+<!ENTITY context.media.label "Adblock Plus: Blokirati audio/video">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Ponovno omogućiti na ovoj stranici">
+<!ENTITY sidebar.title "Stavke koje se mogu blokirati na trenutnoj stranici">
+<!ENTITY settings.label "Postavke">
+<!ENTITY settings.accesskey "t">
+<!ENTITY opensidebar.label "Otvori stavke koje se mogu blokirati">
+<!ENTITY opensidebar.accesskey "b">
+<!ENTITY closesidebar.label "Zatvori stavke koje se mogu blokirati">
+<!ENTITY closesidebar.accesskey "b">
+<!ENTITY whitelist.site.label "Onemogući na ?1?">
+<!ENTITY whitelist.page.label "Onemogući samo na ovoj stranici">
+<!ENTITY objecttab.title "Blokiraj">
+<!ENTITY objecttab.tooltip "Kliknite ovdje da biste ovaj objekt blokirali s Adblock Plus">

=== added file 'chrome/locale/hr/settings.dtd'
--- chrome/locale/hr/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hr/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,91 @@
+<!ENTITY dialog.title "Adblock Plus Postavke">
+<!ENTITY filters.label "Filteri">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Dodaj filter">
+<!ENTITY add.accesskey "j">
+<!ENTITY addsubscription.label "Dodaj pretplatu na filter">
+<!ENTITY addsubscription.accesskey "D">
+<!ENTITY synchsubscriptions.label "Ažuriraj sve pretplate">
+<!ENTITY synchsubscriptions.accesskey "ž">
+<!ENTITY import.label "Uvezi filtere">
+<!ENTITY import.accesskey "v">
+<!ENTITY export.label "Izvezi filtere">
+<!ENTITY export.accesskey "z">
+<!ENTITY clearall.label "Ukloni sve filtere">
+<!ENTITY clearall.accesskey "k">
+<!ENTITY resethitcounts.label "Vrati izvornu statistiku pogodaka">
+<!ENTITY resethitcounts.accesskey "r">
+<!ENTITY edit.label "Uredi">
+<!ENTITY edit.accesskey "r">
+<!ENTITY cut.label "Izreži">
+<!ENTITY cut.accesskey "z">
+<!ENTITY copy.label "Kopiraj">
+<!ENTITY copy.accesskey "o">
+<!ENTITY paste.label "Zalijepi">
+<!ENTITY paste.accesskey "l">
+<!ENTITY remove.label "Obriši">
+<!ENTITY remove.accesskey "b">
+<!ENTITY menu.find.label "Traži">
+<!ENTITY menu.find.accesskey "T">
+<!ENTITY menu.findagain.label "Ponovno traži">
+<!ENTITY menu.findagain.accesskey "n">
+<!ENTITY view.label "Pogledati">
+<!ENTITY view.accesskey "g">
+<!ENTITY sort.label "Posložiti po">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "Neposloženo">
+<!ENTITY sort.none.accesskey "N">
+<!ENTITY sort.ascending.label "A &gt; Z red slaganja">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Z &gt; A red slaganja">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Opcije">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Omogući Adblock Plus">
+<!ENTITY enable.accesskey "m">
+<!ENTITY showintoolbar.label "Prikaži u alatnoj traci">
+<!ENTITY showintoolbar.accesskey "a">
+<!ENTITY showinstatusbar.label "Prikaži u statusnoj traci">
+<!ENTITY showinstatusbar.accesskey "s">
+<!ENTITY objecttabs.label "Prikaži kartice s Flashom i Javom">
+<!ENTITY objecttabs.accesskey "k">
+<!ENTITY collapse.label "Sažmi blokirane elemente">
+<!ENTITY collapse.accesskey "e">
+<!ENTITY help.label "Pomoć">
+<!ENTITY help.accesskey "ć">
+<!ENTITY gettingStarted.label "Kako početi">
+<!ENTITY gettingStarted.accesskey "p">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Često postavljana pitanja">
+<!ENTITY faq.accesskey "t">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Pisanje Adblock Plus filtera">
+<!ENTITY filterdoc.accesskey "i">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "O Adblock Plus">
+<!ENTITY about.accesskey "O">
+<!ENTITY description "Dodajte adrese koje želite blokirati, za prijedloge provjerite padajući popis.
+Možete koristiti * kao joker da bi kreirali još općenitije filtere. Napredni korisnici mogu koristiti regularne izraze kao /banner\d+\.gif$/.">
+<!ENTITY filter.column "Pravilo filtera">
+<!ENTITY filter.accesskey "F">
+<!ENTITY slow.column "Spori filteri">
+<!ENTITY slow.accesskey "w">
+<!ENTITY enabled.column "Omogućeno">
+<!ENTITY enabled.accesskey "n">
+<!ENTITY hitcount.column "Pogoci">
+<!ENTITY hitcount.accesskey "H">
+<!ENTITY lasthit.column "Posljednji pogodak">
+<!ENTITY lasthit.accesskey "L">
+<!ENTITY context.edit.label "Uredi filter">
+<!ENTITY context.resethitcount.label "Vrati izvornu statistiku pogodaka za filter">
+<!ENTITY context.synchsubscription.label "Ažuriraj pretplatu sada">
+<!ENTITY context.editsubscription.label "Uredi pretplatu">
+<!ENTITY context.moveup.label "Pomakni prema gore">
+<!ENTITY context.movedown.label "Pomakni prema dolje">
+<!ENTITY context.movegroupup.label "Pomakni grupu prema gore">
+<!ENTITY context.movegroupdown.label "Pomakni grupu prema dolje">
+<!ENTITY context.enable.label "Omogućiti">
+<!ENTITY context.disable.label "Onemogućiti">
+<!ENTITY apply.label "Primijeni">
+<!ENTITY apply.accesskey "P">
+<!ENTITY fennec.subscription.label "Pretplate na filtere">

=== added file 'chrome/locale/hr/sidebar.dtd'
--- chrome/locale/hr/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hr/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Stavke koje se mogu blokirati (odvojene)">
+<!ENTITY detach.label "Odvoji">
+<!ENTITY reattach.label "Ponovno spoji">
+<!ENTITY search.label "Traži:">
+<!ENTITY search.accesskey "T">
+<!ENTITY type.label "Tip">
+<!ENTITY address.label "Adresa">
+<!ENTITY filter.label "Filter">
+<!ENTITY state.label "Status">
+<!ENTITY size.label "Veličina">
+<!ENTITY docDomain.label "Izvor dokumenta">
+<!ENTITY noitems.label "Nema stavki koje se mogu blokirati">
+<!ENTITY whitelisted.label "Stranica koja je na dopuštenom popisu">
+<!ENTITY tooltip.address.label "Adresa:">
+<!ENTITY tooltip.type.label "Tip:">
+<!ENTITY tooltip.type.blocked "(blokiran)">
+<!ENTITY tooltip.type.whitelisted "(na dozvoljenom popisu)">
+<!ENTITY tooltip.size.label "Veličina:">
+<!ENTITY tooltip.docDomain.label "Izvor dokumenta:">
+<!ENTITY tooltip.filter.label "Filter u upotrebi:">
+<!ENTITY tooltip.filterSource.label "Izvor filtera:">
+<!ENTITY context.block.label "Blokiraj ovu stavku">
+<!ENTITY context.editfilter.label "Uredi filter u upotrebi">
+<!ENTITY context.whitelist.label "Dodaj pravilo izuzimanja za stavku">
+<!ENTITY context.disablefilter.label "Onemogućiti filter ?1?">
+<!ENTITY context.enablefilter.label "Ponovno omogućiti filter ?1?">
+<!ENTITY context.disablefilteronsite.label "Onemogućiti ovaj filter na ?1?">
+<!ENTITY context.open.label "Otvori u novoj kartici">
+<!ENTITY context.flash.label "Osvijetli granice stavke">
+<!ENTITY context.copy.label "Kopiraj adresu stavke">
+<!ENTITY context.copyFilter.label "Kopirati filter">
+<!ENTITY context.selectAll.label "Odabrati sve">

=== added file 'chrome/locale/hr/subscriptionSelection.dtd'
--- chrome/locale/hr/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hr/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Add Adblock Plus pretplate na filtere">
+<!ENTITY dialog.title.edit "Uredi pretplatu na filter">
+<!ENTITY description.newInstall "Adblock Plus će biti najučinkovitiji ako dodate pretplate na filtere. Pretplate na filtere su osigurane od strane drugih korisnika Adblock Plusa, potpuno besplatno. Najprikladnija pretplata za vaš jezik je već odabrana.">
+<!ENTITY adblock.warning "Adblock Plus je otkrio da imate instaliran Adblock ili staru verziju Adblock Plusa. Paralelno korištenje Adblocka i Adblock Plusa može prouzročiti probleme i treba ga izbjegavati. Preporučamo da uklonite Adblock sada.">
+<!ENTITY adblock.uninstall "Ukloniti Adblock">
+<!ENTITY filterset.g.warning "Čini se da koristite Filterset.G. Ta lista filtera je rijetko održavana zadnjih godina i česti je uzork problema sa web stranicama. preporučamo da uklonite Filterset.G sada.">
+<!ENTITY filterset.g.moreinfo "Više informacija">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Ukloniti Filterset.G">
+<!ENTITY subscriptionSelector.label "Molimo odaberite pretplatu na filter sa popisa:">
+<!ENTITY viewList.label "Pogledati filtere">
+<!ENTITY visitHomepage.label "Posjetite početnu stranicu">
+<!ENTITY addSubscription.label "Dodati pretplatu">
+<!ENTITY saveSubscription.label "Spremiti pretplatu">
+<!ENTITY other.label "Dodajte drugu pretplatu">
+<!ENTITY other.accesskey "g">
+<!ENTITY list.download.failed "Adblock Plus nij uspio vratiti popis pretplata">
+<!ENTITY list.download.retry "Pokušajte ponovno">
+<!ENTITY list.download.website "Pogledati stranicu">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Molimo potvrdite da želite dodati ovu pretlatu na filter. Možete promijeniti naziv ili lokaciju pretplate prije nego što je dodate.">
+<!ENTITY edit.description "Možete promijeniti naziv ili lokaciju pretplate po potrebi.">
+<!ENTITY external.description "Ovo je vanjska pretplata na filter; biti će osvježena od strane dodatka koji je stvorio pretplatu.">
+<!ENTITY title.label "Naslov pretplate:">
+<!ENTITY title.accesskey "p">
+<!ENTITY location.label "Mjesto popisa filtera:">
+<!ENTITY location.accesskey "j">
+<!ENTITY autodownload.label "Automatski ažuriraj">
+<!ENTITY autodownload.accesskey "m">
+<!ENTITY supplementMessage "Ova pretplata na filter je namjenjena korištenju sa pretplatom na filter &quot;?1?&quot; koju još ne koristite.">
+<!ENTITY addMain.label "Također dodajte pretplatu na filter &quot;?1?&amp;quot">
+<!ENTITY addMain.accesskey "d">

=== added directory 'chrome/locale/hu'
=== removed directory 'chrome/locale/hu-HU'
=== removed file 'chrome/locale/hu-HU/about.dtd'
--- chrome/locale/hu-HU/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hu-HU/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Az Adblock Plus névjegye">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Verzió">
-<!ENTITY description "Az Adblock Plus segítségével eldöntheti, mit nem szeretne látni a weboldalakon. Nem kell többé letölteni a sok reklámot és banner-t, csak bízza az Adblock Plus-ra!">
-<!ENTITY homepage.label "Az Adblock Plus honlapja:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Készítette:">
-<!ENTITY contributors.label "Közreműködtek:">

=== removed file 'chrome/locale/hu-HU/composer.dtd'
--- chrome/locale/hu-HU/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hu-HU/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,51 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus szűrőszabály hozzáadása">
-<!ENTITY accept.label "Szűrő hozzáadása">
-<!ENTITY advanced.label "Haladó nézet">
-<!ENTITY basic.label "Alap nézet">
-<!ENTITY disabled.warning.beforeLink "Az Adblock Plus jelenleg le van tiltva. Szűrőket hozzáadhat, de azok nem fognak működni,">
-<!ENTITY disabled.warning.link "amíg az Adblock Plus nincs engedélyezve">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "A szűrőcsoport, amelyhez hozzá szeretné adni a szűrőt le van tiltva. Hozzáadás után a szűrő csak akkor fog működni, ha">
-<!ENTITY groupDisabled.warning.link "engedélyezi a csoportot">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Új szűrő:">
-<!ENTITY filter.accesskey "j">
-<!ENTITY preferences.label "Meglévő szűrők megjelenítése...">
-<!ENTITY preferences.accesskey "M">
-<!ENTITY type.filter.label "Blokkoló szűrő">
-<!ENTITY type.filter.accesskey "s">
-<!ENTITY type.whitelist.label "Kivételszabály">
-<!ENTITY type.whitelist.accesskey "K">
-<!ENTITY pattern.label "Minta">
-<!ENTITY pattern.explanation "A minta lehet egy webcím bármely része, amelyben a * szimbólum helyettesítő karakterként szerepelhet. A szűrő csak azokra címekre lesz alkalmazva, amelyekre a minta illeszkedik.">
-<!ENTITY regexp.warning "A megadott minta reguláris kifejezésként fog szerepelni. Sok ilyen kifejezés lassíthatja a böngészést. Ha nem akar használni ilyen kifejezéseket, a minta végére írja a * jelet.">
-<!ENTITY shortpattern.warning "A megadott minta nem optimalizálható, mert túl rövid. Sok ilyen minta lassíthatja a böngészést. Ajánlott ehhez a szűrőhöz egy hosszabb karakterlánc használata.">
-<!ENTITY custom.pattern.label "Egyedi:">
-<!ENTITY custom.pattern.accesskey "g">
-<!ENTITY anchors.label "Minta elfogadása csak:">
-<!ENTITY anchor.start.label "a cím elején">
-<!ENTITY anchor.start.accesskey "e">
-<!ENTITY anchor.start.flexible.label "a tartománynév elején">
-<!--  Note: This access key should usually be the same as anchor.start.flexible.accesskey. It is the same checkbox with different label depending on suggested filter. -->
-<!ENTITY anchor.start.flexible.accesskey "e">
-<!ENTITY anchor.end.label "a cím végén">
-<!ENTITY anchor.end.accesskey "v">
-<!ENTITY options.label "Beállítások">
-<!ENTITY domainRestriction.label "Korlátozás tartományra:">
-<!ENTITY domainRestriction.accesskey "t">
-<!ENTITY domainRestriction.help "Adjon meg egy vagy több tartományt a &quot;|&quot; jellel elválasztva, a szűrő csak ezeken a tartományokon lesz alkalmazva. A &quot;~&quot; jellel a tartománynév elején letilthatja a szűrő használatát az adott tartományon.">
-<!ENTITY firstParty.label "Csak belső címhez">
-<!ENTITY firstParty.accesskey "b">
-<!ENTITY thirdParty.label "Csak külső címhez">
-<!ENTITY thirdParty.accesskey "h">
-<!ENTITY matchCase.label "Kis- és nagy betűk megkülönböztetése">
-<!ENTITY matchCase.accesskey "i">
-<!ENTITY types.label "Alkalmazás típusokra:">
-<!ENTITY selectAllTypes.label "Minden kijelölése">
-<!ENTITY unselectAllTypes.label "Kijelölés törlése">
-<!ENTITY collapse.label "Blokkolt elem összecsukása:">
-<!ENTITY collapse.accesskey "o">
-<!ENTITY collapse.default.yes.label "Alapértelmezett (igen)">
-<!ENTITY collapse.default.no.label "Alapértelmezett (nem)">
-<!ENTITY collapse.yes.label "Igen">
-<!ENTITY collapse.no.label "Nem">

=== removed file 'chrome/locale/hu-HU/global.properties'
--- chrome/locale/hu-HU/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/hu-HU/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=A reklám a múlté!
-status_active_label=Adblock
-status_disabled_label=Kikapcsolva
-action0_tooltip=Kattintson ide a környezeti menühöz, középső gombbal a ki/bekapcsoláshoz.
-action1_tooltip=Kattintson ide a blokkolható elemek megnyitásához/bezárásához, középső gombbal a ki/bekapcsoláshoz.
-action2_tooltip=Kattintson ide a beállítások megnyitásához, középső gombbal a ki/bekapcsoláshoz.
-action3_tooltip=Kattintson ide az Adblock Plus ki/bekapcsolásához.
-active_tooltip=Az Adblock Plus be van kapcsolva.
-disabled_tooltip=Az Adblock Plus ki van kapcsolva.
-whitelisted_tooltip=Az Adblock be van kapcsolva, de a szűrés le van tiltva az aktuális oldalon.
-blocked_count_tooltip=--/--
-no_blocking_suggestions=Nincsenek blokkolható elemek az aktuális oldalon.
-whitelisted_page=Az Adblock Plus le van tiltva az aktuális oldalon
-whitelist_description=Kivételek
-filterlist_description=Reklámszűrők
-invalid_description=Érvénytelen szűrők
-elemhide_description=Elem elrejtési szabályok
-subscription_description=Külső szűrő:
-subscription_wrong_version=Néhány szűrőnek ezen a listán Adblock Plus -- kell a helyes működéshez!
-subscription_source=Forrás:
-subscription_status=Állapot:
-subscription_status_autodownload=Automatikus frissítés
-subscription_status_manualdownload=Manuális frissítés
-subscription_status_externaldownload=Külső frissítés (másik kiterjesztéssel)
-subscription_status_lastdownload=Legutóbb letöltve:
-subscription_status_lastdownload_inprogress=Letöltés...
-subscription_status_lastdownload_unknown=ismeretlen
-remove_subscription_warning=Valóban el kívánja távolítani ezt a szűrőt?
-import_filters_wrong_version=Figyelmeztetés: néhány szűrőnek ezen a listán Adblock Plus -- kell a helyes működéshez. Frissítsen az Adblock Plus legújabb kiadására, mielőtt importálja ezt a listát.
-import_filters_warning=Szeretné felülírni a jelenlegi szűrőket, vagy hozzáfűzi a lista végéhez?
-import_filters_title=Szűrők importálása
-export_filters_title=Szűrők exportálása
-invalid_filters_file=Ez a fájl nem tartalmaz Adblock Plus szűrőt.
-filters_write_error=Nem sikerült a szűrőket a fájlba írni. Győződjön meg arról, hogy a fájl írható és nincs blokkolva más program által.
-clearall_warning=Valóban el szeretné távolítani az összes szűrőt a listából?
-resethitcounts_warning=Biztosan nullázni szeretné az összes szűrő találat-számlálóját? Ezt a műveletet nem lehet visszavonni!
-resethitcounts_selected_warning=Biztosan nullázni szeretné a kijelölt szűrők találat-számlálóját? Ezt a műveletet nem lehet visszavonni!
-filter_regexp_tooltip=Ez a szűrő vagy reguláris kifejezés vagy túl rövid az optimalizációhoz. Túl sok ilyen szűrő lelassíthatja a böngészést.
-filter_elemhide_duplicate_id=Csak egy ID-ját lehet megadni az elrejtendő elemnek
-filter_elemhide_nocriteria=Nincs megadva feltétel az elrejtendő elemre
-subscription_no_location=Adja meg a címet, amelyről le szeretné tölteni a külső szűrőt.
-subscription_invalid_location=A megadott külső szűrőt tartalmazó cím helytelen, vagy hibás fájlnevet tartalmaz.
-subscription_location_exists=Már fel van iratkozva erre a listára.
-synchronize_invalid_url=Sikertelen, érvénytelen cím
-synchronize_connection_error=Sikertelen, letöltési hiba
-synchronize_invalid_data=Sikertelen, érvénytelen szűrőlista
-synchronize_checksum_mismatch=Sikertelen, érvénytelen ellenőrző összeg
-synchronize_ok=Sikeres
-overwrite=Felülírás
-append=Hozzáfűzés
-new_filter_group_title=Új szűrő
-type_label_other=egyéb
-type_label_script=szkript
-type_label_image=kép
-type_label_stylesheet=stíluslap
-type_label_object=objektum
-type_label_subdocument=keret
-type_label_document=dokumentum
-type_label_background=háttér
-type_label_elemhide=rejtett
-type_label_xbl=XBL kötés
-type_label_ping=link ping
-type_label_xmlhttprequest=XML kérés
-type_label_object_subrequest=objektum alkérés
-type_label_dtd=DTD
-type_label_media=hang/videó
-type_label_font=betűtípus

=== removed file 'chrome/locale/hu-HU/overlay.dtd'
--- chrome/locale/hu-HU/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hu-HU/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,23 +0,0 @@
-<!ENTITY status.tooltip "Állapot:">
-<!ENTITY blocked.tooltip "Blokkolt objektumok ezen az oldalon:">
-<!ENTITY filters.tooltip "Legaktívabb szűrők:">
-<!ENTITY menuitem.label "Adblock Plus beállítások">
-<!ENTITY menuitem.accesskey "b">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Blokkolható objektumok">
-<!ENTITY context.image.label "Kép blokkolása">
-<!ENTITY context.object.label "Objektum blokkolása">
-<!ENTITY context.frame.label "Keret blokkolása">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Újra-engedélyezés ezen az oldalon">
-<!ENTITY sidebar.title "Blokkolható objektumok">
-<!ENTITY settings.label "Beállítások">
-<!ENTITY settings.accesskey "B">
-<!ENTITY opensidebar.label "Blokkolható objektumok megjelenítése">
-<!ENTITY opensidebar.accesskey "j">
-<!ENTITY closesidebar.label "Blokkolható objektumok elrejtése">
-<!--  Note: This access key should usually be the same as closesidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open. -->
-<!ENTITY closesidebar.accesskey "j">
-<!ENTITY whitelist.site.label "Szűrés tiltása itt: --">
-<!ENTITY whitelist.page.label "Szűrés tiltása csak ezen az aloldalon">
-<!ENTITY objecttab.title "Blokkolás">
-<!ENTITY objecttab.tooltip "Kattintson ide a blokkoláshoz (Adblock Plus)">

=== removed file 'chrome/locale/hu-HU/settings.dtd'
--- chrome/locale/hu-HU/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hu-HU/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus beállítások">
-<!ENTITY filters.label "Szűrők">
-<!ENTITY filters.accesskey "S">
-<!ENTITY add.label "Szűrő hozzáadása">
-<!ENTITY add.accesskey "h">
-<!ENTITY addsubscription.label "Külső szűrő hozzáadása">
-<!ENTITY addsubscription.accesskey "K">
-<!ENTITY synchsubscriptions.label "Külső szűrők frissítése">
-<!ENTITY synchsubscriptions.accesskey "f">
-<!ENTITY import.label "Szűrők importálása">
-<!ENTITY import.accesskey "i">
-<!ENTITY export.label "Szűrők exportálása">
-<!ENTITY export.accesskey "x">
-<!ENTITY clearall.label "Az összes szűrő törlése">
-<!ENTITY clearall.accesskey "t">
-<!ENTITY resethitcounts.label "Találat-számlálók nullázása">
-<!ENTITY resethitcounts.accesskey "n">
-<!ENTITY edit.label "Szerkesztés">
-<!ENTITY edit.accesskey "z">
-<!ENTITY cut.label "Kivágás">
-<!ENTITY cut.accesskey "K">
-<!ENTITY copy.label "Másolás">
-<!ENTITY copy.accesskey "M">
-<!ENTITY paste.label "Beillesztés">
-<!ENTITY paste.accesskey "B">
-<!ENTITY remove.label "Törlés">
-<!ENTITY remove.accesskey "T">
-<!ENTITY menu.find.label "Keresés">
-<!ENTITY menu.find.accesskey "e">
-<!ENTITY menu.findagain.label "Következő keresése">
-<!ENTITY menu.findagain.accesskey "z">
-<!ENTITY view.label "Nézet">
-<!ENTITY view.accesskey "N">
-<!ENTITY sort.label "Rendezés">
-<!ENTITY sort.accesskey "R">
-<!ENTITY sort.none.label "Rendezetlen">
-<!ENTITY sort.none.accesskey "e">
-<!ENTITY sort.ascending.label "A &gt; Z rendezés">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Z &gt; A rendezés">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Opciók">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Adblock Plus bekapcsolása">
-<!ENTITY enable.accesskey "a">
-<!ENTITY showintoolbar.label "Megjelenítés az eszköztáron">
-<!ENTITY showintoolbar.accesskey "e">
-<!ENTITY showinstatusbar.label "Megjelenítés az állapotsoron">
-<!ENTITY showinstatusbar.accesskey "l">
-<!ENTITY objecttabs.label "Fülek megjelenítése Java és Flash objektumoknál">
-<!ENTITY objecttabs.accesskey "F">
-<!ENTITY collapse.label "Blokkolt objektumok összecsukása">
-<!ENTITY collapse.accesskey "m">
-<!ENTITY help.label "Súgó">
-<!ENTITY help.accesskey "g">
-<!ENTITY gettingStarted.label "Első lépések">
-<!ENTITY gettingStarted.accesskey "l">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Gyakran Ismételt Kérdések (FAQ)">
-<!ENTITY faq.accesskey "G">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Adblock Plus szűrők írása">
-<!ENTITY filterdoc.accesskey "s">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Az Adblock Plus névjegye">
-<!ENTITY about.accesskey "A">
-<!ENTITY description "Az alábbi szűrők meghatározzák, hogy mely címek lesznek blokkolva és melyek lesznek átengedve:">
-<!ENTITY filter.column "Szűrő szabály">
-<!ENTITY filter.accesskey "S">
-<!ENTITY slow.column "Lassú szűrők">
-<!ENTITY slow.accesskey "L">
-<!ENTITY enabled.column "Engedélyezve">
-<!ENTITY enabled.accesskey "n">
-<!ENTITY hitcount.column "Találatok">
-<!ENTITY hitcount.accesskey "T">
-<!ENTITY lasthit.column "Utolsó találat">
-<!ENTITY lasthit.accesskey "U">
-<!ENTITY context.edit.label "Szűrő szerkesztése">
-<!ENTITY context.resethitcount.label "Szűrő találatainak nullázása">
-<!ENTITY context.synchsubscription.label "Külső szűrő frissítése">
-<!ENTITY context.editsubscription.label "Külső szűrő módosítása">
-<!ENTITY context.moveup.label "Mozgatás felfelé">
-<!ENTITY context.movedown.label "Mozgatás lefelé">
-<!ENTITY context.movegroupup.label "Csoport mozgatása felfelé">
-<!ENTITY context.movegroupdown.label "Csoport mozgatása lefelé">
-<!ENTITY context.enable.label "Engedélyezés">
-<!ENTITY context.disable.label "Letiltás">
-<!ENTITY apply.label "Alkalmaz">
-<!ENTITY apply.accesskey "A">

=== removed file 'chrome/locale/hu-HU/sidebar.dtd'
--- chrome/locale/hu-HU/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hu-HU/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Blokkolható objektumok (leválasztva)">
-<!ENTITY detach.label "Leválaszt">
-<!ENTITY reattach.label "Oldalsávba">
-<!ENTITY search.label "Keresés:">
-<!ENTITY search.accesskey "K">
-<!ENTITY type.label "Típus">
-<!ENTITY address.label "Cím">
-<!ENTITY filter.label "Szűrő">
-<!ENTITY state.label "Állapot">
-<!ENTITY size.label "Méret">
-<!ENTITY docDomain.label "Dokumentum forrás">
-<!ENTITY noitems.label "Nincs blokkolható objektum">
-<!ENTITY whitelisted.label "A cím &apos;fehér listán&apos; van">
-<!ENTITY tooltip.address.label "Cím:">
-<!ENTITY tooltip.type.label "Típus:">
-<!ENTITY tooltip.type.blocked "(blokkolva)">
-<!ENTITY tooltip.type.whitelisted "(fehér listán)">
-<!ENTITY tooltip.size.label "Méret:">
-<!ENTITY tooltip.docDomain.label "Dokumentum forrás:">
-<!ENTITY tooltip.filter.label "Alkalmazott szűrők:">
-<!ENTITY tooltip.filterSource.label "Szűrő forrása:">
-<!ENTITY context.block.label "Objektum blokkolása">
-<!ENTITY context.editfilter.label "Alkalmazott szűrő szerkesztése">
-<!ENTITY context.whitelist.label "Kivétel megadása objektumhoz">
-<!ENTITY context.disablefilter.label "Szűrő letiltása --">
-<!ENTITY context.enablefilter.label "Szűrő engedélyezése --">
-<!ENTITY context.disablefilteronsite.label "Szűrő letiltása itt: --">
-<!ENTITY context.open.label "Megnyitás új fülön">
-<!ENTITY context.flash.label "Objektum széleinek villogtatása">
-<!ENTITY context.copy.label "Objektum címének másolása">
-<!ENTITY context.copyFilter.label "Szűrő másolása">
-<!ENTITY context.selectAll.label "Minden kijelölése">

=== removed file 'chrome/locale/hu-HU/subscription.dtd'
--- chrome/locale/hu-HU/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hu-HU/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Külső szűrő szerkesztése">
-<!ENTITY dialog.newtitle "Külső szűrő hozzáadása">
-<!ENTITY new.description "Kérem adjon meg egy webcímet vagy fájlt, amely egy Adblock Plus szűrőlistára mutat.">
-<!ENTITY edit.description "A szűrőlista a megadott címről töltődik le.">
-<!ENTITY external.description "A szűrőt más kiterjesztés regisztrálta és tartja karban.">
-<!ENTITY autodownload.description "Ha bekapcsolja az &apos;Automatikus frissítést&apos;, akkor naponta letöltődnek a frissítések a megadott címről. Ha ki van kapcsolva, akkor bármikor ellenőrizheti, hogy van-e frissítés a külső szűrőhöz a környezeti menüből.">
-<!ENTITY location.label "Szűrőlista címe:">
-<!ENTITY location.accesskey "c">
-<!ENTITY title.label "Külső szűrő neve:">
-<!ENTITY title.accesskey "n">
-<!ENTITY autodownload.label "Automatikus frissítés">
-<!ENTITY autodownload.accesskey "A">
-<!ENTITY enabled.label "Szűrők engedélyezése">
-<!ENTITY enabled.accesskey "S">

=== removed file 'chrome/locale/hu-HU/tip_subscriptions.dtd'
--- chrome/locale/hu-HU/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hu-HU/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Üdvözli az Adblock Plus">
-<!ENTITY description.par1 "Köszönjük, hogy az Adblock Plus kiterjesztést választotta a weboldalakon található reklámok és más nemkívánatos elemek blokkolására. Már csak az utolsó lépés van hátra. Szűrőket kell választania, amelyek szerint lesz a nemkívánatos tartalom blokkolva. Megteheti ezt egyedül, de lehetősége van választani egyszerűbb megoldást is. Külső szűrőket (egyedi szűrőkészlet) is felhasználhat, amelyeket készítőik folyamatosan frissítenek. Természetesen mindezek közben lehetősége van hozzáadni ill. törölni úgy saját mint külső szűrőket.">
-<!ENTITY description.par2 "Itt talál néhány ajánlott külső szűrőt, amelyeket azonnal felhasználhat (később további szűrőket is felvehet a Beállításokban, bár erre általában nincs szükség):">
-<!ENTITY note "Megjegyzés: A leghatásosabb külső szűrő az, amely régiójához közel áll.">
-<!ENTITY adblock.warning "Az Adblock Plus észlelte egy korábbi verzió, vagy az Adblock jelenlétét. Az Adblock és az Adblock Plus párhuzamos jelenléte problémákhoz vezethet. Ajánlott az Adblock eltávolítása.">
-<!ENTITY adblock.uninstall "Adblock eltávolítása">
-<!ENTITY filterset.g.warning "Úgy tűnik, hogy a Filterset.G használatban van. Az utóbbi években alig volt fenntartva, így problémák adódhatnak az oldalakkal kapcsolatban. Ajánlott a Filterset.G eltávolítása.">
-<!ENTITY filterset.g.moreinfo "További információk">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Filterset.G eltávolítása">
-<!ENTITY homepage.label "Honlap">
-<!ENTITY subscribe.label "Hozzáadás">
-<!ENTITY subscribe.accesskey "H">
-<!ENTITY other.label "Külső szűrő hozzáadása">
-<!ENTITY other.accesskey "K">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "További szűrők...">

=== added file 'chrome/locale/hu/about.dtd'
--- chrome/locale/hu/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hu/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Az Adblock Plus névjegye">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Verzió">
+<!ENTITY description "Az Adblock Plus segítségével eldöntheti, mit nem szeretne látni a weboldalakon. Nem kell többé letölteni a sok reklámot és banner-t, csak bízza az Adblock Plus-ra!">
+<!ENTITY homepage.label "Az Adblock Plus honlapja:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Készítette:">
+<!ENTITY contributors.label "Közreműködtek:">
+<!ENTITY developers.label "Fejlesztők:">
+<!ENTITY designers.label "Grafika:">
+<!ENTITY subscriptionAuthors.label "Külső szűrők készítői:">
+<!ENTITY translators.label "Fordítók:">

=== added file 'chrome/locale/hu/composer.dtd'
--- chrome/locale/hu/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hu/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Adblock Plus szűrőszabály hozzáadása">
+<!ENTITY accept.label "Szűrő hozzáadása">
+<!ENTITY advanced.label "Haladó nézet">
+<!ENTITY basic.label "Alap nézet">
+<!ENTITY disabled.warning "Az Adblock Plus jelenleg le van tiltva. Szűrőket hozzáadhat, de azok nem fognak működni, amíg nem [link]engedélyezi az Adblock Plust[/link].">
+<!ENTITY groupDisabled.warning "A(z) &quot;?1?&quot; szűrőcsoport, amelyhez a a szűrőt hozzá szeretné adni, jelenleg le van tiltva. A szűrőt hozzáadhatja, de az nem fog működni, amíg nem [link]engedélyezi a szűrőcsoportot[/link].">
+<!ENTITY filter.label "Új szűrő:">
+<!ENTITY filter.accesskey "j">
+<!ENTITY preferences.label "Meglévő szűrők megjelenítése...">
+<!ENTITY preferences.accesskey "M">
+<!ENTITY type.filter.label "Blokkoló szűrő">
+<!ENTITY type.filter.accesskey "s">
+<!ENTITY type.whitelist.label "Kivételszabály">
+<!ENTITY type.whitelist.accesskey "K">
+<!ENTITY pattern.label "Minta">
+<!ENTITY pattern.explanation "A minta lehet egy webcím bármely része, amelyben a * szimbólum helyettesítő karakterként szerepelhet. A szűrő csak azokra címekre lesz alkalmazva, amelyekre a minta illeszkedik.">
+<!ENTITY regexp.warning "A megadott minta reguláris kifejezésként fog szerepelni. Sok ilyen kifejezés lassíthatja a böngészést. Ha nem akar használni ilyen kifejezéseket, a minta végére írja a * jelet.">
+<!ENTITY shortpattern.warning "A megadott minta nem optimalizálható, mert túl rövid. Sok ilyen minta lassíthatja a böngészést. Ajánlott ehhez a szűrőhöz egy hosszabb karakterlánc használata.">
+<!ENTITY custom.pattern.label "Egyedi:">
+<!ENTITY custom.pattern.accesskey "g">
+<!ENTITY anchors.label "Minta elfogadása csak:">
+<!ENTITY anchor.start.label "a cím elején">
+<!ENTITY anchor.start.accesskey "e">
+<!ENTITY anchor.start.flexible.label "a tartománynév elején">
+<!ENTITY anchor.start.flexible.accesskey "e">
+<!ENTITY anchor.end.label "a cím végén">
+<!ENTITY anchor.end.accesskey "v">
+<!ENTITY options.label "Beállítások">
+<!ENTITY domainRestriction.label "Korlátozás tartományra:">
+<!ENTITY domainRestriction.accesskey "t">
+<!ENTITY domainRestriction.help "Adjon meg egy vagy több tartományt a &quot;|&quot; jellel elválasztva, a szűrő csak ezeken a tartományokon lesz alkalmazva. A &quot;~&quot; jellel a tartománynév elején letilthatja a szűrő használatát az adott tartományon.">
+<!ENTITY firstParty.label "Csak belső címhez">
+<!ENTITY firstParty.accesskey "b">
+<!ENTITY thirdParty.label "Csak külső címhez">
+<!ENTITY thirdParty.accesskey "h">
+<!ENTITY matchCase.label "Kis- és nagy betűk megkülönböztetése">
+<!ENTITY matchCase.accesskey "i">
+<!ENTITY types.label "Alkalmazás típusokra:">
+<!ENTITY selectAllTypes.label "Minden kijelölése">
+<!ENTITY unselectAllTypes.label "Kijelölés törlése">
+<!ENTITY collapse.label "Blokkolt elem összecsukása:">
+<!ENTITY collapse.accesskey "o">
+<!ENTITY collapse.default.yes.label "Alapértelmezett (igen)">
+<!ENTITY collapse.default.no.label "Alapértelmezett (nem)">
+<!ENTITY collapse.yes.label "Igen">
+<!ENTITY collapse.no.label "Nem">

=== added file 'chrome/locale/hu/global.properties'
--- chrome/locale/hu/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/hu/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Kattintson ide a környezeti menühöz, középső gombbal a ki/bekapcsoláshoz.
+action1_tooltip=Kattintson ide a blokkolható elemek megnyitásához/bezárásához, középső gombbal a ki/bekapcsoláshoz.
+action2_tooltip=Kattintson ide a beállítások megnyitásához, középső gombbal a ki/bekapcsoláshoz.
+action3_tooltip=Kattintson ide az Adblock Plus ki/bekapcsolásához.
+disabled_tooltip=Az Adblock Plus ki van kapcsolva.
+active_tooltip=Az Adblock Plus aktív, ?1? szűrő(k) és ?2? saját szűrő(k) van használatban.
+whitelisted_tooltip=Az Adblock be van kapcsolva, de a szűrés le van tiltva az aktuális oldalon.
+blocked_count_tooltip=?1?/?2?
+blocked_count_addendum=(fehérlistán: ?1?, rejtett: ?2?)
+no_blocking_suggestions=Nincsenek blokkolható elemek az aktuális oldalon.
+whitelisted_page=Az Adblock Plus le van tiltva az aktuális oldalon
+whitelist_description=Kivételek
+filterlist_description=Reklámszűrők
+invalid_description=Érvénytelen szűrők
+elemhide_description=Elem elrejtési szabályok
+subscription_description=Külső szűrő:
+subscription_wrong_version=Néhány szűrőnek ezen a listán Adblock Plus ?1? kell a helyes működéshez!
+subscription_source=Forrás:
+subscription_status=Állapot:
+subscription_status_autodownload=Automatikus frissítés
+subscription_status_manualdownload=Manuális frissítés
+subscription_status_externaldownload=Külső frissítés (másik kiterjesztéssel)
+subscription_status_lastdownload=Legutóbb letöltve:
+subscription_status_lastdownload_inprogress=Letöltés...
+subscription_status_lastdownload_unknown=ismeretlen
+remove_subscription_warning=Valóban el kívánja távolítani ezt a szűrőt?
+import_filters_wrong_version=Figyelmeztetés: néhány szűrő megfelelő működéséhez ezen a listán az Adblock Plus ?1? verziója szükséges. Frissítsen az Adblock Plus legújabb kiadására, mielőtt importálja ezt a listát.
+import_filters_warning=Szeretné felülírni a jelenlegi szűrőket, vagy hozzáfűzi a lista végéhez?
+import_filters_title=Szűrők importálása
+export_filters_title=Szűrők exportálása
+invalid_filters_file=Ez a fájl nem tartalmaz Adblock Plus szűrőt.
+filters_write_error=Nem sikerült a szűrőket a fájlba írni. Győződjön meg arról, hogy a fájl írható és nincs blokkolva más program által.
+clearall_warning=Valóban el szeretné távolítani az összes szűrőt a listából?
+resethitcounts_warning=Biztosan nullázni szeretné az összes szűrő találat-számlálóját? Ezt a műveletet nem lehet visszavonni!
+resethitcounts_selected_warning=Biztosan nullázni szeretné a kijelölt szűrők találat-számlálóját? Ezt a műveletet nem lehet visszavonni!
+filter_regexp_tooltip=Ez a szűrő vagy reguláris kifejezés vagy túl rövid az optimalizációhoz. Túl sok ilyen szűrő lelassíthatja a böngészést.
+filter_elemhide_duplicate_id=Csak egy ID-ját lehet megadni az elrejtendő elemnek
+filter_elemhide_nocriteria=Nincs megadva feltétel az elrejtendő elemre
+subscription_notAdded_warning=Nem adott meg szűrőt. Szűrő megadása nélkül az Adblock Plus szűrőit manuálisan kell megadnia.
+subscription_notAdded_warning_addendum=Végrehajtja a műveletet?
+subscription_invalid_location=A megadott külső szűrőt tartalmazó cím helytelen, vagy hibás fájlnevet tartalmaz.
+synchronize_invalid_url=Sikertelen, érvénytelen cím
+synchronize_connection_error=Sikertelen, letöltési hiba
+synchronize_invalid_data=Sikertelen, érvénytelen szűrőlista
+synchronize_checksum_mismatch=Sikertelen, érvénytelen ellenőrző összeg
+synchronize_ok=Sikeres
+overwrite=Felülírás
+append=Hozzáfűzés
+new_filter_group_title=Új szűrő
+type_label_other=egyéb
+type_label_script=szkript
+type_label_image=kép
+type_label_stylesheet=stíluslap
+type_label_object=objektum
+type_label_subdocument=keret
+type_label_document=dokumentum
+type_label_background=háttér
+type_label_elemhide=rejtett
+type_label_xbl=XBL kötés
+type_label_ping=link ping
+type_label_xmlhttprequest=XML kérés
+type_label_object_subrequest=objektum alkérés
+type_label_dtd=DTD
+type_label_media=hang/videó
+type_label_font=betűtípus
+fennec_status_enabled=Adblock Plus bekapcsolva.
+fennec_status_disabled=Adblock Plus kikapcsolva.
+fennec_status_enabled_site=Adblock Plus engedélyezve itt: ?1?.
+fennec_status_disabled_site=Adblock Plus letiltva itt: ?1?.

=== added file 'chrome/locale/hu/meta.properties'
--- chrome/locale/hu/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/hu/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Mikes Kaszmán István
+name=Adblock Plus
+description=A reklám a múlté!
+description.short=A weboldalon sok reklám és más, a weboldalt betöltését lassító elem? Telepítse az Adblock Plus kiterjesztést és gyorsítsa a weboldalak betöltését.\n\nGyors áttekintést a http://www.youtube.com/watch?v=oNvb2SjVjjI weboldalon találhat
+description.long=Az Adblock Plus lehetővé teszi a weboldalakat az Ön elképzelései szerint megtekinteni. Ez a kiegészítő számos nyelven több mint negyven szűrő segítségével automatikusan szűri az ismert weboldalak tartalmán levő reklámokat. Az Adblock Plus továbbá lehetővé teszi az Ön számára a telepített szűrők testreszabását számos beállítási lehetőség felhasználásával: képek helyi menüjéből elérhető opciók, Flash és Java objektumok blokkolása. Felhasználható a blokkolható elemek listája, amely szkriptek és stíluslapok eltávolításában nyújt kiváló segítséget.

=== added file 'chrome/locale/hu/overlay.dtd'
--- chrome/locale/hu/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hu/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Állapot:">
+<!ENTITY blocked.tooltip "Blokkolt objektumok ezen az oldalon:">
+<!ENTITY filters.tooltip "Legaktívabb szűrők:">
+<!ENTITY menuitem.label "Adblock Plus beállítások">
+<!ENTITY menuitem.accesskey "b">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Blokkolható objektumok">
+<!ENTITY context.image.label "Kép blokkolása">
+<!ENTITY context.object.label "Objektum blokkolása">
+<!ENTITY context.frame.label "Keret blokkolása">
+<!ENTITY context.media.label "Adblock Plus: videó/audió blokkolása">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Újra-engedélyezés ezen az oldalon">
+<!ENTITY sidebar.title "Blokkolható objektumok">
+<!ENTITY settings.label "Beállítások">
+<!ENTITY settings.accesskey "B">
+<!ENTITY opensidebar.label "Blokkolható objektumok megjelenítése">
+<!ENTITY opensidebar.accesskey "j">
+<!ENTITY closesidebar.label "Blokkolható objektumok elrejtése">
+<!ENTITY closesidebar.accesskey "j">
+<!ENTITY whitelist.site.label "Szűrés tiltása itt: ?1?">
+<!ENTITY whitelist.page.label "Szűrés tiltása csak ezen az aloldalon">
+<!ENTITY objecttab.title "Blokkolás">
+<!ENTITY objecttab.tooltip "Kattintson ide a blokkoláshoz (Adblock Plus)">

=== added file 'chrome/locale/hu/settings.dtd'
--- chrome/locale/hu/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hu/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus beállítások">
+<!ENTITY filters.label "Szűrők">
+<!ENTITY filters.accesskey "S">
+<!ENTITY add.label "Szűrő hozzáadása">
+<!ENTITY add.accesskey "h">
+<!ENTITY addsubscription.label "Külső szűrő hozzáadása">
+<!ENTITY addsubscription.accesskey "K">
+<!ENTITY synchsubscriptions.label "Külső szűrők frissítése">
+<!ENTITY synchsubscriptions.accesskey "f">
+<!ENTITY import.label "Szűrők importálása">
+<!ENTITY import.accesskey "i">
+<!ENTITY export.label "Szűrők exportálása">
+<!ENTITY export.accesskey "x">
+<!ENTITY clearall.label "Az összes szűrő törlése">
+<!ENTITY clearall.accesskey "t">
+<!ENTITY resethitcounts.label "Találat-számlálók nullázása">
+<!ENTITY resethitcounts.accesskey "n">
+<!ENTITY edit.label "Szerkesztés">
+<!ENTITY edit.accesskey "z">
+<!ENTITY cut.label "Kivágás">
+<!ENTITY cut.accesskey "K">
+<!ENTITY copy.label "Másolás">
+<!ENTITY copy.accesskey "M">
+<!ENTITY paste.label "Beillesztés">
+<!ENTITY paste.accesskey "B">
+<!ENTITY remove.label "Törlés">
+<!ENTITY remove.accesskey "T">
+<!ENTITY menu.find.label "Keresés">
+<!ENTITY menu.find.accesskey "e">
+<!ENTITY menu.findagain.label "Következő keresése">
+<!ENTITY menu.findagain.accesskey "z">
+<!ENTITY view.label "Nézet">
+<!ENTITY view.accesskey "N">
+<!ENTITY sort.label "Rendezés">
+<!ENTITY sort.accesskey "R">
+<!ENTITY sort.none.label "Rendezetlen">
+<!ENTITY sort.none.accesskey "e">
+<!ENTITY sort.ascending.label "A &gt; Z rendezés">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Z &gt; A rendezés">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Opciók">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Adblock Plus bekapcsolása">
+<!ENTITY enable.accesskey "a">
+<!ENTITY showintoolbar.label "Megjelenítés az eszköztáron">
+<!ENTITY showintoolbar.accesskey "e">
+<!ENTITY showinstatusbar.label "Megjelenítés az állapotsoron">
+<!ENTITY showinstatusbar.accesskey "l">
+<!ENTITY objecttabs.label "Fülek megjelenítése Java és Flash objektumoknál">
+<!ENTITY objecttabs.accesskey "F">
+<!ENTITY collapse.label "Blokkolt objektumok összecsukása">
+<!ENTITY collapse.accesskey "m">
+<!ENTITY help.label "Súgó">
+<!ENTITY help.accesskey "g">
+<!ENTITY gettingStarted.label "Első lépések">
+<!ENTITY gettingStarted.accesskey "l">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Gyakran Ismételt Kérdések (FAQ)">
+<!ENTITY faq.accesskey "G">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Adblock Plus szűrők írása">
+<!ENTITY filterdoc.accesskey "s">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Az Adblock Plus névjegye">
+<!ENTITY about.accesskey "A">
+<!ENTITY description "Az alábbi szűrők meghatározzák, hogy mely címek lesznek blokkolva és melyek lesznek átengedve:">
+<!ENTITY filter.column "Szűrő szabály">
+<!ENTITY filter.accesskey "S">
+<!ENTITY slow.column "Lassú szűrők">
+<!ENTITY slow.accesskey "L">
+<!ENTITY enabled.column "Engedélyezve">
+<!ENTITY enabled.accesskey "n">
+<!ENTITY hitcount.column "Találatok">
+<!ENTITY hitcount.accesskey "T">
+<!ENTITY lasthit.column "Utolsó találat">
+<!ENTITY lasthit.accesskey "U">
+<!ENTITY context.edit.label "Szűrő szerkesztése">
+<!ENTITY context.resethitcount.label "Szűrő találatainak nullázása">
+<!ENTITY context.synchsubscription.label "Külső szűrő frissítése">
+<!ENTITY context.editsubscription.label "Külső szűrő módosítása">
+<!ENTITY context.moveup.label "Mozgatás felfelé">
+<!ENTITY context.movedown.label "Mozgatás lefelé">
+<!ENTITY context.movegroupup.label "Csoport mozgatása felfelé">
+<!ENTITY context.movegroupdown.label "Csoport mozgatása lefelé">
+<!ENTITY context.enable.label "Engedélyezés">
+<!ENTITY context.disable.label "Letiltás">
+<!ENTITY apply.label "Alkalmaz">
+<!ENTITY apply.accesskey "A">
+<!ENTITY fennec.subscription.label "Szűrő hozzáadása">

=== added file 'chrome/locale/hu/sidebar.dtd'
--- chrome/locale/hu/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hu/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Blokkolható objektumok (leválasztva)">
+<!ENTITY detach.label "Leválaszt">
+<!ENTITY reattach.label "Oldalsávba">
+<!ENTITY search.label "Keresés:">
+<!ENTITY search.accesskey "K">
+<!ENTITY type.label "Típus">
+<!ENTITY address.label "Cím">
+<!ENTITY filter.label "Szűrő">
+<!ENTITY state.label "Állapot">
+<!ENTITY size.label "Méret">
+<!ENTITY docDomain.label "Dokumentum forrás">
+<!ENTITY noitems.label "Nincs blokkolható objektum">
+<!ENTITY whitelisted.label "A cím &apos;fehér listán&apos; van">
+<!ENTITY tooltip.address.label "Cím:">
+<!ENTITY tooltip.type.label "Típus:">
+<!ENTITY tooltip.type.blocked "(blokkolva)">
+<!ENTITY tooltip.type.whitelisted "(fehér listán)">
+<!ENTITY tooltip.size.label "Méret:">
+<!ENTITY tooltip.docDomain.label "Dokumentum forrás:">
+<!ENTITY tooltip.filter.label "Alkalmazott szűrők:">
+<!ENTITY tooltip.filterSource.label "Szűrő forrása:">
+<!ENTITY context.block.label "Objektum blokkolása">
+<!ENTITY context.editfilter.label "Alkalmazott szűrő szerkesztése">
+<!ENTITY context.whitelist.label "Kivétel megadása objektumhoz">
+<!ENTITY context.disablefilter.label "Szűrő letiltása ?1?">
+<!ENTITY context.enablefilter.label "Szűrő engedélyezése ?1?">
+<!ENTITY context.disablefilteronsite.label "Szűrő letiltása itt: ?1?">
+<!ENTITY context.open.label "Megnyitás új fülön">
+<!ENTITY context.flash.label "Objektum széleinek villogtatása">
+<!ENTITY context.copy.label "Objektum címének másolása">
+<!ENTITY context.copyFilter.label "Szűrő másolása">
+<!ENTITY context.selectAll.label "Minden kijelölése">

=== added file 'chrome/locale/hu/subscriptionSelection.dtd'
--- chrome/locale/hu/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hu/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Adblock Plus szűrő felvétele">
+<!ENTITY dialog.title.edit "Külső szűrő szerkesztése">
+<!ENTITY description.newInstall "Ahhoz, hogy az Adblock Plus hatékonyabb legyen, adjon hozzá szűrőket. Ezeket a szűrőket más Adblock Plus felhasználók készítettek szabad felhasználás céljából. A régiójának megfelelő szűrők már ki vannak választva.">
+<!ENTITY adblock.warning "Az Adblock Plus észlelte egy korábbi verzió, vagy az Adblock jelenlétét. Az Adblock és az Adblock Plus párhuzamos jelenléte problémákhoz vezethet. Ajánlott az Adblock eltávolítása.">
+<!ENTITY adblock.uninstall "Adblock eltávolítása">
+<!ENTITY filterset.g.warning "Úgy tűnik, hogy a Filterset.G használatban van. Az utóbbi években alig volt fenntartva, így problémák adódhatnak az oldalakkal kapcsolatban. Ajánlott a Filterset.G eltávolítása.">
+<!ENTITY filterset.g.moreinfo "További információk">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Filterset.G eltávolítása">
+<!ENTITY subscriptionSelector.label "Kérem válassza ki a szűrőt a listából:">
+<!ENTITY viewList.label "Szűrők megtekintése">
+<!ENTITY visitHomepage.label "Honlap meglátogatása">
+<!ENTITY addSubscription.label "Szűrő hozzáadása">
+<!ENTITY saveSubscription.label "Szűrő mentése">
+<!ENTITY other.label "Külső szűrő hozzáadása">
+<!ENTITY other.accesskey "K">
+<!ENTITY list.download.failed "Hiba a szűrők betöltésekor.">
+<!ENTITY list.download.retry "Próbálja újra">
+<!ENTITY list.download.website "Weboldal megtekintése">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Kérem erősítse meg a szűrő hozzáadását. Módosíthatja a szűrő címét és helyét a hozzáadás előtt.">
+<!ENTITY edit.description "Ha szükséges, módosíthatja a szűrők címét ill. helyét.">
+<!ENTITY external.description "Ez egy külső szűrő. A szűrő frissítését az a kiterjesztés végzi el, amelyik a szűrőt létrehozta.">
+<!ENTITY title.label "Külső szűrő neve:">
+<!ENTITY title.accesskey "n">
+<!ENTITY location.label "Szűrőlista címe:">
+<!ENTITY location.accesskey "c">
+<!ENTITY autodownload.label "Automatikus frissítés">
+<!ENTITY autodownload.accesskey "A">
+<!ENTITY supplementMessage "Ez a szűrő a &quot;?1?&quot; szűrővel együtt használható csak, amely jelenleg nincs a szűrőkhez hozzáadva.">
+<!ENTITY addMain.label "Szűrő hozzáadása: &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "h">

=== modified file 'chrome/locale/hy-AM/about.dtd'
--- chrome/locale/hy-AM/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hy-AM/about.dtd	2010-05-04 14:45:07 +0000
@@ -9,3 +9,7 @@
 <!ENTITY homepage.url "http://adblockplus.org/en/">
 <!ENTITY author.label "Հեղինակ.">
 <!ENTITY contributors.label "Մասնակիցներ.">
+<!ENTITY developers.label "Նախագծողներ:">
+<!ENTITY designers.label "Գրաֆիկական Դիզայն:">
+<!ENTITY subscriptionAuthors.label "Ֆիլտրերի բաժանորդագրությունների հեղինակներ:">
+<!ENTITY translators.label "Թարգմանիչներ:">

=== modified file 'chrome/locale/hy-AM/composer.dtd'
--- chrome/locale/hy-AM/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hy-AM/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "Ավելացնել ֆիլտր">
 <!ENTITY advanced.label "Ընդլայնված տեսք">
 <!ENTITY basic.label "Պարզ տեսք">
-<!ENTITY disabled.warning.beforeLink "«Adblock Plus»ը անջատված է: Դուք կարող եք ավելացնել ֆիլտրեր, բայց դրանց գործելու համար պետք է ">
-<!ENTITY disabled.warning.link "միացնել «Adblock Plus»ը">
-<!ENTITY disabled.warning.afterLink ":">
-<!ENTITY groupDisabled.warning.beforeLink "Ֆիլտրերի &quot;&#37;S&quot; խումբը, որին այս ֆիլտրը ավելացվում է միացած չէ. Ֆիլտրը միևնույն է կարող է ավելացնել, բայց նրա կիրառման համար պետք է">
-<!ENTITY groupDisabled.warning.link "միացնել ֆիլտրի խումբը">
-<!ENTITY groupDisabled.warning.afterLink ":">
+<!ENTITY disabled.warning "«Adblock Plus»ը անջատված է: Դուք կարող եք ավելացնել ֆիլտրեր, բայց դրանց գործելու համար պետք է [link]միացնել «Adblock Plus»ը[/link]:">
+<!ENTITY groupDisabled.warning "Ֆիլտրերի &quot;?1?&quot; խումբը, որին այս ֆիլտրը ավելացվում է միացած չէ. Ֆիլտրը միևնույն է կարող է ավելացնել, բայց նրա կիրառման համար պետք է [link]միացնել ֆիլտրի խումբը[/link]:">
 <!ENTITY filter.label "Նոր Ֆիլտր.">
 <!ENTITY filter.accesskey "ֆ">
 <!ENTITY preferences.label "Նայել առկա ֆիլտրերը...">
@@ -24,10 +20,8 @@
 <!ENTITY custom.pattern.accesskey "փ">
 <!ENTITY anchors.label "Շաբլոններն ընդունել միայն.">
 <!ENTITY anchor.start.label "հասցեի սկզբում">
-<!--  Note: This access key should usually be the same as anchor.start.flexible.accesskey. It is the same checkbox with different label depending on suggested filter. -->
 <!ENTITY anchor.start.accesskey "ս">
 <!ENTITY anchor.start.flexible.label "դոմեյնի անվան սկզբում">
-<!--  Note: This access key should usually be the same as anchor.start.accesskey. It is the same checkbox with different label depending on suggested filter. -->
 <!ENTITY anchor.start.flexible.accesskey "ս">
 <!ENTITY anchor.end.label "հասցեի վերջում">
 <!ENTITY anchor.end.accesskey "վ">

=== modified file 'chrome/locale/hy-AM/global.properties'
--- chrome/locale/hy-AM/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/hy-AM/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,13 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Գովազդները երեկ էին!
-status_active_label=Adblock
-status_disabled_label=Անջատված է
+default_dialog_title=Adblock Plus
 action0_tooltip=Սեղմեք մենյուի համար, կետնտրոնական կոճակով` անջատել/միացնել
 action1_tooltip=Կլիկով` բացել/փակել ֆիլտրվվող տարրերը; կետնտրոնական կոճակով` անջատել/միացնել
 action2_tooltip=Կլիկով` Նախընտրանքներ; կետնտրոնական կոճակով` անջատել/միացնել
 action3_tooltip=Կլիկով` անջատել/միացնել «Adblock Plus»ը:
-active_tooltip=«Adblock Plus»ը միացված է
 disabled_tooltip=«Adblock Plus»ը անջատված է
+active_tooltip=«Adblock Plus»ը միացված է, օգտագործվում է ?1? ֆիլտրի բաժանորդագրություն եւ ?2? ավելացված ֆիլտր
 whitelisted_tooltip=«Adblock Plus»ը միացված է, բայց արգելված այս էջում
-blocked_count_tooltip=-- հատ ` -- հատից
+blocked_count_tooltip=?1? հատ ` ?2? հատից
+blocked_count_addendum=?1?-ը ?2?-ից
 no_blocking_suggestions=Այս էջում ֆիլտրվվող տարրեր չկան
 whitelisted_page=«Adblock Plus»ը անջատված է այս էջի համար
 whitelist_description=Բացառություններ
@@ -16,7 +15,7 @@
 invalid_description=Սխալ ֆիլտրեր
 elemhide_description=Տարրերի թաքցման կանոնը
 subscription_description=Ֆիլտրերի բաժանորդագրություն`
-subscription_wrong_version=Այս բաժանորդագրության որոշ ֆիլտրերի համար անհրաժեշտ է Adblock Plus -- ճիշտ աշխատելու համար!
+subscription_wrong_version=Այս բաժանորդագրության որոշ ֆիլտրերի համար անհրաժեշտ է Adblock Plus ?1? ճիշտ աշխատելու համար!
 subscription_source=Աղբյուրը`
 subscription_status=Վիճակը`
 subscription_status_autodownload=Ավտոմատ թարմացվել է.
@@ -26,7 +25,7 @@
 subscription_status_lastdownload_inprogress=Բեռնում...
 subscription_status_lastdownload_unknown=ՉԿԱ
 remove_subscription_warning=Իրո՞ք ուզում եք հեռացնել այս բաժանորդագրությունը:
-import_filters_wrong_version=Ուշադրություն. Այս ցուցակի որոշ ֆիլտրերի համար անհրաժեշտ է Adblock Plus -- ճիշտ աշխատելու համար: Դուք պետք է տեղադրեք «Adblock Plus»ի վերջին տարբերակը այս ցուցակը բեռնելուց առաջ:
+import_filters_wrong_version=Ուշադրություն. Այս ցուցակի որոշ ֆիլտրերի համար անհրաժեշտ է Adblock Plus ?1? ճիշտ աշխատելու համար: Դուք պետք է տեղադրեք «Adblock Plus»ի վերջին տարբերակը այս ցուցակը բեռնելուց առաջ:
 import_filters_warning=Ցանկանում եք փոխարինե՞լ եղած ֆիլտրերը, թե՞ ավելացնել սրանք ցուցակի վերջում:
 import_filters_title=Ներմուծել ֆիլտրեր
 export_filters_title=Արտածել ֆիլտրերը
@@ -38,9 +37,9 @@
 filter_regexp_tooltip=Ներմուծված շաբլոնը կամ ռեգուլյար արտահայտություն , կամ շատ կարճ է ու չի կարող օպտիմիզացվել, այսպիսի շաբլոնների մեծ քանակը կարող է դանդաղեցնել ծրագրի աշխատանքը:
 filter_elemhide_duplicate_id=Տարրը թաքցնելու համար կարելի է տալ միայն մեկ  ID
 filter_elemhide_nocriteria=Տարրը թաքցնելու ոչ մի չափանիշ տրված չէ
-subscription_no_location=Մուտքագրեք ֆիլտրերի բեռնման հասցե:
+subscription_notAdded_warning=Ֆիլտրի բաժանորդագրում չավելացվեց: Առանց դրանց անհրաժեշտ կլինի ավելացնել ֆիլտրերը ինքնուրույն:
+subscription_notAdded_warning_addendum=Շարունակել?
 subscription_invalid_location=Ֆիլտրերի ցանկի հասցեն կամ սխալ URL է, կամ սխալ ֆայլի անուն:
-subscription_location_exists=Դուք արդեն բաժանորդագրված եք այս ցանկին:
 synchronize_invalid_url=Անհաջող. Սխալ հասցե
 synchronize_connection_error=Անհաջող. Բեռնման սխալ
 synchronize_invalid_data=Անհաջող.  Սխալ ֆիլտրերի ցուցակ
@@ -63,5 +62,9 @@
 type_label_xmlhttprequest=XML կանչ
 type_label_object_subrequest=օբյեկտի կանչ
 type_label_dtd=DTD
-type_label_media=audio/video
-type_label_font=font
+type_label_media=աուդիո/վիդեո
+type_label_font=ֆոնտ
+fennec_status_enabled=Adblock Plus»ը միացված է
+fennec_status_disabled=«Adblock Plus»ը անջատված է
+fennec_status_enabled_site=«Adblock Plus»ը միացված է, բայց արգելված է ?1?-ում
+fennec_status_disabled_site=«Adblock Plus»ը անջատված է ?1?-ում

=== added file 'chrome/locale/hy-AM/meta.properties'
--- chrome/locale/hy-AM/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/hy-AM/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Էդուարդ Բաբայան (edo248)
+name=Adblock Plus
+description=Գովազդները երեկ էին!
+description.short=Հոգնե՞լ եք գովազդներից: Անհանգստացնո՞ւմ է, որ ձեր կլիկերին հետևում են: Զզվցնո՞ւմ են բաններները: Տեղադրեք Adblock Plus-ը, ղեկավարեք ինտերնետի օգտագործումը և փոխեք կայքերի տեսքը.\n\nԿարճ վիդեոնկարագիրը` http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus-ը հնարավորություն է տալիս ղեկավարել ձեր իտերնետից օգտվելը և տեսնել այն ցնացը որը ԴՈՒՔ ուզում եք. Այս add-on-ը աջակցվում է քառասունից ավել ֆիլտրերի բաժանարդոգրություններովs բազմաթիվ լեզուներով, որոնք թույլ են տալիս արգելել գովազդների բեռնումն ու ցուցադրումը, ինչպես նաև պաշտպանում են բազմաթիվ հայտնի վնասակար կայքերից: Adblock Plus-ը նաև թույլ է տալիս խմբագրել ֆիլտրերը հարմար հնարավորություններով, ավտոմատ առաջարկելով մենյու ֆիլտրելու համար նկար, Flash կամ Java, նաև տրամադրելով ամնե էջի բոլոր ֆիլտրվվող տարրերի ցուցակ:

=== modified file 'chrome/locale/hy-AM/overlay.dtd'
--- chrome/locale/hy-AM/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hy-AM/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -8,17 +8,16 @@
 <!ENTITY context.image.label "Adblock` Ֆիլտրել Նկարը">
 <!ENTITY context.object.label "Adblock` Ֆիլտրել Օբյեկտը">
 <!ENTITY context.frame.label "Adblock` Ֆիլտրել Ֆրեյմը">
+<!ENTITY context.media.label "Adblock` Ֆիլտրել Աուդիո/Վիդեո">
 <!ENTITY context.removeWhitelist.label "Adblock Plus: Վերակտիվացնել այս էջում">
 <!ENTITY sidebar.title "Այս էջի ֆիլտրվող տարրերը">
 <!ENTITY settings.label "Նախընտրանքներ">
 <!ENTITY settings.accesskey "Ն">
 <!ENTITY opensidebar.label "Բացել ֆիլտրվող տարրերը">
-<!--  Note: This access key should usually be the same as closesidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open. -->
 <!ENTITY opensidebar.accesskey "տ">
 <!ENTITY closesidebar.label "Փակել ֆիլտրվող տարրերը">
-<!--  Note: This access key should usually be the same as opensidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open. -->
 <!ENTITY closesidebar.accesskey "տ">
-<!ENTITY whitelist.site.label "Անջատել այս կայքում">
+<!ENTITY whitelist.site.label "Անջատել ?1?-ում">
 <!ENTITY whitelist.page.label "Անջատել միայն այս էջի համար">
 <!ENTITY objecttab.title "Ֆիլտրել">
 <!ENTITY objecttab.tooltip "Սեղմել «Adblock Plus»ով այս օբյեկտը ֆիլտրելու համար">

=== modified file 'chrome/locale/hy-AM/settings.dtd'
--- chrome/locale/hy-AM/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hy-AM/settings.dtd	2010-05-04 14:45:07 +0000
@@ -91,3 +91,4 @@
 <!ENTITY context.disable.label "Անջատել">
 <!ENTITY apply.label "Ընդունել">
 <!ENTITY apply.accesskey "դ">
+<!ENTITY fennec.subscription.label "Բաժանորդագրվել ֆիլտրերի">

=== modified file 'chrome/locale/hy-AM/sidebar.dtd'
--- chrome/locale/hy-AM/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hy-AM/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "Ֆիլտրել այս տարրը">
 <!ENTITY context.editfilter.label "Խմբագրել Ազդող ֆիլտրը">
 <!ENTITY context.whitelist.label "Այս տարրի համար Բացառություն ավելացնել">
-<!ENTITY context.disablefilter.label "Անջատել ֆիլտրը --">
-<!ENTITY context.enablefilter.label "Վերակտիվացնել ֆիլտրը --">
-<!ENTITY context.disablefilteronsite.label "Արգելել այս ֆիլտրը -- -ում">
+<!ENTITY context.disablefilter.label "Անջատել ֆիլտրը ?1?">
+<!ENTITY context.enablefilter.label "Վերակտիվացնել ֆիլտրը ?1?">
+<!ENTITY context.disablefilteronsite.label "Արգելել այս ֆիլտրը ?1? -ում">
 <!ENTITY context.open.label "Բացել նոր Թաբում">
 <!ENTITY context.flash.label "Ցույց տալ օբյեկտը էջում">
 <!ENTITY context.copy.label "Կրկնել տարրի հասցեն">

=== removed file 'chrome/locale/hy-AM/subscription.dtd'
--- chrome/locale/hy-AM/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hy-AM/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,24 +0,0 @@
-<!ENTITY dialog.title "Խմբագրել բաժանորդագրությունները">
-<!ENTITY dialog.newtitle "Նոր բաժանորդագրություն">
-<!ENTITY new.description "
-	Մուտքագրեք վեբ էջի կամ ֆայլի հասցե, որտեղ գտնվում են ֆիլտրերը:
-">
-<!ENTITY edit.description "
-	Այս բաժանորդագրության ֆիլտրերի ցուցակը բեռնվելու է տրված հասցեից:
-">
-<!ENTITY external.description "
-	Սա ֆիլտրերի արտաքին բաժանորդագրություն է, այս ֆիլտրերը
-	թարմ են պահվելու դրանց ստեղծող ընդլայնման կողմից:
-">
-<!ENTITY autodownload.description "
-	«Ավտոմատ թարմացում» տարբերակը ընտրելու դեպքում, այս բաժանորդագրությունը թարմացվելու է ամեն օր: 
-	Առանց այս տարբերակը ընտրելու դուք կարող եք թարմացնել այն բաժանորդագրությունների ցուցակի մենյուից:
-">
-<!ENTITY location.label "Ֆիլտրերի հասցեն`">
-<!ENTITY location.accesskey "հ">
-<!ENTITY title.label "Բաժանորդագրության ավանումը`">
-<!ENTITY title.accesskey "ա">
-<!ENTITY autodownload.label "Ավտոմատ թարմացում">
-<!ENTITY autodownload.accesskey "թ">
-<!ENTITY enabled.label "Միացնել այս ֆիլտրերը">
-<!ENTITY enabled.accesskey "Մ">

=== added file 'chrome/locale/hy-AM/subscriptionSelection.dtd'
--- chrome/locale/hy-AM/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/hy-AM/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,44 @@
+<!ENTITY dialog.title "Բարի գալուստ Adblock Plus">
+<!ENTITY dialog.title.edit "Խմբագրել բաժանորդագրությունները">
+<!ENTITY description.newInstall "
+	«Adblock Plus»-ը կլինի շատ էֆֆեկտիվ, եթե դուք ավելացնեք ֆիլտրերի բաժանարդոգրություն:
+	Ֆիլտրերի բաժանարդոգրությունները տրամադրվում են «Adblock Plus»-ի օգտագործողների կողմից
+	անվճար: Ձեր լեզվին ամենահամապատասխան բաժանարդոգրությունը արդեն ընտրված է:
+">
+<!ENTITY adblock.warning "
+	«Adblock Plus»-ից բացի ձեր համակարգում տեղադրված է Adblock կամ 
+	«Adblock Plus»-ի հին տարբերակ: Դրանց զուգահեռ օգտագործումը կարող է 
+	խնդիրներ առաջացնել: Խորհուրդ է տրվում հեռացնել Adblock -ը:
+">
+<!ENTITY adblock.uninstall "Հեռացնել Adblock">
+<!ENTITY filterset.g.warning "
+	Դուք օգտագործում եք Filterset.G. Այս ցանկին վերջին տարիներին 
+	քիչ է փոփոխվումում և այն առաջացնում է մեծ քանակով խնդիրներ կայքերի հետ: 
+	Խորհուրդ է տրվում հեռացնել այդ ցանկը:
+">
+<!ENTITY filterset.g.moreinfo "Ավել տեղեկություն">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Հեռացնել Filterset.G-ն">
+<!ENTITY subscriptionSelector.label "Ընտրեք ֆիլտրի բաժանարդոգրություն ցուցակից`">
+<!ENTITY viewList.label "Նայել ֆիլտրերը">
+<!ENTITY visitHomepage.label "Այցելել կայք">
+<!ENTITY addSubscription.label "Ավելացնել բաժանորդագրություն">
+<!ENTITY saveSubscription.label "Պահպանել բաժանորդագրությունը">
+<!ENTITY other.label "Ավելացնել այլ բաժանորդագրություն">
+<!ENTITY other.accesskey "Ա">
+<!ENTITY list.download.failed "«Adblock Plus»-ը չկարողացավ բեռնել ֆիլտրերի բաժանարդոգրությունների ցուցակը">
+<!ENTITY list.download.retry "Կրկին Փորձել">
+<!ENTITY list.download.website "Այցելել կայք">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Հաստատեք որ ցանկանում եք ավելացնել բաժանորդագրություն: Դուք կարող եք փողել բաժանորդագրության վերնագիրը կամ հասցեն միչև ավելացնելը:">
+<!ENTITY edit.description "Դուք կարող եք փողել բաժանորդագրության վերնագիրը կամ հասցեն ըստ անհրաժեշտության">
+<!ENTITY external.description "Սա արտաքին ֆիլտրի բաժանարդոգրություն է. այն թարմացնելու է ավելացումը(add-on) որը ստեղծել է այն:">
+<!ENTITY title.label "Բաժանորդագրության ավանումը`">
+<!ENTITY title.accesskey "ա">
+<!ENTITY location.label "Ֆիլտրերի հասցեն`">
+<!ENTITY location.accesskey "հ">
+<!ENTITY autodownload.label "Ավտոմատ թարմացում">
+<!ENTITY autodownload.accesskey "թ">
+<!ENTITY supplementMessage "Այս ֆիլտրի բաժանարդոգրությունը հաճախ օգտագործվում է &quot;?1?&quot;-ի հետ, որը դուք չեք օգտագործում:">
+<!ENTITY addMain.label "Ավելացնել բաժանորդագրություն նաև &quot;?1?&quot; ֆիլտրին">
+<!ENTITY addMain.accesskey "ն">

=== removed file 'chrome/locale/hy-AM/tip_subscriptions.dtd'
--- chrome/locale/hy-AM/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/hy-AM/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,37 +0,0 @@
-<!ENTITY dialog.title "Բարի գալուստ Adblock Plus">
-<!ENTITY description.par1 "
-	Շնորհակալություն «Adblock Plus» տեղադրելու համար: Այն կօգնի Ձեզ
-	վերացնելու էջերում գովազդի 99&#37;ը: Սակայն,
-	գովազդի արդյունավետ ֆիլտրման համար Դուք պետք է ճիշտ ֆիլտրեր սահմանեք: Կարող եք դա անել ինքնուրույն, կամ պարզապես բաժանորդագրվել
-	ֆիլտրերի, որոնք մենք ստեղծել ենք Ձեզ համար: Ամեն դեպքում, Դուք միշտ կարող եք
-	ավելացնել սեփական ֆիլտրեր, ավելացնել նոր բաժանորդագրություններ, կամ հեռացնել եղածները:
-">
-<!ENTITY description.par2 "
-	Խորհուրդ ենք տալիս ընտրել բաժանորդագրություն հետևյալ ցուցակից 
-	(այլ բաժանորդագրություններ կարող եք ավելացնել հետո` նախընտրանքներում, 
-	չնայած դրա անհրաժեշտությունը չի լինի):
-">
-<!ENTITY note "
-	Հուշում: Ֆիլտրերը սովորաբար ավելի արդյունավետ են այն տարածաշրջանի կայքերում, որոնց համար ստեղծված են:
-">
-<!ENTITY adblock.warning "
-	«Adblock Plus»-ից բացի ձեր համակարգում տեղադրված է Adblock կամ 
-	«Adblock Plus»-ի հին տարբերակ: Դրանց զուգահեռ օգտագործումը կարող է 
-	խնդիրներ առաջացնել: Խորհուրդ է տրվում հեռացնել Adblock -ը:
-">
-<!ENTITY adblock.uninstall "Հեռացնել Adblock">
-<!ENTITY filterset.g.warning "
-	Դուք օգտագործում եք Filterset.G. Այս ցանկին վերջին տարիներին 
-	քիչ է փոփոխվումում և այն առաջացնում է մեծ քանակով խնդիրներ կայքերի հետ: 
-	Խորհուրդ է տրվում հեռացնել այդ ցանկը:
-">
-<!ENTITY filterset.g.moreinfo "Ավել տեղեկություն">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Հեռացնել Filterset.G-ն">
-<!ENTITY homepage.label "Վեբ էջ">
-<!ENTITY subscribe.label "Բաժանորդագրվել">
-<!ENTITY subscribe.accesskey "Բ">
-<!ENTITY other.label "Ավելացնել բաժանորդագրություն">
-<!ENTITY other.accesskey "Ա">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Նայել բոլոր Բաժանորդագրությունները">

=== added directory 'chrome/locale/id'
=== removed directory 'chrome/locale/id-ID'
=== removed file 'chrome/locale/id-ID/about.dtd'
--- chrome/locale/id-ID/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/id-ID/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-<!ENTITY dialog.title "Tentang Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Versi">
-<!ENTITY description "
-	Adblock Plus membolehkan Anda untuk memilih apa yang tidak harus dilihat pada situs.
-	Anda tidak perlu mendownload semua iklan dan banner, Jika Anda tidak menginginkannya
-	- katakan Adblock Plus!
-">
-<!ENTITY homepage.label "Situs Adblock Plus:">
-<!ENTITY homepage.url "http://adblockplus.org/en/">
-<!ENTITY author.label "Pembuat:">
-<!ENTITY contributors.label "Para Kontributor:">

=== removed file 'chrome/locale/id-ID/composer.dtd'
--- chrome/locale/id-ID/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/id-ID/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,45 +0,0 @@
-<!ENTITY dialog.title "Tambah aturan filter Adblock Plus">
-<!ENTITY accept.label "Tambah filter">
-<!ENTITY advanced.label "View lanjutan">
-<!ENTITY basic.label "View dasar">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus sedang dimatikan. Anda tetap bisa menambahkan filter tapi tidak akan diaplikasikan kecuali Anda">
-<!ENTITY disabled.warning.link "Hidupkan Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY filter.label "Filter baru:">
-<!ENTITY filter.accesskey "F">
-<!ENTITY preferences.label "Tunjukkan filter yang ada...">
-<!ENTITY preferences.accesskey "k">
-<!ENTITY type.filter.label "Pemblokiran Filter">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "Aturan pengecualian">
-<!ENTITY type.whitelist.accesskey "g">
-<!ENTITY pattern.label "Lihat pola">
-<!ENTITY pattern.explanation "Pola bisa diartikan untuk semua bagian dari alamat, simbol * sebagai wildcard. Filter hanya akan diaplikasikan ke alamat yang cocok dengan pola.">
-<!ENTITY regexp.warning "Pola yang Anda masukkan akan diartikan sebagai ekspresi biasa. Banyak ekspresi biasa bisa melambatkan browser Anda. Jika Anda tidak bermmaksud untuk memakai ekspresi biasa, tambahkan tanda * pada akhir pola.">
-<!ENTITY shortpattern.warning "Pola yang anda masukkan terlalu kecil untuk dioptimalkan, terlalu banyak pola bisa melambatkan browser Anda. Disarankan anda memilih string yang lebih panjang untuk filter ini.">
-<!ENTITY custom.pattern.label "Aturan Sendiri:">
-<!ENTITY custom.pattern.accesskey "t">
-<!ENTITY anchors.label "Pola yang disetujui saja:">
-<!ENTITY anchor.start.label "pada awal alamat">
-<!ENTITY anchor.start.accesskey "w">
-<!ENTITY anchor.end.label "pada akhir alamat">
-<!ENTITY anchor.end.accesskey "D">
-<!ENTITY options.label "Opsi">
-<!ENTITY domainRestriction.label "Terlarang ke domain:">
-<!ENTITY domainRestriction.accesskey "e">
-<!ENTITY domainRestriction.help "Spesifikasikan satu atau lebih domain yang dipisahkan oleh simbol &quot;|&quot;, kemudian filter hanya akan dipakai padadomain tersebut. Simbol &quot;~&quot; sebelum nama domain berarti filter tidak seharusnya dipakai pada domain itu.">
-<!ENTITY firstParty.label "Pihak pertama saja">
-<!ENTITY firstParty.accesskey "R">
-<!ENTITY thirdParty.label "Pihak ketiga saja">
-<!ENTITY thirdParty.accesskey "j">
-<!ENTITY matchCase.label "Case tepat">
-<!ENTITY matchCase.accesskey "p">
-<!ENTITY types.label "Dipakai untuk tipe:">
-<!ENTITY selectAllTypes.label "Pilih semua">
-<!ENTITY unselectAllTypes.label "Jangan pilih apapun">
-<!ENTITY collapse.label "Gabungkan yang diblok:">
-<!ENTITY collapse.accesskey "L">
-<!ENTITY collapse.default.yes.label "Gunakan biasa (ya)">
-<!ENTITY collapse.default.no.label "Gunakan biasa (tidak)">
-<!ENTITY collapse.yes.label "Ya">
-<!ENTITY collapse.no.label "Tidak">

=== removed file 'chrome/locale/id-ID/global.properties'
--- chrome/locale/id-ID/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/id-ID/global.properties	1970-01-01 00:00:00 +0000
@@ -1,66 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Iklan telah berlalu!
-status_active_label=Adblock
-status_disabled_label=Matikan
-action0_tooltip=Klik untuk mengambil Menu Konteks, Klik Tengah untuk Hidupkan/Matikan.
-action1_tooltip=Klik untuk membuka/menutup item yang diblok, Klik Tengah untuk Hidupkan/Matikan.
-action2_tooltip=Klik untuk membuka preferensi, Klik Tengah untuk Hidupkan/Matikan.
-action3_tooltip=Klik untuk hidupkan/matikan Adblock Plus.
-active_tooltip=Adblock Plus telah aktif.
-disabled_tooltip=Adblock Plus telah dimatikan.
-whitelisted_tooltip=Adblock Plus telah aktif, tapi dimatikan pada beberapa halaman.
-blocked_count_tooltip=-- diblok --
-no_blocking_suggestions=Tidak ada item yang diblok pada halaman ini
-whitelisted_page=Adblock Plus telah dimatikan untuk halaman ini
-whitelist_description=Aturan Pengecualian
-filterlist_description=Aturan Iklan yang Diblok
-invalid_description=Aturan untuk Tak Valid
-elemhide_description=Aturan Penyembunyian Elemen
-subscription_description=Skrip filter:
-subscription_wrong_version=Beberapa filter pada skrip membutuhkan Adblock Plus -- untuk bekerja normal!
-subscription_source=Sumber:
-subscription_status=Status:
-subscription_status_autodownload=Diupdate secara otomatis
-subscription_status_manualdownload=Diupdate secara manual
-subscription_status_externaldownload=Diupdate secara eksternal (ekstensi lainnya)
-subscription_status_lastdownload=Download terakhir:
-subscription_status_lastdownload_inprogress=Mendownload...
-subscription_status_lastdownload_unknown=Tidak Ada
-remove_subscription_warning=Apakah Anda ingin membuang skrip ini?
-import_filters_wrong_version=Peringatan: beberapa filter di daftar ini membutuhkan Adblock Plus -- untuk bekerja normal. Anda mungkin seharusnya mengupgrade ke Adblock Plus terbaru sebelum mengimpor list ini.
-import_filters_warning=Anda ingin mengganti filter Anda atau menambahkan filter baru di akhir daftar?
-import_filters_title=Impor filter
-export_filters_title=Ekspor filter
-invalid_filters_file=Bukan file filter Adblock Plus yang valid.
-filters_write_error=Ada error dalam menulis filter ke file. Pastikan file tidak terproteksi atau dipakai oleh program lain.
-clearall_warning=Anda benar-benar ingin untuk membuang semua filter dari daftar?
-resethitcounts_warning=Anda benar-benar ingin untuk menyetel ulang semua filter ke nol? Operasi ini tidak bisa selesai!
-resethitcounts_selected_warning=Anda benar-benar ingin untuk menyetel ulang filter terpilih ke nol? Operasi ini tidak bisa selesai!
-filter_regexp_tooltip=Filter ini berekspresi biasa atau terlalu pendek untuk dioptimalkan. Terlalu banyak filter bisa melambatkan browser Anda.
-filter_elemhide_duplicate_id=Hanya satu identitas elemen yang ingin disembunyikan yang bisa dispesifikasi
-filter_elemhide_nocriteria=Kriteria tidak spesifik untuk mengenali elemen yang ingin disembunyikan
-subscription_no_location=Tolong masukkan lokasi untuk mendownload form filter.
-subscription_invalid_location=Lokasi daftar filter bukan URL valid ataupun nama file valid.
-subscription_location_exists=Anda sudah memasukkannya ke daftar filter.
-synchronize_invalid_url=Gagal, bukan alamat valid
-synchronize_connection_error=Download gagal
-synchronize_invalid_data=Gagal, bukan daftar filter yang valid
-synchronize_checksum_mismatch=Gagal, checksum tidak cocok
-synchronize_ok=Sukses
-overwrite=Meniban
-append=Menambahkan
-new_filter_group_title=Filter baru
-type_label_other=lainnya
-type_label_script=skrip
-type_label_image=gambar
-type_label_stylesheet=format stylesheet
-type_label_object=obyek
-type_label_subdocument=subdokumen
-type_label_document=dokumen
-type_label_background=latar belakang
-type_label_elemhide=tersembunyi
-type_label_xbl=format XBL
-type_label_ping=alamat ping
-type_label_xmlhttprequest=permintaan XML
-type_label_object_subrequest=obyek subpermintaan
-type_label_dtd=DTD
-type_label_media=audio atau video

=== removed file 'chrome/locale/id-ID/overlay.dtd'
--- chrome/locale/id-ID/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/id-ID/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY status.tooltip "Status:">
-<!ENTITY blocked.tooltip "Item yang diblok pada halaman ini:">
-<!ENTITY filters.tooltip "Filter yang paling aktif:">
-<!ENTITY menuitem.label "Preferensi Adblock Plus">
-<!ENTITY menuitem.accesskey "r">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Item yang Diblok">
-<!ENTITY context.image.label "Gambar Adblock">
-<!ENTITY context.object.label "Obyek Adblock">
-<!ENTITY context.frame.label "Bingkai Adblock">
-<!ENTITY sidebar.title "Item yang bisa diblok pada halaman ini">
-<!ENTITY settings.label "Preferensi">
-<!ENTITY settings.accesskey "F">
-<!ENTITY opensidebar.label "Buka item yang bisa diblok">
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "Tutup item yang bisa diblok">
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Matikan pada --">
-<!ENTITY whitelist.page.label "Matikan pada halaman ini saja">
-<!ENTITY objecttab.title "Blok">
-<!ENTITY objecttab.tooltip "Klik ini untuk memblok obyek ini dengan Adblock Plus">

=== removed file 'chrome/locale/id-ID/settings.dtd'
--- chrome/locale/id-ID/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/id-ID/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,87 +0,0 @@
-<!ENTITY dialog.title "Preferensi Adblock Plus">
-<!ENTITY filters.label "Filter">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Tambahkan filter">
-<!ENTITY add.accesskey "A">
-<!ENTITY addsubscription.label "Tambahkan skrip filter">
-<!ENTITY addsubscription.accesskey "S">
-<!ENTITY synchsubscriptions.label "Update semua skrip">
-<!ENTITY synchsubscriptions.accesskey "D">
-<!ENTITY import.label "Impor filter">
-<!ENTITY import.accesskey "M">
-<!ENTITY export.label "Ekspor filter buatan sendiri">
-<!ENTITY export.accesskey "E">
-<!ENTITY clearall.label "Buang semua filter buatan sendiri">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "Setel ulang statistik">
-<!ENTITY resethitcounts.accesskey "T">
-<!ENTITY edit.label "Ubah">
-<!ENTITY edit.accesskey "U">
-<!ENTITY cut.label "Potong">
-<!ENTITY cut.accesskey "T">
-<!ENTITY copy.label "Salin">
-<!ENTITY copy.accesskey "S">
-<!ENTITY paste.label "Tempel">
-<!ENTITY paste.accesskey "P">
-<!ENTITY remove.label "Hapus">
-<!ENTITY remove.accesskey "h">
-<!ENTITY menu.find.label "Cari">
-<!ENTITY menu.find.accesskey "C">
-<!ENTITY menu.findagain.label "Cari Lagi">
-<!ENTITY menu.findagain.accesskey "G">
-<!ENTITY view.label "Lihat">
-<!ENTITY view.accesskey "L">
-<!ENTITY sort.label "Urutkan dari">
-<!ENTITY sort.accesskey "i">
-<!ENTITY sort.none.label "Acak">
-<!ENTITY sort.none.accesskey "K">
-<!ENTITY sort.ascending.label "Urut dari A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Urut dari Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Opsi">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Hidupkan Adblock Plus">
-<!ENTITY enable.accesskey "N">
-<!ENTITY showintoolbar.label "Tunjukkan di toolbar">
-<!ENTITY showintoolbar.accesskey "B">
-<!ENTITY showinstatusbar.label "Tunjukkan di status bar">
-<!ENTITY showinstatusbar.accesskey "S">
-<!ENTITY objecttabs.label "Tunjukkan tab pada Flash dan Java">
-<!ENTITY objecttabs.accesskey "T">
-<!ENTITY collapse.label "Gabungkan elemen yang diblok">
-<!ENTITY collapse.accesskey "L">
-<!ENTITY help.label "Bantuan">
-<!ENTITY help.accesskey "b">
-<!ENTITY gettingStarted.label "Memulai">
-<!ENTITY gettingStarted.accesskey "a">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Pertanyaan yang Sering Ditanya">
-<!ENTITY faq.accesskey "y">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Menulis filter Adblock Plus">
-<!ENTITY filterdoc.accesskey "R">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Tentang Adblock Plus">
-<!ENTITY about.accesskey "B">
-<!ENTITY description "Filter ini menunjukkan alamat mana yang harus diblok dan mana yang dibolehkan:">
-<!ENTITY filter.column "Aturan filter">
-<!ENTITY filter.accesskey "F">
-<!ENTITY enabled.column "Hidupkan">
-<!ENTITY enabled.accesskey "N">
-<!ENTITY hitcount.column "Sasaran">
-<!ENTITY hitcount.accesskey "H">
-<!ENTITY lasthit.column "Sasaran terakhir">
-<!ENTITY lasthit.accesskey "L">
-<!ENTITY context.edit.label "Ubah filter">
-<!ENTITY context.resethitcount.label "Setel ulang statistik sasaran untuk filter">
-<!ENTITY context.synchsubscription.label "Update skrip sekarang">
-<!ENTITY context.editsubscription.label "Edit skrip">
-<!ENTITY context.moveup.label "Pindahkan filter ke atas">
-<!ENTITY context.movedown.label "Pindahkan filter ke bawah">
-<!ENTITY context.movegroupup.label "Pindahkan grup ke atas">
-<!ENTITY context.movegroupdown.label "Pindahkan grup ke bawah">
-<!ENTITY context.enable.label "Hidupkan">
-<!ENTITY context.disable.label "Matikan">
-<!ENTITY apply.label "Pakai">
-<!ENTITY apply.accesskey "P">

=== removed file 'chrome/locale/id-ID/sidebar.dtd'
--- chrome/locale/id-ID/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/id-ID/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,30 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Item yang bisa diblok (dilepaskan)">
-<!ENTITY detach.label "Lepas">
-<!ENTITY reattach.label "Sertakan kembali">
-<!ENTITY search.label "Cari:">
-<!ENTITY search.accesskey "C">
-<!ENTITY type.label "Tipe">
-<!ENTITY address.label "Alamat">
-<!ENTITY filter.label "Filter">
-<!ENTITY state.label "Bagian">
-<!ENTITY size.label "Ukuran">
-<!ENTITY noitems.label "Tidak ada item yang bisa diblok">
-<!ENTITY whitelisted.label "Halaman yang dibebaskan">
-<!ENTITY tooltip.address.label "Alamat:">
-<!ENTITY tooltip.type.label "Tipe:">
-<!ENTITY tooltip.type.blocked "(diblok)">
-<!ENTITY tooltip.type.whitelisted "(dibebaskan)">
-<!ENTITY tooltip.size.label "Ukuran:">
-<!ENTITY tooltip.filter.label "Filter efek:">
-<!ENTITY tooltip.filterSource.label "Sumber filter:">
-<!ENTITY context.block.label "Blok item ini">
-<!ENTITY context.editfilter.label "Edit filter efek">
-<!ENTITY context.whitelist.label "Tambahkan Aturan pengecualian untuk item">
-<!ENTITY context.disablefilter.label "Matikan filter --">
-<!ENTITY context.enablefilter.label "Hidupkan ulang filter --">
-<!ENTITY context.disablefilteronsite.label "Matikan filter ini pada --">
-<!ENTITY context.open.label "Buka di tab baru">
-<!ENTITY context.flash.label "Border item yang ber-flash">
-<!ENTITY context.copy.label "Salin alamat item">
-<!ENTITY context.copyFilter.label "Salin filter">
-<!ENTITY context.selectAll.label "Pilih semua">

=== removed file 'chrome/locale/id-ID/subscription.dtd'
--- chrome/locale/id-ID/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/id-ID/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-<!ENTITY dialog.title "Edit skrip filter">
-<!ENTITY dialog.newtitle "Tambahkan skrip filter">
-<!ENTITY new.description "Tolong masukkan alamat web atau file berisi daftar
-	filter Adblock Plus.">
-<!ENTITY edit.description "Daftar filter untuk skrip ini akan didownload
-	dari lokasi yang telah diberikan.">
-<!ENTITY external.description "Ini adalah skrip filter eksternal, daftar filternya
-	akan tetap up-to-date dari ekstensi yang membuat skrip.">
-<!ENTITY autodownload.description "Jika anda memilih &apos;Update otomatis&apos; lokasi ini akan
-	ditandai untuk update setiap hari. Dengan mematikan opsi ini anda tetap
-	bisa memilih update secara manual dari menu konteks skrip.">
-<!ENTITY location.label "Lokasi daftar filter:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Judul Skrip:">
-<!ENTITY title.accesskey "J">
-<!ENTITY autodownload.label "Update otomatis">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.label "Hidupkan filter">
-<!ENTITY enabled.accesskey "N">

=== removed file 'chrome/locale/id-ID/tip_subscriptions.dtd'
--- chrome/locale/id-ID/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/id-ID/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,30 +0,0 @@
-<!ENTITY dialog.title "Tambahkan skrip filter Adblock Plus">
-<!ENTITY description.par1 "Terima kasih telah menginstall Adblock Plus. Ekstensi ini bisa
-	menghilangkan 99&#37; iklan yang Anda lihat di web. Walau begitu,
-	efektifitas menyaring iklan membutuhkan Anda untuk mendefinisikan aturan
-	filter yang baik. Anda bisa melakukannya sendiri, atau Anda bisa memasukkan
-	secara sederhana ke daftar filter yang lainnya dipelihara oleh Anda. Sangat mungkin
-	untuk memasukkan filter sendiri atau deaktif/buang skrip
-	jika diperlukan.">
-<!ENTITY description.par2 "Anda bisa memilih skrip dari daftar skrip yang direkomendasikan
-	di bawah ini (skrip lainnya bisa ditambahkan pada Preferensi Adblock Plus
-	selanjutnya biasanya tidak diperlukan):">
-<!ENTITY note "Catatan: Daftar filter biasanya paling efektif ketika dipakai
-	ke situs yang dituju.">
-<!ENTITY adblock.warning "Adblock Plus telah mendeteksi bahwa Adblock atau versi lama Adblock Plus terinstall.
-	Menjalankan kedua Adblock dan Adblock Plus terpisah bisa menyebabkan
-	masalah dan harus dicegah. Disarankan untuk menghapus Adblock sekarang.">
-<!ENTITY adblock.uninstall "Hapus Adblock">
-<!ENTITY filterset.g.warning "Sepertinya Anda menggunakan Filterset.G. Daftar filter nyata telah dipelihara
-	dalam beberapa tahun terakhir dan merupakan penyebab masalah pada situs.
-	Disarankan Anda untuk menghapus Filterset.G sekarang.">
-<!ENTITY filterset.g.moreinfo "Informasi lebih lanjut">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Hapus Filterset.G">
-<!ENTITY homepage.label "Situs">
-<!ENTITY subscribe.label "Sumbang">
-<!ENTITY subscribe.accesskey "S">
-<!ENTITY other.label "Tambahkan skrip yang berbeda">
-<!ENTITY other.accesskey "y">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Lihat semua skrip">

=== added file 'chrome/locale/id/about.dtd'
--- chrome/locale/id/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/id/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Tentang Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versi">
+<!ENTITY description "
+	Adblock Plus membolehkan Anda untuk memilih apa yang tidak harus dilihat pada situs.
+	Anda tidak perlu mendownload semua iklan dan banner, Jika Anda tidak menginginkannya
+	- katakan Adblock Plus!
+">
+<!ENTITY homepage.label "Situs Adblock Plus:">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "Pembuat:">
+<!ENTITY contributors.label "Para Kontributor:">

=== added file 'chrome/locale/id/composer.dtd'
--- chrome/locale/id/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/id/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,43 @@
+<!ENTITY dialog.title "Tambah aturan filter Adblock Plus">
+<!ENTITY accept.label "Tambah filter">
+<!ENTITY advanced.label "View lanjutan">
+<!ENTITY basic.label "View dasar">
+<!ENTITY disabled.warning "Adblock Plus sedang dimatikan. Anda tetap bisa menambahkan filter tapi tidak akan diaplikasikan kecuali Anda [link]Hidupkan Adblock Plus[/link].">
+<!ENTITY filter.label "Filter baru:">
+<!ENTITY filter.accesskey "F">
+<!ENTITY preferences.label "Tunjukkan filter yang ada...">
+<!ENTITY preferences.accesskey "k">
+<!ENTITY type.filter.label "Pemblokiran Filter">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Aturan pengecualian">
+<!ENTITY type.whitelist.accesskey "g">
+<!ENTITY pattern.label "Lihat pola">
+<!ENTITY pattern.explanation "Pola bisa diartikan untuk semua bagian dari alamat, simbol * sebagai wildcard. Filter hanya akan diaplikasikan ke alamat yang cocok dengan pola.">
+<!ENTITY regexp.warning "Pola yang Anda masukkan akan diartikan sebagai ekspresi biasa. Banyak ekspresi biasa bisa melambatkan browser Anda. Jika Anda tidak bermmaksud untuk memakai ekspresi biasa, tambahkan tanda * pada akhir pola.">
+<!ENTITY shortpattern.warning "Pola yang anda masukkan terlalu kecil untuk dioptimalkan, terlalu banyak pola bisa melambatkan browser Anda. Disarankan anda memilih string yang lebih panjang untuk filter ini.">
+<!ENTITY custom.pattern.label "Aturan Sendiri:">
+<!ENTITY custom.pattern.accesskey "t">
+<!ENTITY anchors.label "Pola yang disetujui saja:">
+<!ENTITY anchor.start.label "pada awal alamat">
+<!ENTITY anchor.start.accesskey "w">
+<!ENTITY anchor.end.label "pada akhir alamat">
+<!ENTITY anchor.end.accesskey "D">
+<!ENTITY options.label "Opsi">
+<!ENTITY domainRestriction.label "Terlarang ke domain:">
+<!ENTITY domainRestriction.accesskey "e">
+<!ENTITY domainRestriction.help "Spesifikasikan satu atau lebih domain yang dipisahkan oleh simbol &quot;|&quot;, kemudian filter hanya akan dipakai padadomain tersebut. Simbol &quot;~&quot; sebelum nama domain berarti filter tidak seharusnya dipakai pada domain itu.">
+<!ENTITY firstParty.label "Pihak pertama saja">
+<!ENTITY firstParty.accesskey "R">
+<!ENTITY thirdParty.label "Pihak ketiga saja">
+<!ENTITY thirdParty.accesskey "j">
+<!ENTITY matchCase.label "Case tepat">
+<!ENTITY matchCase.accesskey "p">
+<!ENTITY types.label "Dipakai untuk tipe:">
+<!ENTITY selectAllTypes.label "Pilih semua">
+<!ENTITY unselectAllTypes.label "Jangan pilih apapun">
+<!ENTITY collapse.label "Gabungkan yang diblok:">
+<!ENTITY collapse.accesskey "L">
+<!ENTITY collapse.default.yes.label "Gunakan biasa (ya)">
+<!ENTITY collapse.default.no.label "Gunakan biasa (tidak)">
+<!ENTITY collapse.yes.label "Ya">
+<!ENTITY collapse.no.label "Tidak">

=== added file 'chrome/locale/id/global.properties'
--- chrome/locale/id/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/id/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,60 @@
+action0_tooltip=Klik untuk mengambil Menu Konteks, Klik Tengah untuk Hidupkan/Matikan.
+action1_tooltip=Klik untuk membuka/menutup item yang diblok, Klik Tengah untuk Hidupkan/Matikan.
+action2_tooltip=Klik untuk membuka preferensi, Klik Tengah untuk Hidupkan/Matikan.
+action3_tooltip=Klik untuk hidupkan/matikan Adblock Plus.
+disabled_tooltip=Adblock Plus telah dimatikan.
+whitelisted_tooltip=Adblock Plus telah aktif, tapi dimatikan pada beberapa halaman.
+blocked_count_tooltip=?1? diblok ?2?
+no_blocking_suggestions=Tidak ada item yang diblok pada halaman ini
+whitelisted_page=Adblock Plus telah dimatikan untuk halaman ini
+whitelist_description=Aturan Pengecualian
+filterlist_description=Aturan Iklan yang Diblok
+invalid_description=Aturan untuk Tak Valid
+elemhide_description=Aturan Penyembunyian Elemen
+subscription_description=Skrip filter:
+subscription_wrong_version=Beberapa filter pada skrip membutuhkan Adblock Plus ?1? untuk bekerja normal!
+subscription_source=Sumber:
+subscription_status=Status:
+subscription_status_autodownload=Diupdate secara otomatis
+subscription_status_manualdownload=Diupdate secara manual
+subscription_status_externaldownload=Diupdate secara eksternal (ekstensi lainnya)
+subscription_status_lastdownload=Download terakhir:
+subscription_status_lastdownload_inprogress=Mendownload...
+subscription_status_lastdownload_unknown=Tidak Ada
+remove_subscription_warning=Apakah Anda ingin membuang skrip ini?
+import_filters_wrong_version=Peringatan: beberapa filter di daftar ini membutuhkan Adblock Plus ?1? untuk bekerja normal. Anda mungkin seharusnya mengupgrade ke Adblock Plus terbaru sebelum mengimpor list ini.
+import_filters_warning=Anda ingin mengganti filter Anda atau menambahkan filter baru di akhir daftar?
+import_filters_title=Impor filter
+export_filters_title=Ekspor filter
+invalid_filters_file=Bukan file filter Adblock Plus yang valid.
+filters_write_error=Ada error dalam menulis filter ke file. Pastikan file tidak terproteksi atau dipakai oleh program lain.
+clearall_warning=Anda benar-benar ingin untuk membuang semua filter dari daftar?
+resethitcounts_warning=Anda benar-benar ingin untuk menyetel ulang semua filter ke nol? Operasi ini tidak bisa selesai!
+resethitcounts_selected_warning=Anda benar-benar ingin untuk menyetel ulang filter terpilih ke nol? Operasi ini tidak bisa selesai!
+filter_regexp_tooltip=Filter ini berekspresi biasa atau terlalu pendek untuk dioptimalkan. Terlalu banyak filter bisa melambatkan browser Anda.
+filter_elemhide_duplicate_id=Hanya satu identitas elemen yang ingin disembunyikan yang bisa dispesifikasi
+filter_elemhide_nocriteria=Kriteria tidak spesifik untuk mengenali elemen yang ingin disembunyikan
+subscription_invalid_location=Lokasi daftar filter bukan URL valid ataupun nama file valid.
+synchronize_invalid_url=Gagal, bukan alamat valid
+synchronize_connection_error=Download gagal
+synchronize_invalid_data=Gagal, bukan daftar filter yang valid
+synchronize_checksum_mismatch=Gagal, checksum tidak cocok
+synchronize_ok=Sukses
+overwrite=Meniban
+append=Menambahkan
+new_filter_group_title=Filter baru
+type_label_other=lainnya
+type_label_script=skrip
+type_label_image=gambar
+type_label_stylesheet=format stylesheet
+type_label_object=obyek
+type_label_subdocument=subdokumen
+type_label_document=dokumen
+type_label_background=latar belakang
+type_label_elemhide=tersembunyi
+type_label_xbl=format XBL
+type_label_ping=alamat ping
+type_label_xmlhttprequest=permintaan XML
+type_label_object_subrequest=obyek subpermintaan
+type_label_dtd=DTD
+type_label_media=audio atau video

=== added file 'chrome/locale/id/meta.properties'
--- chrome/locale/id/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/id/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=Iklan telah berlalu!

=== added file 'chrome/locale/id/overlay.dtd'
--- chrome/locale/id/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/id/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,21 @@
+<!ENTITY status.tooltip "Status:">
+<!ENTITY blocked.tooltip "Item yang diblok pada halaman ini:">
+<!ENTITY filters.tooltip "Filter yang paling aktif:">
+<!ENTITY menuitem.label "Preferensi Adblock Plus">
+<!ENTITY menuitem.accesskey "r">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Item yang Diblok">
+<!ENTITY context.image.label "Gambar Adblock">
+<!ENTITY context.object.label "Obyek Adblock">
+<!ENTITY context.frame.label "Bingkai Adblock">
+<!ENTITY sidebar.title "Item yang bisa diblok pada halaman ini">
+<!ENTITY settings.label "Preferensi">
+<!ENTITY settings.accesskey "F">
+<!ENTITY opensidebar.label "Buka item yang bisa diblok">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "Tutup item yang bisa diblok">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "Matikan pada ?1?">
+<!ENTITY whitelist.page.label "Matikan pada halaman ini saja">
+<!ENTITY objecttab.title "Blok">
+<!ENTITY objecttab.tooltip "Klik ini untuk memblok obyek ini dengan Adblock Plus">

=== added file 'chrome/locale/id/settings.dtd'
--- chrome/locale/id/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/id/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,87 @@
+<!ENTITY dialog.title "Preferensi Adblock Plus">
+<!ENTITY filters.label "Filter">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Tambahkan filter">
+<!ENTITY add.accesskey "A">
+<!ENTITY addsubscription.label "Tambahkan skrip filter">
+<!ENTITY addsubscription.accesskey "S">
+<!ENTITY synchsubscriptions.label "Update semua skrip">
+<!ENTITY synchsubscriptions.accesskey "D">
+<!ENTITY import.label "Impor filter">
+<!ENTITY import.accesskey "M">
+<!ENTITY export.label "Ekspor filter buatan sendiri">
+<!ENTITY export.accesskey "E">
+<!ENTITY clearall.label "Buang semua filter buatan sendiri">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "Setel ulang statistik">
+<!ENTITY resethitcounts.accesskey "T">
+<!ENTITY edit.label "Ubah">
+<!ENTITY edit.accesskey "U">
+<!ENTITY cut.label "Potong">
+<!ENTITY cut.accesskey "T">
+<!ENTITY copy.label "Salin">
+<!ENTITY copy.accesskey "S">
+<!ENTITY paste.label "Tempel">
+<!ENTITY paste.accesskey "P">
+<!ENTITY remove.label "Hapus">
+<!ENTITY remove.accesskey "h">
+<!ENTITY menu.find.label "Cari">
+<!ENTITY menu.find.accesskey "C">
+<!ENTITY menu.findagain.label "Cari Lagi">
+<!ENTITY menu.findagain.accesskey "G">
+<!ENTITY view.label "Lihat">
+<!ENTITY view.accesskey "L">
+<!ENTITY sort.label "Urutkan dari">
+<!ENTITY sort.accesskey "i">
+<!ENTITY sort.none.label "Acak">
+<!ENTITY sort.none.accesskey "K">
+<!ENTITY sort.ascending.label "Urut dari A &gt; Z">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Urut dari Z &gt; A">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Opsi">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Hidupkan Adblock Plus">
+<!ENTITY enable.accesskey "N">
+<!ENTITY showintoolbar.label "Tunjukkan di toolbar">
+<!ENTITY showintoolbar.accesskey "B">
+<!ENTITY showinstatusbar.label "Tunjukkan di status bar">
+<!ENTITY showinstatusbar.accesskey "S">
+<!ENTITY objecttabs.label "Tunjukkan tab pada Flash dan Java">
+<!ENTITY objecttabs.accesskey "T">
+<!ENTITY collapse.label "Gabungkan elemen yang diblok">
+<!ENTITY collapse.accesskey "L">
+<!ENTITY help.label "Bantuan">
+<!ENTITY help.accesskey "b">
+<!ENTITY gettingStarted.label "Memulai">
+<!ENTITY gettingStarted.accesskey "a">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Pertanyaan yang Sering Ditanya">
+<!ENTITY faq.accesskey "y">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Menulis filter Adblock Plus">
+<!ENTITY filterdoc.accesskey "R">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Tentang Adblock Plus">
+<!ENTITY about.accesskey "B">
+<!ENTITY description "Filter ini menunjukkan alamat mana yang harus diblok dan mana yang dibolehkan:">
+<!ENTITY filter.column "Aturan filter">
+<!ENTITY filter.accesskey "F">
+<!ENTITY enabled.column "Hidupkan">
+<!ENTITY enabled.accesskey "N">
+<!ENTITY hitcount.column "Sasaran">
+<!ENTITY hitcount.accesskey "H">
+<!ENTITY lasthit.column "Sasaran terakhir">
+<!ENTITY lasthit.accesskey "L">
+<!ENTITY context.edit.label "Ubah filter">
+<!ENTITY context.resethitcount.label "Setel ulang statistik sasaran untuk filter">
+<!ENTITY context.synchsubscription.label "Update skrip sekarang">
+<!ENTITY context.editsubscription.label "Edit skrip">
+<!ENTITY context.moveup.label "Pindahkan filter ke atas">
+<!ENTITY context.movedown.label "Pindahkan filter ke bawah">
+<!ENTITY context.movegroupup.label "Pindahkan grup ke atas">
+<!ENTITY context.movegroupdown.label "Pindahkan grup ke bawah">
+<!ENTITY context.enable.label "Hidupkan">
+<!ENTITY context.disable.label "Matikan">
+<!ENTITY apply.label "Pakai">
+<!ENTITY apply.accesskey "P">

=== added file 'chrome/locale/id/sidebar.dtd'
--- chrome/locale/id/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/id/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,30 @@
+<!ENTITY detached.title "Adblock Plus: Item yang bisa diblok (dilepaskan)">
+<!ENTITY detach.label "Lepas">
+<!ENTITY reattach.label "Sertakan kembali">
+<!ENTITY search.label "Cari:">
+<!ENTITY search.accesskey "C">
+<!ENTITY type.label "Tipe">
+<!ENTITY address.label "Alamat">
+<!ENTITY filter.label "Filter">
+<!ENTITY state.label "Bagian">
+<!ENTITY size.label "Ukuran">
+<!ENTITY noitems.label "Tidak ada item yang bisa diblok">
+<!ENTITY whitelisted.label "Halaman yang dibebaskan">
+<!ENTITY tooltip.address.label "Alamat:">
+<!ENTITY tooltip.type.label "Tipe:">
+<!ENTITY tooltip.type.blocked "(diblok)">
+<!ENTITY tooltip.type.whitelisted "(dibebaskan)">
+<!ENTITY tooltip.size.label "Ukuran:">
+<!ENTITY tooltip.filter.label "Filter efek:">
+<!ENTITY tooltip.filterSource.label "Sumber filter:">
+<!ENTITY context.block.label "Blok item ini">
+<!ENTITY context.editfilter.label "Edit filter efek">
+<!ENTITY context.whitelist.label "Tambahkan Aturan pengecualian untuk item">
+<!ENTITY context.disablefilter.label "Matikan filter ?1?">
+<!ENTITY context.enablefilter.label "Hidupkan ulang filter ?1?">
+<!ENTITY context.disablefilteronsite.label "Matikan filter ini pada ?1?">
+<!ENTITY context.open.label "Buka di tab baru">
+<!ENTITY context.flash.label "Border item yang ber-flash">
+<!ENTITY context.copy.label "Salin alamat item">
+<!ENTITY context.copyFilter.label "Salin filter">
+<!ENTITY context.selectAll.label "Pilih semua">

=== added file 'chrome/locale/id/subscriptionSelection.dtd'
--- chrome/locale/id/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/id/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,20 @@
+<!ENTITY dialog.title "Tambahkan skrip filter Adblock Plus">
+<!ENTITY dialog.title.edit "Edit skrip filter">
+<!ENTITY adblock.warning "Adblock Plus telah mendeteksi bahwa Adblock atau versi lama Adblock Plus terinstall.
+	Menjalankan kedua Adblock dan Adblock Plus terpisah bisa menyebabkan
+	masalah dan harus dicegah. Disarankan untuk menghapus Adblock sekarang.">
+<!ENTITY adblock.uninstall "Hapus Adblock">
+<!ENTITY filterset.g.warning "Sepertinya Anda menggunakan Filterset.G. Daftar filter nyata telah dipelihara
+	dalam beberapa tahun terakhir dan merupakan penyebab masalah pada situs.
+	Disarankan Anda untuk menghapus Filterset.G sekarang.">
+<!ENTITY filterset.g.moreinfo "Informasi lebih lanjut">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Hapus Filterset.G">
+<!ENTITY other.label "Tambahkan skrip yang berbeda">
+<!ENTITY other.accesskey "y">
+<!ENTITY title.label "Judul Skrip:">
+<!ENTITY title.accesskey "J">
+<!ENTITY location.label "Lokasi daftar filter:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Update otomatis">
+<!ENTITY autodownload.accesskey "P">

=== added directory 'chrome/locale/is'
=== removed directory 'chrome/locale/is-IS'
=== removed file 'chrome/locale/is-IS/about.dtd'
--- chrome/locale/is-IS/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/is-IS/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-<!ENTITY dialog.title "Um Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Útgáfa">
-<!ENTITY description "
-	Adblock Plus gerir þér kleyft að ákveða hvað þú vilt ekki sjá á vefnum.
-	Þú þarft ekki framar að niðurhala auglýsingum og auglýsingaborðum, ef þú
-	vilt það ekki - notaðu Adblock Plus!
-">
-<!ENTITY homepage.label "Adblock Plus heimasíða:">
-<!ENTITY homepage.url "http://adblockplus.org/en/">
-<!ENTITY author.label "Höfundur:">
-<!ENTITY contributors.label "Þátttakendur:">

=== removed file 'chrome/locale/is-IS/composer.dtd'
--- chrome/locale/is-IS/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/is-IS/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Bæta við Adblock Plus síureglu">
-<!ENTITY accept.label "Bæta við síu">
-<!ENTITY advanced.label "Ítarleg sýn">
-<!ENTITY basic.label "Einföld sýn">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus er óvirkt eins og er. Þú getur samt bætt við síum en síurnar munu ekki vera virkar nema þú">
-<!ENTITY disabled.warning.link "virkjir Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Síuhópurinn &quot;&#37;S&quot; sem þessi sía á að bætast við er ekki virkur. Þú getur bætt síunni við en hún mun ekki verða virkjuð nema þú">
-<!ENTITY groupDisabled.warning.link "gerir síuhópinn virkan">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Ný sía:">
-<!ENTITY filter.accesskey "s">
-<!ENTITY preferences.label "Sýna núverandi síur...">
-<!ENTITY preferences.accesskey "v">
-<!ENTITY type.filter.label "Lokunarsía">
-<!ENTITY type.filter.accesskey "L">
-<!ENTITY type.whitelist.label "Frávikregla">
-<!ENTITY type.whitelist.accesskey "F">
-<!ENTITY pattern.label "Leita að mynstri">
-<!ENTITY pattern.explanation "Mynstrið getur verið hvaða hluti sem er í netfanginu, táknið * virkar sem algildisstafur. Síunni verður aðeins beitt á þau netföng sem passa við mynstrið.">
-<!ENTITY regexp.warning "Mynstrið sem þú slóst inn verður túlkað sem regluleg segð. Margar reglulegar segðir gætu haft þau áhrif að hægja á vöfrun. Ef þú ætlar ekki að nota reglulega segðir, bættu þá * tákni við enda mynstursins.">
-<!ENTITY shortpattern.warning "Mynstrið sem þú slóst inn er of stutt til að hægt sé að nota það, of mörg svona mynstur geta hægt á vöfrun. Mælt er með að þú notir lengri streng fyrir þessa síu.">
-<!ENTITY custom.pattern.label "Sérsnið:">
-<!ENTITY custom.pattern.accesskey "n">
-<!ENTITY anchors.label "Aðeins samþykkja mynstur:">
-<!ENTITY anchor.start.label "í byrjun netfangs">
-<!ENTITY anchor.start.accesskey "b">
-<!ENTITY anchor.start.flexible.label "í byrjun lénsins">
-<!ENTITY anchor.start.flexible.accesskey "b">
-<!ENTITY anchor.end.label "í enda netfangs">
-<!ENTITY anchor.end.accesskey "d">
-<!ENTITY options.label "Valkostir">
-<!ENTITY domainRestriction.label "Takmarka við lén:">
-<!ENTITY domainRestriction.accesskey "T">
-<!ENTITY domainRestriction.help "Sláðu inn eitt eða fleiri lén aðskilið með tákninu &quot;|&quot;, sían verður aðeins beitt á þessi lén. Táknið &quot;~&quot; fyrir framan lén þýðir að ekki ætti að beita síunni á það lén.">
-<!ENTITY firstParty.label "Aðeins fyrsta aðila">
-<!ENTITY firstParty.accesskey "r">
-<!ENTITY thirdParty.label "Aðeins þriðja aðila">
-<!ENTITY thirdParty.accesskey "A">
-<!ENTITY matchCase.label "Passa við stafstöðu">
-<!ENTITY matchCase.accesskey "P">
-<!ENTITY types.label "Virkja fyrir tegundir:">
-<!ENTITY selectAllTypes.label "Velja allt">
-<!ENTITY unselectAllTypes.label "Velja ekkert">
-<!ENTITY collapse.label "Fella saman lokaða hluti:">
-<!ENTITY collapse.accesskey "m">
-<!ENTITY collapse.default.yes.label "Nota sjálfgefið (já)">
-<!ENTITY collapse.default.no.label "Nota sjálfgefið (nei)">
-<!ENTITY collapse.yes.label "Já">
-<!ENTITY collapse.no.label "Nei">

=== removed file 'chrome/locale/is-IS/global.properties'
--- chrome/locale/is-IS/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/is-IS/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Auglýsingar eru hluti af fortíðinni!
-status_active_label=Adblock
-status_disabled_label=Óvirkt
-action0_tooltip=Smelltu til að birta valmynd, miðju smelltu á músinni til að virkja/gera óvirkt.
-action1_tooltip=Smelltu til að opna/loka hlutum, miðju smella til að virkja/gera óvirkt.
-action2_tooltip=Smelltu til að opna stillingar, miðju smelltu til að virkja/gera óvirkt.
-action3_tooltip=Smelltu til að virkja/gera óvirkt Adblock Plus.
-active_tooltip=Adblock Plus er virkur.
-disabled_tooltip=Adblock Plus er óvirkur.
-whitelisted_tooltip=Adblock Plus er í gangi en er óvirkur á núverandi síðu.
-blocked_count_tooltip=-- af --
-no_blocking_suggestions=Engir lokaðir hlutir á núverandi síðu
-whitelisted_page=Búið er að gera Adblock Plus óvirkt fyrir núverandi síðu
-whitelist_description=Undantekningareglur
-filterlist_description=Auglýsingareglur
-invalid_description=Ógildar síur
-elemhide_description=Reglur til að fela hluti
-subscription_description=Síu áskrift:
-subscription_wrong_version=Sumar síur í þessari áskrift þarfnast Adblock Plus -- til að virka almennilega!
-subscription_source=Uppruni:
-subscription_status=Staða:
-subscription_status_autodownload=Sjálfvirk uppfærsla
-subscription_status_manualdownload=Uppfært handvirkt
-subscription_status_externaldownload=Uppfært frá utanaðkomandi (önnur viðbót)
-subscription_status_lastdownload=Seinasta niðurhal:
-subscription_status_lastdownload_inprogress=Hleður...
-subscription_status_lastdownload_unknown=Óþekkt
-remove_subscription_warning=Viltu fjarlægja þessa áskrift?
-import_filters_wrong_version=Aðvörun: sumar síur í þessum lista þarfnast Adblock Plus -- til að virka almennilega. Þú ættir að uppfæra í nýjustu útgáfuna af Adblock Plus áður en þú flytur inn þennan lista.
-import_filters_warning=Viltu skrifa yfir núverandi síur eða bæta nýju síunum við endann á núverandi lista?
-import_filters_title=Flytja inn síur
-export_filters_title=Flytja út síur
-invalid_filters_file=Ekki gild Adblock Plus síuskrá.
-filters_write_error=Villa kom upp við að skrifa síur í skránna. Athugaðu hvort skráin sé ekki skrifvarinn eða sé í notkun af öðru forriti.
-clearall_warning=Viltu fjarlægja allar síur frá listanum?
-resethitcounts_warning=Viltu örugglega endurstilla talningar fyrir síur á núll? Ekki er hægt að afturkalla þessa aðgerð!
-resethitcounts_selected_warning=Viltu örugglega endurstilla talningar fyrir valdar síur á núll? Ekki er hægt að afturkalla þessa aðgerð!
-filter_regexp_tooltip=Sían er annaðhvort regluleg segð eða of stutt til að hægt sé að nota. Of margar af svona síum gætu hægt á vöfrun.
-filter_elemhide_duplicate_id=Aðeins er hægt að skilgreina eitt auðkenni fyrir hlut sem á að fela
-filter_elemhide_nocriteria=Engin viðmiðun skilgreind til þess að bera kennsl á hlut til að fela
-subscription_no_location=Sláðu inn staðsetningu til þess að niðurhala síur frá.
-subscription_invalid_location=Staðsetning síu er ekki gilt URL eða gilt skráarnafn.
-subscription_location_exists=Þú ert þegar áskrifandi að þessum síulista.
-synchronize_invalid_url=Mistókst, ekki gilt netfang
-synchronize_connection_error=Mistókst, gat ekki niðurhalað
-synchronize_invalid_data=Mistókst, ekki gildur síulisti
-synchronize_checksum_mismatch=Mistókst, prófsumma stemmir ekki
-synchronize_ok=Tókst
-overwrite=Yfirskrifa
-append=Bæta við
-new_filter_group_title=Ný sía
-type_label_other=annað
-type_label_script=skrifta
-type_label_image=mynd
-type_label_stylesheet=stílblað
-type_label_object=hlutur
-type_label_subdocument=rammi
-type_label_document=skjal
-type_label_background=bakgrunnur
-type_label_elemhide=falið
-type_label_xbl=XBL tenging
-type_label_ping=tengla ping
-type_label_xmlhttprequest=XML beiðni
-type_label_object_subrequest=undiraðgerð hlutar
-type_label_dtd=DTD
-type_label_media=hljóð/mynd
-type_label_font=leturgerð

=== removed file 'chrome/locale/is-IS/overlay.dtd'
--- chrome/locale/is-IS/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/is-IS/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Staða:">
-<!ENTITY blocked.tooltip "Lokaðir hlutir á þessari síðu:">
-<!ENTITY filters.tooltip "Mest notaðar síur:">
-<!ENTITY menuitem.label "Adblock Plus stillingar">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Lokaðir hlutir">
-<!ENTITY context.image.label "Loka auglýsingamynd">
-<!ENTITY context.object.label "Loka auglýsingahlut">
-<!ENTITY context.frame.label "Loka auglýsingaramma">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Endurvirkja á þessari síðu">
-<!ENTITY sidebar.title "Hlutir á núverandi síðu sem hægt er að loka á">
-<!ENTITY settings.label "Stillingar">
-<!ENTITY settings.accesskey "S">
-<!ENTITY opensidebar.label "Skoða hluti">
-<!ENTITY opensidebar.accesskey "l">
-<!ENTITY closesidebar.label "Loka hlutum">
-<!ENTITY closesidebar.accesskey "l">
-<!ENTITY whitelist.site.label "Gera óvirkt á --">
-<!ENTITY whitelist.page.label "Gera óvirkt aðeins á þessari síðu">
-<!ENTITY objecttab.title "Loka á">
-<!ENTITY objecttab.tooltip "Smelltu hér til að loka á þennan hlut með Adblock Plus">

=== removed file 'chrome/locale/is-IS/settings.dtd'
--- chrome/locale/is-IS/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/is-IS/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus stillingar">
-<!ENTITY filters.label "Síur">
-<!ENTITY filters.accesskey "S">
-<!ENTITY add.label "Bæta við síu">
-<!ENTITY add.accesskey "t">
-<!ENTITY addsubscription.label "Bæta við síuáskrift">
-<!ENTITY addsubscription.accesskey "S">
-<!ENTITY synchsubscriptions.label "Uppfæra allar áskriftir">
-<!ENTITY synchsubscriptions.accesskey "U">
-<!ENTITY import.label "Flytja inn síur">
-<!ENTITY import.accesskey "F">
-<!ENTITY export.label "Flytja út síur">
-<!ENTITY export.accesskey "y">
-<!ENTITY clearall.label "Fjarlægja allar síur">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "Endurstilla talningar">
-<!ENTITY resethitcounts.accesskey "E">
-<!ENTITY edit.label "Breyta">
-<!ENTITY edit.accesskey "B">
-<!ENTITY cut.label "Klippa">
-<!ENTITY cut.accesskey "K">
-<!ENTITY copy.label "Afrita">
-<!ENTITY copy.accesskey "A">
-<!ENTITY paste.label "Líma">
-<!ENTITY paste.accesskey "L">
-<!ENTITY remove.label "Eyða">
-<!ENTITY remove.accesskey "E">
-<!ENTITY menu.find.label "Leita">
-<!ENTITY menu.find.accesskey "t">
-<!ENTITY menu.findagain.label "Leita aftur">
-<!ENTITY menu.findagain.accesskey "f">
-<!ENTITY view.label "Skoða">
-<!ENTITY view.accesskey "k">
-<!ENTITY sort.label "Raða eftir">
-<!ENTITY sort.accesskey "f">
-<!ENTITY sort.none.label "Óraðað">
-<!ENTITY sort.none.accesskey "r">
-<!ENTITY sort.ascending.label "A &gt; Ö röðun">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Ö &gt; A röðun">
-<!ENTITY sort.descending.accesskey "Ö">
-<!ENTITY options.label "Valkostir">
-<!ENTITY options.accesskey "V">
-<!ENTITY enable.label "Virkja Adblock Plus">
-<!ENTITY enable.accesskey "A">
-<!ENTITY showintoolbar.label "Sýna í tækjaslá">
-<!ENTITY showintoolbar.accesskey "t">
-<!ENTITY showinstatusbar.label "Sýna í stöðuslá">
-<!ENTITY showinstatusbar.accesskey "S">
-<!ENTITY objecttabs.label "Sýna flipa fyrir Flass og Java">
-<!ENTITY objecttabs.accesskey "f">
-<!ENTITY collapse.label "Fella saman lokaða hluti">
-<!ENTITY collapse.accesskey "L">
-<!ENTITY help.label "Hjálp">
-<!ENTITY help.accesskey "H">
-<!ENTITY gettingStarted.label "Byrja notkun">
-<!ENTITY gettingStarted.accesskey "n">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Oft spurðar spurningar">
-<!ENTITY faq.accesskey "O">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Hvernig á að búa til Adblock Plus síur">
-<!ENTITY filterdoc.accesskey "v">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Um Adblock Plus">
-<!ENTITY about.accesskey "B">
-<!ENTITY description "Eftirfarandi síur ákvarða hvaða netföng á að loka á og hvaða netföng eigi að leyfa:">
-<!ENTITY filter.column "Síu regla">
-<!ENTITY filter.accesskey "g">
-<!ENTITY slow.column "Hægar síur">
-<!ENTITY slow.accesskey "æ">
-<!ENTITY enabled.column "Virkt">
-<!ENTITY enabled.accesskey "V">
-<!ENTITY hitcount.column "Notkun">
-<!ENTITY hitcount.accesskey "N">
-<!ENTITY lasthit.column "Seinast heimsótt">
-<!ENTITY lasthit.accesskey "h">
-<!ENTITY context.edit.label "Breyta">
-<!ENTITY context.resethitcount.label "Endurstilla talningu fyrir síu">
-<!ENTITY context.synchsubscription.label "Uppfæra áskrift núna">
-<!ENTITY context.editsubscription.label "Breyta áskrift">
-<!ENTITY context.moveup.label "Færa upp">
-<!ENTITY context.movedown.label "Færa niður">
-<!ENTITY context.movegroupup.label "Færa hóp upp">
-<!ENTITY context.movegroupdown.label "Færa hóp niður">
-<!ENTITY context.enable.label "Gera virkt">
-<!ENTITY context.disable.label "Gera óvirkt">
-<!ENTITY apply.label "Nota">
-<!ENTITY apply.accesskey "N">

=== removed file 'chrome/locale/is-IS/sidebar.dtd'
--- chrome/locale/is-IS/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/is-IS/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Lokaðir hlutir (aðskildir)">
-<!ENTITY detach.label "Aftengja">
-<!ENTITY reattach.label "Festa aftur">
-<!ENTITY search.label "Leita:">
-<!ENTITY search.accesskey "L">
-<!ENTITY type.label "Tegund">
-<!ENTITY address.label "Netfang">
-<!ENTITY filter.label "Sía">
-<!ENTITY state.label "Ríki">
-<!ENTITY size.label "Stærð">
-<!ENTITY docDomain.label "Frumkóði síðu">
-<!ENTITY noitems.label "Engir hlutir til að loka á">
-<!ENTITY whitelisted.label "Síða fyrir hvítlista">
-<!ENTITY tooltip.address.label "Netfang:">
-<!ENTITY tooltip.type.label "Tegund:">
-<!ENTITY tooltip.type.blocked "(stöðvað)">
-<!ENTITY tooltip.type.whitelisted "(hvítlisti)">
-<!ENTITY tooltip.size.label "Stærð:">
-<!ENTITY tooltip.docDomain.label "Frumkóði síðu:">
-<!ENTITY tooltip.filter.label "Sía í notkun:">
-<!ENTITY tooltip.filterSource.label "Sía frumkóða:">
-<!ENTITY context.block.label "Loka á þennan hlut">
-<!ENTITY context.editfilter.label "Breyta núverandi síu">
-<!ENTITY context.whitelist.label "Bæta við undantekningu fyrir hlut">
-<!ENTITY context.disablefilter.label "Aftengja síu --">
-<!ENTITY context.enablefilter.label "Virkja aftur síu --">
-<!ENTITY context.disablefilteronsite.label "Aftengja síu fyrir --">
-<!ENTITY context.open.label "Opna í nýjum flipa">
-<!ENTITY context.flash.label "Rammi Flash hlutar">
-<!ENTITY context.copy.label "Afrita netfang hlutar">
-<!ENTITY context.copyFilter.label "Afrita síu">
-<!ENTITY context.selectAll.label "Velja allt">

=== removed file 'chrome/locale/is-IS/subscription.dtd'
--- chrome/locale/is-IS/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/is-IS/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY dialog.title "Breyta síuáskrift">
-<!ENTITY dialog.newtitle "Bæta við síuáskrift">
-<!ENTITY new.description "Sláðu inn netfang eða skráarnafn sem inniheldur lista af
-	Adblock Plus síum.">
-<!ENTITY edit.description "Síulistinn fyrir þessa áskrift verður niðurhalað
-	frá gefinni staðsetningu.">
-<!ENTITY external.description "Áskrift þessi er ytri síuáskrift, síulistinn
-	verður uppfærður af viðbótinni sem bjó til þessa
-	áskrift.">
-<!ENTITY autodownload.description "Ef þú velur að 'Uppfæra sjálfvirkt' mun þessi staðsetning verða
-	athuguð daglega fyrir uppfærslur. Ef þessi valmöguleiki er óvirkur
-	geturðu samt uppfært handvirkt frá
-	áskriftarvalmynd.">
-<!ENTITY location.label "Staðsetning síulista:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Áskriftartitill:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Uppfæra sjálfvirkt">
-<!ENTITY autodownload.accesskey "U">
-<!ENTITY enabled.label "Virkja síur">
-<!ENTITY enabled.accesskey "V">

=== removed file 'chrome/locale/is-IS/tip_subscriptions.dtd'
--- chrome/locale/is-IS/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/is-IS/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,31 +0,0 @@
-<!ENTITY dialog.title "Bæta við Adblock Plus síu áskrift">
-<!ENTITY description.par1 "Þakka þér fyrir að setja inn Adblock Plus. Þessi viðbót getur
-	fjarlægt 99&#37; af öllum auglýsingum sem þú sérð á vefnum. Hinsvegar,
-	til þess að ná þessum árangri þarftu að skilgreina góðar
-	síur. Þú getur skilgreint svoleiðis sjálfur, eða þú getur einfaldlega gerst áskrifandi
-	að síulistum sem aðrir sjá um að viðhalda fyrir þig. Það er samt alltaf hægt að
-	bæta við þínum eigin síum eða gera óvirkar/fjarlægja áskriftir
-	hvenær sem er.">
-<!ENTITY description.par2 "Þú getur valið eina áskrift af áskriftarlistunum sem mælt er með
-	hér fyrir neðan (fleiri áskriftir er hægt að
-	bæta við seinna í Adblock Plus stillingaglugganum þótt venjulega sé það ekki
-	nauðsynlegt):">
-<!ENTITY note "Athugið: Síulisti er venjulega árangursríkastur þegar honum er beitt
-	á þau vefsvæði sem eru frá því svæði sem listinn var búinn til fyrir.">
-<!ENTITY adblock.warning "Adblock Plus hefur uppgötvað að Adblock eða gömul útgáfa af Adblock Plus er
-	uppsett. Ef þú keyrir bæði Adblock og Adblock Plus samsíða getur það valdið
-	vandræðum og ætti að forðast í lengstu lög. Mælt er með að þú takir út Adblock strax.">
-<!ENTITY adblock.uninstall "Taka út Adblock">
-<!ENTITY filterset.g.warning "Svo virðist sem þú sért að nota Filterset.G. Þessum síulista hefur ekki verið
-	viðhaldið seinustu árin og er algeng ástæða fyrir vandamálum á
-	vefsíðum. Mælt er með að þú takir út Filterset.G strax.">
-<!ENTITY filterset.g.moreinfo "Meiri upplýsingar">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Taka út Filterset.G">
-<!ENTITY homepage.label "Heimasíða">
-<!ENTITY subscribe.label "Gerast áskrifandi">
-<!ENTITY subscribe.accesskey "G">
-<!ENTITY other.label "Bæta við öðruvísi áskrift">
-<!ENTITY other.accesskey "T">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Skoða allar áskriftir">

=== added file 'chrome/locale/is/about.dtd'
--- chrome/locale/is/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/is/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,14 @@
+<!ENTITY dialog.title "Um Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Útgáfa">
+<!ENTITY description "Adblock Plus gerir þér kleyft að ákveða hvað þú vilt ekki sjá á vefnum.
+	Þú þarft ekki framar að niðurhala auglýsingum og auglýsingaborðum, ef þú
+	vilt það ekki - notaðu Adblock Plus!">
+<!ENTITY homepage.label "Adblock Plus heimasíða:">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "Höfundur:">
+<!ENTITY contributors.label "Þátttakendur:">
+<!ENTITY developers.label "Þróunaraðilar:">
+<!ENTITY designers.label "Grafískir hönnuðir:">
+<!ENTITY subscriptionAuthors.label "Sía eftir áskriftahöfundar:">
+<!ENTITY translators.label "Þýðendur:">

=== added file 'chrome/locale/is/composer.dtd'
--- chrome/locale/is/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/is/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Bæta við Adblock Plus síureglu">
+<!ENTITY accept.label "Bæta við síu">
+<!ENTITY advanced.label "Ítarleg sýn">
+<!ENTITY basic.label "Einföld sýn">
+<!ENTITY disabled.warning "Adblock Plus er óvirkt eins og er. Þú getur samt bætt við síum en síurnar munu ekki vera virkar nema þú [link]virkjir Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Síuhópurinn &quot;?1?&quot; sem þessi sía á að bætast við er ekki virkur. Þú getur bætt síunni við en hún mun ekki verða virkjuð nema þú [link]gerir síuhópinn virkan[/link].">
+<!ENTITY filter.label "Ný sía:">
+<!ENTITY filter.accesskey "s">
+<!ENTITY preferences.label "Sýna núverandi síur...">
+<!ENTITY preferences.accesskey "v">
+<!ENTITY type.filter.label "Lokunarsía">
+<!ENTITY type.filter.accesskey "L">
+<!ENTITY type.whitelist.label "Frávikregla">
+<!ENTITY type.whitelist.accesskey "F">
+<!ENTITY pattern.label "Leita að mynstri">
+<!ENTITY pattern.explanation "Mynstrið getur verið hvaða hluti sem er í netfanginu, táknið * virkar sem algildisstafur. Síunni verður aðeins beitt á þau netföng sem passa við mynstrið.">
+<!ENTITY regexp.warning "Mynstrið sem þú slóst inn verður túlkað sem regluleg segð. Margar reglulegar segðir gætu haft þau áhrif að hægja á vöfrun. Ef þú ætlar ekki að nota reglulega segðir, bættu þá * tákni við enda mynstursins.">
+<!ENTITY shortpattern.warning "Mynstrið sem þú slóst inn er of stutt til að hægt sé að nota það, of mörg svona mynstur geta hægt á vöfrun. Mælt er með að þú notir lengri streng fyrir þessa síu.">
+<!ENTITY custom.pattern.label "Sérsnið:">
+<!ENTITY custom.pattern.accesskey "n">
+<!ENTITY anchors.label "Aðeins samþykkja mynstur:">
+<!ENTITY anchor.start.label "í byrjun netfangs">
+<!ENTITY anchor.start.accesskey "b">
+<!ENTITY anchor.start.flexible.label "í byrjun lénsins">
+<!ENTITY anchor.start.flexible.accesskey "b">
+<!ENTITY anchor.end.label "í enda netfangs">
+<!ENTITY anchor.end.accesskey "d">
+<!ENTITY options.label "Valkostir">
+<!ENTITY domainRestriction.label "Takmarka við lén:">
+<!ENTITY domainRestriction.accesskey "T">
+<!ENTITY domainRestriction.help "Sláðu inn eitt eða fleiri lén aðskilið með tákninu &quot;|&quot;, sían verður aðeins beitt á þessi lén. Táknið &quot;~&quot; fyrir framan lén þýðir að ekki ætti að beita síunni á það lén.">
+<!ENTITY firstParty.label "Aðeins fyrsta aðila">
+<!ENTITY firstParty.accesskey "r">
+<!ENTITY thirdParty.label "Aðeins þriðja aðila">
+<!ENTITY thirdParty.accesskey "A">
+<!ENTITY matchCase.label "Passa við stafstöðu">
+<!ENTITY matchCase.accesskey "P">
+<!ENTITY types.label "Virkja fyrir tegundir:">
+<!ENTITY selectAllTypes.label "Velja allt">
+<!ENTITY unselectAllTypes.label "Velja ekkert">
+<!ENTITY collapse.label "Fella saman lokaða hluti:">
+<!ENTITY collapse.accesskey "m">
+<!ENTITY collapse.default.yes.label "Nota sjálfgefið (já)">
+<!ENTITY collapse.default.no.label "Nota sjálfgefið (nei)">
+<!ENTITY collapse.yes.label "Já">
+<!ENTITY collapse.no.label "Nei">

=== added file 'chrome/locale/is/global.properties'
--- chrome/locale/is/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/is/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Smelltu til að birta valmynd, miðju smelltu á músinni til að virkja/gera óvirkt.
+action1_tooltip=Smelltu til að opna/loka hlutum, miðju smella til að virkja/gera óvirkt.
+action2_tooltip=Smelltu til að opna stillingar, miðju smelltu til að virkja/gera óvirkt.
+action3_tooltip=Smelltu til að virkja/gera óvirkt Adblock Plus.
+disabled_tooltip=Adblock Plus er óvirkur.
+active_tooltip=Adblock Plus er virku, ?1? síu áskriftir og ?2? sérsniðnar síur í notkun.
+whitelisted_tooltip=Adblock Plus er í gangi en er óvirkur á núverandi síðu.
+blocked_count_tooltip=?1? af ?2?
+blocked_count_addendum=(einnig á hvítlista: ?1?, falið: ?2?)
+no_blocking_suggestions=Engir lokaðir hlutir á núverandi síðu
+whitelisted_page=Búið er að gera Adblock Plus óvirkt fyrir núverandi síðu
+whitelist_description=Undantekningareglur
+filterlist_description=Auglýsingareglur
+invalid_description=Ógildar síur
+elemhide_description=Reglur til að fela hluti
+subscription_description=Síu áskrift:
+subscription_wrong_version=Sumar síur í þessari áskrift þarfnast Adblock Plus ?1? til að virka almennilega!
+subscription_source=Uppruni:
+subscription_status=Staða:
+subscription_status_autodownload=Sjálfvirk uppfærsla
+subscription_status_manualdownload=Uppfært handvirkt
+subscription_status_externaldownload=Uppfært frá utanaðkomandi (önnur viðbót)
+subscription_status_lastdownload=Seinasta niðurhal:
+subscription_status_lastdownload_inprogress=Hleður...
+subscription_status_lastdownload_unknown=Óþekkt
+remove_subscription_warning=Viltu fjarlægja þessa áskrift?
+import_filters_wrong_version=Aðvörun: sumar síur í þessum lista þarfnast Adblock Plus ?1? til að virka almennilega. Þú ættir að uppfæra í nýjustu útgáfuna af Adblock Plus áður en þú flytur inn þennan lista.
+import_filters_warning=Viltu skrifa yfir núverandi síur eða bæta nýju síunum við endann á núverandi lista?
+import_filters_title=Flytja inn síur
+export_filters_title=Flytja út síur
+invalid_filters_file=Ekki gild Adblock Plus síuskrá.
+filters_write_error=Villa kom upp við að skrifa síur í skránna. Athugaðu hvort skráin sé ekki skrifvarinn eða sé í notkun af öðru forriti.
+clearall_warning=Viltu fjarlægja allar síur frá listanum?
+resethitcounts_warning=Viltu örugglega endurstilla talningar fyrir síur á núll? Ekki er hægt að afturkalla þessa aðgerð!
+resethitcounts_selected_warning=Viltu örugglega endurstilla talningar fyrir valdar síur á núll? Ekki er hægt að afturkalla þessa aðgerð!
+filter_regexp_tooltip=Sían er annaðhvort regluleg segð eða of stutt til að hægt sé að nota. Of margar af svona síum gætu hægt á vöfrun.
+filter_elemhide_duplicate_id=Aðeins er hægt að skilgreina eitt auðkenni fyrir hlut sem á að fela
+filter_elemhide_nocriteria=Engin viðmiðun skilgreind til þess að bera kennsl á hlut til að fela
+subscription_notAdded_warning=Þú bættir ekki við síu áskrift. Án síu áskriftar verðurðu að bæta við við Adblock síum handvirkt.
+subscription_notAdded_warning_addendum=Viltu halda áfram?
+subscription_invalid_location=Staðsetning síu er ekki gilt URL eða gilt skráarnafn.
+synchronize_invalid_url=Mistókst, ekki gilt netfang
+synchronize_connection_error=Mistókst, gat ekki niðurhalað
+synchronize_invalid_data=Mistókst, ekki gildur síulisti
+synchronize_checksum_mismatch=Mistókst, prófsumma stemmir ekki
+synchronize_ok=Tókst
+overwrite=Yfirskrifa
+append=Bæta við
+new_filter_group_title=Ný sía
+type_label_other=annað
+type_label_script=skrifta
+type_label_image=mynd
+type_label_stylesheet=stílblað
+type_label_object=hlutur
+type_label_subdocument=rammi
+type_label_document=skjal
+type_label_background=bakgrunnur
+type_label_elemhide=falið
+type_label_xbl=XBL tenging
+type_label_ping=tengla ping
+type_label_xmlhttprequest=XML beiðni
+type_label_object_subrequest=undiraðgerð hlutar
+type_label_dtd=DTD
+type_label_media=hljóð/mynd
+type_label_font=leturgerð
+fennec_status_enabled=Adblock Plus er virkt.
+fennec_status_disabled=Adblock Plus er óvirkt.
+fennec_status_enabled_site=Adblock Plus er virkt fyrir ?1?.
+fennec_status_disabled_site=Adblock Plus er óvirkt fyrir ?1?.

=== added file 'chrome/locale/is/meta.properties'
--- chrome/locale/is/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/is/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Kristján Bjarni Guðmundsson
+name=Adblock Plus
+description=Auglýsingar eru hluti af fortíðinni!
+description.short=Hatarðu auglýsingar? Hefurðu áhyggjur af því að verið sé að fylgjast með þér? Ertu þreyttur á auglýsingaborðum? Settu inn Adblock Plus til að ná aftur stjórn á netinu og breyttu því hvernig þú notar vefinn.
+description.long=Adblock Plus gerir þér kleyft að ná aftur stjórn á netinu og gerir þér kleyft að vafra á vefnum eins og þú vilt. Viðbótin styður yfir fjörutíu síu áskriftir á ýmsum tungumálum sem gera meðal annars kleyft að loka á auglýsingar yfir í það að stöðva öll þekkt vefsvæði sem innihalda óværu. Adblock Plus leyfir þér einnig að sérsníða síurnar með hinum ýmsum möguleikum, meðal annars sérstökum valmöguleikum fyrir myndir, Flash og Java hluti, og einnig lista yfir hluti eins og skriftur og stílsnið.

=== added file 'chrome/locale/is/overlay.dtd'
--- chrome/locale/is/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/is/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Staða:">
+<!ENTITY blocked.tooltip "Lokaðir hlutir á þessari síðu:">
+<!ENTITY filters.tooltip "Mest notaðar síur:">
+<!ENTITY menuitem.label "Adblock Plus stillingar">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Lokaðir hlutir">
+<!ENTITY context.image.label "Loka auglýsingamynd">
+<!ENTITY context.object.label "Loka auglýsingahlut">
+<!ENTITY context.frame.label "Loka auglýsingaramma">
+<!ENTITY context.media.label "Adblock Plus: Loka á myndefni/hljóð">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Endurvirkja á þessari síðu">
+<!ENTITY sidebar.title "Hlutir á núverandi síðu sem hægt er að loka á">
+<!ENTITY settings.label "Stillingar">
+<!ENTITY settings.accesskey "S">
+<!ENTITY opensidebar.label "Skoða hluti">
+<!ENTITY opensidebar.accesskey "l">
+<!ENTITY closesidebar.label "Loka hlutum">
+<!ENTITY closesidebar.accesskey "l">
+<!ENTITY whitelist.site.label "Gera óvirkt á ?1?">
+<!ENTITY whitelist.page.label "Gera óvirkt aðeins á þessari síðu">
+<!ENTITY objecttab.title "Loka á">
+<!ENTITY objecttab.tooltip "Smelltu hér til að loka á þennan hlut með Adblock Plus">

=== added file 'chrome/locale/is/settings.dtd'
--- chrome/locale/is/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/is/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus stillingar">
+<!ENTITY filters.label "Síur">
+<!ENTITY filters.accesskey "S">
+<!ENTITY add.label "Bæta við síu">
+<!ENTITY add.accesskey "t">
+<!ENTITY addsubscription.label "Bæta við síuáskrift">
+<!ENTITY addsubscription.accesskey "S">
+<!ENTITY synchsubscriptions.label "Uppfæra allar áskriftir">
+<!ENTITY synchsubscriptions.accesskey "U">
+<!ENTITY import.label "Flytja inn síur">
+<!ENTITY import.accesskey "F">
+<!ENTITY export.label "Flytja út síur">
+<!ENTITY export.accesskey "y">
+<!ENTITY clearall.label "Fjarlægja allar síur">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "Endurstilla talningar">
+<!ENTITY resethitcounts.accesskey "E">
+<!ENTITY edit.label "Breyta">
+<!ENTITY edit.accesskey "B">
+<!ENTITY cut.label "Klippa">
+<!ENTITY cut.accesskey "K">
+<!ENTITY copy.label "Afrita">
+<!ENTITY copy.accesskey "A">
+<!ENTITY paste.label "Líma">
+<!ENTITY paste.accesskey "L">
+<!ENTITY remove.label "Eyða">
+<!ENTITY remove.accesskey "E">
+<!ENTITY menu.find.label "Leita">
+<!ENTITY menu.find.accesskey "t">
+<!ENTITY menu.findagain.label "Leita aftur">
+<!ENTITY menu.findagain.accesskey "f">
+<!ENTITY view.label "Skoða">
+<!ENTITY view.accesskey "k">
+<!ENTITY sort.label "Raða eftir">
+<!ENTITY sort.accesskey "f">
+<!ENTITY sort.none.label "Óraðað">
+<!ENTITY sort.none.accesskey "r">
+<!ENTITY sort.ascending.label "A &gt; Ö röðun">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Ö &gt; A röðun">
+<!ENTITY sort.descending.accesskey "Ö">
+<!ENTITY options.label "Valkostir">
+<!ENTITY options.accesskey "V">
+<!ENTITY enable.label "Virkja Adblock Plus">
+<!ENTITY enable.accesskey "A">
+<!ENTITY showintoolbar.label "Sýna í tækjaslá">
+<!ENTITY showintoolbar.accesskey "t">
+<!ENTITY showinstatusbar.label "Sýna í stöðuslá">
+<!ENTITY showinstatusbar.accesskey "S">
+<!ENTITY objecttabs.label "Sýna flipa fyrir Flass og Java">
+<!ENTITY objecttabs.accesskey "f">
+<!ENTITY collapse.label "Fella saman lokaða hluti">
+<!ENTITY collapse.accesskey "L">
+<!ENTITY help.label "Hjálp">
+<!ENTITY help.accesskey "H">
+<!ENTITY gettingStarted.label "Byrja notkun">
+<!ENTITY gettingStarted.accesskey "n">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Oft spurðar spurningar">
+<!ENTITY faq.accesskey "O">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Hvernig á að búa til Adblock Plus síur">
+<!ENTITY filterdoc.accesskey "v">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Um Adblock Plus">
+<!ENTITY about.accesskey "B">
+<!ENTITY description "Eftirfarandi síur ákvarða hvaða netföng á að loka á og hvaða netföng eigi að leyfa:">
+<!ENTITY filter.column "Síu regla">
+<!ENTITY filter.accesskey "g">
+<!ENTITY slow.column "Hægar síur">
+<!ENTITY slow.accesskey "æ">
+<!ENTITY enabled.column "Virkt">
+<!ENTITY enabled.accesskey "V">
+<!ENTITY hitcount.column "Notkun">
+<!ENTITY hitcount.accesskey "N">
+<!ENTITY lasthit.column "Seinast heimsótt">
+<!ENTITY lasthit.accesskey "h">
+<!ENTITY context.edit.label "Breyta">
+<!ENTITY context.resethitcount.label "Endurstilla talningu fyrir síu">
+<!ENTITY context.synchsubscription.label "Uppfæra áskrift núna">
+<!ENTITY context.editsubscription.label "Breyta áskrift">
+<!ENTITY context.moveup.label "Færa upp">
+<!ENTITY context.movedown.label "Færa niður">
+<!ENTITY context.movegroupup.label "Færa hóp upp">
+<!ENTITY context.movegroupdown.label "Færa hóp niður">
+<!ENTITY context.enable.label "Gera virkt">
+<!ENTITY context.disable.label "Gera óvirkt">
+<!ENTITY apply.label "Nota">
+<!ENTITY apply.accesskey "N">
+<!ENTITY fennec.subscription.label "Síu áskrift">

=== added file 'chrome/locale/is/sidebar.dtd'
--- chrome/locale/is/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/is/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Lokaðir hlutir (aðskildir)">
+<!ENTITY detach.label "Aftengja">
+<!ENTITY reattach.label "Festa aftur">
+<!ENTITY search.label "Leita:">
+<!ENTITY search.accesskey "L">
+<!ENTITY type.label "Tegund">
+<!ENTITY address.label "Netfang">
+<!ENTITY filter.label "Sía">
+<!ENTITY state.label "Ríki">
+<!ENTITY size.label "Stærð">
+<!ENTITY docDomain.label "Netfang síðu">
+<!ENTITY noitems.label "Engir hlutir til að loka á">
+<!ENTITY whitelisted.label "Síða fyrir hvítlista">
+<!ENTITY tooltip.address.label "Netfang:">
+<!ENTITY tooltip.type.label "Tegund:">
+<!ENTITY tooltip.type.blocked "(stöðvað)">
+<!ENTITY tooltip.type.whitelisted "(hvítlisti)">
+<!ENTITY tooltip.size.label "Stærð:">
+<!ENTITY tooltip.docDomain.label "Netfang síðu:">
+<!ENTITY tooltip.filter.label "Sía í notkun:">
+<!ENTITY tooltip.filterSource.label "Sía frumkóða:">
+<!ENTITY context.block.label "Loka á þennan hlut">
+<!ENTITY context.editfilter.label "Breyta núverandi síu">
+<!ENTITY context.whitelist.label "Bæta við undantekningu fyrir hlut">
+<!ENTITY context.disablefilter.label "Aftengja síu ?1?">
+<!ENTITY context.enablefilter.label "Virkja aftur síu ?1?">
+<!ENTITY context.disablefilteronsite.label "Aftengja síu fyrir ?1?">
+<!ENTITY context.open.label "Opna í nýjum flipa">
+<!ENTITY context.flash.label "Rammi Flash hlutar">
+<!ENTITY context.copy.label "Afrita vefslóð hlutar">
+<!ENTITY context.copyFilter.label "Afrita síu">
+<!ENTITY context.selectAll.label "Velja allt">

=== added file 'chrome/locale/is/subscriptionSelection.dtd'
--- chrome/locale/is/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/is/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,36 @@
+<!ENTITY dialog.title "Bæta við Adblock Plus síu áskrift">
+<!ENTITY dialog.title.edit "Breyta síuáskrift">
+<!ENTITY description.newInstall "Til að Adblock Plus sé sem árangursríkast ættirðu að bæta við síu áskrift. Síu áskriftirnar eru ókeypis í boði annarra Adblock Plus notenda. Viðeigandi síu áskrift fyrir þitt tungumál er þegar valið.">
+<!ENTITY adblock.warning "Adblock Plus hefur uppgötvað að Adblock eða gömul útgáfa af Adblock Plus er
+	uppsett. Ef þú keyrir bæði Adblock og Adblock Plus samsíða getur það valdið
+	vandræðum og ætti að forðast í lengstu lög. Mælt er með að þú takir út Adblock strax.">
+<!ENTITY adblock.uninstall "Taka út Adblock">
+<!ENTITY filterset.g.warning "Svo virðist sem þú sért að nota Filterset.G. Þessum síulista hefur ekki verið
+	viðhaldið seinustu árin og er algeng ástæða fyrir vandamálum á
+	vefsíðum. Mælt er með að þú takir út Filterset.G strax.">
+<!ENTITY filterset.g.moreinfo "Meiri upplýsingar">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Taka út Filterset.G">
+<!ENTITY subscriptionSelector.label "Veldu síu áskrift úr listanum:">
+<!ENTITY viewList.label "Skoða síur">
+<!ENTITY visitHomepage.label "Heimsækja heimasíðu">
+<!ENTITY addSubscription.label "Bæta við áskrift">
+<!ENTITY saveSubscription.label "Vista áskrift">
+<!ENTITY other.label "Bæta við öðruvísi áskrift">
+<!ENTITY other.accesskey "T">
+<!ENTITY list.download.failed "Gat ekki náð í lista af áskriftum">
+<!ENTITY list.download.retry "Reyndu aftur">
+<!ENTITY list.download.website "Skoða vefsvæði">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Staðfestu að þú viljir bæta við þessari síu áskrift. Þú getur breytt titlinum eða staðsetningu áður en þú bætir við.">
+<!ENTITY edit.description "Þú getur breytt titli eða staðsetningu ef nauðsynlegt er.">
+<!ENTITY external.description "Þetta er utanáliggjandi síu áskrift, síulistinn verður uppfærður af viðbótinni sem bjó til þessa áskrift.">
+<!ENTITY title.label "Áskriftartitill:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Staðsetning síulista:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Uppfæra sjálfvirkt">
+<!ENTITY autodownload.accesskey "U">
+<!ENTITY supplementMessage "Þessi síu áskrift er ætluð til þess að vera notuð með síu áskrift &quot;?1?&quot; sem þú hefur ekki ennþá bætt við.">
+<!ENTITY addMain.label "Bættu einnig við síu áskrift &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "s">

=== added directory 'chrome/locale/it'
=== removed directory 'chrome/locale/it-IT'
=== removed file 'chrome/locale/it-IT/about.dtd'
--- chrome/locale/it-IT/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/it-IT/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-<!ENTITY dialog.title "Informazioni su Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Versione">
-<!ENTITY description "
-		Adblock Plus permette di decidere cosa vedere sul web. Non sarà più
-	necessario caricare pubblicità e/o banner indesiderati, grazie
-	ad Adblock Plus!
-">
-<!ENTITY homepage.label "Sito web di Adblock Plus:">
-<!ENTITY homepage.url "http://adblockplus.org/en/">
-<!ENTITY author.label "Autore:">
-<!ENTITY contributors.label "Collaboratori:">

=== removed file 'chrome/locale/it-IT/composer.dtd'
--- chrome/locale/it-IT/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/it-IT/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,52 +0,0 @@
-<!ENTITY dialog.title "Nuovo filtro di Adblock Plus">
-<!ENTITY accept.label "Aggiungi filtro">
-<!ENTITY advanced.label "Avanzate &gt;&gt;">
-<!ENTITY basic.label "&lt;&lt; Generali">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus è attualmente disattivata. È comunque possibile aggiungere filtri, ma questi verranno applicati solo dopo la">
-<!ENTITY disabled.warning.link "riattivazione di Adblock Plus">
-<!ENTITY disabled.warning.afterLink " ">
-<!ENTITY groupDisabled.warning.beforeLink "Il gruppo di filtri &quot;&#37;S&quot; al quale bisognerebbe aggiungere il filtro è attualmente disattivato. È comunque possibile aggiungere il filtro, ma questo verrà applicato solo dopo la ">
-<!ENTITY groupDisabled.warning.link "riattivazione del gruppo di filtri ">
-<!ENTITY groupDisabled.warning.afterLink " ">
-<!ENTITY filter.label "Nuovo filtro:">
-<!ENTITY filter.accesskey "N">
-<!ENTITY preferences.label "Mostra i filtri esistenti…">
-<!ENTITY preferences.accesskey "M">
-<!ENTITY type.filter.label "Filtri per bloccare">
-<!ENTITY type.filter.accesskey "b">
-<!ENTITY type.whitelist.label "Eccezioni">
-<!ENTITY type.whitelist.accesskey "E">
-<!ENTITY pattern.label "Modelli">
-<!ENTITY pattern.explanation "Il modello può corrispondere a qualsiasi parte dell&apos;indirizzo web, il carattere * corrisponde ad un carattere jolly. Il filtro verrà applicato ai soli indirizzi web corrispondenti al modello">
-<!ENTITY regexp.warning "Il modello inserito verrà interpretato come espressione regolare. Un numero eccessivo di tali modelli potrebbe rallentare la navigazione. Se non si intende utilizzare le espressioni regolari aggiungere il carattere * alla fine del modello">
-<!ENTITY shortpattern.warning "Il modello inserito è troppo breve per essere ottimizzato. Un numero eccessivo di tali modelli potrebbe rallentare la navigazione. Sarebbe preferibile utilizzare una stringa più lunga">
-<!ENTITY custom.pattern.label "Personalizza:">
-<!ENTITY custom.pattern.accesskey "P">
-<!ENTITY anchors.label "Accetta modelli solo:">
-<!ENTITY anchor.start.label "all&apos;inizio dell&apos;indirizzo web">
-<!--  Note: This access key should usually be the same as anchor.start.flexible.accesskey. It is the same checkbox with different label depending on suggested filter. -->
-<!ENTITY anchor.start.accesskey "i">
-<!ENTITY anchor.start.flexible.label "all&apos;inizio del nome del dominio">
-<!--  Note: This access key should usually be the same as anchor.start.accesskey. It is the same checkbox with different label depending on suggested filter. -->
-<!ENTITY anchor.start.flexible.accesskey "i">
-<!ENTITY anchor.end.label "alla fine dell&apos;indirizzo web">
-<!ENTITY anchor.end.accesskey "f">
-<!ENTITY options.label "Opzioni">
-<!ENTITY domainRestriction.label "Limita al dominio qui sotto">
-<!ENTITY domainRestriction.accesskey "t">
-<!ENTITY domainRestriction.help "È possibile specificare uno o più dominii separandoli con il carattere &quot;|&quot;: il filtro verrà applicato solamente a tali dominii (si noti che il carattere &quot;~&quot; prima del nome di un dominio significa che il filtro non verrà applicato per tale dominio)">
-<!ENTITY firstParty.label "Solo dominii di primo livello">
-<!ENTITY firstParty.accesskey "d">
-<!ENTITY thirdParty.label "Solo dominii non di primo livello">
-<!ENTITY thirdParty.accesskey "S">
-<!ENTITY matchCase.label "Maiuscole/minuscole">
-<!ENTITY matchCase.accesskey "u">
-<!ENTITY types.label "Applica ai tipi:">
-<!ENTITY selectAllTypes.label "Seleziona tutti">
-<!ENTITY unselectAllTypes.label "Deseleziona">
-<!ENTITY collapse.label "Contrai bloccati:">
-<!ENTITY collapse.accesskey "l">
-<!ENTITY collapse.default.yes.label "Utilizza predefiniti (sì)">
-<!ENTITY collapse.default.no.label "Utilizza predefiniti (no)">
-<!ENTITY collapse.yes.label "Sì">
-<!ENTITY collapse.no.label "No">

=== removed file 'chrome/locale/it-IT/global.properties'
--- chrome/locale/it-IT/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/it-IT/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Permette di dire 'no' alla pubblicità presente nelle pagine web!
-status_active_label=Adblock Plus
-status_disabled_label=Inattiva
-action0_tooltip=Fare clic per sollevare il menu contestuale, clic centrale per attivare/disattivare
-action1_tooltip=Fare clic per aprire/chiudere la finestra degli elementi bloccabili, clic centrale per attivare/disattivare
-action2_tooltip=Fare clic per aprire la finestra delle impostazioni, clic centrale per attivare/disattivare
-action3_tooltip=Fare clic per attivare/disattivare Adblock Plus
-active_tooltip=Adblock Plus è attiva
-disabled_tooltip=Adblock Plus è disattivata
-whitelisted_tooltip=Adblock Plus è attiva ma è stata disattivata per la pagina attuale
-blocked_count_tooltip=-- di --
-no_blocking_suggestions=Nessun elemento bloccabile nella pagina attuale
-whitelisted_page=Adblock Plus è stata disattivata per la pagina attuale
-whitelist_description=Da escludere
-filterlist_description=Da filtrare
-invalid_description=Filtri non validi
-elemhide_description=Elemento da escludere dalle regole
-subscription_description=Filtri da sottoscrivere:
-subscription_wrong_version=Alcuni filtri in questa sottoscrizione richiedono Adblock Plus -- per funzionare correttamente
-subscription_source=Fonte:
-subscription_status=Stato:
-subscription_status_autodownload=Aggiornati automaticamente
-subscription_status_manualdownload=Aggiornati manualmente
-subscription_status_externaldownload=Aggiornati esternamente (da un'altra estensione)
-subscription_status_lastdownload=Ultimo aggiornamento:
-subscription_status_lastdownload_inprogress=Download in corso…
-subscription_status_lastdownload_unknown=Sconosciuto
-remove_subscription_warning=Eliminare questa sottoscrizione?
-import_filters_wrong_version=Alcuni filtri in questa lista richiedono Adblock Plus -- per funzionare correttamente
-import_filters_warning=Sovrascrivere gli attuali elementi della lista?\nSelezionare 'Sovrascrivi' per sovrascrivere o 'Unisci' per unire
-import_filters_title=Importa lista dei filtri
-export_filters_title=Esporta lista dei filtri
-invalid_filters_file=Il file della lista dei filtri non è valido
-filters_write_error=Si sono verificati alcuni errori di scrittura del file della lista dei filtri. Accertarsi che il file non sia di sola lettura oppure in uso da parte di un altro programma
-clearall_warning=Eliminare tutti gli elementi della lista?
-resethitcounts_warning=Azzerare le statistiche per tutti i filtri? L'operazione non potrà essere annullata
-resethitcounts_selected_warning=Azzerare davvero le statistiche per i filtri selezionati? L'operazione non potrà essere annullata
-filter_regexp_tooltip=Il filtro inserito verrà interpretato come un'espressione regolare. Un numero eccessivo di tali filtri potrebbe rallentare la navigazione
-filter_elemhide_duplicate_id=È possibile specificare solo un ID dell'elemento da nascondere
-filter_elemhide_nocriteria=Non è stato specificato alcun criterio per rilevare l'elemento da nascondere
-subscription_no_location=Inserire l'indirizzo dal quale effettuare il download della lista dei filtri
-subscription_invalid_location=L'indirizzo della lista dei filtri non è nè un indirizzo web valido nè un nome di file valido
-subscription_location_exists=Esiste già una sottoscrizione per questa lista
-synchronize_invalid_url=Sincronizzazione non riuscita, indirizzo web non valido
-synchronize_connection_error=Sincronizzazione non riuscita, errore durante il download
-synchronize_invalid_data=Sincronizzazione non riuscita, lista dei filtri non valida
-synchronize_checksum_mismatch=Sincronizzazione non riuscita, checksum non corrispondente
-synchronize_ok=Sincronizzazione effettuata con successo
-overwrite=Sovrascrivi
-append=Unisci
-new_filter_group_title=Nuovo filtro
-type_label_other=altro
-type_label_script=script
-type_label_image=immagine
-type_label_stylesheet=foglio di stile
-type_label_object=oggetto
-type_label_subdocument=riquadro
-type_label_document=documento
-type_label_background=sfondo
-type_label_elemhide=nascosto
-type_label_xbl=XBL binding
-type_label_ping=ping al link
-type_label_xmlhttprequest=richiesta XML
-type_label_object_subrequest=oggetto sottorichiesto
-type_label_dtd=file dtd
-type_label_media=audio/video 
-type_label_font=carattere

=== removed file 'chrome/locale/it-IT/overlay.dtd'
--- chrome/locale/it-IT/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/it-IT/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,24 +0,0 @@
-<!ENTITY status.tooltip "Stato:">
-<!ENTITY blocked.tooltip "Elementi bloccati nella pagina attuale:">
-<!ENTITY filters.tooltip "Filtri maggiormente attivi:">
-<!ENTITY menuitem.label "Impostazioni di Adblock Plus">
-<!ENTITY menuitem.accesskey "A">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Elementi bloccabili con Adblock Plus">
-<!ENTITY context.image.label "Blocca immagine con Adblock Plus">
-<!ENTITY context.object.label "Blocca oggetto con Adblock Plus">
-<!ENTITY context.frame.label "Blocca riquadro con Adblock Plus">
-<!ENTITY context.removeWhitelist.label "Riattiva Adblock Plus nella pagina attuale">
-<!ENTITY sidebar.title "Elementi bloccabili della pagina attuale">
-<!ENTITY settings.label "Impostazioni">
-<!ENTITY settings.accesskey "I">
-<!ENTITY opensidebar.label "Apri gli elementi bloccabili">
-<!--  Note: This access key should usually be the same as closesidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open. -->
-<!ENTITY opensidebar.accesskey "b">
-<!ENTITY closesidebar.label "Chiudi gli elementi bloccabili">
-<!--  Note: This access key should usually be the same as opensidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open. -->
-<!ENTITY closesidebar.accesskey "b">
-<!ENTITY whitelist.site.label "Disattiva per --">
-<!ENTITY whitelist.page.label "Disattiva solo per la pagina attuale">
-<!ENTITY objecttab.title "Blocca">
-<!ENTITY objecttab.tooltip "Fare clic qui per bloccare l&apos;oggetto con Adblock Plus">

=== removed file 'chrome/locale/it-IT/settings.dtd'
--- chrome/locale/it-IT/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/it-IT/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Impostazioni di Adblock Plus">
-<!ENTITY filters.label "Filtri">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Aggiungi filtro">
-<!ENTITY add.accesskey "A">
-<!ENTITY addsubscription.label "Aggiungi sottoscrizione">
-<!ENTITY addsubscription.accesskey "u">
-<!ENTITY synchsubscriptions.label "Aggiorna tutte le sottoscrizioni">
-<!ENTITY synchsubscriptions.accesskey "t">
-<!ENTITY import.label "Importa lista dei filtri">
-<!ENTITY import.accesskey "m">
-<!ENTITY export.label "Esporta filtri personalizzati">
-<!ENTITY export.accesskey "s">
-<!ENTITY clearall.label "Elimina tutti i filtri personalizzati">
-<!ENTITY clearall.accesskey "E">
-<!ENTITY resethitcounts.label "Ripristina le statistiche di accesso">
-<!ENTITY resethitcounts.accesskey "R">
-<!ENTITY edit.label "Modifica">
-<!ENTITY edit.accesskey "M">
-<!ENTITY cut.label "Taglia">
-<!ENTITY cut.accesskey "T">
-<!ENTITY copy.label "Copia">
-<!ENTITY copy.accesskey "C">
-<!ENTITY paste.label "Incolla">
-<!ENTITY paste.accesskey "I">
-<!ENTITY remove.label "Elimina">
-<!ENTITY remove.accesskey "E">
-<!ENTITY menu.find.label "Trova">
-<!ENTITY menu.find.accesskey "v">
-<!ENTITY menu.findagain.label "Trova successivo">
-<!ENTITY menu.findagain.accesskey "u">
-<!ENTITY view.label "Visualizza">
-<!ENTITY view.accesskey "V">
-<!ENTITY sort.label "Ordina">
-<!ENTITY sort.accesskey "O">
-<!ENTITY sort.none.label "Non ordinate">
-<!ENTITY sort.none.accesskey "d">
-<!ENTITY sort.ascending.label "Ordina A &gt; Z">
-<!ENTITY sort.ascending.accesskey "r">
-<!ENTITY sort.descending.label "Ordina Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Opzioni">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Attiva Adblock Plus">
-<!ENTITY enable.accesskey "P">
-<!ENTITY showintoolbar.label "Visualizza nella barra degli strumenti">
-<!ENTITY showintoolbar.accesskey "b">
-<!ENTITY showinstatusbar.label "Visualizza nella barra di stato">
-<!ENTITY showinstatusbar.accesskey "s">
-<!ENTITY objecttabs.label "Mostra linguetta per elementi Flash e Java">
-<!ENTITY objecttabs.accesskey "t">
-<!ENTITY collapse.label "Nascondi elementi bloccati">
-<!ENTITY collapse.accesskey "e">
-<!ENTITY help.label "?">
-<!ENTITY help.accesskey "?">
-<!ENTITY gettingStarted.label "Come iniziare">
-<!ENTITY gettingStarted.accesskey "C">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "FAQ di Adblock Plus">
-<!ENTITY faq.accesskey "F">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Scrittura dei filtri di Adblock Plus">
-<!ENTITY filterdoc.accesskey "k">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Informazioni su Adblock Plus">
-<!ENTITY about.accesskey "z">
-<!ENTITY description "I filtri presenti nel riquadro qui sotto determinano gli indirizzi web da permettere oppure da bloccare">
-<!ENTITY filter.column "Ruolo del filtro">
-<!ENTITY filter.accesskey "f">
-<!ENTITY slow.column "Filtri lenti">
-<!ENTITY slow.accesskey "l">
-<!ENTITY enabled.column "Attivato">
-<!ENTITY enabled.accesskey "t">
-<!ENTITY hitcount.column "Accessi">
-<!ENTITY hitcount.accesskey "A">
-<!ENTITY lasthit.column "Ultimo accesso">
-<!ENTITY lasthit.accesskey "U">
-<!ENTITY context.edit.label "Modifica filtro">
-<!ENTITY context.resethitcount.label "Ripristina le statistiche di accesso per il filtro">
-<!ENTITY context.synchsubscription.label "Aggiorna la sottoscrizione ora">
-<!ENTITY context.editsubscription.label "Modifica la sottoscrizione">
-<!ENTITY context.moveup.label "Sposta il filtro su">
-<!ENTITY context.movedown.label "Sposta il filtro giù">
-<!ENTITY context.movegroupup.label "Sposta il gruppo su">
-<!ENTITY context.movegroupdown.label "Sposta il gruppo giù">
-<!ENTITY context.enable.label "Attiva">
-<!ENTITY context.disable.label "Disattiva">
-<!ENTITY apply.label "Applica">
-<!ENTITY apply.accesskey "c">

=== removed file 'chrome/locale/it-IT/sidebar.dtd'
--- chrome/locale/it-IT/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/it-IT/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Elementi bloccabili con Adblock Plus (separati)">
-<!ENTITY detach.label "Separa">
-<!ENTITY reattach.label "Riunisci">
-<!ENTITY search.label "Cerca:">
-<!ENTITY search.accesskey "C">
-<!ENTITY type.label "Tipo">
-<!ENTITY address.label "Indirizzo">
-<!ENTITY filter.label "Filtro">
-<!ENTITY state.label "Stato">
-<!ENTITY size.label "Dimensione">
-<!ENTITY docDomain.label "Sorgente">
-<!ENTITY noitems.label "Nessun elemento bloccabile">
-<!ENTITY whitelisted.label "Pagina in lista di siti permessi">
-<!ENTITY tooltip.address.label "Indirizzo web:">
-<!ENTITY tooltip.type.label "Tipo:">
-<!ENTITY tooltip.type.blocked "(bloccato)">
-<!ENTITY tooltip.type.whitelisted "(in lista di siti permessi)">
-<!ENTITY tooltip.size.label "Dimensione:">
-<!ENTITY tooltip.docDomain.label "Sorgente del documento:">
-<!ENTITY tooltip.filter.label "Filtro effettivo:">
-<!ENTITY tooltip.filterSource.label "Sorgente del filtro:">
-<!ENTITY context.block.label "Blocca questo elemento">
-<!ENTITY context.editfilter.label "Modifica il filtro in effetto">
-<!ENTITY context.whitelist.label "Aggiungi un&apos;eccezione per l&apos;elemento">
-<!ENTITY context.disablefilter.label "Disattiva il filtro --">
-<!ENTITY context.enablefilter.label "Riattiva il filtro --">
-<!ENTITY context.disablefilteronsite.label "Disattiva il filtro per --">
-<!ENTITY context.open.label "Apri in una nuova scheda">
-<!ENTITY context.flash.label "Fai lampeggiare il contorno dell&apos;elemento selezionato">
-<!ENTITY context.copy.label "Copia l&apos;indirizzo web dell&apos;elemento">
-<!ENTITY context.copyFilter.label "Copia il filtro">
-<!ENTITY context.selectAll.label "Seleziona tutto">

=== removed file 'chrome/locale/it-IT/subscription.dtd'
--- chrome/locale/it-IT/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/it-IT/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,29 +0,0 @@
-<!ENTITY dialog.title "Modifica sottoscrizione">
-<!ENTITY dialog.newtitle "Nuova sottoscrizione">
-<!ENTITY new.description "
-		Inserire l&apos;indirizzo web oppure il percorso del file contenente la
-	lista dei filtri per Adblock Plus.
-">
-<!ENTITY edit.description "
-		Il download della lista dei filtri per questa sottoscrizione verrà
-	avviato dall&apos;indirizzo dato
-">
-<!ENTITY external.description "
-		Questa è una sottoscrizione esterna, la relativa lista dei filtri
-	sarà mantenuta aggiornata dall&apos;estensione che ha creato questa
-	sottoscrizione
-">
-<!ENTITY autodownload.description "
-		Selezionando &apos;Aggiorna automaticamente&apos; l&apos;indirizzo verrà
-	controllato quotidianamente, mentre disattivando questa opzione
-	sarà possibile aggiornare manualmente tramite il menu contestuale
-	delle sottoscrizioni
-">
-<!ENTITY location.label "URL/percorso della lista dei filtri:">
-<!ENTITY location.accesskey "U">
-<!ENTITY title.label "Titolo della sottoscrizione:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Aggiorna automaticamente">
-<!ENTITY autodownload.accesskey "A">
-<!ENTITY enabled.label "Attiva i filtri">
-<!ENTITY enabled.accesskey "f">

=== removed file 'chrome/locale/it-IT/tip_subscriptions.dtd'
--- chrome/locale/it-IT/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/it-IT/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,41 +0,0 @@
-<!ENTITY dialog.title "Nuova sottoscrizione di Adblock Plus">
-<!ENTITY description.par1 "
-		Grazie per aver installato Adblock Plus. Questa estensione può 
-	eliminare il 99&#37; della pubblicità in internet. Tuttavia, per 
-	filtrare efficacemente la pubblicità si deve definire una buona 
-	serie di filtri. Lo si può fare da soli o si può semplicemente 
-	sottoscrivere le liste dei filtri mantenute da terzi. È possibile 
-	aggiungere i propri filtri così come disattivare/eliminare le
-	sottoscrizioni quando necessario
-">
-<!ENTITY description.par2 "
-		Qui c&apos;è una lista di sottoscrizioni consigliate 
-	fra le quali scegliere (possono essere aggiunte più sottoscrizioni tramite 
-	la finestra delle impostazioni di Adblock Plus nonostante ciò di
-	solito non sia necessario):
-">
-<!ENTITY note "
-		Nota: una lista di filtri è in genere più efficace quando la si applica
-	ai siti web della zona per la quale viene creata la lista dei filtri
-">
-<!ENTITY adblock.warning "
-	Adblock Plus ha rilevato la presenza di Adblock oppure di una versione 
-	precedente di Adblock Plus fra le estensioni installate. Si raccomanda 
-	di disinstallare qualsiasi precedente versione
-">
-<!ENTITY adblock.uninstall "Disinstalla Adblock">
-<!ENTITY filterset.g.warning "
-	Adblock Plus ha rilevato la presenza di Filterset.G, la cui lista di filtri è
-	stata mantenuta a malapena negli ultimi anni ed attualmente è causa comune di
-	problemi con i siti web. Si raccomanda di disinstallare Filterset.G
-">
-<!ENTITY filterset.g.moreinfo "Ulteriori informazioni">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Disinstalla Filterset.G">
-<!ENTITY homepage.label "Sito web">
-<!ENTITY subscribe.label "Sottoscrivi">
-<!ENTITY subscribe.accesskey "S">
-<!ENTITY other.label "Nuova sottoscrizione…">
-<!ENTITY other.accesskey "N">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Visualizza tutte le sottoscrizioni">

=== added file 'chrome/locale/it/about.dtd'
--- chrome/locale/it/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/it/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,16 @@
+<!ENTITY dialog.title "Informazioni su Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "versione">
+<!ENTITY description "
+	Adblock Plus permette di decidere cosa vedere sul web. Non sarà più
+	necessario caricare pubblicità e/o banner indesiderati, grazie
+	ad Adblock Plus!
+">
+<!ENTITY homepage.label "Sito web di Adblock Plus">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "Autore">
+<!ENTITY contributors.label "Collaboratori">
+<!ENTITY developers.label "Sviluppatori:">
+<!ENTITY designers.label "Disegnatori grafici:">
+<!ENTITY subscriptionAuthors.label "Autori dei filtri delle sottoscrizioni:">
+<!ENTITY translators.label "Traduttori:">

=== added file 'chrome/locale/it/composer.dtd'
--- chrome/locale/it/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/it/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Nuovo filtro di Adblock Plus">
+<!ENTITY accept.label "Aggiungi filtro">
+<!ENTITY advanced.label "Avanzate &gt;&gt;">
+<!ENTITY basic.label "&lt;&lt; Generali">
+<!ENTITY disabled.warning "Adblock Plus è attualmente disattivata. È comunque possibile aggiungere filtri, ma questi verranno applicati solo dopo la [link]riattivazione di Adblock Plus[/link]">
+<!ENTITY groupDisabled.warning "Il gruppo di filtri &quot;?1?&quot; al quale bisognerebbe aggiungere il filtro è attualmente disattivato. È comunque possibile aggiungere il filtro, ma questo verrà applicato solo dopo la [link]riattivazione del gruppo di filtri[/link]">
+<!ENTITY filter.label "Nuovo filtro:">
+<!ENTITY filter.accesskey "N">
+<!ENTITY preferences.label "Mostra i filtri esistenti…">
+<!ENTITY preferences.accesskey "M">
+<!ENTITY type.filter.label "Filtri per bloccare">
+<!ENTITY type.filter.accesskey "b">
+<!ENTITY type.whitelist.label "Eccezioni">
+<!ENTITY type.whitelist.accesskey "E">
+<!ENTITY pattern.label "Modelli">
+<!ENTITY pattern.explanation "Il modello può corrispondere a qualsiasi parte dell&apos;indirizzo web, il carattere * corrisponde ad un carattere jolly. Il filtro verrà applicato ai soli indirizzi web corrispondenti al modello">
+<!ENTITY regexp.warning "Il modello inserito verrà interpretato come espressione regolare. Un numero eccessivo di tali modelli potrebbe rallentare la navigazione. Se non si intende utilizzare le espressioni regolari aggiungere il carattere * alla fine del modello">
+<!ENTITY shortpattern.warning "Il modello inserito è troppo breve per essere ottimizzato. Un numero eccessivo di tali modelli potrebbe rallentare la navigazione. Sarebbe preferibile utilizzare una stringa più lunga">
+<!ENTITY custom.pattern.label "Personalizza:">
+<!ENTITY custom.pattern.accesskey "P">
+<!ENTITY anchors.label "Accetta modelli solo:">
+<!ENTITY anchor.start.label "all&apos;inizio dell&apos;indirizzo web">
+<!ENTITY anchor.start.accesskey "i">
+<!ENTITY anchor.start.flexible.label "all&apos;inizio del nome del dominio">
+<!ENTITY anchor.start.flexible.accesskey "i">
+<!ENTITY anchor.end.label "alla fine dell&apos;indirizzo web">
+<!ENTITY anchor.end.accesskey "f">
+<!ENTITY options.label "Opzioni">
+<!ENTITY domainRestriction.label "Limita al dominio qui sotto">
+<!ENTITY domainRestriction.accesskey "t">
+<!ENTITY domainRestriction.help "È possibile specificare uno o più dominii separandoli con il carattere &quot;|&quot;: il filtro verrà applicato solamente a tali dominii (si noti che il carattere &quot;~&quot; prima del nome di un dominio significa che il filtro non verrà applicato per tale dominio)">
+<!ENTITY firstParty.label "Solo dominii di primo livello">
+<!ENTITY firstParty.accesskey "d">
+<!ENTITY thirdParty.label "Solo dominii non di primo livello">
+<!ENTITY thirdParty.accesskey "S">
+<!ENTITY matchCase.label "Maiuscole/minuscole">
+<!ENTITY matchCase.accesskey "u">
+<!ENTITY types.label "Applica ai tipi:">
+<!ENTITY selectAllTypes.label "Seleziona tutti">
+<!ENTITY unselectAllTypes.label "Deseleziona">
+<!ENTITY collapse.label "Contrai bloccati:">
+<!ENTITY collapse.accesskey "l">
+<!ENTITY collapse.default.yes.label "Utilizza predefiniti (sì)">
+<!ENTITY collapse.default.no.label "Utilizza predefiniti (no)">
+<!ENTITY collapse.yes.label "Sì">
+<!ENTITY collapse.no.label "No">

=== added file 'chrome/locale/it/global.properties'
--- chrome/locale/it/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/it/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Fare clic per sollevare il menu contestuale, clic centrale per attivare/disattivare
+action1_tooltip=Fare clic per aprire/chiudere la finestra degli elementi bloccabili, clic centrale per attivare/disattivare
+action2_tooltip=Fare clic per aprire la finestra delle impostazioni, clic centrale per attivare/disattivare
+action3_tooltip=Fare clic per attivare/disattivare Adblock Plus
+disabled_tooltip=Adblock Plus è disattivata
+active_tooltip=Adblock Plus è attiva (sottoscrizioni di filtri in uso: ?1?, filtri in uso: ?2?)
+whitelisted_tooltip=Adblock Plus è attiva ma è stata disattivata per la pagina attuale
+blocked_count_tooltip=?1? di ?2?
+blocked_count_addendum=(elementi permessi: ?1?, elementi nascosti: ?2?)
+no_blocking_suggestions=Nessun elemento bloccabile nella pagina attuale
+whitelisted_page=Adblock Plus è stata disattivata per la pagina attuale
+whitelist_description=Elementi da permettere
+filterlist_description=Elementi da bloccare
+invalid_description=Elementi non validi
+elemhide_description=Elementi da nascondere
+subscription_description=Elementi della sottoscrizione
+subscription_wrong_version=Alcuni filtri in questa sottoscrizione richiedono Adblock Plus ?1? per funzionare correttamente
+subscription_source=Fonte:
+subscription_status=Stato:
+subscription_status_autodownload=Aggiornati automaticamente
+subscription_status_manualdownload=Aggiornati manualmente
+subscription_status_externaldownload=Aggiornati esternamente (da un'altra estensione)
+subscription_status_lastdownload=Ultimo aggiornamento:
+subscription_status_lastdownload_inprogress=Download in corso…
+subscription_status_lastdownload_unknown=Sconosciuto
+remove_subscription_warning=Eliminare questa sottoscrizione?
+import_filters_wrong_version=Alcuni filtri in questa lista richiedono Adblock Plus ?1? per funzionare correttamente
+import_filters_warning=Sovrascrivere gli attuali elementi della lista?\nSelezionare 'Sovrascrivi' per sovrascrivere o 'Unisci' per unire
+import_filters_title=Importa lista dei filtri
+export_filters_title=Esporta lista dei filtri
+invalid_filters_file=Il file della lista dei filtri non è valido
+filters_write_error=Si sono verificati alcuni errori di scrittura del file della lista dei filtri. Accertarsi che il file non sia di sola lettura oppure in uso da parte di un altro programma
+clearall_warning=Eliminare tutti gli elementi della lista?
+resethitcounts_warning=Azzerare le statistiche per tutti i filtri? L'operazione non potrà essere annullata
+resethitcounts_selected_warning=Azzerare le statistiche per i filtri selezionati? L'operazione non potrà essere annullata
+filter_regexp_tooltip=Il filtro inserito verrà interpretato come un'espressione regolare. Un numero eccessivo di tali filtri potrebbe rallentare la navigazione
+filter_elemhide_duplicate_id=È possibile specificare solo un ID dell'elemento da nascondere
+filter_elemhide_nocriteria=Non è stato specificato alcun criterio per rilevare l'elemento da nascondere
+subscription_notAdded_warning=Non è stata selezionata alcuna sottoscrizione di filtri, per cui sarà necessario aggiungere in seguito manualmente i filtri ad Adblock Plus.
+subscription_notAdded_warning_addendum=Procedere comunque?
+subscription_invalid_location=Attenzione: per poter aggiungere una sottoscrizione è necessario che i campi 'Titolo della sottoscrizione:' ed 'Indirizzo della lista dei filtri:' non siano lasciati vuoti e corrispondano a nomi di file validi. Inserire tali dati e ripetere la procedura
+synchronize_invalid_url=Sincronizzazione non riuscita, indirizzo web non valido
+synchronize_connection_error=Sincronizzazione non riuscita, errore durante il download
+synchronize_invalid_data=Sincronizzazione non riuscita, lista dei filtri non valida
+synchronize_checksum_mismatch=Sincronizzazione non riuscita, checksum non corrispondente
+synchronize_ok=Sincronizzazione effettuata con successo
+overwrite=Sovrascrivi
+append=Unisci
+new_filter_group_title=Nuovo filtro
+type_label_other=altro
+type_label_script=script
+type_label_image=immagine
+type_label_stylesheet=foglio di stile
+type_label_object=oggetto
+type_label_subdocument=riquadro
+type_label_document=documento
+type_label_background=sfondo
+type_label_elemhide=nascosto
+type_label_xbl=XBL binding
+type_label_ping=ping al link
+type_label_xmlhttprequest=richiesta XML
+type_label_object_subrequest=oggetto sottorichiesto
+type_label_dtd=file dtd
+type_label_media=audio/video 
+type_label_font=carattere
+fennec_status_enabled=Adblock Plus è attiva
+fennec_status_disabled=Adblock Plus è disattivata
+fennec_status_enabled_site=Adblock Plus è attiva per ?1?
+fennec_status_disabled_site=Adblock Plus è disattivata per ?1?

=== added file 'chrome/locale/it/meta.properties'
--- chrome/locale/it/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/it/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Luana Di Muzio
+name=Adblock Plus
+description=Permette di dire 'no' alla pubblicità presente nelle pagine web!
+description.short=Infastiditi da pubblicità, banner o da possibili tracciature? Installando Adblock Plus è possibile cambiare il modo in cui si naviga sul web!\n\nPer una rapida anteprima video in inglese visitare http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus permette di riprendere il controllo di internet e cambiare il modo in cui si naviga sul web! È possibile sia scegliere fra più di quaranta sottoscrizioni di filtri in svariate lingue che si configurano automaticamente per spaziare dall'eliminazione della pubblicità presente nelle pagine web al blocco di tutti i domini noti per essere pericolosi (in quanto contenenti potenzialmente dialer, virus, etc), sia personalizzare i filtri tramite svariate funzioni utili, tra cui voci di menu contestuale per bloccare immagini/oggetti/riquadri/video/audio, una linguetta per bloccare elementi Flash e Java ed infine una finestra -separabile- contenente gli elementi bloccabili per gestire script e fogli di stile

=== added file 'chrome/locale/it/overlay.dtd'
--- chrome/locale/it/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/it/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Stato">
+<!ENTITY blocked.tooltip "Elementi bloccati nella pagina attuale">
+<!ENTITY filters.tooltip "Filtri maggiormente attivi">
+<!ENTITY menuitem.label "Impostazioni di Adblock Plus">
+<!ENTITY menuitem.accesskey "A">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Elementi bloccabili con Adblock Plus">
+<!ENTITY context.image.label "Blocca immagine con Adblock Plus">
+<!ENTITY context.object.label "Blocca oggetto con Adblock Plus">
+<!ENTITY context.frame.label "Blocca riquadro con Adblock Plus">
+<!ENTITY context.media.label "Blocca video/audio con Adblock Plus">
+<!ENTITY context.removeWhitelist.label "Riattiva Adblock Plus nella pagina attuale">
+<!ENTITY sidebar.title "Elementi bloccabili della pagina attuale">
+<!ENTITY settings.label "Impostazioni">
+<!ENTITY settings.accesskey "I">
+<!ENTITY opensidebar.label "Apri gli elementi bloccabili">
+<!ENTITY opensidebar.accesskey "b">
+<!ENTITY closesidebar.label "Chiudi gli elementi bloccabili">
+<!ENTITY closesidebar.accesskey "b">
+<!ENTITY whitelist.site.label "Disattiva per ?1?">
+<!ENTITY whitelist.page.label "Disattiva solo per la pagina attuale">
+<!ENTITY objecttab.title "Blocca">
+<!ENTITY objecttab.tooltip "Fare clic qui per bloccare l&apos;oggetto con Adblock Plus">

=== added file 'chrome/locale/it/settings.dtd'
--- chrome/locale/it/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/it/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Impostazioni di Adblock Plus">
+<!ENTITY filters.label "Filtri">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Aggiungi filtro">
+<!ENTITY add.accesskey "A">
+<!ENTITY addsubscription.label "Aggiungi sottoscrizione">
+<!ENTITY addsubscription.accesskey "u">
+<!ENTITY synchsubscriptions.label "Aggiorna tutte le sottoscrizioni">
+<!ENTITY synchsubscriptions.accesskey "t">
+<!ENTITY import.label "Importa lista dei filtri">
+<!ENTITY import.accesskey "m">
+<!ENTITY export.label "Esporta filtri personalizzati">
+<!ENTITY export.accesskey "s">
+<!ENTITY clearall.label "Elimina tutti i filtri personalizzati">
+<!ENTITY clearall.accesskey "E">
+<!ENTITY resethitcounts.label "Ripristina le statistiche di accesso">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "Modifica">
+<!ENTITY edit.accesskey "M">
+<!ENTITY cut.label "Taglia">
+<!ENTITY cut.accesskey "T">
+<!ENTITY copy.label "Copia">
+<!ENTITY copy.accesskey "C">
+<!ENTITY paste.label "Incolla">
+<!ENTITY paste.accesskey "I">
+<!ENTITY remove.label "Elimina">
+<!ENTITY remove.accesskey "E">
+<!ENTITY menu.find.label "Trova">
+<!ENTITY menu.find.accesskey "v">
+<!ENTITY menu.findagain.label "Trova successivo">
+<!ENTITY menu.findagain.accesskey "u">
+<!ENTITY view.label "Visualizza">
+<!ENTITY view.accesskey "V">
+<!ENTITY sort.label "Ordina">
+<!ENTITY sort.accesskey "O">
+<!ENTITY sort.none.label "Non ordinare">
+<!ENTITY sort.none.accesskey "d">
+<!ENTITY sort.ascending.label "Ordina A &gt; Z">
+<!ENTITY sort.ascending.accesskey "r">
+<!ENTITY sort.descending.label "Ordina Z &gt; A">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Opzioni">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Attiva Adblock Plus">
+<!ENTITY enable.accesskey "P">
+<!ENTITY showintoolbar.label "Visualizza nella barra degli strumenti">
+<!ENTITY showintoolbar.accesskey "b">
+<!ENTITY showinstatusbar.label "Visualizza nella barra di stato">
+<!ENTITY showinstatusbar.accesskey "s">
+<!ENTITY objecttabs.label "Mostra linguetta per elementi Flash e Java">
+<!ENTITY objecttabs.accesskey "t">
+<!ENTITY collapse.label "Nascondi elementi bloccati">
+<!ENTITY collapse.accesskey "e">
+<!ENTITY help.label "?">
+<!ENTITY help.accesskey "?">
+<!ENTITY gettingStarted.label "Come iniziare">
+<!ENTITY gettingStarted.accesskey "C">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "FAQ di Adblock Plus">
+<!ENTITY faq.accesskey "F">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Scrittura dei filtri di Adblock Plus">
+<!ENTITY filterdoc.accesskey "k">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Informazioni su Adblock Plus">
+<!ENTITY about.accesskey "z">
+<!ENTITY description "I filtri presenti nel riquadro qui sotto determinano gli elementi da permettere/bloccare/nascondere oppure delle liste di sottoscrizione">
+<!ENTITY filter.column "Ruolo del filtro">
+<!ENTITY filter.accesskey "f">
+<!ENTITY slow.column "Filtri lenti">
+<!ENTITY slow.accesskey "l">
+<!ENTITY enabled.column "Attivato">
+<!ENTITY enabled.accesskey "t">
+<!ENTITY hitcount.column "Accessi">
+<!ENTITY hitcount.accesskey "A">
+<!ENTITY lasthit.column "Ultimo accesso">
+<!ENTITY lasthit.accesskey "U">
+<!ENTITY context.edit.label "Modifica filtro">
+<!ENTITY context.resethitcount.label "Ripristina le statistiche di accesso per il filtro">
+<!ENTITY context.synchsubscription.label "Aggiorna la sottoscrizione ora">
+<!ENTITY context.editsubscription.label "Modifica la sottoscrizione">
+<!ENTITY context.moveup.label "Sposta il filtro su">
+<!ENTITY context.movedown.label "Sposta il filtro giù">
+<!ENTITY context.movegroupup.label "Sposta il gruppo su">
+<!ENTITY context.movegroupdown.label "Sposta il gruppo giù">
+<!ENTITY context.enable.label "Attiva">
+<!ENTITY context.disable.label "Disattiva">
+<!ENTITY apply.label "Applica">
+<!ENTITY apply.accesskey "c">
+<!ENTITY fennec.subscription.label "Sottoscrizione di filtri di Adblock Plus">

=== added file 'chrome/locale/it/sidebar.dtd'
--- chrome/locale/it/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/it/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Elementi bloccabili con Adblock Plus (separati)">
+<!ENTITY detach.label "Separa">
+<!ENTITY reattach.label "Riunisci">
+<!ENTITY search.label "Cerca:">
+<!ENTITY search.accesskey "C">
+<!ENTITY type.label "Tipo">
+<!ENTITY address.label "Indirizzo">
+<!ENTITY filter.label "Filtro">
+<!ENTITY state.label "Stato">
+<!ENTITY size.label "Dimensione">
+<!ENTITY docDomain.label "Sorgente">
+<!ENTITY noitems.label "Nessun elemento bloccabile">
+<!ENTITY whitelisted.label "Pagina in lista di siti permessi">
+<!ENTITY tooltip.address.label "Indirizzo web:">
+<!ENTITY tooltip.type.label "Tipo:">
+<!ENTITY tooltip.type.blocked "(in lista di elementi bloccati)">
+<!ENTITY tooltip.type.whitelisted "(in lista di elementi permessi)">
+<!ENTITY tooltip.size.label "Dimensione:">
+<!ENTITY tooltip.docDomain.label "Sorgente del documento:">
+<!ENTITY tooltip.filter.label "Filtro effettivo:">
+<!ENTITY tooltip.filterSource.label "Sorgente del filtro:">
+<!ENTITY context.block.label "Blocca questo elemento">
+<!ENTITY context.editfilter.label "Modifica il filtro in effetto">
+<!ENTITY context.whitelist.label "Aggiungi un&apos;eccezione per l&apos;elemento">
+<!ENTITY context.disablefilter.label "Disattiva il filtro ?1?">
+<!ENTITY context.enablefilter.label "Riattiva il filtro ?1?">
+<!ENTITY context.disablefilteronsite.label "Disattiva il filtro per ?1?">
+<!ENTITY context.open.label "Apri in una nuova scheda">
+<!ENTITY context.flash.label "Fai lampeggiare il contorno dell&apos;elemento selezionato">
+<!ENTITY context.copy.label "Copia l&apos;indirizzo web dell&apos;elemento">
+<!ENTITY context.copyFilter.label "Copia il filtro">
+<!ENTITY context.selectAll.label "Seleziona tutto">

=== added file 'chrome/locale/it/subscriptionSelection.dtd'
--- chrome/locale/it/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/it/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,45 @@
+<!ENTITY dialog.title "Sottoscrizione di filtri di Adblock Plus">
+<!ENTITY dialog.title.edit "Modifica della sottoscrizione di filtri">
+<!ENTITY description.newInstall "
+    Grazie per aver installato Adblock Plus, che permette di eliminare il 99&#37; di pubblicità e banner in internet. Per filtrare
+	efficacemente pubblicità e banner è necessaria una buona serie di filtri. È possibile selezionare qui sotto una delle
+	sottoscrizioni di liste di filtri mantenute da terzi: quella più appropriata per nazione viene evidenziata (è possibile in 
+	seguito aggiungere manualmente ulteriori/propri filtri così come disattivare/eliminare le sottoscrizioni quando necessario)
+">
+<!ENTITY adblock.warning "
+	Adblock Plus ha rilevato la presenza di Adblock oppure di una versione 
+	precedente di Adblock Plus fra le estensioni installate. Si raccomanda 
+	di disinstallare qualsiasi precedente versione
+">
+<!ENTITY adblock.uninstall "Disinstalla Adblock">
+<!ENTITY filterset.g.warning "
+	Adblock Plus ha rilevato la presenza di Filterset.G, la cui lista di filtri è
+	stata mantenuta a malapena negli ultimi anni ed attualmente è causa comune di
+	problemi con i siti web. Si raccomanda di disinstallare Filterset.G
+">
+<!ENTITY filterset.g.moreinfo "Ulteriori informazioni">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Disinstalla Filterset.G">
+<!ENTITY subscriptionSelector.label "Selezionare una sottoscrizione di filtri dalla seguente lista:">
+<!ENTITY viewList.label "Visualizza i filtri della sottoscrizione">
+<!ENTITY visitHomepage.label "Visita il sito web">
+<!ENTITY addSubscription.label "Aggiungi sottoscrizione">
+<!ENTITY saveSubscription.label "Salva la sottoscrizione">
+<!ENTITY other.label "Altre sottoscrizioni">
+<!ENTITY other.accesskey "e">
+<!ENTITY list.download.failed "Recupero della lista di sottoscrizioni non riuscito">
+<!ENTITY list.download.retry "Riprova">
+<!ENTITY list.download.website "Visita il sito web delle sottoscrizioni">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Confermare l&apos;aggiunta della sottoscrizione di filtri. È possibile modificare il titolo della sottoscrizione oppure l&apos;URL/percorso della lista dei filtri prima di aggiungere">
+<!ENTITY edit.description "È possibile modificare il titolo della sottoscrizione oppure l&apos;URL/percorso della lista dei filtri">
+<!ENTITY external.description "Questa è una sottoscrizione esterna, la relativa lista dei filtri sarà mantenuta aggiornata dall&apos;estensione che ha creato questa sottoscrizione">
+<!ENTITY title.label "Titolo della sottoscrizione:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Indirizzo della lista dei filtri:">
+<!ENTITY location.accesskey "z">
+<!ENTITY autodownload.label "Aggiorna automaticamente">
+<!ENTITY autodownload.accesskey "A">
+<!ENTITY supplementMessage "Questa sottoscrizione di filtri verrà utilizzata insieme a quella chiamata &quot; ?1?&quot; (ancora non aggiunta).">
+<!ENTITY addMain.label "Aggiungere la sottoscrizione di filtri &quot; ?1?&quot;">
+<!ENTITY addMain.accesskey "s">

=== added directory 'chrome/locale/ja'
=== removed directory 'chrome/locale/ja-JP'
=== removed file 'chrome/locale/ja-JP/about.dtd'
--- chrome/locale/ja-JP/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ja-JP/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus について">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "バージョン">
-<!ENTITY description "
-	Adblock Plus はウェブ上で非表示にするものを決めることができます。
-	見たくないすべての広告とバナーをダウンロードする必要が無くなります。
-	-- Adblock Plus にアドレスを追加するだけです！
-">
-<!ENTITY homepage.label "Adblock Plus ホームページ:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "製作者:">
-<!ENTITY contributors.label "貢献者:">

=== removed file 'chrome/locale/ja-JP/composer.dtd'
--- chrome/locale/ja-JP/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ja-JP/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,52 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus フィルタを追加">
-<!ENTITY accept.label "フィルタ追加">
-<!ENTITY advanced.label "詳細表示">
-<!ENTITY basic.label "簡易表示">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus は現在無効です。フィルタを追加して適用するのはあなたしだいです。 ">
-<!ENTITY disabled.warning.link "Adblock Plus を有効にする">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "このフィルタを追加するフィルタグループ &quot;&#37;S&quot; は現在、無効となっています。フィルタを追加することはできますが適用されません。">
-<!ENTITY groupDisabled.warning.link "フィルタグループを有効にする">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "新規フィルタ：">
-<!ENTITY filter.accesskey "f">
-<!ENTITY preferences.label "既存フィルタを表示...">
-<!ENTITY preferences.accesskey "S">
-<!ENTITY type.filter.label "ブロックフィルタ">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "例外ルール">
-<!ENTITY type.whitelist.accesskey "x">
-<!ENTITY pattern.label "パターンを探す">
-<!ENTITY pattern.explanation "パターンはアドレスの任意の部分になり、シンボル * はワイルドカードの役割をします。フィルタは単にパターンと一致するアドレスに適用されるでしょう。">
-<!ENTITY regexp.warning "入力したパターンは正規表現として解釈されるでしょう。多くの正規表現がブラウジングを遅くするかもしれません。正規表現を使用するつもりでなければパターンの終わりに * シンボルを加えてください。">
-<!ENTITY shortpattern.warning "入力したパターンは短すぎるので最適ではありません。多くのそのようなパターンがブラウジングを遅くするかもしれません。このフィルタ用にはより長い文字列を選ぶのをお勧めします。">
-<!ENTITY custom.pattern.label "カスタム：">
-<!ENTITY custom.pattern.accesskey "C">
-<!ENTITY anchors.label "パターン限定対応：">
-<!ENTITY anchor.start.label "アドレスの先頭">
-<!-- Note: This access key should usually be the same as anchor.start.flexible.accesskey. It is the same checkbox with different label depending on suggested filter.-->
-<!ENTITY anchor.start.accesskey "g">
-<!ENTITY anchor.start.flexible.label "ドメインの先頭">
-<!-- Note: This access key should usually be the same as anchor.start.accesskey. It is the same checkbox with different label depending on suggested filter.-->
-<!ENTITY anchor.start.flexible.accesskey "g">
-<!ENTITY anchor.end.label "アドレスの最後">
-<!ENTITY anchor.end.accesskey "n">
-<!ENTITY options.label "オプション">
-<!ENTITY domainRestriction.label "ドメイン制限：">
-<!ENTITY domainRestriction.accesskey "d">
-<!ENTITY domainRestriction.help "シンボル 「 | 」 によって分けられる一つ以上のドメインを指定してください。フィルタは単にそのドメイン領域で適用されることになります。ドメイン名の前のシンボル 「 ~」 はフィルタがそのドメインで適用してはならないことを意味します。">
-<!ENTITY firstParty.label "ファーストパーティのみ">
-<!ENTITY firstParty.accesskey "r">
-<!ENTITY thirdParty.label "サードパーティのみ">
-<!ENTITY thirdParty.accesskey "T">
-<!ENTITY matchCase.label "一致ケース">
-<!ENTITY matchCase.accesskey "M">
-<!ENTITY types.label "種別適用：">
-<!ENTITY selectAllTypes.label "すべて選択">
-<!ENTITY unselectAllTypes.label "選択なし">
-<!ENTITY collapse.label "折りたたみブロック：">
-<!ENTITY collapse.accesskey "l">
-<!ENTITY collapse.default.yes.label "デフォルト使用（はい）">
-<!ENTITY collapse.default.no.label "デフォルト使用（いいえ）">
-<!ENTITY collapse.yes.label "はい">
-<!ENTITY collapse.no.label "いいえ">

=== removed file 'chrome/locale/ja-JP/global.properties'
--- chrome/locale/ja-JP/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/ja-JP/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=広告は過去の遺物です！
-status_active_label=Adblock
-status_disabled_label=停止中
-action0_tooltip=左クリック：コンテキストメニュー   中央クリック：有効／無効 切り替え
-action1_tooltip=左クリック：ブロック要素一覧の開閉   中央クリック：有効／無効 切り替え
-action2_tooltip=左クリック：設定   中央クリック：有効／無効 切り替え
-action3_tooltip=左クリック： Adblock Plus 有効／無効 切り替え
-active_tooltip=Adblock Plus 有効
-disabled_tooltip=Adblock Plus 停止中
-whitelisted_tooltip=Adblock Plus 有効 - 現在のページはホワイトリスト指定です
-blocked_count_tooltip=-- = ブロック要素数／全要素数 = --
-no_blocking_suggestions=現在のページではブロック可能なアイテムはありません
-whitelisted_page=Adblock Plus は現在のページでは無効です
-whitelist_description=適用ホワイトリスト
-filterlist_description=適用フィルタ
-invalid_description=無効フィルタ
-elemhide_description=非表示要素フィルタ
-subscription_description=フィルタ読み込み:
-subscription_wrong_version=この閲覧でいくつかのフィルタを機能させるには Adblock Plus が必要です！
-subscription_source=ソース:
-subscription_status=ステータス:
-subscription_status_autodownload=自動アップデート
-subscription_status_manualdownload=手動アップデート
-subscription_status_externaldownload=他の方法でアップデート(別の拡張機能など)
-subscription_status_lastdownload=最後のダウンロード:
-subscription_status_lastdownload_inprogress=ダウンロード中です
-subscription_status_lastdownload_unknown=N/A
-remove_subscription_warning=本当にこの読み込みを取り除きたいですか？
-import_filters_wrong_version=警告： このリストの中のいくつかのフィルタを機能させるには Adblock Plus が必要です --  このリストをインポートする前に最新の Adblock Plus リリースにアップグレードすべきです。
-import_filters_warning=本当に現在のフィルタリストに上書きしますか？ それとも追加しますか？
-import_filters_title=フィルタのインポート
-export_filters_title=フィルタのエクスポート
-invalid_filters_file=フィルタファイルは無効です
-filters_write_error=フィルタファイルへの書き込みに失敗しました。ファイルが書込み禁止になってないか、他のプログラムから使用されてないか確認してください。
-clearall_warning=本当にリストからすべてのフィルタを削除しますか？
-resethitcounts_warning=本当にすべてのフィルタのヒット数をリセットしますか？ この操作は元に戻すことができません！
-resethitcounts_selected_warning=本当に選択したフィルタのヒット数をリセットしますか？ この操作は元に戻すことができません！
-filter_regexp_tooltip=このフィルタは、最適化ができないほど正規表現か短いです。 これらのフィルタが多過ぎる為、ブラウジング速度が減速するかもしれません。
-filter_elemhide_duplicate_id=隠す要素の１つの ID だけは指定することができます
-filter_elemhide_nocriteria=基準は隠す要素を認識できるように指定されませんでした
-subscription_no_location=フィルタをダウンロードする場所またはタイトルを入力してください
-subscription_invalid_location=フィルタリストの場所は有効な URL でなく、また有効なファイル名ではありません
-subscription_location_exists=既にこのフィルタリストは読み込み済です
-synchronize_invalid_url=失敗です　有効なアドレスではありません
-synchronize_connection_error=失敗です　ダウンロードできません
-synchronize_invalid_data=失敗です　有効なフィルタリストではありません
-synchronize_checksum_mismatch=失敗です　チェックサムが一致しません
-synchronize_ok=成功
-overwrite=上書き
-append=追加
-new_filter_group_title=新規フィルター
-type_label_other=その他
-type_label_script=スクリプト
-type_label_image=画像
-type_label_stylesheet=スタイルシート
-type_label_object=オブジェクト
-type_label_subdocument=フレーム
-type_label_document=ドキュメント
-type_label_background=背景画像
-type_label_elemhide=非表示
-type_label_xbl=XBL 結合
-type_label_ping=リンク ping
-type_label_xmlhttprequest=XML リクエスト
-type_label_object_subrequest=subrequest オブジェクト
-type_label_dtd=DTD
-type_label_media=audio/video
-type_label_font=フォント

=== removed file 'chrome/locale/ja-JP/overlay.dtd'
--- chrome/locale/ja-JP/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ja-JP/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,24 +0,0 @@
-<!ENTITY status.tooltip "状態：">
-<!ENTITY blocked.tooltip "このページのブロック要素数：">
-<!ENTITY filters.tooltip "機能中のフィルタ（要素数）：">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus ブロックアイテム">
-<!ENTITY context.image.label "Adblock Plus 画像をブロック">
-<!ENTITY context.object.label "Adblock Plus オブジェクトをブロック">
-<!ENTITY context.frame.label "Adblock Plus フレームをブロック">
-<!ENTITY context.removeWhitelist.label "Adblock Plus このページを有効に戻す">
-<!ENTITY sidebar.title "Adblock Plus このページのブロック要素">
-<!ENTITY settings.label "設定">
-<!ENTITY settings.accesskey "F">
-<!ENTITY opensidebar.label "ブロック要素一覧を開く">
-<!-- Note: This access key should usually be the same as closesidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open.-->
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "ブロック要素一覧を閉じる">
-<!-- Note: This access key should usually be the same as opensidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open.-->
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "-- をホワイトリストに追加">
-<!ENTITY whitelist.page.label "現在のページをホワイトリストに追加">
-<!ENTITY objecttab.title "ブロック">
-<!ENTITY objecttab.tooltip "Adblock Plus クリックでブロックします">

=== removed file 'chrome/locale/ja-JP/settings.dtd'
--- chrome/locale/ja-JP/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ja-JP/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,91 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus 設定">
-<!ENTITY filters.label "フィルタ">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "追加">
-<!ENTITY add.accesskey "A">
-<!ENTITY addsubscription.label "同期フィルタの読み込み追加">
-<!ENTITY addsubscription.accesskey "S">
-<!ENTITY synchsubscriptions.label "すべての同期フィルタをアップデート">
-<!ENTITY synchsubscriptions.accesskey "D">
-<!ENTITY import.label "フィルタのインポート">
-<!ENTITY import.accesskey "M">
-<!ENTITY export.label "フィルタのエクスポート">
-<!ENTITY export.accesskey "X">
-<!ENTITY clearall.label "すべてのフィルタを削除">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "ヒット数をリセット">
-<!ENTITY resethitcounts.accesskey "R">
-<!ENTITY edit.label "編集">
-<!ENTITY edit.accesskey "E">
-<!ENTITY cut.label "切り取り">
-<!ENTITY cut.accesskey "T">
-<!ENTITY copy.label "コピー">
-<!ENTITY copy.accesskey "C">
-<!ENTITY paste.label "貼り付け">
-<!ENTITY paste.accesskey "P">
-<!ENTITY remove.label "削除">
-<!ENTITY remove.accesskey "D">
-<!ENTITY menu.find.label "検索">
-<!ENTITY menu.find.accesskey "F">
-<!ENTITY menu.findagain.label "再検索">
-<!ENTITY menu.findagain.accesskey "G">
-<!ENTITY view.label "表示">
-<!ENTITY view.accesskey "V">
-<!ENTITY sort.label "並び替え">
-<!ENTITY sort.accesskey "S">
-<!ENTITY sort.none.label "ソートしない">
-<!ENTITY sort.none.accesskey "U">
-<!ENTITY sort.ascending.label "A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "オプション">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Adblock Plus を有効にする">
-<!ENTITY enable.accesskey "N">
-<!ENTITY showintoolbar.label "ツールバー表示">
-<!ENTITY showintoolbar.accesskey "B">
-<!ENTITY showinstatusbar.label "ステータスバー表示">
-<!ENTITY showinstatusbar.accesskey "S">
-<!ENTITY objecttabs.label "オブジェクト（Flashなど）にタブを付ける">
-<!ENTITY objecttabs.accesskey "T">
-<!ENTITY collapse.label "ブロック要素を隠す">
-<!ENTITY collapse.accesskey "L">
-<!ENTITY help.label "ヘルプ">
-<!ENTITY help.accesskey "H">
-<!ENTITY gettingStarted.label "開始">
-<!ENTITY gettingStarted.accesskey "s">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "よくある質問と回答（FAQ）">
-<!ENTITY faq.accesskey "F">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Adblock Plus フィルタ記述ガイド">
-<!ENTITY filterdoc.accesskey "R">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Adblock Plus について">
-<!ENTITY about.accesskey "B">
-<!ENTITY description "ドロップダウンリストの中からブロックしたいアドレスを追加してください。
-		汎用的なフィルタを作成する場合はワイルドカードとして * (アスタリスク)が使用できます。
-		上級ユーザは /banner\d+\.gif$/ のような正規表現を使用することができます。">
-<!ENTITY filter.column "フィルタのルール">
-<!ENTITY filter.accesskey "F">
-<!ENTITY slow.column "低速フィルタ">
-<!ENTITY slow.accesskey "w">
-<!ENTITY enabled.column "有効">
-<!ENTITY enabled.accesskey "n">
-<!ENTITY hitcount.column "ヒット数">
-<!ENTITY hitcount.accesskey "H">
-<!ENTITY lasthit.column "最終ヒット日時">
-<!ENTITY lasthit.accesskey "L">
-<!ENTITY context.edit.label "フィルタ編集">
-<!ENTITY context.resethitcount.label "フィルタヒット数をリセット">
-<!ENTITY context.synchsubscription.label "今すぐ同期フィルタをアップデート">
-<!ENTITY context.editsubscription.label "読み込み編集">
-<!ENTITY context.moveup.label "上へ">
-<!ENTITY context.movedown.label "下へ">
-<!ENTITY context.movegroupup.label "上のグループへ">
-<!ENTITY context.movegroupdown.label "下のグループへ">
-<!ENTITY context.enable.label "有効">
-<!ENTITY context.disable.label "無効">
-<!ENTITY apply.label "適 用">
-<!ENTITY apply.accesskey "P">

=== removed file 'chrome/locale/ja-JP/sidebar.dtd'
--- chrome/locale/ja-JP/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ja-JP/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus このページのブロック要素">
-<!ENTITY detach.label "ウィンドウ表示にする">
-<!ENTITY reattach.label "ページ内表示にする">
-<!ENTITY search.label "検索：">
-<!ENTITY search.accesskey "S">
-<!ENTITY type.label "種別">
-<!ENTITY address.label "アドレス">
-<!ENTITY filter.label "フィルタ">
-<!ENTITY state.label "状態">
-<!ENTITY size.label "サイズ">
-<!ENTITY docDomain.label "ドキュメントソース">
-<!ENTITY noitems.label "ブロック可能な要素はありません">
-<!ENTITY whitelisted.label "ホワイトリストに登録されたページです">
-<!ENTITY tooltip.address.label "アドレス：">
-<!ENTITY tooltip.type.label "種別：">
-<!ENTITY tooltip.type.blocked "(ブロック)">
-<!ENTITY tooltip.type.whitelisted "(ホワイトリスト)">
-<!ENTITY tooltip.size.label "サイズ：">
-<!ENTITY tooltip.docDomain.label "ドキュメントソース：">
-<!ENTITY tooltip.filter.label "フィルタ：">
-<!ENTITY tooltip.filterSource.label "フィルタのソース：">
-<!ENTITY context.block.label "この要素をブロック">
-<!ENTITY context.editfilter.label "フィルタを編集">
-<!ENTITY context.whitelist.label "ホワイトリストに追加">
-<!ENTITY context.disablefilter.label "フィルタを無効 --">
-<!ENTITY context.enablefilter.label "再度フィルタを有効 --">
-<!ENTITY context.disablefilteronsite.label "このフィルタを無効 --">
-<!ENTITY context.open.label "新規タブに開く">
-<!ENTITY context.flash.label "領域枠の点滅表示">
-<!ENTITY context.copy.label "アドレスのコピー">
-<!ENTITY context.copyFilter.label "フィルタのコピー">
-<!ENTITY context.selectAll.label "すべて選択">

=== removed file 'chrome/locale/ja-JP/subscription.dtd'
--- chrome/locale/ja-JP/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ja-JP/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,26 +0,0 @@
-<!ENTITY dialog.title "同期フィルタを編集">
-<!ENTITY dialog.newtitle "同期フィルタを追加">
-<!ENTITY new.description "
-	Adblock Plus のフィルタリストを含むファイルか
-	ウェブアドレスを入力してください
-">
-<!ENTITY edit.description "
-	指定した場所からこの読み込みのためのフィルタリストを
-	ダウンロードします
-">
-<!ENTITY external.description "
-	他の拡張機能（Filterset.G Updater）を経由してフィルタリストを読み込みます。
-	リストの更新はその拡張機能によって行われます。
-">
-<!ENTITY autodownload.description "
-	「自動アップデート」を選ぶとアップデートがないかどうかこの場所を毎日チェックします。
-	この設定を無効にしても読み込みのコンテキストメニューから手動でアップデートできます。
-">
-<!ENTITY location.label "フィルタリスト場所:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "購読タイトル:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "自動アップデートにする">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.label "フィルタを有効にする">
-<!ENTITY enabled.accesskey "N">

=== removed file 'chrome/locale/ja-JP/tip_subscriptions.dtd'
--- chrome/locale/ja-JP/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ja-JP/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,37 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus へようこそ">
-<!ENTITY description.par1 "
-	Adblock Plus をインストールしていただき、ありがとうございます。
-	この拡張機能はウェブ上で見る広告の 99&#37; を排除することができます。
-	効果的な広告フィルタリングのためには適切なフィルタを定義する必要があります。
-	自分で定義するのも可能ですし、メンテナンスされている他のフィルタリストを利用することでも可能です。
-	閲覧する際、必要に応じて自分でフィルタを追加したり無効化したり削除することができます。
-">
-<!ENTITY description.par2 "
-	以下のお勧めの購読リストから 1 つの購読を選ぶことができます。
-	(これは通常必要ではありませんが後から Adblock Plus 設定でも
-	より多くの購読を追加することができます。):
-">
-<!ENTITY note "
-	参考: 対象外の地域でこのフィルタリストを使用しても効果の少ない場合があります。
-">
-<!ENTITY adblock.warning "
-	Adblock Plus が Adblock 、あるいは Adblock Plus の古いバージョンがインストールされて
-	いるのを検出しました。 Adblock と Adblock Plus を並行して機能させるのは問題を引き起こす
-	ことになりますので避けるべきです。 今すぐ Adblock のアンインストールをお勧めします。
-">
-<!ENTITY adblock.uninstall "Adblock アンストールについて">
-<!ENTITY filterset.g.warning "
-	Filterset.G を使用していると思われます。このフィルタ・リストは過去数年の間かろうじて
-	維持されている状態でウェブサイトに関する問題の共通の原因となっています。今すぐ Filterset.G
-	のアンインストールをお勧めします。
-">
-<!ENTITY filterset.g.moreinfo "詳細情報">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Filterset.G アンインストールについて">
-<!ENTITY homepage.label "ホームページ">
-<!ENTITY subscribe.label "購読">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "別の購読を追加">
-<!ENTITY other.accesskey "f">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "すべての購読リストを見る">

=== added file 'chrome/locale/ja/about.dtd'
--- chrome/locale/ja/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ja/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,15 @@
+<!ENTITY dialog.title "Adblock Plus について">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "バージョン">
+<!ENTITY description "
+	Adblock Plus でウェブ上の見たくないものを非表示にできます。
+	いらない広告やバナーをダウンロードする必要はもうありません。
+	-- Adblock Plus にアドレスを追加するだけです！">
+<!ENTITY homepage.label "Adblock Plus ホームページ:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "製作者:">
+<!ENTITY contributors.label "貢献者:">
+<!ENTITY developers.label "開発者:">
+<!ENTITY designers.label "グラフィックデザイナー:">
+<!ENTITY subscriptionAuthors.label "同期フィルタ作者:">
+<!ENTITY translators.label "翻訳者:">

=== added file 'chrome/locale/ja/composer.dtd'
--- chrome/locale/ja/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ja/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Adblock Plus フィルタを追加">
+<!ENTITY accept.label "フィルタ追加">
+<!ENTITY advanced.label "詳細表示">
+<!ENTITY basic.label "簡易表示">
+<!ENTITY disabled.warning "Adblock Plus は現在無効です。フィルタを追加することはできますが適用されません。 [link]Adblock Plus を有効にする[/link] ">
+<!ENTITY groupDisabled.warning "このフィルタを追加するフィルタグループ &quot;?1?&quot; は現在、無効となっています。フィルタを追加することはできますが適用されません。 [link]フィルタグループを有効にする[/link] ">
+<!ENTITY filter.label "新規フィルタ：">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "既存のフィルタを表示...">
+<!ENTITY preferences.accesskey "S">
+<!ENTITY type.filter.label "ブロックフィルタ">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "ホワイトリスト">
+<!ENTITY type.whitelist.accesskey "x">
+<!ENTITY pattern.label "パターンを探す">
+<!ENTITY pattern.explanation "アドレスの一部をパターンとして使用します。シンボル * はワイルドカードの役割をします。パターンに一致するアドレスにだけフィルタが適用されます。">
+<!ENTITY regexp.warning "入力されたパターンは正規表現として認識されます。正規表現を多用しすぎるとブラウジングが遅くなる可能性があります。正規表現を使用するつもりでなければパターンの終わりに * シンボルを加えてください。">
+<!ENTITY shortpattern.warning "入力されたパターンは最適化に必要な文字数に達していません。このようなパターンを多用しすぎるとブラウジングが遅くなる可能性があります。より長い文字列が推奨されます。">
+<!ENTITY custom.pattern.label "カスタム：">
+<!ENTITY custom.pattern.accesskey "C">
+<!ENTITY anchors.label "パターン限定対応：">
+<!ENTITY anchor.start.label "アドレスの先頭">
+<!ENTITY anchor.start.accesskey "g">
+<!ENTITY anchor.start.flexible.label "ドメインの先頭">
+<!ENTITY anchor.start.flexible.accesskey "g">
+<!ENTITY anchor.end.label "アドレスの最後">
+<!ENTITY anchor.end.accesskey "n">
+<!ENTITY options.label "オプション">
+<!ENTITY domainRestriction.label "ドメイン制限：">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "シンボル 「 | 」 によって分けられる一つ以上のドメインを指定してください。フィルタはそのドメインにのみ適用されることになります。ドメイン名の前のシンボル 「 ~」 はフィルタがそのドメインでは適用されないことを意味します。">
+<!ENTITY firstParty.label "現在のサイト内のみ適用">
+<!ENTITY firstParty.accesskey "r">
+<!ENTITY thirdParty.label "サードパーティのみ適用">
+<!ENTITY thirdParty.accesskey "T">
+<!ENTITY matchCase.label "大文字/小文字を区別">
+<!ENTITY matchCase.accesskey "M">
+<!ENTITY types.label "種別適用：">
+<!ENTITY selectAllTypes.label "すべて選択">
+<!ENTITY unselectAllTypes.label "すべて選択解除">
+<!ENTITY collapse.label "折りたたみブロック：">
+<!ENTITY collapse.accesskey "l">
+<!ENTITY collapse.default.yes.label "デフォルト使用（はい）">
+<!ENTITY collapse.default.no.label "デフォルト使用（いいえ）">
+<!ENTITY collapse.yes.label "はい">
+<!ENTITY collapse.no.label "いいえ">

=== added file 'chrome/locale/ja/global.properties'
--- chrome/locale/ja/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ja/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=左クリック：コンテキストメニュー   中央クリック：有効・無効 切り替え
+action1_tooltip=左クリック：ブロック要素一覧の開閉   中央クリック：有効・無効 切り替え
+action2_tooltip=左クリック：設定   中央クリック：有効・無効 切り替え
+action3_tooltip=左クリック： Adblock Plus 有効・無効 切り替え
+disabled_tooltip=Adblock Plus 停止中
+active_tooltip=Adblock Plus 有効, ?1? 個の同期フィルタと ?2? 個のカスタムフィルタを使用中
+whitelisted_tooltip=Adblock Plus 有効 - 現在のページでは無効
+blocked_count_tooltip=?1? = ブロック要素数／全要素数 = ?2?
+blocked_count_addendum=(ホワイトリスト: ?1?, 非表示: ?2?)
+no_blocking_suggestions=現在のページにはブロック可能なアイテムはありません
+whitelisted_page=Adblock Plus は現在のページでは無効に設定されました
+whitelist_description=ホワイトリスト
+filterlist_description=ブロックフィルタ
+invalid_description=不正なフィルタ
+elemhide_description=要素非表示フィルタ
+subscription_description=同期フィルタ:
+subscription_wrong_version=この同期フィルタのすべての機能を利用するには Adblock Plus ?1? が必要です
+subscription_source=ソース:
+subscription_status=ステータス:
+subscription_status_autodownload=自動
+subscription_status_manualdownload=手動
+subscription_status_externaldownload=外部機能（他のアドオン）により更新済み
+subscription_status_lastdownload=最終更新:
+subscription_status_lastdownload_inprogress=ダウンロード中...
+subscription_status_lastdownload_unknown=不明
+remove_subscription_warning=本当にこの同期フィルタを削除しますか？
+import_filters_wrong_version=警告： このリストに含まれるフィルタをすべて機能させるには Adblock Plus ?1? が必要です。このリストをインポートする前に最新の Adblock Plus リリースにアップグレードすべきです。
+import_filters_warning=本当に現在のフィルタリストに上書きしますか？ それとも追加しますか？
+import_filters_title=フィルタのインポート
+export_filters_title=フィルタのエクスポート
+invalid_filters_file=フィルタファイルは無効です
+filters_write_error=フィルタファイルへの書き込みに失敗しました。ファイルが書込み禁止になってないか、他のプログラムから使用されてないか確認してください。
+clearall_warning=本当にリストからすべてのフィルタを削除しますか？
+resethitcounts_warning=本当にすべてのフィルタのヒット数をリセットしますか？ 注意：この操作は元に戻すことができません。
+resethitcounts_selected_warning=本当に選択したフィルタのヒット数をリセットしますか？ 注意：この操作は元に戻すことができません。
+filter_regexp_tooltip=このフィルタは正規表現か、最適化に必要な文字数に達していません。 このようなフィルタを多用しすぎるとブラウジングが遅くなる可能性があります。
+filter_elemhide_duplicate_id=非表示要素の ID は一つしか指定できません。
+filter_elemhide_nocriteria=非表示要素の識別に必要な文字列が設定されていません。
+subscription_notAdded_warning=同期フィルタは追加されません。フィルタは手動で設定することになります。
+subscription_notAdded_warning_addendum=続行してもいいですか？
+subscription_invalid_location=不正な URL 又はファイル名です。
+synchronize_invalid_url=失敗です　有効なアドレスではありません
+synchronize_connection_error=失敗です　ダウンロードできません
+synchronize_invalid_data=失敗です　有効なフィルタリストではありません
+synchronize_checksum_mismatch=失敗です　チェックサムが一致しません
+synchronize_ok=成功
+overwrite=上書き
+append=追加
+new_filter_group_title=新規フィルタ
+type_label_other=その他
+type_label_script=スクリプト
+type_label_image=画像
+type_label_stylesheet=スタイルシート
+type_label_object=オブジェクト
+type_label_subdocument=フレーム
+type_label_document=ドキュメント
+type_label_background=背景画像
+type_label_elemhide=非表示
+type_label_xbl=XBL 結合
+type_label_ping=リンク ping
+type_label_xmlhttprequest=XML リクエスト
+type_label_object_subrequest=オブジェクト・サブリクエスト
+type_label_dtd=DTD
+type_label_media=オーディオ/ビデオ
+type_label_font=フォント
+fennec_status_enabled=Adblock Plus 有効
+fennec_status_disabled=Adblock Plus 無効
+fennec_status_enabled_site=Adblock Plus は ?1? で有効
+fennec_status_disabled_site=Adblock Plus は ?1? で無効

=== added file 'chrome/locale/ja/meta.properties'
--- chrome/locale/ja/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ja/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Schuzak, Premier
+name=Adblock Plus
+description=広告は過去の遺物です！
+description.short=広告やトラッキングで困っていませんか？ Adblock Plus でコントロールして自分好みに変えてしまいましょう。 \n\n http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus では Web をコントロールし外観を変えることができます。広告削除からマルウェアのブロックまで対応できる 40 以上の同期フィルタがあり、言語に応じて自動的に設定されます。また、コンテキストメニューやタブ、リストからの選択など便利な機能を利用して自分でカスタマイズすることもできます。

=== added file 'chrome/locale/ja/overlay.dtd'
--- chrome/locale/ja/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ja/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "状態：">
+<!ENTITY blocked.tooltip "このページのブロック済アイテム数：">
+<!ENTITY filters.tooltip "ヒット数最多のフィルタ：">
+<!ENTITY menuitem.label "Adblock Plus 設定">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus：ブロック対象">
+<!ENTITY context.image.label "Adblock Plus：画像をブロック">
+<!ENTITY context.object.label "Adblock Plus：オブジェクトをブロック">
+<!ENTITY context.frame.label "Adblock Plus：フレームをブロック">
+<!ENTITY context.media.label "Adblock Plus：ビデオ/オーディオをブロック">
+<!ENTITY context.removeWhitelist.label "Adblock Plus：このページを有効に戻す">
+<!ENTITY sidebar.title "このページのブロック対象">
+<!ENTITY settings.label "設定">
+<!ENTITY settings.accesskey "F">
+<!ENTITY opensidebar.label "ブロック対象一覧を開く">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "ブロック対象一覧を閉じる">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "?1? では無効にする">
+<!ENTITY whitelist.page.label "このページでは無効にする">
+<!ENTITY objecttab.title "ブロック">
+<!ENTITY objecttab.tooltip "クリックして Adblock Plus でオブジェクトをブロック">

=== added file 'chrome/locale/ja/settings.dtd'
--- chrome/locale/ja/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ja/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus 設定">
+<!ENTITY filters.label "フィルタ">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "追加">
+<!ENTITY add.accesskey "A">
+<!ENTITY addsubscription.label "同期フィルタの追加">
+<!ENTITY addsubscription.accesskey "S">
+<!ENTITY synchsubscriptions.label "すべての同期フィルタを更新">
+<!ENTITY synchsubscriptions.accesskey "D">
+<!ENTITY import.label "フィルタのインポート">
+<!ENTITY import.accesskey "M">
+<!ENTITY export.label "フィルタのエクスポート">
+<!ENTITY export.accesskey "X">
+<!ENTITY clearall.label "すべてのフィルタを削除">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "ヒット数をリセット">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "編集">
+<!ENTITY edit.accesskey "E">
+<!ENTITY cut.label "切り取り">
+<!ENTITY cut.accesskey "T">
+<!ENTITY copy.label "コピー">
+<!ENTITY copy.accesskey "C">
+<!ENTITY paste.label "貼り付け">
+<!ENTITY paste.accesskey "P">
+<!ENTITY remove.label "削除">
+<!ENTITY remove.accesskey "D">
+<!ENTITY menu.find.label "検索">
+<!ENTITY menu.find.accesskey "F">
+<!ENTITY menu.findagain.label "再検索">
+<!ENTITY menu.findagain.accesskey "G">
+<!ENTITY view.label "表示">
+<!ENTITY view.accesskey "V">
+<!ENTITY sort.label "並べ替え">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "並べ替えない">
+<!ENTITY sort.none.accesskey "U">
+<!ENTITY sort.ascending.label "A &gt; Z">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Z &gt; A">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "オプション">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Adblock Plus を有効にする">
+<!ENTITY enable.accesskey "N">
+<!ENTITY showintoolbar.label "ツールバー表示">
+<!ENTITY showintoolbar.accesskey "B">
+<!ENTITY showinstatusbar.label "ステータスバー表示">
+<!ENTITY showinstatusbar.accesskey "S">
+<!ENTITY objecttabs.label "Flash と Java にタブを付ける">
+<!ENTITY objecttabs.accesskey "T">
+<!ENTITY collapse.label "ブロック要素を隠す">
+<!ENTITY collapse.accesskey "L">
+<!ENTITY help.label "ヘルプ">
+<!ENTITY help.accesskey "H">
+<!ENTITY gettingStarted.label "開始">
+<!ENTITY gettingStarted.accesskey "s">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "よくある質問と回答（FAQ）">
+<!ENTITY faq.accesskey "F">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Adblock Plus フィルタ記述ガイド">
+<!ENTITY filterdoc.accesskey "R">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Adblock Plus について">
+<!ENTITY about.accesskey "B">
+<!ENTITY description "以下のフィルタでブロックの可否を設定します。">
+<!ENTITY filter.column "フィルタのルール">
+<!ENTITY filter.accesskey "F">
+<!ENTITY slow.column "低速フィルタ">
+<!ENTITY slow.accesskey "w">
+<!ENTITY enabled.column "有効">
+<!ENTITY enabled.accesskey "n">
+<!ENTITY hitcount.column "ヒット数">
+<!ENTITY hitcount.accesskey "H">
+<!ENTITY lasthit.column "最終ヒット日時">
+<!ENTITY lasthit.accesskey "L">
+<!ENTITY context.edit.label "フィルタ編集">
+<!ENTITY context.resethitcount.label "フィルタヒット数をリセット">
+<!ENTITY context.synchsubscription.label "今すぐ同期フィルタを更新">
+<!ENTITY context.editsubscription.label "同期フィルタの設定">
+<!ENTITY context.moveup.label "上へ">
+<!ENTITY context.movedown.label "下へ">
+<!ENTITY context.movegroupup.label "上のグループへ">
+<!ENTITY context.movegroupdown.label "下のグループへ">
+<!ENTITY context.enable.label "有効">
+<!ENTITY context.disable.label "無効">
+<!ENTITY apply.label "適 用">
+<!ENTITY apply.accesskey "P">
+<!ENTITY fennec.subscription.label "同期フィルタ">

=== added file 'chrome/locale/ja/sidebar.dtd'
--- chrome/locale/ja/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ja/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus：ブロック対象">
+<!ENTITY detach.label "ウィンドウ表示にする">
+<!ENTITY reattach.label "ページ内表示にする">
+<!ENTITY search.label "検索：">
+<!ENTITY search.accesskey "S">
+<!ENTITY type.label "種別">
+<!ENTITY address.label "アドレス">
+<!ENTITY filter.label "フィルタ">
+<!ENTITY state.label "状態">
+<!ENTITY size.label "サイズ">
+<!ENTITY docDomain.label "ドキュメントソース">
+<!ENTITY noitems.label "ブロック可能なアイテムはありません">
+<!ENTITY whitelisted.label "ホワイトリストに登録されたページです">
+<!ENTITY tooltip.address.label "アドレス：">
+<!ENTITY tooltip.type.label "種別：">
+<!ENTITY tooltip.type.blocked "(ブロック)">
+<!ENTITY tooltip.type.whitelisted "(ホワイトリスト)">
+<!ENTITY tooltip.size.label "サイズ：">
+<!ENTITY tooltip.docDomain.label "ドキュメントソース：">
+<!ENTITY tooltip.filter.label "フィルタ：">
+<!ENTITY tooltip.filterSource.label "フィルタのソース：">
+<!ENTITY context.block.label "このアイテムをブロック">
+<!ENTITY context.editfilter.label "フィルタを編集">
+<!ENTITY context.whitelist.label "ホワイトリストに追加">
+<!ENTITY context.disablefilter.label "フィルタを無効 ?1?">
+<!ENTITY context.enablefilter.label "再度フィルタを有効 ?1?">
+<!ENTITY context.disablefilteronsite.label "このフィルタを無効 ?1?">
+<!ENTITY context.open.label "新規タブに開く">
+<!ENTITY context.flash.label "領域枠の点滅表示">
+<!ENTITY context.copy.label "アドレスのコピー">
+<!ENTITY context.copyFilter.label "フィルタのコピー">
+<!ENTITY context.selectAll.label "すべて選択">

=== added file 'chrome/locale/ja/subscriptionSelection.dtd'
--- chrome/locale/ja/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ja/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,44 @@
+<!ENTITY dialog.title "Adblock Plus 同期フィルタの追加">
+<!ENTITY dialog.title.edit "同期フィルタを編集">
+<!ENTITY description.newInstall "
+	Adblock Plus では同期フィルタを使うと効果的です。
+	以下のフィルタは有志によって作成され無償で提供されています。
+	あなたが使っている言語に最も適したものが選択されています。
+">
+<!ENTITY adblock.warning "
+	Adblock Plus が Adblock 、あるいは Adblock Plus の古いバージョンがインストールされて
+	いるのを検出しました。 Adblock と Adblock Plus を並行して機能させるのは問題を引き起こす
+	ことになりますので避けるべきです。 今すぐ Adblock のアンインストールをお勧めします。
+">
+<!ENTITY adblock.uninstall "Adblock アンストール">
+<!ENTITY filterset.g.warning "
+	Filterset.G を使用していると思われます。このフィルタ・リストは過去数年の間かろうじて
+	維持されている状態でウェブサイトに関する問題の共通の原因となっています。今すぐ Filterset.G
+	のアンインストールをお勧めします。
+">
+<!ENTITY filterset.g.moreinfo "詳細情報">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Filterset.G アンインストール">
+<!ENTITY subscriptionSelector.label "リストから同期フィルタを選択してください：">
+<!ENTITY viewList.label "内容を確認する">
+<!ENTITY visitHomepage.label "ホームページ">
+<!ENTITY addSubscription.label "追加">
+<!ENTITY saveSubscription.label "保存">
+<!ENTITY other.label "上記以外を追加">
+<!ENTITY other.accesskey "f">
+<!ENTITY list.download.failed "リスト取得に失敗しました。">
+<!ENTITY list.download.retry "再試行">
+<!ENTITY list.download.website "ウェブサイトで見る">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "追加する同期フィルタを確認してください。保存する前に名前と場所を変更できます。">
+<!ENTITY edit.description "必要に応じて変更できます。名前と場所を入力することで上記以外の同期フィルタも使えます。">
+<!ENTITY external.description "これは外部同期フィルタです。このフィルタを設定した外部アドオンによって更新されます">
+<!ENTITY title.label "名前:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "場所:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "自動更新にする">
+<!ENTITY autodownload.accesskey "P">
+<!ENTITY supplementMessage "この同期フィルタは &quot;?1?&quot; との併用が推奨されています。">
+<!ENTITY addMain.label " &quot;?1?&quot; も追加する">
+<!ENTITY addMain.accesskey "s">

=== added directory 'chrome/locale/ka'
=== removed directory 'chrome/locale/ka-GE'
=== removed file 'chrome/locale/ka-GE/.incomplete'
=== removed file 'chrome/locale/ka-GE/about.dtd'
--- chrome/locale/ka-GE/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ka-GE/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,7 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus-ის შესახებ">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "ვერსია">
-<!ENTITY description "Adblock Plus შესაძლებლობას გაძლევთ თვითონ გადაწყვიტოთ გინდათ თუ არა ამა თუ იმ რეკლამის, ბანერის, ფლეშ ობიექტის ან სურათის ნახვა გინდათ თუ არა. ამიერიდან არ ხართ ვალდებული ინტერნეტიდან გადმოქაჩოთ ყველა რეკლამა, ბანერი და სხვა, თუ რაღაცა არ გჭირდებათ უბრალოდ უთხარიტ Adblock Plus-ს და ამით პრობლემა ამოწურული იქნება!">
-<!ENTITY homepage.label "Adblock Plus-ის საიტი">
-<!ENTITY author.label "ავტორი">
-<!ENTITY contributors.label "დამხმარებლები">

=== removed file 'chrome/locale/ka-GE/composer.dtd'
=== removed file 'chrome/locale/ka-GE/global.properties'
=== removed file 'chrome/locale/ka-GE/overlay.dtd'
--- chrome/locale/ka-GE/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ka-GE/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY status.tooltip "სტატუსი:">
-<!ENTITY blocked.tooltip "ამ web-გვერდზე ბლოკირებული ელემენტები:">
-<!ENTITY filters.tooltip "ყველაზე აქტიური ფილტრები:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY context.image.label "დაბლოკე სურათი">
-<!ENTITY context.object.label "დაბლოკე ობიექტი">
-<!ENTITY context.frame.label "დაბლოკე ფრეიმი">
-<!ENTITY sidebar.title "ამ web-გვერდის ბლოკირებადი ელემენტები">
-<!ENTITY settings.label "ოპციები">
-<!ENTITY settings.accesskey "А">
-<!ENTITY opensidebar.label "გახსენი ბლოკირებადი ელემენტები">
-<!ENTITY opensidebar.accesskey "И">
-<!ENTITY closesidebar.label "დახურე ბლოკირებადი ელემენტები">
-<!ENTITY closesidebar.accesskey "И">
-<!ENTITY whitelist.site.label "გამორთე ––ზე">
-<!ENTITY whitelist.page.label "გამორთე მხოლოდ ამ web-გვერდზე">

=== removed file 'chrome/locale/ka-GE/settings.dtd'
=== removed file 'chrome/locale/ka-GE/sidebar.dtd'
=== removed file 'chrome/locale/ka-GE/subscription.dtd'
--- chrome/locale/ka-GE/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ka-GE/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,4 +0,0 @@
-<!ENTITY new.description "შეიყვანეთ იმ ფილტრის web-ადრესი, რომელში Adblock Plus-ის ფილტრებია.">
-<!ENTITY edit.description "ამ სუბსკრიპტიონის ფილტრი გადმოტვირთული იქნება იმ web-ადრესიდან, რომელიც შეიყვანეთ.">
-<!ENTITY external.description "ეს არის გარეთა ფილტრების სუბსკრიპტიონი, იმის ფილტრების სია up-to-date იქნება იმ გაფართოების მეშვეობით, რომელიც გააკეთა.">
-<!ENTITY autodownload.description "თუ თქვენ">

=== removed file 'chrome/locale/ka-GE/tip_subscriptions.dtd'
--- chrome/locale/ka-GE/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ka-GE/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,6 +0,0 @@
-<!ENTITY note "მოგახსენებთ: ფილტრების სია მეტად ეფექტურია, როცა არის იმ ქვეყნიდან, სადაც თქვენ ცხოვრობთ (ან საიდან თქვენთვის საინტერესო საიტები არიან).">
-<!ENTITY homepage.label "Adblock Plus-ის საიტი">
-<!ENTITY subscribe.label "პოდპისკა">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "სხვა პოდპისკის დამატება">
-<!ENTITY other.accesskey "T">

=== added file 'chrome/locale/ka/.incomplete'
=== added file 'chrome/locale/ka/about.dtd'
--- chrome/locale/ka/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ka/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,7 @@
+<!ENTITY dialog.title "Adblock Plus-ის შესახებ">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "ვერსია">
+<!ENTITY description "Adblock Plus შესაძლებლობას გაძლევთ თვითონ გადაწყვიტოთ გინდათ თუ არა ამა თუ იმ რეკლამის, ბანერის, ფლეშ ობიექტის ან სურათის ნახვა გინდათ თუ არა. ამიერიდან არ ხართ ვალდებული ინტერნეტიდან გადმოქაჩოთ ყველა რეკლამა, ბანერი და სხვა, თუ რაღაცა არ გჭირდებათ უბრალოდ უთხარიტ Adblock Plus-ს და ამით პრობლემა ამოწურული იქნება!">
+<!ENTITY homepage.label "Adblock Plus-ის საიტი">
+<!ENTITY author.label "ავტორი">
+<!ENTITY contributors.label "დამხმარებლები">

=== added file 'chrome/locale/ka/overlay.dtd'
--- chrome/locale/ka/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ka/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,17 @@
+<!ENTITY status.tooltip "სტატუსი:">
+<!ENTITY blocked.tooltip "ამ web-გვერდზე ბლოკირებული ელემენტები:">
+<!ENTITY filters.tooltip "ყველაზე აქტიური ფილტრები:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY context.image.label "დაბლოკე სურათი">
+<!ENTITY context.object.label "დაბლოკე ობიექტი">
+<!ENTITY context.frame.label "დაბლოკე ფრეიმი">
+<!ENTITY sidebar.title "ამ web-გვერდის ბლოკირებადი ელემენტები">
+<!ENTITY settings.label "ოპციები">
+<!ENTITY settings.accesskey "А">
+<!ENTITY opensidebar.label "გახსენი ბლოკირებადი ელემენტები">
+<!ENTITY opensidebar.accesskey "И">
+<!ENTITY closesidebar.label "დახურე ბლოკირებადი ელემენტები">
+<!ENTITY closesidebar.accesskey "И">
+<!ENTITY whitelist.site.label "გამორთე ––ზე">
+<!ENTITY whitelist.page.label "გამორთე მხოლოდ ამ web-გვერდზე">

=== added file 'chrome/locale/ka/subscriptionSelection.dtd'
--- chrome/locale/ka/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ka/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+<!ENTITY other.label "სხვა პოდპისკის დამატება">
+<!ENTITY other.accesskey "T">

=== modified file 'chrome/locale/kk-KZ/about.dtd'
--- chrome/locale/kk-KZ/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kk-KZ/about.dtd	2010-05-04 14:45:07 +0000
@@ -8,3 +8,7 @@
 <!ENTITY homepage.url "http://adblockplus.org/en/">
 <!ENTITY author.label "Авторы:">
 <!ENTITY contributors.label "Үлес қосушылар:">
+<!ENTITY developers.label "Жасағандар:">
+<!ENTITY designers.label "Графиканы жасағандар:">
+<!ENTITY subscriptionAuthors.label "Сүзгі жазылуларын жасағандар:">
+<!ENTITY translators.label "Аудармашылар:">

=== modified file 'chrome/locale/kk-KZ/composer.dtd'
--- chrome/locale/kk-KZ/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kk-KZ/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "Фильтрді қосу">
 <!ENTITY advanced.label "Кеңейтілген көрінісі">
 <!ENTITY basic.label "Негізгі көрінісі">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus қазір сөндірулі. Фильтрлерді қазір де қоса аласыз, бірақ олар жұмыс істемейді, сіз">
-<!ENTITY disabled.warning.link "Adblock Plus қосқанға дейін">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Осы фильтр қосылатын &quot;&#37;S&quot; фильтрлер тобы қазір сөндірулі. Сіз фильтрді қоса аласыз, бірақ фильтрлер тобы қосылған">
-<!ENTITY groupDisabled.warning.link "кезде ғана іске асады">
-<!ENTITY groupDisabled.warning.afterLink ".">
+<!ENTITY disabled.warning "Adblock Plus қазір сөндірулі. Фильтрлерді қазір де қоса аласыз, бірақ олар жұмыс істемейді, сіз [link]Adblock Plus қосқанға дейін[/link].">
+<!ENTITY groupDisabled.warning "Осы фильтр қосылатын &quot;?1?&quot; фильтрлер тобы қазір сөндірулі. Сіз фильтрді қоса аласыз, бірақ фильтрлер тобы қосылған [link]кезде ғана іске асады[/link].">
 <!ENTITY filter.label "Жаңа фильтр:">
 <!ENTITY filter.accesskey "ф">
 <!ENTITY preferences.label "Бар фильтрлерді көрсету...">

=== modified file 'chrome/locale/kk-KZ/global.properties'
--- chrome/locale/kk-KZ/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/kk-KZ/global.properties	2010-05-04 14:45:07 +0000
@@ -1,22 +1,21 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Жарнамаға жол жоқ!
-status_active_label=Adblock
-status_disabled_label=Сөндірулі
+default_dialog_title=Adblock Plus
 action0_tooltip=Контексті мәзірін ашу үшін шертіңіз, тышқанның ортаңғы батырмасы - қосу/сөндіру үшін.
 action1_tooltip=Блокталған құраманы ашу/жабу үшін шертіңіз, тышқанның ортаңғы батырмасы - қосу/сөндіру үшін.
 action2_tooltip=Баптауларды ашу үшін шертіңіз, тышқанның ортаңғы батырмасы - қосу/сөндіру үшін.
 action3_tooltip=Adblock Plus қосу/сөндіру үшін шертіңіз.
-active_tooltip=Adblock Plus қосулы тұр.
 disabled_tooltip=Adblock Plus сөндірулі тұр.
+active_tooltip=Adblock Plus қосулы тұр, ?1? сүзгілерге жазылу мен ?2? пайдаланушы сүзгілері қолданылуда.
 whitelisted_tooltip=Adblock Plus қосулы, бірақ осы парақ үшін сөндірулі.
-blocked_count_tooltip=-- келесіден --
+blocked_count_tooltip=?1? келесіден ?2?
+blocked_count_addendum=(сүзгіден тыс: ?1?, жасырын: ?2?)
 no_blocking_suggestions=Ағымдағы парақта блоктауға болатын құрама жоқ
 whitelisted_page=Adblock Plus ағымдағы парақ үшін сөндірулі тұр
 whitelist_description=Менің ерекше ережелерім
 filterlist_description=Менің Adblock Plus ережелерім
 invalid_description=Менің қате ережелерім
 elemhide_description=Менің құраманы жасыру ережелерім
-subscription_description=Фильтрге жазылу:
-subscription_wrong_version=Осы жазылудағы кейбір фильтрлер Adblock Plus керек етеді - дұрыс жұмыс істеу үшін!
+subscription_description=Сүзгіге жазылу:
+subscription_wrong_version=Осы жазылудағы кейбір сүзгілер Adblock Plus ?1? керек етеді - дұрыс жұмыс істеу үшін!
 subscription_source=Көзі:
 subscription_status=Күйі:
 subscription_status_autodownload=Автоматты жаңарту
@@ -26,29 +25,29 @@
 subscription_status_lastdownload_inprogress=Жүктелуде...
 subscription_status_lastdownload_unknown=Ешқашан
 remove_subscription_warning=Осы жазылуды өшіруды шынымен қалайсыз ба?
-import_filters_wrong_version=Ескерту: осы тізімдегі кейбір фильтрлер Adblock Plus керек етеді - дұрыс жұмыс істеу үшін! Осы тізімді қолдану алдында сіз Adblock Plus соңғы нұсқасына дейін жаңартуыңыз керек.
-import_filters_warning=Сіз өзіңіздің фильрлеріңізді ауыстыруды немесе жаңа фильтрлерді тізімнің соңына қосуды таңдайсыз?
-import_filters_title=Фильтрлерді импорттау
-export_filters_title=Фильтрлерді экспорттау
-invalid_filters_file=Дұрыс Adblock Plus фильтрлер файлы емес.
-filters_write_error=Фильтрлерді файлға жазу кезінде қате кетті. Файл тек жазі үшін емес күйінде емес екеніне және басқа бағдарлама оны ашып тұрмағанына көзіңізді жеткізіңіз.
-clearall_warning=Тізімдегі барлық фильтрлерді өшіруді шынымен қалайсыз ба?
-resethitcounts_warning=Барлық фильтрлер үшін хит статистикасын нөлге тастау керек пе? Бұны қайтаруға болмайды!
-resethitcounts_selected_warning=Ерекшеленген фильтрлер үшін хит статистикасын нөлге тастау керек пе? Бұны қайтаруға болмайды!
-filter_regexp_tooltip=Бұл фильтр не регулярлы өрнек, не оптимизация үшін тым қысқа. Осындай фильтрлер көп болса, браузеріңіздің жұмысын тежеу мүмкін.
+import_filters_wrong_version=Ескерту: осы тізімдегі кейбір сүзгілер Adblock Plus ?1? керек етеді - дұрыс жұмыс істеу үшін! Осы тізімді қолдану алдында сіз Adblock Plus соңғы нұсқасына дейін жаңартуыңыз керек.
+import_filters_warning=Сіз өзіңіздің фильрлеріңізді ауыстыруды немесе жаңа сүзгілерді тізімнің соңына қосуды таңдайсыз ба?
+import_filters_title=Сүзгілерді импорттау
+export_filters_title=Сүзгілерді экспорттау
+invalid_filters_file=Дұрыс Adblock Plus сүзгілер файлы емес.
+filters_write_error=Сүзгілерді файлға жазу кезінде қате кетті. Файл тек жазі үшін емес күйінде емес екеніне және басқа бағдарлама оны ашып тұрмағанына көзіңізді жеткізіңіз.
+clearall_warning=Тізімдегі барлық сүзгілерді өшіруді шынымен қалайсыз ба?
+resethitcounts_warning=Барлық сүзгілер үшін хит статистикасын нөлге тастау керек пе? Бұны қайтаруға болмайды!
+resethitcounts_selected_warning=Ерекшеленген сүзгілер үшін хит статистикасын нөлге тастау керек пе? Бұны қайтаруға болмайды!
+filter_regexp_tooltip=Бұл сүзгі не регулярлы өрнек, не оптимизация үшін тым қысқа. Осындай сүзгілер көп болса, браузеріңіздің жұмысын тежеу мүмкін.
 filter_elemhide_duplicate_id=Жасыралатын элементтің идентификаторы тек біреу болу керек.
 filter_elemhide_nocriteria=Элементті жасыру үшін бірде-бір шарт анықталмады
-subscription_no_location=Фильтрлер тізімі жүктеліп алынатын адресті енгізіңіз.
+subscription_notAdded_warning=Сүзгілерге жазылған жоқсыз. Оларсыз Adblock Plus сүзгілерін қолмен енгізу керек болады.
+subscription_notAdded_warning_addendum=Жалғастыруды қалайсыз ба?
 subscription_invalid_location=Енгізілген адрес не интернет адресі, не файл мекен-жайы ретінде анықталмады.
-subscription_location_exists=Осы фильтрлер тізіміне алдында жазылдыңыз.
 synchronize_invalid_url=Қате, дұрыс адрес емес
 synchronize_connection_error=Қате, жүктеу мүмкін емес
-synchronize_invalid_data=Қате, дұрыс фильтрлер файлы емес
+synchronize_invalid_data=Қате, дұрыс сүзгілер файлы емес
 synchronize_checksum_mismatch=Қате, тексеру сомасы сәйкес емес
 synchronize_ok=Сәтті аяқталды
 overwrite=Үстінен жазу
 append=Соңынан қосу
-new_filter_group_title=Жаңа фильтр
+new_filter_group_title=Жаңа сүзгі
 type_label_other=Басқа
 type_label_script=Скрипт
 type_label_image=Сурет
@@ -65,3 +64,7 @@
 type_label_dtd=DTD
 type_label_media=Аудио/видео
 type_label_font=қаріп
+fennec_status_enabled=Adblock Plus қосулы тұр.
+fennec_status_disabled=Adblock Plus сөндірулі тұр.
+fennec_status_enabled_site=Adblock Plus ?1? үшін қосулы тұр.
+fennec_status_disabled_site=Adblock Plus ?1? үшін сөндірулі тұр.

=== added file 'chrome/locale/kk-KZ/meta.properties'
--- chrome/locale/kk-KZ/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/kk-KZ/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Бауржан Муфтахидинов
+name=Adblock Plus
+description=Жарнамаға жол жоқ!
+description.short=Жарнамадан шаршадыңыз ба? Баннерлер мазаңызды алды ма? Интернетпен жұмысыңызды икемді қылу үшін Adblock Plus қазір орнатыңыз.\n\nҚысқа видеосы осында бар: http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus сізге интернетті басқаруды қолыңызға қайтарып, вебті өзіңіз қалаған түрде көруге мүмкіндік береді. Бұл аддон әр түрлі тілдердегі қырықтан астам сүзгілерге жазылуларды қолдайды, олар болса, интернеттегі мазалайтын жарнамадан бастап, шабуыл жасайтын домендерді блоктауға дейін барады. Оған қоса, Adblock Plus сізге сүзгілерді қолыңызбен баптап, тағы да суреттер үшін контекст мәзірі, Flash пен Java объектілер үшін блоктау батырмасын, парақтағы блоктауға болатын нәрселер тізімін көрсету сияқты мүмкіндіктерді ұсынады.

=== modified file 'chrome/locale/kk-KZ/overlay.dtd'
--- chrome/locale/kk-KZ/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kk-KZ/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -8,6 +8,7 @@
 <!ENTITY context.image.label "Adblock Plus: Суретті блоктау">
 <!ENTITY context.object.label "Adblock Plus: Объектті блоктау">
 <!ENTITY context.frame.label "Adblock Plus: Фреймді блоктау">
+<!ENTITY context.media.label "Adblock Plus: Аудио/Видеоны блоктау">
 <!ENTITY context.removeWhitelist.label "Adblock Plus: Осы парақта қайта қосу">
 <!ENTITY sidebar.title "Ағымдағы парақ құрамасы">
 <!ENTITY settings.label "Баптаулары">
@@ -16,7 +17,7 @@
 <!ENTITY opensidebar.accesskey "у">
 <!ENTITY closesidebar.label "Блокталған құраманы жабу">
 <!ENTITY closesidebar.accesskey "у">
-<!ENTITY whitelist.site.label "Келесі үшін сөндіру: --">
+<!ENTITY whitelist.site.label "Келесі үшін сөндіру: ?1?">
 <!ENTITY whitelist.page.label "Тек осы парақ үшін сөндіру">
 <!ENTITY objecttab.title "Блоктау">
 <!ENTITY objecttab.tooltip "Adblock Plus көмегімен осы объектті блоктау үшін шертіңіз">

=== modified file 'chrome/locale/kk-KZ/settings.dtd'
--- chrome/locale/kk-KZ/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kk-KZ/settings.dtd	2010-05-04 14:45:07 +0000
@@ -87,3 +87,4 @@
 <!ENTITY context.disable.label "Сөндіру">
 <!ENTITY apply.label "Іске асыру">
 <!ENTITY apply.accesskey "с">
+<!ENTITY fennec.subscription.label "Сүзгіге жазылу">

=== modified file 'chrome/locale/kk-KZ/sidebar.dtd'
--- chrome/locale/kk-KZ/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kk-KZ/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "Бұл элементті блоктау">
 <!ENTITY context.editfilter.label "Қолданудағы фильтрді түзету">
 <!ENTITY context.whitelist.label "Элемент үшін ерекше ереже жасау">
-<!ENTITY context.disablefilter.label "Фильтрді сөндіру --">
-<!ENTITY context.enablefilter.label "Фильтрді қайта қосу --">
-<!ENTITY context.disablefilteronsite.label "Келесі үшін фильтрді өшіру --">
+<!ENTITY context.disablefilter.label "Фильтрді сөндіру ?1?">
+<!ENTITY context.enablefilter.label "Фильтрді қайта қосу ?1?">
+<!ENTITY context.disablefilteronsite.label "Келесі үшін фильтрді өшіру ?1?">
 <!ENTITY context.open.label "Жаңа бетте ашу">
 <!ENTITY context.flash.label "Flash құрамасының шектері">
 <!ENTITY context.copy.label "Элемент адресін көшіру">

=== removed file 'chrome/locale/kk-KZ/subscription.dtd'
--- chrome/locale/kk-KZ/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kk-KZ/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Фильтрге жазылуды түзету">
-<!ENTITY dialog.newtitle "Фильтрге жазылуды қосу">
-<!ENTITY new.description "Adblock Plus үшін фильтрлер тізімі орналасқан интернет адресін
-	немесе файл мекен-жайын енгізіңіз.">
-<!ENTITY edit.description "Осы жазылу үшін фильтр тізімі берілген адрестен жүктеледі.">
-<!ENTITY external.description "Бұл сыртқы жазылу, ол оны қосқан кеңейтуімен жаңартылады.">
-<!ENTITY autodownload.description "&apos;Автоматты түрде жаңарту&apos; таңдасаңыз, осы адрестен жаңартулар күнде
-	жүктелінеді. Осы таңдалмаса, жаңартуды жазылудың контексті мізірінен
-	қолмен қосу керек болады.">
-<!ENTITY location.label "Фильтр тізім адресі:">
-<!ENTITY location.accesskey "д">
-<!ENTITY title.label "Жазылудың аты:">
-<!ENTITY title.accesskey "з">
-<!ENTITY autodownload.label "Автоматты түрде жаңарту">
-<!ENTITY autodownload.accesskey "а">
-<!ENTITY enabled.label "Фильтрлерді қосу">
-<!ENTITY enabled.accesskey "с">

=== added file 'chrome/locale/kk-KZ/subscriptionSelection.dtd'
--- chrome/locale/kk-KZ/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/kk-KZ/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,36 @@
+<!ENTITY dialog.title "Adblock Plus фильтрлерге жазылуды қосу">
+<!ENTITY dialog.title.edit "Фильтрге жазылуды түзету">
+<!ENTITY description.newInstall "Adblock Plus сүзгі жазылуы қосылса пайдалы болады.Басқа Adblock Plus пайдаланушылары ұсынған сүзгілер тегін. Тіліңіз үшін сәйкес келетін сүзгілер таңдаулы тұр.">
+<!ENTITY adblock.warning "Adblock Plus бұл бағдарламада Adblock немесе Adblock Plus ескі нұсқасы қолданылып
+	тұрғанын анықтады. Adblock пен Adblock Plus бірге қолдану мәселелерді тұғызуы мүмкін.
+	Оларды болдырмау үшін Adblock өшіру ұсынылады.">
+<!ENTITY adblock.uninstall "Adblock өшіру">
+<!ENTITY filterset.g.warning "Сіз Filterset.G қолданатын сияқтысыз. Бұл фильтрлер тізімі бірнеше жыл
+	жаңартылмады, және көп мәселелердің көзі болды.
+	Мәселелерді болдырмау үшін Filterset.G өшіру ұсынылады.">
+<!ENTITY filterset.g.moreinfo "Көбірек білу">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Filterset.G өшіру">
+<!ENTITY subscriptionSelector.label "Тізімнен сүзгіге жазылуды таңдаңыз:">
+<!ENTITY viewList.label "Сүзгілерді қарап шығу">
+<!ENTITY visitHomepage.label "Үй парағын шолу">
+<!ENTITY addSubscription.label "Жазылуды қосу">
+<!ENTITY saveSubscription.label "Жазылуды сақтау">
+<!ENTITY other.label "Басқа жазылуды қосу">
+<!ENTITY other.accesskey "с">
+<!ENTITY list.download.failed "Adblock Plus жазылулар тізімін жүктеп ала алмаған.">
+<!ENTITY list.download.retry "Қайтадан көру">
+<!ENTITY list.download.website "Веб сайтты шолу">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Сүзгі жазылуын қосуды растаңыз. Қосу алдында оның атауын не орналасуын өзгерте аласыз.">
+<!ENTITY edit.description "Керек болса, жазылудың атауын не орналасуын өзгерте аласыз.">
+<!ENTITY external.description "Бұл сыртқы сүзгі жазылуы; ол жасаған аддонмен жаңартылуы тиіс.">
+<!ENTITY title.label "Жазылудың аты:">
+<!ENTITY title.accesskey "з">
+<!ENTITY location.label "Фильтр тізім адресі:">
+<!ENTITY location.accesskey "д">
+<!ENTITY autodownload.label "Автоматты түрде жаңарту">
+<!ENTITY autodownload.accesskey "а">
+<!ENTITY supplementMessage "Бұл фильтрге жазылу сізде әлі қосылмаған &quot;?1?&quot; сүзгімен бірге қолданылуы тиіс.">
+<!ENTITY addMain.label "&quot;?1?&quot; сүзгі жазылуын да қосу">
+<!ENTITY addMain.accesskey "у">

=== removed file 'chrome/locale/kk-KZ/tip_subscriptions.dtd'
--- chrome/locale/kk-KZ/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kk-KZ/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,29 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus фильтрлерге жазылуды қосу">
-<!ENTITY description.par1 "Adblock Plus орнатқаныңызға рахмет. Бұл кеңейту Интернеттегі
-	жарнаманың 99&#37; болдырмауға көмектеседі. Бірақ, жақсы нәтиже алу үшін
-	жақсы фильтрлер жиыны керек. Сіз осы фильтрлерді өзіңіз анықтай аласыз,
-	немесе басқалар құрап отырған фильтрлер тізімдеріне жазыла аласыз.
-	Соған қоса фильтрлерді өзіңіз жасай аласыз, және жазылуларды
-	кез-келген уақытта сөндіре не өшіре аласыз.">
-<!ENTITY description.par2 "Төменде ұсынылатын жазылулар тізімі көрсетілген, сіз олардың біреуін
-	таңдай аласыз (көбірек жазылуларды кейін Adblock Plus баптаулары ішінде
-	қоса аласыз, бірақта әдетте бұл керек емес):">
-<!ENTITY note "Қосымша: Фильтрлер тізімі, көбінесе, қай регион үшін құрылған, сол
-	регион сайттары үшін қолдануға тиімді.">
-<!ENTITY adblock.warning "Adblock Plus бұл бағдарламада Adblock немесе Adblock Plus ескі нұсқасы қолданылып
-	тұрғанын анықтады. Adblock пен Adblock Plus бірге қолдану мәселелерді тұғызуы мүмкін.
-	Оларды болдырмау үшін Adblock өшіру ұсынылады.">
-<!ENTITY adblock.uninstall "Adblock өшіру">
-<!ENTITY filterset.g.warning "Сіз Filterset.G қолданатын сияқтысыз. Бұл фильтрлер тізімі бірнеше жыл
-	жаңартылмады, және көп мәселелердің көзі болды.
-	Мәселелерді болдырмау үшін Filterset.G өшіру ұсынылады.">
-<!ENTITY filterset.g.moreinfo "Көбірек білу">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Filterset.G өшіру">
-<!ENTITY homepage.label "Үй парағы">
-<!ENTITY subscribe.label "Жазылу">
-<!ENTITY subscribe.accesskey "Ж">
-<!ENTITY other.label "Басқа жазылуды қосу">
-<!ENTITY other.accesskey "с">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Барлық жазылуларды қарап шығу">

=== added directory 'chrome/locale/kn'
=== removed directory 'chrome/locale/kn-IN'
=== removed file 'chrome/locale/kn-IN/.incomplete'
=== removed file 'chrome/locale/kn-IN/about.dtd'
--- chrome/locale/kn-IN/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kn-IN/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,7 +0,0 @@
-<!ENTITY dialog.title "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌ ಬಗ್ಗೆ">
-<!ENTITY caption.title "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌">
-<!ENTITY version.title "ವರ್‌ಶನ್">
-<!ENTITY description "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌ ನೀವು ಅಂತರ್ಜಾಲದಲ್ಲಿ ಏನನ್ನು ನೋಡಲಿಚ್ಚಿಸುವುದಿಲ್ಲವೆಂಬುದನ್ನು ನಿರ್ಧರಿಸಲು ಸಹಕರಿಸುತ್ತದೆ. ಇನ್ನು ಮುಂದೆ ನೀವು ಎಲ್ಲಾ ಜಾಹೀರಾತುಗಳನ್ನು ಡೌನ್‌ಲೋಡ್ ಮಾಡಬೇಕಾಗಿಲ್ಲ, ನಿಮಗೆ ಅವು ಬೇಡವೆಂದಾದರೆ ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌‌ಗೆ ತಿಳಿಸಿ!">
-<!ENTITY homepage.label "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌ ಮುಖ್ಯತಾಣ:">
-<!ENTITY author.label "ಕರ್ತೃ:">
-<!ENTITY contributors.label "ಸಹಕರಿಸಿದವರು:">

=== removed file 'chrome/locale/kn-IN/composer.dtd'
=== removed file 'chrome/locale/kn-IN/global.properties'
--- chrome/locale/kn-IN/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/kn-IN/global.properties	1970-01-01 00:00:00 +0000
@@ -1,42 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=ಜಾಹೀರಾತುಗಳು ನಿನ್ನೆಯದಾದವು!
-status_active_label=ಆಡ್‌ಬ್ಲಾಕ್
-status_disabled_label=ನಿಷ್ಕ್ರಿಯವಾಗಿದೆ
-action0_tooltip=ಮೆನುವನ್ನು ಮುಂದೆ ತರಲು ಕ್ಲಿಕ್ ಮಾಡಿ, ಸಕ್ರಿಯ/ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲು ಮಧ್ಯದ ಗುಂಡಿಯನ್ನು ಕ್ಲಿಕ್ ಮಾಡಿ.
-action1_tooltip=ತಡೆಹಿಡಿಯಬಹುದಾದ ವಸ್ತುಗಳನ್ನು ತೆರೆಯಲು/ಮುಚ್ಚಲು ಕ್ಲಿಕ್ ಮಾಡಿ, ಸಕ್ರಿಯ/ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲು ಮಧ್ಯದ ಗುಂಡಿಯನ್ನು ಕ್ಲಿಕ್ ಮಾಡಿ.
-action2_tooltip=ಆದ್ಯತೆಗಳನ್ನು ತೆರೆಯಲು ಕ್ಲಿಕ್ ಮಾಡಿ, ಸಕ್ರಿಯ/ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲು ಮಧ್ಯದ ಗುಂಡಿಯನ್ನು ಕ್ಲಿಕ್ ಮಾಡಿ.
-action3_tooltip=ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್ ಅನ್ನು ಸಕ್ರಿಯ/ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲು ಕ್ಲಿಕ್ ಮಾಡಿ.
-active_tooltip=ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್ ಸಕ್ರಿಯವಾಗಿದೆ.
-disabled_tooltip=ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್ ನಿಷ್ಕ್ರಿಯವಾಗಿದೆ.
-whitelisted_tooltip=ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್ ಸಕ್ರಿಯವಾಗಿದೆ ಆದರೆ ಸಧ್ಯದ ಪುಟದಲ್ಲಿ ನಿಷ್ಕ್ರಿಯವಾಗಿದೆ.
-blocked_count_tooltip=-- ರ --
-no_blocking_suggestions=ಸಧ್ಯದ ಪುಟದಲ್ಲಿ ತಡೆಹಿಡಿಯಬಹುದಾದ ಯಾವುದೇ ವಸ್ತುಗಳಿಲ್ಲ.
-whitelisted_page=ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್ ಸಧ್ಯದ ಪುಟದಲ್ಲಿ ನಿಷ್ಕ್ರಿಯವಾಗಿದೆ.
-whitelist_description=ಎಕ್ಸೆಪ್ಶನ್ ನಿಯಮಗಳು
-filterlist_description=ಜಾಹೀರಾತು ಫಿಲ್ಟರ್‌ಗಳು
-invalid_description=ಸರಿಯಿಲ್ಲದ ಫಿಲ್ಟರ್‌ಗಳು
-elemhide_description=ಭಾಗವೊಂದನ್ನು ಅಡಗಿಸುವ ನಿಯಮಗಳು
-subscription_description=ಫಿಲ್ಟರ್ ಚಂದಾ:
-subscription_source=ಮೂಲ:
-subscription_status=ಸ್ಟೇಟಸ್:
-subscription_status_autodownload=ಸ್ವಯಂಚಾಲಿತವಾಗಿ ನವೀಕರಿಸಲ್ಪಟ್ಟಿದೆ
-subscription_status_manualdownload=ನಿಮ್ಮಿಂದಾಗಿ ನವೀಕರಿಸಲ್ಪಟ್ಟಿದೆ
-subscription_status_externaldownload=ಬಾಹ್ಯರೀತಿಯಿಂದ ನವೀಕರಿಸಲ್ಪಟ್ಟಿದೆ (ಇನ್ನೊಂದು ಎಕ್ಸ್‍ಟೆನ್ಶನ್)
-subscription_status_lastdownload=ಹಿಂದಿನ ಡೌನ್‌ಲೋಡ್:
-subscription_status_lastdownload_inprogress=ಡೌನ್‌ಲೋಡ್ ಆಗುತ್ತಿದೆ...
-subscription_status_lastdownload_unknown=ಸಂಬಂಧಪಡದ
-remove_subscription_warning=ಈ ಚಂದಾವನ್ನು ನಿಜವಾಗಿಯೂ ತೆಗೆಯಲು ಇಚ್ಚಿಸುತ್ತೀರಾ?
-synchronize_ok=ಗೆಲುವು
-append=ಸೇರಿಸು
-type_label_other=ಇತರ
-type_label_script=ಸ್ಕ್ರಿಪ್ಟ್
-type_label_stylesheet=ಸ್ಟೈಲ್ ಶೀಟ್
-type_label_object=ವಸ್ತು
-type_label_subdocument=ಫ್ರೇಮ್
-type_label_document=ಬರಹ
-type_label_background=ಹಿನ್ನೆಲೆ
-type_label_elemhide=ಅಡಗಿಸಲಾದ
-type_label_xbl=XBL binding
-type_label_ping=ಲಿಂಕ್ ಪಿಂಗ್
-type_label_xmlhttprequest=XML ಕೋರಿಕೆ
-type_label_object_subrequest=ವಸ್ತುವಿನ ಉಪಕೋರಿಕೆ
-type_label_dtd=DTD

=== removed file 'chrome/locale/kn-IN/overlay.dtd'
--- chrome/locale/kn-IN/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kn-IN/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-<!ENTITY status.tooltip "ಸ್ಟೇಟಸ್:">
-<!ENTITY blocked.tooltip "ಈ ಪುಟದಲ್ಲಿ ತಡೆಹಿಡಿದಿರುವ ವಸ್ತುಗಳು">
-<!ENTITY filters.tooltip "ಬಹಳ ಸಕ್ರಿಯವಾಗಿರುವ ಫಿಲ್ಟರ್‌ಗಳು:">
-<!ENTITY menuitem.label "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY context.image.label "ಚಿತ್ರವನ್ನು ಆಡ್‌ಬ್ಲಾಕ್ ಮಾಡು">
-<!ENTITY context.object.label "ವಸ್ತುವನ್ನು ಆಡ್‌ಬ್ಲಾಕ್ ಮಾಡು">
-<!ENTITY context.frame.label "ಫ್ರೇಮ್ ಅನ್ನು ಆಡ್‌ಬ್ಲಾಕ್ ಮಾಡು">
-<!ENTITY sidebar.title "ಈ ಪುಟದಲ್ಲಿನ ತಡೆಹಿಡಿಯಬಹುದಾದ ವಸ್ತುಗಳು">
-<!ENTITY settings.label "ಆದ್ಯತೆಗಳು">
-<!ENTITY settings.accesskey "F">
-<!ENTITY opensidebar.label "ತಡೆಹಿಡಿಯಬಹುದಾದ ವಸ್ತುಗಳನ್ನು ತೆರೆ">
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "ತಡೆಹಿಡಿಯಬಹುದಾದ ವಸ್ತುಗಳನ್ನು ಮುಚ್ಚು">
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "-- ಅಲ್ಲಿ ನಿಷ್ಕ್ರಿಯಗೊಳಿಸು">
-<!ENTITY whitelist.page.label "ಈ ಪುಟದಲ್ಲಿ ಮಾತ್ರ ನಿಷ್ಕ್ರಿಯಗೊಳಿಸು">
-<!ENTITY objecttab.title "ತಡೆ ಹಿಡಿ">
-<!ENTITY objecttab.tooltip "ಈ ವಸ್ತುವನ್ನು ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌ ಮೂಲಕ ತಡೆಹಿಡಿಯಲು ಇಲ್ಲ್ಲಿ ಕ್ಲಿಕ್ ಮಾಡಿ">

=== removed file 'chrome/locale/kn-IN/settings.dtd'
=== removed file 'chrome/locale/kn-IN/sidebar.dtd'
--- chrome/locale/kn-IN/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kn-IN/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY detached.title "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌: ತಡೆಹಿಡಿಯಬಹುದಾದ ವಸ್ತುಗಳು (ಹೊರ ತೆಗೆದಿದೆ)">
-<!ENTITY detach.label "ಹೊರ ತೆಗೆ">
-<!ENTITY reattach.label "ಮರು ಲಗತ್ತಿಸು">
-<!ENTITY search.label "ಹುಡುಕು:">
-<!ENTITY search.accesskey "S">
-<!ENTITY type.label "ಟೈಪ್ ಮಾಡಿ">
-<!ENTITY address.label "ವಿಳಾಸ">
-<!ENTITY filter.label "ಫಿಲ್ಟರ್">
-<!ENTITY state.label "ಸ್ಥಿತಿ">
-<!ENTITY noitems.label "ತಡೆಹಿಡಿಯಬಹುದಾದ ಯಾವುದೇ ವಸ್ತುಗಳಿಲ್ಲ">
-<!ENTITY whitelisted.label "ನಂಬಿಗಸ್ಥ ಪುಟ">
-<!ENTITY tooltip.address.label "ವಿಳಾಸ:">
-<!ENTITY tooltip.type.label "ಟೈಪ್ ಮಾಡಿ:">
-<!ENTITY tooltip.type.blocked "(ತಡೆಹಿಡಿದಿದೆ)">
-<!ENTITY tooltip.type.whitelisted "(ನಂಬಿಗಸ್ಥ)">
-<!ENTITY tooltip.filter.label "ಚಾಲ್ತಿಯಲ್ಲಿರುವ ಫಿಲ್ಟರ್">
-<!ENTITY context.block.label "ಈ ವಸ್ತುವನ್ನು ತಡೆಹಿಡಿ">
-<!ENTITY context.editfilter.label "ಚಾಲ್ತಿಯಲ್ಲಿರುವ ಫಿಲ್ಟರ್ ಅನ್ನು ಸಂಪಾದಿಸು">
-<!ENTITY context.whitelist.label "ವಸ್ತುವಿಗೆ ಒಂದು ಎಕ್ಸೆಪ್ಶನ್ ಸೇರಿಸು">
-<!ENTITY context.open.label "ಹೊಸ ಹಾಳೆಯಲ್ಲಿ ತೆರೆ">
-<!ENTITY context.flash.label "ಫ್ಲಾಶ್ ವಸ್ತುಗಳ ಗಡಿ">
-<!ENTITY context.copy.label "ವಸ್ತುವಿನ ವಿಳಾಸವನ್ನು ಕಾಪಿ ಮಾಡು">

=== removed file 'chrome/locale/kn-IN/subscription.dtd'
--- chrome/locale/kn-IN/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kn-IN/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "ಫಿಲ್ಟರ್ ಚಂದಾವನ್ನು ಸಂಪಾದಿಸು">
-<!ENTITY dialog.newtitle "ಫಿಲ್ಟರ್ ಚಂದಾವನ್ನು ಸೇರಿಸು">
-<!ENTITY new.description "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್ ಫಿಲ್ಟರ್‌ಗಳ ಪಟ್ಟಿಯಿರುವ ತಾಣದ ವಿಳಾಸವನ್ನು ಅಥವಾ ಕಡತವನ್ನು ಬರೆಯಿರಿ">
-<!ENTITY edit.description "ಈ ಚಂದಾದ ಫಿಲ್ಟರ್ ಪಟ್ಟಿಯನ್ನು ಈ ಕೆಳಗಿನ ಸ್ಥಾನದಿಂದ ಡೌನ್‌ಲೋಡ್ ಮಾಡಲಾಗುವುದು">
-<!ENTITY external.description "ಇದೊಂದು ಬಾಹಿರ ಫಿಲ್ಟರ್ ಚಂದಾ, ಯಾವ ಎಕ್ಸ್‌ಟೆನ್ಶನ್ ಈ ಚಂದಾವನ್ನು ಸೃಷ್ಟಿಸಿದೆಯೋ ಅದು ಇದರ ಫಿಲ್ಟರ್ ಪಟ್ಟಿಯನ್ನು ವರ್ತಮಾನದಲ್ಲಿಡುತ್ತದೆ.">
-<!ENTITY autodownload.description "ನೀವು &quot;ಸ್ವಯಂಚಾಲಿತವಾಗಿ ನವೇದಿಸು&quot; ಅನ್ನು ಆಯ್ಕೆ ಮಾಡಿದರೆ ಈ ಸ್ಥಾನವನ್ನು ಪ್ರತಿದಿನ ನವೇದನೆಗಳಿಗಾಗಿ ಪರಿಶೀಲಿಸಲಾಗುವುದು. ಈ ಆಯ್ಕೆಯು ನಿಶ್ಕ್ರಿಯವಾಗಿದ್ದರೂ ಕೂಡಾ ನೀವಾಗಿ ಚಂದಾದ ಮೆನುವಿನಿಂದ ನವೇದಿಸಬಹುದು.">
-<!ENTITY location.label "ಫಿಲ್ಟರ್ ಪಟ್ಟಿಯ ಸ್ಥಾನ:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "ಚಂದಾ ಶೀರ್ಷಿಕೆ:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "ಸ್ವಯಂಚಾಲಿತವಾಗಿ ನವೇನಗೊಳಿಸು">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.label "ಫಿಲ್ಟರ್‌ಗಳನ್ನು ಸಕ್ರಿಯಗೊಳಿಸು">
-<!ENTITY enabled.accesskey "N">

=== removed file 'chrome/locale/kn-IN/tip_subscriptions.dtd'
--- chrome/locale/kn-IN/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/kn-IN/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,5 +0,0 @@
-<!ENTITY homepage.label "ಮುಖ್ಯ ತಾಣ">
-<!ENTITY subscribe.label "ಚಂದಾದಾರರಾಗಿ">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "ಇನ್ನೊಂದು ಚಂದಾವನ್ನು ಸೇರಿಸಿ">
-<!ENTITY other.accesskey "T">

=== added file 'chrome/locale/kn/.incomplete'
=== added file 'chrome/locale/kn/about.dtd'
--- chrome/locale/kn/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/kn/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,7 @@
+<!ENTITY dialog.title "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌ ಬಗ್ಗೆ">
+<!ENTITY caption.title "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌">
+<!ENTITY version.title "ವರ್‌ಶನ್">
+<!ENTITY description "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌ ನೀವು ಅಂತರ್ಜಾಲದಲ್ಲಿ ಏನನ್ನು ನೋಡಲಿಚ್ಚಿಸುವುದಿಲ್ಲವೆಂಬುದನ್ನು ನಿರ್ಧರಿಸಲು ಸಹಕರಿಸುತ್ತದೆ. ಇನ್ನು ಮುಂದೆ ನೀವು ಎಲ್ಲಾ ಜಾಹೀರಾತುಗಳನ್ನು ಡೌನ್‌ಲೋಡ್ ಮಾಡಬೇಕಾಗಿಲ್ಲ, ನಿಮಗೆ ಅವು ಬೇಡವೆಂದಾದರೆ ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌‌ಗೆ ತಿಳಿಸಿ!">
+<!ENTITY homepage.label "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌ ಮುಖ್ಯತಾಣ:">
+<!ENTITY author.label "ಕರ್ತೃ:">
+<!ENTITY contributors.label "ಸಹಕರಿಸಿದವರು:">

=== added file 'chrome/locale/kn/global.properties'
--- chrome/locale/kn/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/kn/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,38 @@
+action0_tooltip=ಮೆನುವನ್ನು ಮುಂದೆ ತರಲು ಕ್ಲಿಕ್ ಮಾಡಿ, ಸಕ್ರಿಯ/ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲು ಮಧ್ಯದ ಗುಂಡಿಯನ್ನು ಕ್ಲಿಕ್ ಮಾಡಿ.
+action1_tooltip=ತಡೆಹಿಡಿಯಬಹುದಾದ ವಸ್ತುಗಳನ್ನು ತೆರೆಯಲು/ಮುಚ್ಚಲು ಕ್ಲಿಕ್ ಮಾಡಿ, ಸಕ್ರಿಯ/ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲು ಮಧ್ಯದ ಗುಂಡಿಯನ್ನು ಕ್ಲಿಕ್ ಮಾಡಿ.
+action2_tooltip=ಆದ್ಯತೆಗಳನ್ನು ತೆರೆಯಲು ಕ್ಲಿಕ್ ಮಾಡಿ, ಸಕ್ರಿಯ/ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲು ಮಧ್ಯದ ಗುಂಡಿಯನ್ನು ಕ್ಲಿಕ್ ಮಾಡಿ.
+action3_tooltip=ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್ ಅನ್ನು ಸಕ್ರಿಯ/ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲು ಕ್ಲಿಕ್ ಮಾಡಿ.
+disabled_tooltip=ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್ ನಿಷ್ಕ್ರಿಯವಾಗಿದೆ.
+whitelisted_tooltip=ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್ ಸಕ್ರಿಯವಾಗಿದೆ ಆದರೆ ಸಧ್ಯದ ಪುಟದಲ್ಲಿ ನಿಷ್ಕ್ರಿಯವಾಗಿದೆ.
+blocked_count_tooltip=?1? ರ ?2?
+no_blocking_suggestions=ಸಧ್ಯದ ಪುಟದಲ್ಲಿ ತಡೆಹಿಡಿಯಬಹುದಾದ ಯಾವುದೇ ವಸ್ತುಗಳಿಲ್ಲ.
+whitelisted_page=ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್ ಸಧ್ಯದ ಪುಟದಲ್ಲಿ ನಿಷ್ಕ್ರಿಯವಾಗಿದೆ.
+whitelist_description=ಎಕ್ಸೆಪ್ಶನ್ ನಿಯಮಗಳು
+filterlist_description=ಜಾಹೀರಾತು ಫಿಲ್ಟರ್‌ಗಳು
+invalid_description=ಸರಿಯಿಲ್ಲದ ಫಿಲ್ಟರ್‌ಗಳು
+elemhide_description=ಭಾಗವೊಂದನ್ನು ಅಡಗಿಸುವ ನಿಯಮಗಳು
+subscription_description=ಫಿಲ್ಟರ್ ಚಂದಾ:
+subscription_source=ಮೂಲ:
+subscription_status=ಸ್ಟೇಟಸ್:
+subscription_status_autodownload=ಸ್ವಯಂಚಾಲಿತವಾಗಿ ನವೀಕರಿಸಲ್ಪಟ್ಟಿದೆ
+subscription_status_manualdownload=ನಿಮ್ಮಿಂದಾಗಿ ನವೀಕರಿಸಲ್ಪಟ್ಟಿದೆ
+subscription_status_externaldownload=ಬಾಹ್ಯರೀತಿಯಿಂದ ನವೀಕರಿಸಲ್ಪಟ್ಟಿದೆ (ಇನ್ನೊಂದು ಎಕ್ಸ್‍ಟೆನ್ಶನ್)
+subscription_status_lastdownload=ಹಿಂದಿನ ಡೌನ್‌ಲೋಡ್:
+subscription_status_lastdownload_inprogress=ಡೌನ್‌ಲೋಡ್ ಆಗುತ್ತಿದೆ...
+subscription_status_lastdownload_unknown=ಸಂಬಂಧಪಡದ
+remove_subscription_warning=ಈ ಚಂದಾವನ್ನು ನಿಜವಾಗಿಯೂ ತೆಗೆಯಲು ಇಚ್ಚಿಸುತ್ತೀರಾ?
+synchronize_ok=ಗೆಲುವು
+append=ಸೇರಿಸು
+type_label_other=ಇತರ
+type_label_script=ಸ್ಕ್ರಿಪ್ಟ್
+type_label_stylesheet=ಸ್ಟೈಲ್ ಶೀಟ್
+type_label_object=ವಸ್ತು
+type_label_subdocument=ಫ್ರೇಮ್
+type_label_document=ಬರಹ
+type_label_background=ಹಿನ್ನೆಲೆ
+type_label_elemhide=ಅಡಗಿಸಲಾದ
+type_label_xbl=XBL binding
+type_label_ping=ಲಿಂಕ್ ಪಿಂಗ್
+type_label_xmlhttprequest=XML ಕೋರಿಕೆ
+type_label_object_subrequest=ವಸ್ತುವಿನ ಉಪಕೋರಿಕೆ
+type_label_dtd=DTD

=== added file 'chrome/locale/kn/meta.properties'
--- chrome/locale/kn/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/kn/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=ಜಾಹೀರಾತುಗಳು ನಿನ್ನೆಯದಾದವು!

=== added file 'chrome/locale/kn/overlay.dtd'
--- chrome/locale/kn/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/kn/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,19 @@
+<!ENTITY status.tooltip "ಸ್ಟೇಟಸ್:">
+<!ENTITY blocked.tooltip "ಈ ಪುಟದಲ್ಲಿ ತಡೆಹಿಡಿದಿರುವ ವಸ್ತುಗಳು">
+<!ENTITY filters.tooltip "ಬಹಳ ಸಕ್ರಿಯವಾಗಿರುವ ಫಿಲ್ಟರ್‌ಗಳು:">
+<!ENTITY menuitem.label "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY context.image.label "ಚಿತ್ರವನ್ನು ಆಡ್‌ಬ್ಲಾಕ್ ಮಾಡು">
+<!ENTITY context.object.label "ವಸ್ತುವನ್ನು ಆಡ್‌ಬ್ಲಾಕ್ ಮಾಡು">
+<!ENTITY context.frame.label "ಫ್ರೇಮ್ ಅನ್ನು ಆಡ್‌ಬ್ಲಾಕ್ ಮಾಡು">
+<!ENTITY sidebar.title "ಈ ಪುಟದಲ್ಲಿನ ತಡೆಹಿಡಿಯಬಹುದಾದ ವಸ್ತುಗಳು">
+<!ENTITY settings.label "ಆದ್ಯತೆಗಳು">
+<!ENTITY settings.accesskey "F">
+<!ENTITY opensidebar.label "ತಡೆಹಿಡಿಯಬಹುದಾದ ವಸ್ತುಗಳನ್ನು ತೆರೆ">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "ತಡೆಹಿಡಿಯಬಹುದಾದ ವಸ್ತುಗಳನ್ನು ಮುಚ್ಚು">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "?1? ಅಲ್ಲಿ ನಿಷ್ಕ್ರಿಯಗೊಳಿಸು">
+<!ENTITY whitelist.page.label "ಈ ಪುಟದಲ್ಲಿ ಮಾತ್ರ ನಿಷ್ಕ್ರಿಯಗೊಳಿಸು">
+<!ENTITY objecttab.title "ತಡೆ ಹಿಡಿ">
+<!ENTITY objecttab.tooltip "ಈ ವಸ್ತುವನ್ನು ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌ ಮೂಲಕ ತಡೆಹಿಡಿಯಲು ಇಲ್ಲ್ಲಿ ಕ್ಲಿಕ್ ಮಾಡಿ">

=== added file 'chrome/locale/kn/sidebar.dtd'
--- chrome/locale/kn/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/kn/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,22 @@
+<!ENTITY detached.title "ಆಡ್‌ಬ್ಲಾಕ್ ಪ್ಲಸ್‌: ತಡೆಹಿಡಿಯಬಹುದಾದ ವಸ್ತುಗಳು (ಹೊರ ತೆಗೆದಿದೆ)">
+<!ENTITY detach.label "ಹೊರ ತೆಗೆ">
+<!ENTITY reattach.label "ಮರು ಲಗತ್ತಿಸು">
+<!ENTITY search.label "ಹುಡುಕು:">
+<!ENTITY search.accesskey "S">
+<!ENTITY type.label "ಟೈಪ್ ಮಾಡಿ">
+<!ENTITY address.label "ವಿಳಾಸ">
+<!ENTITY filter.label "ಫಿಲ್ಟರ್">
+<!ENTITY state.label "ಸ್ಥಿತಿ">
+<!ENTITY noitems.label "ತಡೆಹಿಡಿಯಬಹುದಾದ ಯಾವುದೇ ವಸ್ತುಗಳಿಲ್ಲ">
+<!ENTITY whitelisted.label "ನಂಬಿಗಸ್ಥ ಪುಟ">
+<!ENTITY tooltip.address.label "ವಿಳಾಸ:">
+<!ENTITY tooltip.type.label "ಟೈಪ್ ಮಾಡಿ:">
+<!ENTITY tooltip.type.blocked "(ತಡೆಹಿಡಿದಿದೆ)">
+<!ENTITY tooltip.type.whitelisted "(ನಂಬಿಗಸ್ಥ)">
+<!ENTITY tooltip.filter.label "ಚಾಲ್ತಿಯಲ್ಲಿರುವ ಫಿಲ್ಟರ್">
+<!ENTITY context.block.label "ಈ ವಸ್ತುವನ್ನು ತಡೆಹಿಡಿ">
+<!ENTITY context.editfilter.label "ಚಾಲ್ತಿಯಲ್ಲಿರುವ ಫಿಲ್ಟರ್ ಅನ್ನು ಸಂಪಾದಿಸು">
+<!ENTITY context.whitelist.label "ವಸ್ತುವಿಗೆ ಒಂದು ಎಕ್ಸೆಪ್ಶನ್ ಸೇರಿಸು">
+<!ENTITY context.open.label "ಹೊಸ ಹಾಳೆಯಲ್ಲಿ ತೆರೆ">
+<!ENTITY context.flash.label "ಫ್ಲಾಶ್ ವಸ್ತುಗಳ ಗಡಿ">
+<!ENTITY context.copy.label "ವಸ್ತುವಿನ ವಿಳಾಸವನ್ನು ಕಾಪಿ ಮಾಡು">

=== added file 'chrome/locale/kn/subscriptionSelection.dtd'
--- chrome/locale/kn/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/kn/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,9 @@
+<!ENTITY dialog.title.edit "ಫಿಲ್ಟರ್ ಚಂದಾವನ್ನು ಸಂಪಾದಿಸು">
+<!ENTITY other.label "ಇನ್ನೊಂದು ಚಂದಾವನ್ನು ಸೇರಿಸಿ">
+<!ENTITY other.accesskey "T">
+<!ENTITY title.label "ಚಂದಾ ಶೀರ್ಷಿಕೆ:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "ಫಿಲ್ಟರ್ ಪಟ್ಟಿಯ ಸ್ಥಾನ:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "ಸ್ವಯಂಚಾಲಿತವಾಗಿ ನವೇನಗೊಳಿಸು">
+<!ENTITY autodownload.accesskey "P">

=== added directory 'chrome/locale/ko'
=== removed directory 'chrome/locale/ko-KR'
=== removed file 'chrome/locale/ko-KR/about.dtd'
--- chrome/locale/ko-KR/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ko-KR/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus에 대하여">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "버전">
-<!ENTITY description "
-	Adblock Plus는 원치않는 광고를 제거합니다.
-	더 이상 광고 또는 배너를 다운로드할 필요가 없습니다.
-	이제 Adblock Plus에게 알려주십시오!
-">
-<!ENTITY homepage.label "Adblock Plus 홈페이지:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "제작자:">
-<!ENTITY contributors.label "배포자:">

=== removed file 'chrome/locale/ko-KR/composer.dtd'
--- chrome/locale/ko-KR/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ko-KR/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus 필터 규칙 추가">
-<!ENTITY accept.label "필터 추가">
-<!ENTITY advanced.label "고급 보기">
-<!ENTITY basic.label "기본 보기">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus가 현재 중지 중입니다. 필터는 추가할 수 있지만 적용되지는 않습니다.">
-<!ENTITY disabled.warning.link "Adblock Plus 사용">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "추가될 필터 그룹 &quot;&#37;S&quot;은(는) 현재 사용 해제 상태입니다. 필터를 더 추가할 수 있지만 자동으로 적용되지는 않습니다.">
-<!ENTITY groupDisabled.warning.link "필터 그룹 사용">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "새 필터:">
-<!ENTITY filter.accesskey "f">
-<!ENTITY preferences.label "저장된 필터 보기...">
-<!ENTITY preferences.accesskey "S">
-<!ENTITY type.filter.label "차단 필터">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "예외 규칙">
-<!ENTITY type.whitelist.accesskey "x">
-<!ENTITY pattern.label "패턴 찾기">
-<!ENTITY pattern.explanation "주소의 어느 부분도 패턴이 될 수 있으며, * 표시는 와일드카드로 동작합니다. 필터는 패턴과 일치하는 주소에만 적용됩니다.">
-<!ENTITY regexp.warning "입력된 패턴은 정규표현식으로 해석되었습니다. 많은 정규표현식은 브라우저의 속도를 저하시킵니다. 정규표현식으로 사용치 않으려면, 패턴 끝부분에 * 표시를 추가하십시오.">
-<!ENTITY shortpattern.warning "입력된 패턴은 최적화하기 너무 짧으며, 이러한 패턴은 브라우저의 속도를 저하시킬 수 있습니다. 좀 더 긴 필터의 입력이 권장됩니다.">
-<!ENTITY custom.pattern.label "사용자:">
-<!ENTITY custom.pattern.accesskey "C">
-<!ENTITY anchors.label "허용 패턴:">
-<!ENTITY anchor.start.label "주소 시작 부분">
-<!ENTITY anchor.start.accesskey "g">
-<!ENTITY anchor.start.flexible.label "도메인명 시작지점">
-<!ENTITY anchor.start.flexible.accesskey "g">
-<!ENTITY anchor.end.label "주소 끝 부분">
-<!ENTITY anchor.end.accesskey "n">
-<!ENTITY options.label "옵션">
-<!ENTITY domainRestriction.label "도메인 제한:">
-<!ENTITY domainRestriction.accesskey "d">
-<!ENTITY domainRestriction.help "한 개 또는 &quot;|&quot; 기호를 이용하여 여러 도메인을 지정하면, 필터는 지정된 도메인에 대해서만 적용됩니다. 도메인명 앞에 &quot;~&quot; 기호는 필터 적용에서 제외됩니다.">
-<!ENTITY firstParty.label "First-party 만">
-<!ENTITY firstParty.accesskey "r">
-<!ENTITY thirdParty.label "Third-party 만">
-<!ENTITY thirdParty.accesskey "T">
-<!ENTITY matchCase.label "대/소문자 구별">
-<!ENTITY matchCase.accesskey "M">
-<!ENTITY types.label "적용 형식:">
-<!ENTITY selectAllTypes.label "모두 선택">
-<!ENTITY unselectAllTypes.label "모든 선택 취소">
-<!ENTITY collapse.label "차단 항목 숨김:">
-<!ENTITY collapse.accesskey "l">
-<!ENTITY collapse.default.yes.label "기본값 적용(예)">
-<!ENTITY collapse.default.no.label "기본값 적용(아니오)">
-<!ENTITY collapse.yes.label "예">
-<!ENTITY collapse.no.label "아니오">

=== removed file 'chrome/locale/ko-KR/global.properties'
--- chrome/locale/ko-KR/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/ko-KR/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=광고는 이제 안녕!
-status_active_label=Adblock
-status_disabled_label=사용 해제
-action0_tooltip=마우스 클릭으로 컨텍스트 메뉴를 엽니다. 가운데 클릭으로 사용 또는 중지합니다.
-action1_tooltip=마우스 클릭으로 차단 가능한 항목을 열거나 닫습니다. 가운데 클릭으로 사용 또는 중지합니다.
-action2_tooltip=마우스 클릭으로 설정 메뉴를 엽니다. 가운데 클릭으로 사용 또는 중지합니다.
-action3_tooltip=마우스 클릭으로 Adblock Plus을 사용 또는 중지합니다.
-active_tooltip=Adblock Plus가 동작 중입니다.
-disabled_tooltip=Adblock Plus가 중지되었습니다.
-whitelisted_tooltip=Adblock Plus가 사용 중이지만, 현재 페이지에서는 중지되었습니다.
-blocked_count_tooltip=-- 항목, 전체 항목: --
-no_blocking_suggestions=현재 페이지에 차단 가능한 항목이 없습니다.
-whitelisted_page=현재 페이지에서 Adblock Plus의 사용이 해제되었습니다.
-whitelist_description=예외 규칙
-filterlist_description=광고 필터
-invalid_description=유효하지 않은 필터
-elemhide_description=항목 감춤 규칙
-subscription_description=필터 표현식:
-subscription_wrong_version=이 표현식의 일부 필터는 정확한 동작을 위해 Adblock Plus를 필요로 합니다.
-subscription_source=소스:
-subscription_status=상태:
-subscription_status_autodownload=자동으로 업데이트 되었습니다.
-subscription_status_manualdownload=수동으로 업데이트 되었습니다.
-subscription_status_externaldownload=외부적으로 업데이트 되었습니다. (다른 확장 기능)
-subscription_status_lastdownload=마지막 다운로드:
-subscription_status_lastdownload_inprogress=다운로드 중...
-subscription_status_lastdownload_unknown=알 수 없음
-remove_subscription_warning=이 표현식을 제거하시겠습니까?
-import_filters_wrong_version=경고: 이 목록의 일부 필터는 정확한 동작을 위해 Adblock Plus를 필요로 합니다. 이 목록을 가져오기 전에 Adblock Plus를 최근 버전으로 업그레이드해야 합니다.
-import_filters_warning=목록 마지막에 현재 필터를 덮어쓰거나 새로운 필터를 추가하시겠습니까?
-import_filters_title=필터 가져오기
-export_filters_title=필터 내보내기
-invalid_filters_file=Adblock Plus 필터 파일이 아닙니다.
-filters_write_error=필터를 파일로 쓰는 중 에러가 발생했습니다. 쓰기 금지 파일이거나 다른 프로그램에서 사용 중인 파일인지 확인하십시오.
-clearall_warning=목록에서 모든 필터를 제거하시겠습니까?
-resethitcounts_warning=히트 통계를 초기화하시겠습니까? 이 기능은 되돌릴 수 없습니다!
-resethitcounts_selected_warning=선택된 필터에 대한 히트 통계를 초기화하시겠습니까? 이 기능은 되돌릴 수 없습니다!
-filter_regexp_tooltip=이 필터는 정규표현식이 아니거나 최적화하기 너무 짧습니다. 이러한 필터들은 브라우저의 속도를 저하시킬 수 있습니다.
-filter_elemhide_duplicate_id=숨겨질 ID는 단 한 개만 정의할 수 있습니다.
-filter_elemhide_nocriteria=크리테리아(criteria)가 정의되지 않았습니다.
-subscription_no_location=필터를 다운로드할 위치를 입력해 주십시오.
-subscription_invalid_location=위치 주소 또는 파일명이 올바르지 않습니다.
-subscription_location_exists=이 필터 목록은 이미 서명되었습니다.
-synchronize_invalid_url=실패함, 유효하지 않은 주소
-synchronize_connection_error=실패함, 다운로드 실패
-synchronize_invalid_data=실패함, 유효하지 않은 필터 목록
-synchronize_checksum_mismatch=실패함, 체크섬 불일치
-synchronize_ok=성공
-overwrite=덮어쓰기
-append=추가
-new_filter_group_title=새 필터
-type_label_other=기타
-type_label_script=스크립트
-type_label_image=이미지
-type_label_stylesheet=스타일시트
-type_label_object=객체
-type_label_subdocument=프레임
-type_label_document=문서
-type_label_background=배경
-type_label_elemhide=숨김
-type_label_xbl=XBL 바인딩
-type_label_ping=링크 핑
-type_label_xmlhttprequest=XML 요청
-type_label_object_subrequest=오브젝트 하위 요구
-type_label_dtd=DTD
-type_label_media=음성/영상
-type_label_font=글꼴

=== removed file 'chrome/locale/ko-KR/overlay.dtd'
--- chrome/locale/ko-KR/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ko-KR/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "상태:">
-<!ENTITY blocked.tooltip "이 페이지에서 차단된 항목:">
-<!ENTITY filters.tooltip "최상위 활성 필터:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: 차단 가능 항목">
-<!ENTITY context.image.label "Adblock Plus: 이미지 차단">
-<!ENTITY context.object.label "Adblock Plus: 객체 차단">
-<!ENTITY context.frame.label "Adblock Plus: 프레임 차단">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: 이 페이지 재설정">
-<!ENTITY sidebar.title "현재 페이지에서 차단 가능한 항목">
-<!ENTITY settings.label "설정">
-<!ENTITY settings.accesskey "F">
-<!ENTITY opensidebar.label "차단 가능한 항목 열기">
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "차단 가능한 항목 닫기">
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "다음 사이트는 차단 안 함 --">
-<!ENTITY whitelist.page.label "현재 페이지만 차단 안 함">
-<!ENTITY objecttab.title "차단">
-<!ENTITY objecttab.tooltip "Adblock Plus로 이 객체를 차단하려면 여기를 누르십시오.">

=== removed file 'chrome/locale/ko-KR/settings.dtd'
--- chrome/locale/ko-KR/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ko-KR/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,91 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus 설정">
-<!ENTITY filters.label "필터">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "필터 추가">
-<!ENTITY add.accesskey "A">
-<!ENTITY addsubscription.label "필터 표현식 추가">
-<!ENTITY addsubscription.accesskey "S">
-<!ENTITY synchsubscriptions.label "모든 표현식 업데이트">
-<!ENTITY synchsubscriptions.accesskey "D">
-<!ENTITY import.label "필터 가져오기">
-<!ENTITY import.accesskey "M">
-<!ENTITY export.label "필터 내보내기">
-<!ENTITY export.accesskey "X">
-<!ENTITY clearall.label "모든 필터 제거">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "통계 초기화">
-<!ENTITY resethitcounts.accesskey "R">
-<!ENTITY edit.label "편집">
-<!ENTITY edit.accesskey "E">
-<!ENTITY cut.label "잘라내기">
-<!ENTITY cut.accesskey "T">
-<!ENTITY copy.label "복사">
-<!ENTITY copy.accesskey "C">
-<!ENTITY paste.label "붙여넣기">
-<!ENTITY paste.accesskey "P">
-<!ENTITY remove.label "삭제">
-<!ENTITY remove.accesskey "D">
-<!ENTITY menu.find.label "찾기">
-<!ENTITY menu.find.accesskey "F">
-<!ENTITY menu.findagain.label "다시 찾기">
-<!ENTITY menu.findagain.accesskey "G">
-<!ENTITY view.label "보기">
-<!ENTITY view.accesskey "V">
-<!ENTITY sort.label "정렬:">
-<!ENTITY sort.accesskey "S">
-<!ENTITY sort.none.label "정렬 안 함">
-<!ENTITY sort.none.accesskey "U">
-<!ENTITY sort.ascending.label "오름차순(A &gt; Z)">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "내림차순(Z &gt; A)">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "옵션">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Adblock Plus 사용하기">
-<!ENTITY enable.accesskey "N">
-<!ENTITY showintoolbar.label "도구 모음에 보이기">
-<!ENTITY showintoolbar.accesskey "B">
-<!ENTITY showinstatusbar.label "상태 표시줄에 보이기">
-<!ENTITY showinstatusbar.accesskey "S">
-<!ENTITY objecttabs.label "플래쉬와 자바를 탭으로 보이기">
-<!ENTITY objecttabs.accesskey "T">
-<!ENTITY collapse.label "차단된 항목 감추기">
-<!ENTITY collapse.accesskey "L">
-<!ENTITY help.label "도움말">
-<!ENTITY help.accesskey "H">
-<!ENTITY gettingStarted.label "시작하기">
-<!ENTITY gettingStarted.accesskey "s">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "자주 묻는 질문">
-<!ENTITY faq.accesskey "F">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Adblock Plus 필터 기록">
-<!ENTITY filterdoc.accesskey "R">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Adblock Plus에 대하여">
-<!ENTITY about.accesskey "B">
-<!ENTITY description "차단하고자 하는 주소를 추가하십시오.
-		일반적인 필터는 &apos;*&apos;을 사용할 수 있습니다.
-		고급 사용자는 정규표현식을 사용할 수 있습니다.(예: /banner\d+\.gif$/)">
-<!ENTITY filter.column "필터 규칙">
-<!ENTITY filter.accesskey "F">
-<!ENTITY slow.column "느린 필터">
-<!ENTITY slow.accesskey "w">
-<!ENTITY enabled.column "사용">
-<!ENTITY enabled.accesskey "n">
-<!ENTITY hitcount.column "히트">
-<!ENTITY hitcount.accesskey "H">
-<!ENTITY lasthit.column "마지막 적용">
-<!ENTITY lasthit.accesskey "L">
-<!ENTITY context.edit.label "필터 편집">
-<!ENTITY context.resethitcount.label "히트 통계 초기화">
-<!ENTITY context.synchsubscription.label "지금 필터 업데이트">
-<!ENTITY context.editsubscription.label "표현식 편집">
-<!ENTITY context.moveup.label "위로">
-<!ENTITY context.movedown.label "아래로">
-<!ENTITY context.movegroupup.label "그룹 위로">
-<!ENTITY context.movegroupdown.label "그룹 아래로">
-<!ENTITY context.enable.label "사용함">
-<!ENTITY context.disable.label "사용 안 함">
-<!ENTITY apply.label "적용">
-<!ENTITY apply.accesskey "P">

=== removed file 'chrome/locale/ko-KR/sidebar.dtd'
--- chrome/locale/ko-KR/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ko-KR/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: 차단 가능한 항목 (제거됨)">
-<!ENTITY detach.label "창 분리">
-<!ENTITY reattach.label "창 통합">
-<!ENTITY search.label "검색:">
-<!ENTITY search.accesskey "S">
-<!ENTITY type.label "형식">
-<!ENTITY address.label "주소">
-<!ENTITY filter.label "필터">
-<!ENTITY state.label "상태">
-<!ENTITY size.label "크기">
-<!ENTITY docDomain.label "문서 원본">
-<!ENTITY noitems.label "차단 가능한 항목 없음">
-<!ENTITY whitelisted.label "차단 목록 페이지">
-<!ENTITY tooltip.address.label "주소:">
-<!ENTITY tooltip.type.label "형식:">
-<!ENTITY tooltip.type.blocked "(차단됨)">
-<!ENTITY tooltip.type.whitelisted "(허용 목록)">
-<!ENTITY tooltip.size.label "크기:">
-<!ENTITY tooltip.docDomain.label "문서 원본:">
-<!ENTITY tooltip.filter.label "필터:">
-<!ENTITY tooltip.filterSource.label "필터 소스:">
-<!ENTITY context.block.label "이 항목 차단">
-<!ENTITY context.editfilter.label "유효한 필터 편집">
-<!ENTITY context.whitelist.label "예외 규칙 추가">
-<!ENTITY context.disablefilter.label "필터 금지 --">
-<!ENTITY context.enablefilter.label "필터 재시작 --">
-<!ENTITY context.disablefilteronsite.label "이 필터 사용 해제 --">
-<!ENTITY context.open.label "새 탭으로 열기">
-<!ENTITY context.flash.label "플래쉬 항목의 테두리">
-<!ENTITY context.copy.label "항목 주소 복사">
-<!ENTITY context.copyFilter.label "필터 복사">
-<!ENTITY context.selectAll.label "모두 선택">

=== removed file 'chrome/locale/ko-KR/subscription.dtd'
--- chrome/locale/ko-KR/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ko-KR/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,15 +0,0 @@
-<!ENTITY dialog.title "필터 표현식 편집">
-<!ENTITY dialog.newtitle "필터 표현식 추가">
-<!ENTITY new.description "Adblock Plus 필터 목록이 포함된 웹주소 또는 파일을 입력하십시오.">
-<!ENTITY edit.description "입력된 주소로부터 필터 목록을 다운로드합니다.">
-<!ENTITY external.description "이것은 외부 필터입니다. 이 필터 목록은 확장 기능에 의해 업데이트할 수 있습니다.">
-<!ENTITY autodownload.description "&apos;자동 업데이트&apos;를 선택하면 매일 매일 업데이트를 확인합니다.
-	이 기능이 선택되면 컨텍스트 메뉴에서 수동 업데이트 기능은 사용할 수 없습니다.">
-<!ENTITY location.label "필터 목록 위치:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "표현식 제목:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "자동 업데이트">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.label "필터 사용하기">
-<!ENTITY enabled.accesskey "N">

=== removed file 'chrome/locale/ko-KR/tip_subscriptions.dtd'
--- chrome/locale/ko-KR/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ko-KR/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus에 오신 것을 환영합니다.">
-<!ENTITY description.par1 "Adblock Plus를 설치해 주셔서 감사합니다.
-이 확장 기능은 광고를 필터링 합니다.
-효율적인 필터링을 위해서는 필터를 잘 설정하여야 합니다.
-필터 설정은 사용자 스스로 할 수 있으며, 간단히 기존의 것을 추가할 수도 있습니다.
-또한 언제라도 필요에 따라 추가/비활성화/삭제가 가능합니다.">
-<!ENTITY description.par2 "아래 목록에서 추천되는 표현식을 선택할 수 있습니다.">
-<!ENTITY note "주: 필터 목록은 그 필터가 생성된 웹사이트에서 가장 효율적으로 동작합니다.">
-<!ENTITY adblock.warning "Adblock Plus가 Adblock 또는 이전 버전의 Adblock Plus를 찾았습니다. Adblock과 Adblock Plus를 동시에 실행하면 문제를 일으킬 수 있어 피해야 합니다. 지금 Adblock을 제거하시는 것이 좋습니다.(권장됨)">
-<!ENTITY adblock.uninstall "Adblock 제거">
-<!ENTITY filterset.g.warning "Filterset.G가 사용 중인 것 같습니다. 이 필터 목록은 현재 거의 관리되지 않아, 웹사이트와 문제를 일으킬 수 있습니다. 지금 Filterset.G를 제거하시는 것이 좋습니다.(권장됨)">
-<!ENTITY filterset.g.moreinfo "더 많은 정보">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Filterset.G 제거">
-<!ENTITY homepage.label "홈페이지">
-<!ENTITY subscribe.label "표현식">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "다른 표현식 추가">
-<!ENTITY other.accesskey "f">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "모든 표현식 보기">

=== added file 'chrome/locale/ko/about.dtd'
--- chrome/locale/ko/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ko/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Adblock Plus 정보">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "버전">
+<!ENTITY description "Adblock Plus(애드블록 플러스)는 보기 싫은 광고를 제거하여 더욱 빠르고 쾌적한 인터넷 환경을 만들어줍니다. 성가신 광고가 있다면 이젠 Adblock Plus와 함께 하십시오.">
+<!ENTITY homepage.label "홈페이지">
+<!ENTITY homepage.url "http://adblockplus.org">
+<!ENTITY author.label "개발자">
+<!ENTITY contributors.label "공헌자">
+<!ENTITY developers.label "개발자">
+<!ENTITY designers.label "그래픽 디자이너">
+<!ENTITY subscriptionAuthors.label "구독 필터 유지자">
+<!ENTITY translators.label "번역가">

=== added file 'chrome/locale/ko/composer.dtd'
--- chrome/locale/ko/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ko/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "필터 추가">
+<!ENTITY accept.label "추가">
+<!ENTITY advanced.label "고급 보기">
+<!ENTITY basic.label "기본 보기">
+<!ENTITY disabled.warning "현재 Adblock Plus 사용 안 함 : 필터 추가 가능 + 필터 적용 안 함 [link]⇔ Adblock Plus 사용함[/link]">
+<!ENTITY groupDisabled.warning "현재 &quot;?1?&quot; 그룹 사용 안 함 : 필터 추가 가능 + 필터 적용 안 함 [link]⇔ 이 그룹 사용함[/link]">
+<!ENTITY filter.label "새 필터">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "필터 목록에서 주소 편집">
+<!ENTITY preferences.accesskey "S">
+<!ENTITY type.filter.label "차단 필터">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "허용 필터">
+<!ENTITY type.whitelist.accesskey "x">
+<!ENTITY pattern.label "패턴 찾기">
+<!ENTITY pattern.explanation "패턴과 일치하는 주소에만 필터가 적용되며, 패턴은 일치하는 주소를 찾는 텍스트 문자열로서 필터에 반영됩니다.">
+<!ENTITY regexp.warning "[느린 필터] 패턴 끝에 와일드카드(*)가 없으면 정규 표현식으로 해석되며, 웹 페이지를 불러오는 속도가 느려짐.">
+<!ENTITY shortpattern.warning "[느린 필터] 패턴의 길이가 너무 짧으면 필터가 비효율적으로 처리되며, 웹 페이지를 불러오는 속도가 느려짐.">
+<!ENTITY custom.pattern.label "사용자 정의 (C)">
+<!ENTITY custom.pattern.accesskey "C">
+<!ENTITY anchors.label "패턴 일치 조건 :">
+<!ENTITY anchor.start.label "주소 시작 부분에 일치">
+<!ENTITY anchor.start.accesskey "g">
+<!ENTITY anchor.start.flexible.label "도메인 시작 부분에 일치">
+<!ENTITY anchor.start.flexible.accesskey "g">
+<!ENTITY anchor.end.label "주소 끝 부분에 일치">
+<!ENTITY anchor.end.accesskey "n">
+<!ENTITY options.label "옵션">
+<!ENTITY domainRestriction.label "지정된 도메인에만 적용(D) :">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "1. 파이프 기호(|)를 이용해 여러 도메인에 적용 (예시 : site1.com|site2.net). 2. 물결 기호(~)를 이용해 필터를 적용하지 않을 도메인 지정 (예시 : ~site.com)">
+<!ENTITY firstParty.label "도메인이 같은 사이트에만 적용">
+<!ENTITY firstParty.accesskey "r">
+<!ENTITY thirdParty.label "도메인이 다른 사이트에만 적용">
+<!ENTITY thirdParty.accesskey "T">
+<!ENTITY matchCase.label "대/소문자 구분">
+<!ENTITY matchCase.accesskey "M">
+<!ENTITY types.label "적용 형식">
+<!ENTITY selectAllTypes.label "모두 선택">
+<!ENTITY unselectAllTypes.label "선택 없음">
+<!ENTITY collapse.label "차단된 요소의 영역 접기">
+<!ENTITY collapse.accesskey "l">
+<!ENTITY collapse.default.yes.label "기본값 (예)">
+<!ENTITY collapse.default.no.label "기본값 (아니오)">
+<!ENTITY collapse.yes.label "예">
+<!ENTITY collapse.no.label "아니오">

=== added file 'chrome/locale/ko/global.properties'
--- chrome/locale/ko/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ko/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=마우스 오른쪽 버튼 - 문맥 메뉴. 마우스 오른쪽 버튼 - 문맥 메뉴
+action1_tooltip=마우스 왼쪽 - 차단 가능한 항목 열기/닫기. 마우스 가운데 버튼 - 사용함/사용 안 함
+action2_tooltip=마우스 왼쪽 버튼 - 설정 창 열기. 마우스 오른쪽 버튼 - 문맥 메뉴
+action3_tooltip=광고차단 더하기 사용함/사용 안 함
+disabled_tooltip=Adblock Plus 사용 안 함
+active_tooltip=Adblock Plus 사용함 [구독 필터 : ?1?개, 사용자 필터 : ?2?개 ]
+whitelisted_tooltip=Adblock Plus 사용함 + 현재 페이지 허용됨
+blocked_count_tooltip=차단 : ?1?개, 전체 항목 : ?2?개
+blocked_count_addendum=(허용 : ?1?개, 요소 숨김 : ?2?개)
+no_blocking_suggestions=현재 페이지에 차단 가능한 항목이 없습니다.
+whitelisted_page=허용된 페이지
+whitelist_description=허용 규칙
+filterlist_description=차단 규칙
+invalid_description=유효하지 않은 필터
+elemhide_description=요소 숨김 규칙
+subscription_description=구독 필터 :
+subscription_wrong_version=구독 필터가 정상적으로 기능하기 위해선 Adblock Plus ?1? 버전을 설치해야 합니다.
+subscription_source=위치 :
+subscription_status=상태 :
+subscription_status_autodownload=자동 업데이트
+subscription_status_manualdownload=수동 업데이트
+subscription_status_externaldownload=외부 업데이트(다른 부가 기능)
+subscription_status_lastdownload=마지막 다운로드 :
+subscription_status_lastdownload_inprogress=다운로드 중...
+subscription_status_lastdownload_unknown=알 수 없음
+remove_subscription_warning=이 구독 필터를 제거하시겠습니까?
+import_filters_wrong_version=경고 : 정상적인 필터 작동을 위해 Adblock Plus ?1? 버전 이상을 설치해야 합니다. 이 목록을 가져오기 전에 Adblock Plu 최신 버전으로 업그레이드하십시오.
+import_filters_warning=가져온 필터를 현재의 사용자 필터에 덮어쓰거나 규칙별로 목록 끝에 추가하시겠습니까?
+import_filters_title=필터 가져오기
+export_filters_title=사용자 필터 내보내기
+invalid_filters_file=Adblock Plus의 필터 파일이 아닙니다.
+filters_write_error=필터를 파일로 저장하는 중 오류가 발생했습니다. 쓰기 금지 파일이거나 다른 프로그램에서 사용 중인 파일인지 확인하십시오.
+clearall_warning=필터 목록에서 모든 사용자 필터를 제거하시겠습니까?
+resethitcounts_warning=필터 적용 횟수를 초기화하시겠습니까? 이 기능은 되돌릴 수 없습니다!
+resethitcounts_selected_warning=선택한 필터의 적용 횟수를 초기화하시겠습니까? 이 기능은 되돌릴 수 없습니다!
+filter_regexp_tooltip=이 필터는 정규 표현식이거나 최적화하기에 길이가 너무 짧으므로 웹 페이지를 불러오는 속도가 느려짐
+filter_elemhide_duplicate_id=숨길 요소의 ID는 한 개만 정의할 수 있습니다.
+filter_elemhide_nocriteria=숨길 요소를 인식하기 위한 기준이 정의되지 않았습니다.
+subscription_notAdded_warning=구독 필터를 추가하지 않았습니다. 구독 필터가 없으면 필터를 직접 추가해야 합니다.
+subscription_notAdded_warning_addendum=계속 진행하시겠습니까?
+subscription_invalid_location=구독 필터의 위치에 입력하는 URL 또는 파일명이 올바르지 않습니다.
+synchronize_invalid_url=실패함 : 잘못된 주소
+synchronize_connection_error=실패함 : 다운로드 실패
+synchronize_invalid_data=실패함 : 유효하지 않은 필터
+synchronize_checksum_mismatch=실패함 : 체크섬 불일치
+synchronize_ok=동기화 성공
+overwrite=덮어쓰기
+append=추가
+new_filter_group_title=새 필터
+type_label_other=기타
+type_label_script=스크립트
+type_label_image=이미지
+type_label_stylesheet=스타일시트
+type_label_object=객체
+type_label_subdocument=프레임
+type_label_document=문서
+type_label_background=배경
+type_label_elemhide=숨긴 요소
+type_label_xbl=XBL 바인딩
+type_label_ping=링크 핑
+type_label_xmlhttprequest=XML 요청
+type_label_object_subrequest=객체 하위 요청
+type_label_dtd=DTD
+type_label_media=오디오/비디오
+type_label_font=글꼴
+fennec_status_enabled=Adblock Plus 사용함
+fennec_status_disabled=Adblock Plus 사용 안 함
+fennec_status_enabled_site=?1?에서 Adblock Plus 사용함
+fennec_status_disabled_site=?1?에서 Adblock Plus 사용 안 함

=== added file 'chrome/locale/ko/meta.properties'
--- chrome/locale/ko/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ko/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=sushizang, maybee
+name=Adblock Plus
+description=광고, 이제 안녕!
+description.short=성가신 배너나 짜증나는 광고가 있습니까? 인터넷 상의 개인 정보 누출을 걱정하고 있습니까? 인터넷 통제권을 되찾고, 웹 문서를 보는 방식의 변화를 위해 지금 Adblock Plus를 설치하십시오.\n\n간략한 소개 영상 : http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus를 이용하면 인터넷 통제권을 되찾고, 보고 싶은 방식대로 웹 문서를 볼 수 있습니다. 이 부가 기능은 온라인 광고 제거에서부터 유명한 모든 악성 도메인 차단까지 다양한 목적을 위해 자동 설정되는 구독 필터를 지원하며, 현재 수십개 언어에 대한 40개 이상의 구독 필터를 이용 가능합니다. 뿐만 아니라 이미지 차단을 위한 문맥 메뉴, 플래시와 자바 객체에 대한 차단 탭, 스크립트와 스타일시트까지 제거할 수 있는 차단 가능한 항목의 목록 등 다양하고 유용한 기능을 지원하여 원하는 형태의 필터를 작성할 수 있습니다.

=== added file 'chrome/locale/ko/overlay.dtd'
--- chrome/locale/ko/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ko/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "상태">
+<!ENTITY blocked.tooltip "이 페이지에 적용된 규칙">
+<!ENTITY filters.tooltip "많이 적용된 필터">
+<!ENTITY menuitem.label "설정">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus : 차단 가능 항목">
+<!ENTITY context.image.label "Adblock Plus : 이미지 차단">
+<!ENTITY context.object.label "Adblock Plus : 객체 차단">
+<!ENTITY context.frame.label "Adblock Plus : 프레임 차단">
+<!ENTITY context.media.label "Adblock Plus : 비디오/오디오 차단">
+<!ENTITY context.removeWhitelist.label "Adblock Plus : 페이지 허용 필터 삭제">
+<!ENTITY sidebar.title "현재 페이지에서 차단 가능한 항목">
+<!ENTITY settings.label "설정">
+<!ENTITY settings.accesskey "F">
+<!ENTITY opensidebar.label "차단 가능한 항목 열기 (B)">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "차단 가능한 항목 닫기 (B)">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "사이트 허용 : ?1?">
+<!ENTITY whitelist.page.label "현재 페이지만 허용">
+<!ENTITY objecttab.title "차단">
+<!ENTITY objecttab.tooltip "Adblock Plus로 이 객체를 차단하려면 차단 탭을 누르십시오.">

=== added file 'chrome/locale/ko/settings.dtd'
--- chrome/locale/ko/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ko/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "설정">
+<!ENTITY filters.label "필터">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "필터 추가">
+<!ENTITY add.accesskey "A">
+<!ENTITY addsubscription.label "구독 필터 추가">
+<!ENTITY addsubscription.accesskey "S">
+<!ENTITY synchsubscriptions.label "모든 구독 필터 업데이트">
+<!ENTITY synchsubscriptions.accesskey "D">
+<!ENTITY import.label "필터 가져오기">
+<!ENTITY import.accesskey "M">
+<!ENTITY export.label "사용자 필터 내보내기">
+<!ENTITY export.accesskey "X">
+<!ENTITY clearall.label "모든 사용자 필터 제거">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "필터 적용 횟수 초기화">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "편집">
+<!ENTITY edit.accesskey "E">
+<!ENTITY cut.label "잘라내기">
+<!ENTITY cut.accesskey "T">
+<!ENTITY copy.label "복사">
+<!ENTITY copy.accesskey "C">
+<!ENTITY paste.label "붙여넣기">
+<!ENTITY paste.accesskey "P">
+<!ENTITY remove.label "삭제">
+<!ENTITY remove.accesskey "D">
+<!ENTITY menu.find.label "찾기">
+<!ENTITY menu.find.accesskey "F">
+<!ENTITY menu.findagain.label "다시 찾기">
+<!ENTITY menu.findagain.accesskey "G">
+<!ENTITY view.label "보기">
+<!ENTITY view.accesskey "V">
+<!ENTITY sort.label "정렬">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "정렬 안 함">
+<!ENTITY sort.none.accesskey "U">
+<!ENTITY sort.ascending.label "오름차순 (A ⇒ Z)">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "내림차순 (Z ⇒ A)">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "옵션">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Adblock Plus 사용함">
+<!ENTITY enable.accesskey "N">
+<!ENTITY showintoolbar.label "툴바에 아이콘 보이기">
+<!ENTITY showintoolbar.accesskey "B">
+<!ENTITY showinstatusbar.label "상태 표시줄에 아이콘 보이기">
+<!ENTITY showinstatusbar.accesskey "S">
+<!ENTITY objecttabs.label "플래시/자바 차단 탭 표시">
+<!ENTITY objecttabs.accesskey "T">
+<!ENTITY collapse.label "차단된 요소의 영역 접기">
+<!ENTITY collapse.accesskey "L">
+<!ENTITY help.label "도움말">
+<!ENTITY help.accesskey "H">
+<!ENTITY gettingStarted.label "시작하기">
+<!ENTITY gettingStarted.accesskey "s">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "자주 묻는 질문">
+<!ENTITY faq.accesskey "F">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "필터 작성 방법">
+<!ENTITY filterdoc.accesskey "R">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Adblock Plus 정보">
+<!ENTITY about.accesskey "B">
+<!ENTITY description "애드블록 플러스의 필터는 웹 콘텐트의 주소를 차단/허용하거나 페이지의 구성 요소를 숨길 수 있습니다.">
+<!ENTITY filter.column "필터">
+<!ENTITY filter.accesskey "F">
+<!ENTITY slow.column "느린 필터(!)">
+<!ENTITY slow.accesskey "w">
+<!ENTITY enabled.column "사용">
+<!ENTITY enabled.accesskey "n">
+<!ENTITY hitcount.column "적용 횟수">
+<!ENTITY hitcount.accesskey "H">
+<!ENTITY lasthit.column "마지막 적용 날짜">
+<!ENTITY lasthit.accesskey "L">
+<!ENTITY context.edit.label "필터 편집">
+<!ENTITY context.resethitcount.label "필터 적용 횟수 초기화">
+<!ENTITY context.synchsubscription.label "구독 필터 업데이트">
+<!ENTITY context.editsubscription.label "구독 필터 편집">
+<!ENTITY context.moveup.label "필터를 위로 이동">
+<!ENTITY context.movedown.label "필터를 아래로 이동">
+<!ENTITY context.movegroupup.label "그룹을 위로 이동">
+<!ENTITY context.movegroupdown.label "그룹을 아래로 이동">
+<!ENTITY context.enable.label "필터/그룹 사용함">
+<!ENTITY context.disable.label "필터/그룹 사용 안 함">
+<!ENTITY apply.label "적용">
+<!ENTITY apply.accesskey "P">
+<!ENTITY fennec.subscription.label "구독 필터">

=== added file 'chrome/locale/ko/sidebar.dtd'
--- chrome/locale/ko/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ko/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "차단 가능한 항목 (분리됨)">
+<!ENTITY detach.label "분리">
+<!ENTITY reattach.label "통합">
+<!ENTITY search.label "검색 (S)">
+<!ENTITY search.accesskey "S">
+<!ENTITY type.label "형식">
+<!ENTITY address.label "주소">
+<!ENTITY filter.label "필터">
+<!ENTITY state.label "상태">
+<!ENTITY size.label "크기">
+<!ENTITY docDomain.label "문서 위치">
+<!ENTITY noitems.label "차단 가능한 항목 없음">
+<!ENTITY whitelisted.label "허용된 페이지">
+<!ENTITY tooltip.address.label "주소 :">
+<!ENTITY tooltip.type.label "형식 :">
+<!ENTITY tooltip.type.blocked "(차단됨)">
+<!ENTITY tooltip.type.whitelisted "(허용됨)">
+<!ENTITY tooltip.size.label "크기 :">
+<!ENTITY tooltip.docDomain.label "문서 위치 :">
+<!ENTITY tooltip.filter.label "필터 :">
+<!ENTITY tooltip.filterSource.label "그룹 :">
+<!ENTITY context.block.label "차단 필터 추가">
+<!ENTITY context.editfilter.label "필터 편집">
+<!ENTITY context.whitelist.label "허용 필터 추가">
+<!ENTITY context.disablefilter.label "필터 사용 안 함 : ?1?">
+<!ENTITY context.enablefilter.label "필터 다시 사용함 : ?1?">
+<!ENTITY context.disablefilteronsite.label "필터 적용 안 할 도메인 지정 : ?1?">
+<!ENTITY context.open.label "새 탭으로 열기">
+<!ENTITY context.flash.label "항목 테두리 깜빡임">
+<!ENTITY context.copy.label "주소 복사">
+<!ENTITY context.copyFilter.label "필터 복사">
+<!ENTITY context.selectAll.label "모두 선택">

=== added file 'chrome/locale/ko/subscriptionSelection.dtd'
--- chrome/locale/ko/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ko/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "구독 필터 추가">
+<!ENTITY dialog.title.edit "구독 필터 편집">
+<!ENTITY description.newInstall "구독 필터는 주기적으로 업데이트되는 필터 목록을 통해 광고를 효율적으로 차단할 수 있는 편리함을 제공합니다.">
+<!ENTITY adblock.warning "Adblock 또는 Adblock Plus 구버전을 찾았습니다. Adblock과 Adblock Plus를 함께 설치하면 문제가 발생할 수 있으니 Adblock 제거를 권장합니다.">
+<!ENTITY adblock.uninstall "Adblock Plus 제거">
+<!ENTITY filterset.g.warning "Filterset.G를 사용 중입니다. 이 구독 필터는 현재 관리되지 않아 웹 사이트 방문 시 문제가 발생할 수 있습니다. Filterset.G 제거를 권장합니다.">
+<!ENTITY filterset.g.moreinfo "더 많은 정보">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Filterset.G 제거">
+<!ENTITY subscriptionSelector.label "목록에서 구독할 필터를 선택하거나 이름/위치를 직접 입력하십시오.">
+<!ENTITY viewList.label "필터 보기">
+<!ENTITY visitHomepage.label "홈페이지">
+<!ENTITY addSubscription.label "추가">
+<!ENTITY saveSubscription.label "확인">
+<!ENTITY other.label "다른 구독 필터 추가">
+<!ENTITY other.accesskey "f">
+<!ENTITY list.download.failed "구독 필터 목록의 검색 실패">
+<!ENTITY list.download.retry "재시도">
+<!ENTITY list.download.website "웹 사이트">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "추가하고자 한 구독 필터인지 확인하십시오. 추가하기 전에 이름 또는 위치를 변경할 수 있습니다.">
+<!ENTITY edit.description "구독 필터의 이름 또는 위치를 변경할 수 있습니다.">
+<!ENTITY external.description "외부 구독 필터입니다. 이 구독 필터에 의해 필터 목록이 주기적으로 업데이트됩니다.">
+<!ENTITY title.label "이름 (T)">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "위치 (L)">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "자동 업데이트 (P)">
+<!ENTITY autodownload.accesskey "P">
+<!ENTITY supplementMessage "위에서 선택한 구독 필터는 &quot;?1?&quot;와(과) 함께 사용할 것을 권장합니다.">
+<!ENTITY addMain.label "&quot;?1?&quot; 구독 필터도 함께 추가">
+<!ENTITY addMain.accesskey "s">

=== added directory 'chrome/locale/lt'
=== removed directory 'chrome/locale/lt-LT'
=== removed file 'chrome/locale/lt-LT/about.dtd'
--- chrome/locale/lt-LT/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/lt-LT/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Apie „Adblock Plus“">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Versija">
-<!ENTITY description "„Adblock Plus“ Jums patiems leidžia nuspręsti, ką norite matyti Internete. Jums nereikia siųsti visų reklamų, jei jų nenorite matyti - nurodykite „Adblock Plus“!">
-<!ENTITY homepage.label "„Adblock Plus“ pradžios tinklalapis:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Autorius:">
-<!ENTITY contributors.label "Prisidėjo:">

=== removed file 'chrome/locale/lt-LT/composer.dtd'
=== removed file 'chrome/locale/lt-LT/global.properties'
--- chrome/locale/lt-LT/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/lt-LT/global.properties	1970-01-01 00:00:00 +0000
@@ -1,55 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Reklamos - tai jau praeitis!
-status_active_label=Reklamų blokavimas
-status_disabled_label=Išjungta
-action0_tooltip=Spragtelkite, norėdami iškviesti kontekstinį meniu; spragtelkite viduriniuoju klavišu norėdami įjungti/išjungti.
-action1_tooltip=Spragtelkite, norėdami atverti/užverti blokuojamus elementus; spragtelkite viduriniuoju klavišu norėdami įjungti/išjungti.
-action2_tooltip=Spragtelkite, norėdami atverti nustatymus; spragtelkite viduriniuoju klavišu norėdami įjungti/išjungti.
-action3_tooltip=Spragtelkite, norėdami įjungti/išjungti „Adblock Plus“.
-active_tooltip=„Adblock Plus“ aktyvus.
-disabled_tooltip=„Adblock Plus“ išjungtas.
-whitelisted_tooltip=„Adblock Plus“ aktyvus, bet išjungtas dabartiniam tinklalapiui.
-blocked_count_tooltip=-- iš --
-no_blocking_suggestions=Jokių blokuojamų elementų dabartiniame tinklalapyje
-whitelisted_page=„Adblock Plus“ yra išjungtas dabartiniam tinklalapiui
-whitelist_description=Išimčių taisyklės
-filterlist_description=Reklamų filtrai
-invalid_description=Netaisyklingi filtrai
-elemhide_description=Elementų paslėpimo taisyklės
-subscription_description=Filtrų prenumerata:
-subscription_wrong_version=Kai kurių šios prenumeratos filtrų tinkamam darbui reikia „Adblock Plus“ --!
-subscription_source=Šaltinis:
-subscription_status=Būsena:
-subscription_status_autodownload=Automatiškai atnaujinta
-subscription_status_manualdownload=Atnaujinta rankiniu būdu
-subscription_status_externaldownload=Atnaujinta kitu priedu
-subscription_status_lastdownload=Paskutinis atsiuntimas:
-subscription_status_lastdownload_inprogress=Atsiunčiama...
-subscription_status_lastdownload_unknown=N/D
-remove_subscription_warning=Ar tikrai norite atsisakyti šios prenumeratos?
-import_filters_wrong_version=Įspėjimas: kai kurių šio sąrašo filtrų tinkamam darbui reikia „Adblock Plus“ --. Jūs turėtumėte atnaujinti „Adblock Plus“ prieš importuodami šį sąrašą.
-import_filters_warning=Ar norite pakeisti dabartinius filtrus, ar pridėti naujus filtrus į sąrašo apačią?
-import_filters_title=Importuoti filtrus
-export_filters_title=Eksportuoti filtrus
-invalid_filters_file=Netinkamas „Adblock Plus“ filtrų failas.
-filters_write_error=Įvyko klaida rašant filtrus į failą. Įsitikinkite, kad failas nėra apsaugotas nuo rašymo ar naudojamas kitos programos.
-clearall_warning=Ar tikrai norite pašalinti visus filtrus iš sąrašo?
-resethitcounts_warning=Ar tikrai norite atstatyti aplankymų skaitiklius visiems filtrams? Šis veiksmas negali būti grąžinamas!
-resethitcounts_selected_warning=Ar tikrai norite atstatyti aplankymų skaitiklius pasirinktiems filtrams? Šis veiksmas negali būti grąžinamas!
-subscription_no_location=Įveskite adresą, iš kurio siųsitės filtrus.
-subscription_invalid_location=Filtrų sąrašo adresas nėra taisyklingas URL ar failo vardas.
-subscription_location_exists=Jūs jau užsiprenumeravote šį filtrų sąrašą.
-synchronize_invalid_url=Nepavyko, netinkamas adresas
-synchronize_connection_error=Nepavyko, atsiuntimo klaida
-synchronize_invalid_data=Nepavyko, netinkamas filtrų sąrašas
-synchronize_ok=Pavyko
-overwrite=Pakeisti
-append=Pridėti
-type_label_other=kita
-type_label_script=skriptas
-type_label_image=paveikslėlis
-type_label_stylesheet=stilius
-type_label_object=objektas
-type_label_subdocument=kadras
-type_label_document=dokumentas
-type_label_background=fonas
-type_label_elemhide=paslėpta

=== removed file 'chrome/locale/lt-LT/overlay.dtd'
--- chrome/locale/lt-LT/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/lt-LT/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-<!ENTITY status.tooltip "Būsena:">
-<!ENTITY blocked.tooltip "Šiame tinklalapyje užblokuoti elementai:">
-<!ENTITY filters.tooltip "Aktyviausi filtrai:">
-<!ENTITY menuitem.label "„Adblock Plus“">
-<!ENTITY menuitem.accesskey "A">
-<!ENTITY context.image.label "Blokuoti paveikslėlį">
-<!ENTITY context.object.label "Blokuoti objektą">
-<!ENTITY context.frame.label "Blokuoti kadrą">
-<!ENTITY sidebar.title "Blokuojami elementai dabartiniame tinklalapyje">
-<!ENTITY settings.label "Nustatymai">
-<!ENTITY settings.accesskey "N">
-<!ENTITY opensidebar.label "Atverti blokuojamus elementus">
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "Užverti blokuojamus elementus">
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Išjungti --">
-<!ENTITY whitelist.page.label "Išjungti šiam tinklalapiui">
-<!ENTITY objecttab.title "Blokuoti">
-<!ENTITY objecttab.tooltip "Spragtelkite čia norėdami užblokuoti šį objektą su „Adblock Plus“">

=== removed file 'chrome/locale/lt-LT/settings.dtd'
--- chrome/locale/lt-LT/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/lt-LT/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-<!ENTITY dialog.title "„Adblock Plus“ nustatymai">
-<!ENTITY filters.label "Filtrai">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Pridėti filtrą">
-<!ENTITY add.accesskey "D">
-<!ENTITY addsubscription.label "Pridėti filtro prenumeratą">
-<!ENTITY addsubscription.accesskey "P">
-<!ENTITY synchsubscriptions.label "Atnaujinti visas prenumeratas">
-<!ENTITY synchsubscriptions.accesskey "u">
-<!ENTITY import.label "Importuoti filtrus">
-<!ENTITY import.accesskey "M">
-<!ENTITY export.label "Eksportuoti filtrus">
-<!ENTITY export.accesskey "K">
-<!ENTITY clearall.label "Pašalinti visus filtrus">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "Atstatyti aplankymų statistiką">
-<!ENTITY resethitcounts.accesskey "S">
-<!ENTITY edit.label "Taisa">
-<!ENTITY edit.accesskey "T">
-<!ENTITY cut.label "Iškirpti">
-<!ENTITY cut.accesskey "r">
-<!ENTITY copy.label "Kopijuoti">
-<!ENTITY copy.accesskey "K">
-<!ENTITY paste.label "Įdėti">
-<!ENTITY paste.accesskey "d">
-<!ENTITY remove.label "Pašalinti">
-<!ENTITY remove.accesskey "š">
-<!ENTITY menu.find.label "Rasti">
-<!ENTITY menu.find.accesskey "A">
-<!ENTITY menu.findagain.label "Rasti vėl">
-<!ENTITY menu.findagain.accesskey "V">
-<!ENTITY options.label "Pasirinktys">
-<!ENTITY options.accesskey "P">
-<!ENTITY enable.label "Įjungti „Adblock Plus“">
-<!ENTITY enable.accesskey "J">
-<!ENTITY showintoolbar.label "Rodyti priemonių juostoje">
-<!ENTITY showintoolbar.accesskey "P">
-<!ENTITY showinstatusbar.label "Rodyti būsenos juostoje">
-<!ENTITY showinstatusbar.accesskey "B">
-<!ENTITY objecttabs.label "Rodyti korteles Flash ir Java elementams">
-<!ENTITY objecttabs.accesskey "F">
-<!ENTITY collapse.label "Suskleisti užblokuotus elementus">
-<!ENTITY collapse.accesskey "S">
-<!ENTITY help.label "Pagalba">
-<!ENTITY help.accesskey "G">
-<!ENTITY faq.label "Dažnai užduodami klausimai">
-<!ENTITY faq.accesskey "D">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Kaip rašyti „Adblock Plus“ filtrus">
-<!ENTITY filterdoc.accesskey "f">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Apie „Adblock Plus“">
-<!ENTITY about.accesskey "A">
-<!ENTITY description "Pridėkite adresus, kuriuos norite blokuoti. Norėdami gauti pasiūlymus, peržiūrėkite išskleidžiamąjį sąrašą. Galite pridėti „*“ kaip pakaitos simbolį norėdami sukurti bendresnius filtrus. Patyrę naudotojai gali naudoti reguliariuosius reiškinius, tokius kaip „/banner\d+\.gif$/“.">
-<!ENTITY enabled.column "Įjungta">
-<!ENTITY hitcount.column "Aplankymai">
-<!ENTITY lasthit.column "Paskutinis blokavimas">
-<!ENTITY context.edit.label "Redaguoti filtrą">
-<!ENTITY context.resethitcount.label "Atstatyti aplankymų statistiką filtrui">
-<!ENTITY context.synchsubscription.label "Atnaujinti prenumeratą">
-<!ENTITY context.editsubscription.label "Redaguoti prenumeratą">
-<!ENTITY context.moveup.label "Perkelti aukščiau">
-<!ENTITY context.movedown.label "Perkelti žemiau">
-<!ENTITY context.movegroupup.label "Perkelti grupę aukščiau">
-<!ENTITY context.movegroupdown.label "Perkelti grupę žemiau">
-<!ENTITY apply.label "Pritaikyti">
-<!ENTITY apply.accesskey "R">

=== removed file 'chrome/locale/lt-LT/sidebar.dtd'
--- chrome/locale/lt-LT/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/lt-LT/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY detached.title "„Adblock Plus“ blokuojami elementai (iškelta)">
-<!ENTITY detach.label "Iškelti">
-<!ENTITY reattach.label "Iš naujo įkelti">
-<!ENTITY search.label "Ieškoti:">
-<!ENTITY search.accesskey "I">
-<!ENTITY type.label "Tipas">
-<!ENTITY address.label "Adresas">
-<!ENTITY filter.label "Filtras">
-<!ENTITY state.label "Būsena">
-<!ENTITY noitems.label "Nėra blokuojamų elementų">
-<!ENTITY whitelisted.label "Tinklalapis, įtrauktas į išimtis">
-<!ENTITY tooltip.address.label "Adresas:">
-<!ENTITY tooltip.type.label "Tipas:">
-<!ENTITY tooltip.type.blocked "(užblokuota)">
-<!ENTITY tooltip.type.whitelisted "(įtraukta į išimtis)">
-<!ENTITY tooltip.filter.label "Galiojantys filtrai:">
-<!ENTITY context.block.label "Blokuoti šį elementą">
-<!ENTITY context.editfilter.label "Redaguoti aktyvų filtrą">
-<!ENTITY context.whitelist.label "Pridėti išimties taisyklę šiam elementui">
-<!ENTITY context.open.label "Atverti naujoje kortelėje">
-<!ENTITY context.flash.label "Paryškinti elemento rėmelį">
-<!ENTITY context.copy.label "Kopijuoti elemento adresą">

=== removed file 'chrome/locale/lt-LT/subscription.dtd'
--- chrome/locale/lt-LT/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/lt-LT/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Redaguoti filtrų prenumeratą">
-<!ENTITY dialog.newtitle "Pridėti filtrų prenumeratą">
-<!ENTITY new.description "Įveskite adresą, kuriame yra „Adblock Plus“ filtrai.">
-<!ENTITY edit.description "Filtrų sąrašas šiai prenumeratai bus atsiųstas iš nurodyto adreso.">
-<!ENTITY external.description "Tai yra išorinė filtrų prenumerata. Jos filtrų sąrašas bus atnaujinamas to priedo, kuris sukūrė prenumeratą.">
-<!ENTITY autodownload.description "Jei pasirinksite „Automatiškai atnaujinti“, šis adresas bus tikrinamas dėl atnaujinimų kasdien. Jei ir išjungtas šis pasirinkimas, Jūs vistiek galite atnaujinti rankiniu būdu iš prenumeratos kontekstinio meniu.">
-<!ENTITY location.label "Filtrų sąrašo vieta:">
-<!ENTITY location.accesskey "V">
-<!ENTITY title.label "Prenumeratos pavadinimas:">
-<!ENTITY title.accesskey "P">
-<!ENTITY autodownload.label "Automatiškai atnaujinti">
-<!ENTITY autodownload.accesskey "A">
-<!ENTITY enabled.label "Įjungti filtrus">
-<!ENTITY enabled.accesskey "J">

=== removed file 'chrome/locale/lt-LT/tip_subscriptions.dtd'
--- chrome/locale/lt-LT/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/lt-LT/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,10 +0,0 @@
-<!ENTITY dialog.title "Sveiki">
-<!ENTITY description.par1 "Ačiū, kad įdiegėte „Adblock Plus“. Šis priedas gali pašalinti 99 procentus reklamų, matomų Internete. Kaip bebūtų, efektyviam reklamų blokavimui reikia nustatyti gerą filtrų rinkinį. Jūs tai galite padaryti patys arba paprasčiausiai užsiprenumeruoti filtrų sąrašus, kuriuos už Jus tvarkys kiti. Taip pat bus įmanoma pridėti savo filtrus, kai, esant reikalui, norėsite išjungti/pašalinti prenumeratas.">
-<!ENTITY description.par2 "Jūs galite pasirinkti vieną prenumeratą iš žemiau esančio rekomenduojamų prenumeratų sąrašo (daugiau prenumeratų galima pridėti „Adblock Plus“ nustatymų lange, nors paprastai tai nėra būtina):">
-<!ENTITY note "Dėmesio: Filtrų sąrašas paprastai būna efektyviausias tada, kai jis specialiai pritaikytas Jūsų regionui.">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY homepage.label "Pradžios tinklalapis">
-<!ENTITY subscribe.label "Prenumeruoti">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "Pridėti kitą prenumeratą">
-<!ENTITY other.accesskey "T">

=== added file 'chrome/locale/lt/.incomplete'
=== added file 'chrome/locale/lt/about.dtd'
--- chrome/locale/lt/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/lt/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,8 @@
+<!ENTITY dialog.title "Apie „Adblock Plus“">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versija">
+<!ENTITY description "„Adblock Plus“ Jums patiems leidžia nuspręsti, ką norite matyti Internete. Jums nereikia siųsti visų reklamų, jei jų nenorite matyti - nurodykite „Adblock Plus“!">
+<!ENTITY homepage.label "„Adblock Plus“ pradžios tinklalapis:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Autorius:">
+<!ENTITY contributors.label "Prisidėjo:">

=== added file 'chrome/locale/lt/global.properties'
--- chrome/locale/lt/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/lt/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,49 @@
+action0_tooltip=Spragtelkite, norėdami iškviesti kontekstinį meniu; spragtelkite viduriniuoju klavišu norėdami įjungti/išjungti.
+action1_tooltip=Spragtelkite, norėdami atverti/užverti blokuojamus elementus; spragtelkite viduriniuoju klavišu norėdami įjungti/išjungti.
+action2_tooltip=Spragtelkite, norėdami atverti nustatymus; spragtelkite viduriniuoju klavišu norėdami įjungti/išjungti.
+action3_tooltip=Spragtelkite, norėdami įjungti/išjungti „Adblock Plus“.
+disabled_tooltip=„Adblock Plus“ išjungtas.
+whitelisted_tooltip=„Adblock Plus“ aktyvus, bet išjungtas dabartiniam tinklalapiui.
+blocked_count_tooltip=?1? iš ?2?
+no_blocking_suggestions=Jokių blokuojamų elementų dabartiniame tinklalapyje
+whitelisted_page=„Adblock Plus“ yra išjungtas dabartiniam tinklalapiui
+whitelist_description=Išimčių taisyklės
+filterlist_description=Reklamų filtrai
+invalid_description=Netaisyklingi filtrai
+elemhide_description=Elementų paslėpimo taisyklės
+subscription_description=Filtrų prenumerata:
+subscription_wrong_version=Kai kurių šios prenumeratos filtrų tinkamam darbui reikia „Adblock Plus“ ?1?!
+subscription_source=Šaltinis:
+subscription_status=Būsena:
+subscription_status_autodownload=Automatiškai atnaujinta
+subscription_status_manualdownload=Atnaujinta rankiniu būdu
+subscription_status_externaldownload=Atnaujinta kitu priedu
+subscription_status_lastdownload=Paskutinis atsiuntimas:
+subscription_status_lastdownload_inprogress=Atsiunčiama...
+subscription_status_lastdownload_unknown=N/D
+remove_subscription_warning=Ar tikrai norite atsisakyti šios prenumeratos?
+import_filters_wrong_version=Įspėjimas: kai kurių šio sąrašo filtrų tinkamam darbui reikia „Adblock Plus“ ?1?. Jūs turėtumėte atnaujinti „Adblock Plus“ prieš importuodami šį sąrašą.
+import_filters_warning=Ar norite pakeisti dabartinius filtrus, ar pridėti naujus filtrus į sąrašo apačią?
+import_filters_title=Importuoti filtrus
+export_filters_title=Eksportuoti filtrus
+invalid_filters_file=Netinkamas „Adblock Plus“ filtrų failas.
+filters_write_error=Įvyko klaida rašant filtrus į failą. Įsitikinkite, kad failas nėra apsaugotas nuo rašymo ar naudojamas kitos programos.
+clearall_warning=Ar tikrai norite pašalinti visus filtrus iš sąrašo?
+resethitcounts_warning=Ar tikrai norite atstatyti aplankymų skaitiklius visiems filtrams? Šis veiksmas negali būti grąžinamas!
+resethitcounts_selected_warning=Ar tikrai norite atstatyti aplankymų skaitiklius pasirinktiems filtrams? Šis veiksmas negali būti grąžinamas!
+subscription_invalid_location=Filtrų sąrašo adresas nėra taisyklingas URL ar failo vardas.
+synchronize_invalid_url=Nepavyko, netinkamas adresas
+synchronize_connection_error=Nepavyko, atsiuntimo klaida
+synchronize_invalid_data=Nepavyko, netinkamas filtrų sąrašas
+synchronize_ok=Pavyko
+overwrite=Pakeisti
+append=Pridėti
+type_label_other=kita
+type_label_script=skriptas
+type_label_image=paveikslėlis
+type_label_stylesheet=stilius
+type_label_object=objektas
+type_label_subdocument=kadras
+type_label_document=dokumentas
+type_label_background=fonas
+type_label_elemhide=paslėpta

=== added file 'chrome/locale/lt/meta.properties'
--- chrome/locale/lt/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/lt/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=Reklamos - tai jau praeitis!

=== added file 'chrome/locale/lt/overlay.dtd'
--- chrome/locale/lt/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/lt/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,19 @@
+<!ENTITY status.tooltip "Būsena:">
+<!ENTITY blocked.tooltip "Šiame tinklalapyje užblokuoti elementai:">
+<!ENTITY filters.tooltip "Aktyviausi filtrai:">
+<!ENTITY menuitem.label "„Adblock Plus“">
+<!ENTITY menuitem.accesskey "A">
+<!ENTITY context.image.label "Blokuoti paveikslėlį">
+<!ENTITY context.object.label "Blokuoti objektą">
+<!ENTITY context.frame.label "Blokuoti kadrą">
+<!ENTITY sidebar.title "Blokuojami elementai dabartiniame tinklalapyje">
+<!ENTITY settings.label "Nustatymai">
+<!ENTITY settings.accesskey "N">
+<!ENTITY opensidebar.label "Atverti blokuojamus elementus">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "Užverti blokuojamus elementus">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "Išjungti ?1?">
+<!ENTITY whitelist.page.label "Išjungti šiam tinklalapiui">
+<!ENTITY objecttab.title "Blokuoti">
+<!ENTITY objecttab.tooltip "Spragtelkite čia norėdami užblokuoti šį objektą su „Adblock Plus“">

=== added file 'chrome/locale/lt/settings.dtd'
--- chrome/locale/lt/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/lt/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,67 @@
+<!ENTITY dialog.title "„Adblock Plus“ nustatymai">
+<!ENTITY filters.label "Filtrai">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Pridėti filtrą">
+<!ENTITY add.accesskey "D">
+<!ENTITY addsubscription.label "Pridėti filtro prenumeratą">
+<!ENTITY addsubscription.accesskey "P">
+<!ENTITY synchsubscriptions.label "Atnaujinti visas prenumeratas">
+<!ENTITY synchsubscriptions.accesskey "u">
+<!ENTITY import.label "Importuoti filtrus">
+<!ENTITY import.accesskey "M">
+<!ENTITY export.label "Eksportuoti filtrus">
+<!ENTITY export.accesskey "K">
+<!ENTITY clearall.label "Pašalinti visus filtrus">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "Atstatyti aplankymų statistiką">
+<!ENTITY resethitcounts.accesskey "S">
+<!ENTITY edit.label "Taisa">
+<!ENTITY edit.accesskey "T">
+<!ENTITY cut.label "Iškirpti">
+<!ENTITY cut.accesskey "r">
+<!ENTITY copy.label "Kopijuoti">
+<!ENTITY copy.accesskey "K">
+<!ENTITY paste.label "Įdėti">
+<!ENTITY paste.accesskey "d">
+<!ENTITY remove.label "Pašalinti">
+<!ENTITY remove.accesskey "š">
+<!ENTITY menu.find.label "Rasti">
+<!ENTITY menu.find.accesskey "A">
+<!ENTITY menu.findagain.label "Rasti vėl">
+<!ENTITY menu.findagain.accesskey "V">
+<!ENTITY options.label "Pasirinktys">
+<!ENTITY options.accesskey "P">
+<!ENTITY enable.label "Įjungti „Adblock Plus“">
+<!ENTITY enable.accesskey "J">
+<!ENTITY showintoolbar.label "Rodyti priemonių juostoje">
+<!ENTITY showintoolbar.accesskey "P">
+<!ENTITY showinstatusbar.label "Rodyti būsenos juostoje">
+<!ENTITY showinstatusbar.accesskey "B">
+<!ENTITY objecttabs.label "Rodyti korteles Flash ir Java elementams">
+<!ENTITY objecttabs.accesskey "F">
+<!ENTITY collapse.label "Suskleisti užblokuotus elementus">
+<!ENTITY collapse.accesskey "S">
+<!ENTITY help.label "Pagalba">
+<!ENTITY help.accesskey "G">
+<!ENTITY faq.label "Dažnai užduodami klausimai">
+<!ENTITY faq.accesskey "D">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Kaip rašyti „Adblock Plus“ filtrus">
+<!ENTITY filterdoc.accesskey "f">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Apie „Adblock Plus“">
+<!ENTITY about.accesskey "A">
+<!ENTITY description "Pridėkite adresus, kuriuos norite blokuoti. Norėdami gauti pasiūlymus, peržiūrėkite išskleidžiamąjį sąrašą. Galite pridėti „*“ kaip pakaitos simbolį norėdami sukurti bendresnius filtrus. Patyrę naudotojai gali naudoti reguliariuosius reiškinius, tokius kaip „/banner\d+\.gif$/“.">
+<!ENTITY enabled.column "Įjungta">
+<!ENTITY hitcount.column "Aplankymai">
+<!ENTITY lasthit.column "Paskutinis blokavimas">
+<!ENTITY context.edit.label "Redaguoti filtrą">
+<!ENTITY context.resethitcount.label "Atstatyti aplankymų statistiką filtrui">
+<!ENTITY context.synchsubscription.label "Atnaujinti prenumeratą">
+<!ENTITY context.editsubscription.label "Redaguoti prenumeratą">
+<!ENTITY context.moveup.label "Perkelti aukščiau">
+<!ENTITY context.movedown.label "Perkelti žemiau">
+<!ENTITY context.movegroupup.label "Perkelti grupę aukščiau">
+<!ENTITY context.movegroupdown.label "Perkelti grupę žemiau">
+<!ENTITY apply.label "Pritaikyti">
+<!ENTITY apply.accesskey "R">

=== added file 'chrome/locale/lt/sidebar.dtd'
--- chrome/locale/lt/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/lt/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,22 @@
+<!ENTITY detached.title "„Adblock Plus“ blokuojami elementai (iškelta)">
+<!ENTITY detach.label "Iškelti">
+<!ENTITY reattach.label "Iš naujo įkelti">
+<!ENTITY search.label "Ieškoti:">
+<!ENTITY search.accesskey "I">
+<!ENTITY type.label "Tipas">
+<!ENTITY address.label "Adresas">
+<!ENTITY filter.label "Filtras">
+<!ENTITY state.label "Būsena">
+<!ENTITY noitems.label "Nėra blokuojamų elementų">
+<!ENTITY whitelisted.label "Tinklalapis, įtrauktas į išimtis">
+<!ENTITY tooltip.address.label "Adresas:">
+<!ENTITY tooltip.type.label "Tipas:">
+<!ENTITY tooltip.type.blocked "(užblokuota)">
+<!ENTITY tooltip.type.whitelisted "(įtraukta į išimtis)">
+<!ENTITY tooltip.filter.label "Galiojantys filtrai:">
+<!ENTITY context.block.label "Blokuoti šį elementą">
+<!ENTITY context.editfilter.label "Redaguoti aktyvų filtrą">
+<!ENTITY context.whitelist.label "Pridėti išimties taisyklę šiam elementui">
+<!ENTITY context.open.label "Atverti naujoje kortelėje">
+<!ENTITY context.flash.label "Paryškinti elemento rėmelį">
+<!ENTITY context.copy.label "Kopijuoti elemento adresą">

=== added file 'chrome/locale/lt/subscriptionSelection.dtd'
--- chrome/locale/lt/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/lt/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,10 @@
+<!ENTITY dialog.title.edit "Redaguoti filtrų prenumeratą">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY other.label "Pridėti kitą prenumeratą">
+<!ENTITY other.accesskey "T">
+<!ENTITY title.label "Prenumeratos pavadinimas:">
+<!ENTITY title.accesskey "P">
+<!ENTITY location.label "Filtrų sąrašo vieta:">
+<!ENTITY location.accesskey "V">
+<!ENTITY autodownload.label "Automatiškai atnaujinti">
+<!ENTITY autodownload.accesskey "A">

=== added directory 'chrome/locale/lv'
=== added file 'chrome/locale/lv/.incomplete'
=== added file 'chrome/locale/lv/about.dtd'
--- chrome/locale/lv/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/lv/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,8 @@
+<!ENTITY dialog.title "Par Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versija">
+<!ENTITY description "  Adblock Plus ļauj jums izlemt, ko vēlaties redzēt Internetā.  Jums vairs nav nepieciešams lejupielādēt reklāmu un reklāmkarogus, ja jūs  nevēlaties tos - aizvāciet ar Adblock Plus!">
+<!ENTITY homepage.label "Adblock Plus mājaslapa:">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "Autori:">
+<!ENTITY contributors.label "Atbalstītāji:">

=== added file 'chrome/locale/lv/composer.dtd'
--- chrome/locale/lv/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/lv/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Pievienot Adblock Plus filtra nosacījumu">
+<!ENTITY accept.label "Pievienot filtru">
+<!ENTITY advanced.label "Paplašināts skatījums">
+<!ENTITY basic.label "Pamata skatījums">
+<!ENTITY disabled.warning "Adblock Plus šobrīd ir atspējots. Jūs joprojām varat pievienot filtrus, bet tie netiks piemēroti tik ilgi, kamēr jūs [link] neiespējosiet Adblock Plus [/ link].">
+<!ENTITY groupDisabled.warning "Filtrs grupa &quot;?1?&quot; kurai šis filtrs būs jāpievieno pašlaik ir atspējota. Jūs joprojām varat pievienot filtru, taču tas nav piemērojams, kamēr jūs [link] neiespējosiet filtra grupu [/link].">
+<!ENTITY filter.label "Jauns filtrs:">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "Rādīt esošos filtrus...">
+<!ENTITY preferences.accesskey "S">
+<!ENTITY type.filter.label "Bloķēšanas filtrs">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Izņēmuma nosacījums">
+<!ENTITY type.whitelist.accesskey "x">
+<!ENTITY pattern.label "Meklēt paraugu">
+<!ENTITY pattern.explanation "Paraugs var būt jebkura daļa no adreses, zvaigznīte (*) darbojas kā aizstājējzīme. Filtrs var tikt piemērots tikai adresei, kas atbilst paredzētajam modelim.">
+<!ENTITY regexp.warning "Modelis jūs ievadījāt tiks interpretēts kā regulāra izteiksme, ko Adblock Plus nevar efektīvi apstrādāt un tas var palēnināt jūsu pārlūkošanu. Ja jūs neplānojat izmantot regulāra izteiksmi, pievienojiet zvaigznīti (*) parauga beigās.">
+<!ENTITY shortpattern.warning "Paraugs, kuru jūs ievadījāt, ir pārāk īss, lai būtu optimizēts un tas var palēnināt jūsu pārlūkošanu. Ieteicams izvēlēties garāku virkni šim filtram, lai Adblock Plus varētu apstrādāt filtru efektīvāk.">
+<!ENTITY custom.pattern.label "Pielāgots:">
+<!ENTITY custom.pattern.accesskey "C">
+<!ENTITY anchors.label "Apstiprināt tiaki paraugus:">
+<!ENTITY anchor.start.label "adreses sākumā">
+<!ENTITY anchor.start.accesskey "g">
+<!ENTITY anchor.start.flexible.label "domēna vārda sākumā">
+<!ENTITY anchor.start.flexible.accesskey "g">
+<!ENTITY anchor.end.label "adreses beigās">
+<!ENTITY anchor.end.accesskey "n">
+<!ENTITY options.label "Opcijas">
+<!ENTITY domainRestriction.label "Ierobežot līdz domēnam:">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "Izmantojiet šo opciju, lai precizētu vienu vai vairākus domēnus, atdalītus ar joslu līniju (|). Filtrs tiks attiecināts tikai uz izvēlēto domēnu(-iem). Tilde (~) pirms domēna vārda norāda, ka filtrs netiek piemērots attiecībā uz šo domēnu.">
+<!ENTITY firstParty.label "Tikai pirmās puses">
+<!ENTITY firstParty.accesskey "r">
+<!ENTITY thirdParty.label "Tikai trešās puses">
+<!ENTITY thirdParty.accesskey "T">
+<!ENTITY matchCase.label "Saderīgs gadījums">
+<!ENTITY matchCase.accesskey "M">
+<!ENTITY types.label "Pielietot tipiem:">
+<!ENTITY selectAllTypes.label "Izvēlēties visu">
+<!ENTITY unselectAllTypes.label "Izvēlēties nevienu ">
+<!ENTITY collapse.label "Collapse blocked:">
+<!ENTITY collapse.accesskey "l">
+<!ENTITY collapse.default.yes.label "Lietot noklusēto vērtību (jā)">
+<!ENTITY collapse.default.no.label "Lietot noklusēto vērtību (nē)">
+<!ENTITY collapse.yes.label "Jā">
+<!ENTITY collapse.no.label "Nē">

=== added file 'chrome/locale/lv/meta.properties'
--- chrome/locale/lv/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/lv/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,3 @@
+translator=Klaids Borovs
+name=Adblock Plus
+description=Reklmas ir vakardiena!

=== added file 'chrome/locale/lv/settings.dtd'
--- chrome/locale/lv/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/lv/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus Iestatījumi">
+<!ENTITY filters.label "Filtri">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Pievienot Filtru">
+<!ENTITY add.accesskey "A">
+<!ENTITY addsubscription.label "Pievienot filtra abonēšanu">
+<!ENTITY addsubscription.accesskey "s">
+<!ENTITY synchsubscriptions.label "Atjaunot visus abonementus">
+<!ENTITY synchsubscriptions.accesskey "d">
+<!ENTITY import.label "Importēt filtrus">
+<!ENTITY import.accesskey "m">
+<!ENTITY export.label "Eksportēt atseviškos filtrus">
+<!ENTITY export.accesskey "x">
+<!ENTITY clearall.label "Aizvākt visus atseviškos filtrus">
+<!ENTITY clearall.accesskey "l">
+<!ENTITY resethitcounts.label "Atiestatīt klikšķu statistiku">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "Rediģēt">
+<!ENTITY edit.accesskey "E">
+<!ENTITY cut.label "Izgriezt">
+<!ENTITY cut.accesskey "t">
+<!ENTITY copy.label "Kopēt">
+<!ENTITY copy.accesskey "C">
+<!ENTITY paste.label "Ielīmēt">
+<!ENTITY paste.accesskey "P">
+<!ENTITY remove.label "Dzēst">
+<!ENTITY remove.accesskey "D">
+<!ENTITY menu.find.label "Meklēt">
+<!ENTITY menu.find.accesskey "F">
+<!ENTITY menu.findagain.label "Meklēt atkāroti">
+<!ENTITY menu.findagain.accesskey "g">
+<!ENTITY view.label "Skatīt">
+<!ENTITY view.accesskey "V">
+<!ENTITY sort.label "Kārtot pēc">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "Nesakārtots">
+<!ENTITY sort.none.accesskey "U">
+<!ENTITY sort.ascending.label "A &gt; Z kārtošanas secība">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Z &gt; A kārtošanas secība">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Iespējas">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Iespējot Adblock Plus">
+<!ENTITY enable.accesskey "n">
+<!ENTITY showintoolbar.label "Rādīt rīkjoslā">
+<!ENTITY showintoolbar.accesskey "b">
+<!ENTITY showinstatusbar.label "Rādīt stāvokļa joslā">
+<!ENTITY showinstatusbar.accesskey "s">
+<!ENTITY objecttabs.label "Rādīt cilnes Flash un Java">
+<!ENTITY objecttabs.accesskey "t">
+<!ENTITY collapse.label "Savērst bloķētos elementus">
+<!ENTITY collapse.accesskey "l">
+<!ENTITY help.label "Palīdzība">
+<!ENTITY help.accesskey "H">
+<!ENTITY gettingStarted.label "Iesākumam">
+<!ENTITY gettingStarted.accesskey "s">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Biežāk Uzdotie Jautājumi">
+<!ENTITY faq.accesskey "F">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Rakstīt Adblock Plus filtrus">
+<!ENTITY filterdoc.accesskey "r">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Par Adblock Plus">
+<!ENTITY about.accesskey "b">
+<!ENTITY description "Šādi filtri nosaka, kurām adresēm ir jābūt bloķētām, un kādas ir atļautas:">
+<!ENTITY filter.column "Filtra noteikumi">
+<!ENTITY filter.accesskey "F">
+<!ENTITY slow.column "Lēni filtri">
+<!ENTITY slow.accesskey "w">
+<!ENTITY enabled.column "Iespējots">
+<!ENTITY enabled.accesskey "n">
+<!ENTITY hitcount.column "Klikšķi">
+<!ENTITY hitcount.accesskey "H">
+<!ENTITY lasthit.column "Pēdējai klikšķis">
+<!ENTITY lasthit.accesskey "L">
+<!ENTITY context.edit.label "Rediģēt filtru">
+<!ENTITY context.resethitcount.label "Atiestatīt klikšķu statistiku filtram">
+<!ENTITY context.synchsubscription.label "Atjaunot abonēšanu">
+<!ENTITY context.editsubscription.label "Rediģēt abonementu">
+<!ENTITY context.moveup.label "Pārvietot filtru augšup">
+<!ENTITY context.movedown.label "Pārvietot filtru lejup">
+<!ENTITY context.movegroupup.label "Pārvietot grupu augšup">
+<!ENTITY context.movegroupdown.label "Pārvietot grupu lejup">
+<!ENTITY context.enable.label "Iespējot">
+<!ENTITY context.disable.label "Atspējot">
+<!ENTITY apply.label "Apstiprināt">
+<!ENTITY apply.accesskey "p">
+<!ENTITY fennec.subscription.label "Filtra abonements">

=== added file 'chrome/locale/lv/subscriptionSelection.dtd'
--- chrome/locale/lv/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/lv/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Pievienot Adblock Plus filtra abonementu">
+<!ENTITY dialog.title.edit "Rediģēt filtra abonementu">
+<!ENTITY description.newInstall "  Adblock Plus būs visefektīgākais, ja jūs pievienosiet filtru abonementu.  Filtru abonementus bez maksas sniedz citi Adblock Plus lietotāji. Vispiemērotākais abonements Jūsu valodā jau ir izvēlēts.">
+<!ENTITY adblock.warning "  Adblock Plus ir konstatējis, ka ir uzstādīta Adblock vai vecā Adblock Plus versija. Gan Adblock un Adblock Plus vienlaicīga darbība var radīt  problēmām un no tā ir jāizvairās. Ieteicams nekavējoties atinstalēt Adblock.">
+<!ENTITY adblock.uninstall "Atinstalēt Adblock">
+<!ENTITY filterset.g.warning "  Šķiet, ka jūs izmantojat Filterset.G. Šis filtru saraksts ir tik tikko  saglabts pēdējos gados, un izraisa kopējas problēmas ar interneta  vietnēm. Ieteicams nekavējoties atinstalēt Filterset.G.">
+<!ENTITY filterset.g.moreinfo "Vairāk informācijas">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Atinstalēt Filterset.G">
+<!ENTITY subscriptionSelector.label "Lūdzu, izvēlieties filtru abonementu no saraksta:">
+<!ENTITY viewList.label "Skatīt filtrus">
+<!ENTITY visitHomepage.label "Apmeklēt mājaslapu">
+<!ENTITY addSubscription.label "Pievienot abonementu">
+<!ENTITY saveSubscription.label "Saglabāt abonementu">
+<!ENTITY other.label "Pievienot citu abonementu">
+<!ENTITY other.accesskey "f">
+<!ENTITY list.download.failed "Adblock Plus neizdevās ielādēt abonentu sarakstu.">
+<!ENTITY list.download.retry "Mēģiniet vēlreiz">
+<!ENTITY list.download.website "Skatīt tīmekļa vietni">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Lūdzu, apstipriniet, ka vēlaties pievienot šī filtra abonementu. Jūs varat mainīt abonementa nosaukumu vai atrašanās vietu pirms pievienošanas.">
+<!ENTITY edit.description "Nepieciešamības gadījumā Jūs varat mainīt abonementa nosaukumu vai atrašanās vietu.">
+<!ENTITY external.description "Tas ir ārējā filtra abonements, tas tiks atjaunināts ar paplašinājumu, kas ir izveidojis šo abonementu.">
+<!ENTITY title.label "Abonementa nosaukums:">
+<!ENTITY title.accesskey "t">
+<!ENTITY location.label "Filtru saraksta atrašanās vieta:">
+<!ENTITY location.accesskey "l">
+<!ENTITY autodownload.label "Jaunināt filtrus automātiski">
+<!ENTITY autodownload.accesskey "p">
+<!ENTITY supplementMessage "Šī filtra abonements ir paredzēts lietošanai kopā ar filtra abonementu &quot;?1?&quot; kuru jūs vēl neizmantojat.">
+<!ENTITY addMain.label "Pievienot arī filtra abonementu &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "s">

=== added directory 'chrome/locale/mn'
=== removed directory 'chrome/locale/mn-MN'
=== removed file 'chrome/locale/mn-MN/about.dtd'
--- chrome/locale/mn-MN/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/mn-MN/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus-ийн тухай">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Хувилбар">
-<!ENTITY description "
-	Adblock Plus нь вэб хуудас дээр таны харахыг хүсэхгүй байгааг тань шийдэж өгнө.
-	Хэрэв та хүсээгүй зүйлсээ Adblock Plus-д хэлснээр, тэдгээр сурталчилгаа, баннер
-	болон бусад зүйлсийг татах хэрэггүй болно!
-">
-<!ENTITY homepage.label "Adblock Plus-ийн вэб хуудас:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Зохиогч:">
-<!ENTITY contributors.label "Дэмжигчид:">

=== removed file 'chrome/locale/mn-MN/composer.dtd'
--- chrome/locale/mn-MN/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/mn-MN/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,45 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus шүүлтүүрийн дүрэм нэмэх">
-<!ENTITY accept.label "Шүүлтүүр нэмэх">
-<!ENTITY advanced.label "Дэвшмэл харагдац">
-<!ENTITY basic.label "Үндсэн харагдац">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus нь одоогоор хаалттай байна.  Та шүүлтүүр нэмж чадах боловч хэрэгжихгүй байх болно.">
-<!ENTITY disabled.warning.link "Adblock Plus-ийг нээх">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY filter.label "Шинэ шүүлтүүр:">
-<!ENTITY filter.accesskey "ш">
-<!ENTITY preferences.label "Байгаа шүүлтүүрүүдийг харах...">
-<!ENTITY preferences.accesskey "Б">
-<!ENTITY type.filter.label "Хаших шүүлтүүр">
-<!ENTITY type.filter.accesskey "Х">
-<!ENTITY type.whitelist.label "Үл хаших дүрэм">
-<!ENTITY type.whitelist.accesskey "Ү">
-<!ENTITY pattern.label "Эсгүүрийн байдал">
-<!ENTITY pattern.explanation "Эсгүүр нь хаягийн аль нэг хэсэг, * тэмдэг шиг байж болно. Энэ шүүлтүүр нь зөвхөн энэ эсгүүртэй холбогдох хаяг дээр хэрэгжинэ.">
-<!ENTITY regexp.warning "Эсгүүр нь энгийн илэрхийлэл шиг байж болно. Хэт их энгийн илэрхийлэл нь ажиллагааг удаашруулж болзошгүй. If you didn&apos;t intend to use regular expressions, add a * symbol at the end of the pattern.">
-<!ENTITY shortpattern.warning "The pattern you entered is too short to be optimized, many such patterns might slow down your browsing. It is recommended that you choose a longer string for this filter.">
-<!ENTITY custom.pattern.label "Тусгай:">
-<!ENTITY custom.pattern.accesskey "Т">
-<!ENTITY anchors.label "Эсгүүрийг зөвхөн зөвшөөрөх нь:">
-<!ENTITY anchor.start.label "хаягийн эхлэлд">
-<!ENTITY anchor.start.accesskey "э">
-<!ENTITY anchor.end.label "хаягийн төгсгөлд">
-<!ENTITY anchor.end.accesskey "Д">
-<!ENTITY options.label "Сонголтууд">
-<!ENTITY domainRestriction.label "Хязгаарлах хаяг">
-<!ENTITY domainRestriction.accesskey "Я">
-<!ENTITY domainRestriction.help "Specify one or more domains separated by the symbol &quot;|&quot;, the filter will only be applied on these domains then. The symbol &quot;~&quot; before a domain name means that the filter should not be applied on that domain.">
-<!ENTITY firstParty.label "Зөвхөн эхний хэсэг">
-<!ENTITY firstParty.accesskey "з">
-<!ENTITY thirdParty.label "Зөвхөн гуравдагч хэсэг">
-<!ENTITY thirdParty.accesskey "г">
-<!ENTITY matchCase.label "Том жижиг ялгах">
-<!ENTITY matchCase.accesskey "Ж">
-<!ENTITY types.label "Хэрэглэх төрлүүд:">
-<!ENTITY selectAllTypes.label "Бүгдийг сонгох">
-<!ENTITY unselectAllTypes.label "Бүгдийг үл сонгох">
-<!ENTITY collapse.label "Хашигдсанг хураах нь:">
-<!ENTITY collapse.accesskey "у">
-<!ENTITY collapse.default.yes.label "Анхдагчийг (тийм) хэрэглэх">
-<!ENTITY collapse.default.no.label "Анхдагчийг (үгүй) хэрэглэх">
-<!ENTITY collapse.yes.label "Тийм">
-<!ENTITY collapse.no.label "Үгүй">

=== removed file 'chrome/locale/mn-MN/global.properties'
--- chrome/locale/mn-MN/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/mn-MN/global.properties	1970-01-01 00:00:00 +0000
@@ -1,66 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Сурталчилгаа бол өчигдөр байлаа!
-status_active_label=Adblock
-status_disabled_label=Хаалттай
-action0_tooltip=Товшвол хамаарах цэсийг гаргана, дунд товшилтоор идэвхжүүлнэ/хаана.
-action1_tooltip=Товшвол хашигдах зүйлсийг нээнэ/хаана, дунд товшилтоор идэвхжүүлнэ/хаана.
-action2_tooltip=Товшвол тохиргоонуудыг нээн, дунд товшилтоо идэвхжүүлнэ/хаана.
-action3_tooltip=Товшилтоор Adblock Plus-ийг идэвхжүүлнэ/хаана.
-active_tooltip=Adblock Plus нь идэвхтэй.
-disabled_tooltip=Adblock Plus нь идэвхгүй.
-whitelisted_tooltip=Adblock Plus нь идэвхтэй боловч тухайн хуудсанд хаалттай.
-blocked_count_tooltip=-- хэтрэлт --
-no_blocking_suggestions=Тухайн хуудсанд хашигдах зүйлс алга
-whitelisted_page=Adblock Plus нь тухайн хуудсанд хаалттай байна
-whitelist_description=Онцгой дүрмүүд
-filterlist_description=Сурталчилгааны шүүлтүүр
-invalid_description=Буруу шүүлтүүр
-elemhide_description=Элемент хайх дүрмүүд
-subscription_description=Шүүлтүүр мэдээлэгч:
-subscription_wrong_version=Уг мэдээлэгч дэх зарим шүүлтүүр нь Adblock Plus-ийг шаардана -- зөв ажиллахын тулд!
-subscription_source=Эх сурвалж:
-subscription_status=Төлөв:
-subscription_status_autodownload=Автоаматаар шинэчлэгдсэн
-subscription_status_manualdownload=Гараар шинэчлэгдсэн
-subscription_status_externaldownload=Бусдаар (өөр нэмэлт) шинэчлэгдсэн
-subscription_status_lastdownload=Сүүлийн таталт:
-subscription_status_lastdownload_inprogress=Татаж байна...
-subscription_status_lastdownload_unknown=N/A
-remove_subscription_warning=Та үнэхээр уг мэдээлэгчийг устгамаар байна уу?
-import_filters_wrong_version=Анхааруулга: уг жагсаалт дах шүүлтүүрүүдийн зарим нь Adblock Plus-ийг шаардана -- зөв ажиллахын тулд. Энэ жагсаалтыг оруулахаасаа өмнө магадгүй та Adblock Plus-ийн сүүлийн байдлаарх хувилбараар шинэчлэх хэрэгтэй.
-import_filters_warning=Та тухайн шүүлтүүрүүдийг солих эсвэл шинэ шүүлтүүрүүдийг жагсаалтын төгсгөлд нэмэхийг хүсэж байна уу?
-import_filters_title=Шүүлтүүрүүд оруулах
-export_filters_title=Шүүлтүүрүүд гаргах
-invalid_filters_file=Adblock Plus-ийн шүүлтүүрийн зөв файл биш байна.
-filters_write_error=Шүүлтүүрүүдийг файл руу бичих үест алдаа гарлаа. Файл нь бичигдэх эрхтэй эсвэл өөр програм ашиглаж буй эсэхийг шалгана уу.
-clearall_warning=Та жагсаалтаас бүх шүүлтүүрүүдийг устгамаар байна уу?
-resethitcounts_warning=Та бүх шүүлтүүрийн хандалтын тоог буцааж тэг болгомоор байна уу? Уг үйлдлийг буцааж болдоггүй!
-resethitcounts_selected_warning=Та сонгогдсон шүүлтүүрийн хандалтын тоог буцааж тэг болгомоор байна уу? Уг үйлдлийг буцааж болдоггүй!
-filter_regexp_tooltip=Шүүлтүүр нь энгийн илэрхийлэл эсвэл богино байвал зохимжтой. Хэт их шүүлтүүр нь таны хөтчийг удаашруулах магадлалтай.
-filter_elemhide_duplicate_id=Нуух элементүүдийн зөвхөн нэг ID нь тодорхойлогдох боломжтой
-filter_elemhide_nocriteria=Нуух элементийг таних шалгуур тодорхойлогдоогүй байна
-subscription_no_location=Шүүлтүүрүүдийг татах хаягийг оруулна уу.
-subscription_invalid_location=Шүүлтүүрийн жагсаалтын байрлал нь буруу URL эсвэл файлын нэр буруу.
-subscription_location_exists=Та уг шүүлтүүрийн жагсаалтад бүргэгдчихсэн байна.
-synchronize_invalid_url=Бүтэлгүйтэв, буруу хаяг
-synchronize_connection_error=Бүтэлгүйтэв, таталтын бүтэлгүйтэл
-synchronize_invalid_data=Бүтэлгүйтэв, буруу шүүлтүүрийн жагсаалт
-synchronize_checksum_mismatch=Бүтэлгүйтлээ, шалгалт таарсангүй
-synchronize_ok=Амжилттай
-overwrite=Давхарлах
-append=Нэмэх
-new_filter_group_title=Шинэ шүүлтүүр
-type_label_other=бусад
-type_label_script=скрипт
-type_label_image=зураг
-type_label_stylesheet=stylesheet
-type_label_object=объект
-type_label_subdocument=хүрээ
-type_label_document=баримт
-type_label_background=ар дэвсгэр
-type_label_elemhide=нууц
-type_label_xbl=XBL боолт
-type_label_ping=холбоос шалгах
-type_label_xmlhttprequest=XML хүсэлт
-type_label_object_subrequest=объект дэдхүсэлт
-type_label_dtd=ДТД
-type_label_media=дуу/дүрс

=== removed file 'chrome/locale/mn-MN/overlay.dtd'
--- chrome/locale/mn-MN/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/mn-MN/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,21 +0,0 @@
-<!ENTITY status.tooltip "Төлөв:">
-<!ENTITY blocked.tooltip "Уг хуудас дахь хашигдсан зүйлс:">
-<!ENTITY filters.tooltip "Хамгийн идэвхтэй шүүлтүүрүүд:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Нэмэх">
-<!ENTITY view.blockableItems.label "Adblock Нэмэх:Хашигдахуйц зүйлс">
-<!ENTITY context.image.label "Adblock Зураг">
-<!ENTITY context.object.label "Adblock Объект">
-<!ENTITY context.frame.label "Adblock Хүрээ">
-<!ENTITY sidebar.title "Тухайн хуудас дахь хашигдаж болох зүйлс">
-<!ENTITY settings.label "Тохиргоонууд">
-<!ENTITY settings.accesskey "Т">
-<!ENTITY opensidebar.label "Хашигдах зүйлсийг нээх">
-<!ENTITY opensidebar.accesskey "Х">
-<!ENTITY closesidebar.label "Хашигдах зүйлсийг хаах">
-<!ENTITY closesidebar.accesskey "Х">
-<!ENTITY whitelist.site.label "Хаах нь --">
-<!ENTITY whitelist.page.label "Зөвхөн уг хуудсанд хаах">
-<!ENTITY objecttab.title "Хаших">
-<!ENTITY objecttab.tooltip "Энд дарвал уг объектийг Adblock Plus-аар хаших болно">

=== removed file 'chrome/locale/mn-MN/settings.dtd'
--- chrome/locale/mn-MN/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/mn-MN/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus Тохиргоонууд">
-<!ENTITY filters.label "Шүүлтүүрүүд">
-<!ENTITY filters.accesskey "Ш">
-<!ENTITY add.label "Шүүлт нэмэх">
-<!ENTITY add.accesskey "Н">
-<!ENTITY addsubscription.label "Шүүлтүүр мэдээлэгч нэмэх">
-<!ENTITY addsubscription.accesskey "М">
-<!ENTITY synchsubscriptions.label "Бүх мэдээлэгчийг шинэчлэх">
-<!ENTITY synchsubscriptions.accesskey "Б">
-<!ENTITY import.label "Шүүлтүүр оруулах">
-<!ENTITY import.accesskey "О">
-<!ENTITY export.label "Шүүлтүүр гаргах">
-<!ENTITY export.accesskey "Г">
-<!ENTITY clearall.label "Бүх шүүлтүүрүүдийг хасах">
-<!ENTITY clearall.accesskey "С">
-<!ENTITY resethitcounts.label "Хандалтын төлвийг эхлүүлэх">
-<!ENTITY resethitcounts.accesskey "Т">
-<!ENTITY edit.label "Засвар">
-<!ENTITY edit.accesskey "З">
-<!ENTITY cut.label "Хайчлах">
-<!ENTITY cut.accesskey "Ч">
-<!ENTITY copy.label "Хуулах">
-<!ENTITY copy.accesskey "Х">
-<!ENTITY paste.label "Тавих">
-<!ENTITY paste.accesskey "Т">
-<!ENTITY remove.label "Устгах">
-<!ENTITY remove.accesskey "У">
-<!ENTITY menu.find.label "Хайх">
-<!ENTITY menu.find.accesskey "А">
-<!ENTITY menu.findagain.label "Дахин хайх">
-<!ENTITY menu.findagain.accesskey "Д">
-<!ENTITY view.label "Харах">
-<!ENTITY view.accesskey "Х">
-<!ENTITY sort.label "Эрэмбэлэх нь">
-<!ENTITY sort.accesskey "Э">
-<!ENTITY sort.none.label "Эрэмбэ үгүй">
-<!ENTITY sort.none.accesskey "Ү">
-<!ENTITY sort.ascending.label "А &gt; Я эрэмбэлэх">
-<!ENTITY sort.ascending.accesskey "А">
-<!ENTITY sort.descending.label "Я &gt; А эрэмбэлэх">
-<!ENTITY sort.descending.accesskey "Я">
-<!ENTITY options.label "Сонголтууд">
-<!ENTITY options.accesskey "О">
-<!ENTITY enable.label "Adblock Plus идэвхтэй">
-<!ENTITY enable.accesskey "И">
-<!ENTITY showintoolbar.label "Хэрэгслийн мөрт харуулах">
-<!ENTITY showintoolbar.accesskey "М">
-<!ENTITY showinstatusbar.label "Төлвийн мөрт харуулах">
-<!ENTITY showinstatusbar.accesskey "Т">
-<!ENTITY objecttabs.label "Flash болон Java-д tab харуулах">
-<!ENTITY objecttabs.accesskey "Х">
-<!ENTITY collapse.label "Хашигдсан элементийг хумих">
-<!ENTITY collapse.accesskey "Э">
-<!ENTITY help.label "Тусламж">
-<!ENTITY help.accesskey "Т">
-<!ENTITY gettingStarted.label "Эхлэл">
-<!ENTITY gettingStarted.accesskey "Э">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Түгээмэл Асуултын Хариултууд">
-<!ENTITY faq.accesskey "А">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Adblock Plus шүүлтүүрүүд бичих">
-<!ENTITY filterdoc.accesskey "Б">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Adblock Plus-ийн тухай">
-<!ENTITY about.accesskey "Т">
-<!ENTITY description "Хашихыг хүссэн хаягаа нэмэхдээ, доош унжих жагсаалтаас авч боломжтой.
-		Та * ашиглан илүү ерөнхий шүүлтүүр үүсгэж болно. Илүү хэрэглэгчид
-		энгийн илэрхийлэл (regexpression) ашиглаж чадна. Ж: /banner\d+\.gif$/.">
-<!ENTITY filter.column "Шүүх дүрэм">
-<!ENTITY filter.accesskey "Ш">
-<!ENTITY enabled.column "Идэвхтэй">
-<!ENTITY enabled.accesskey "И">
-<!ENTITY hitcount.column "Хандалт">
-<!ENTITY hitcount.accesskey "Х">
-<!ENTITY lasthit.column "Сүүлийн хандалт">
-<!ENTITY lasthit.accesskey "С">
-<!ENTITY context.edit.label "Шүүлтүүр засах">
-<!ENTITY context.resethitcount.label "Шүүлтүүрийн хандалтын статистикийг эхлүүлэх">
-<!ENTITY context.synchsubscription.label "Мэдээлэгчийг одоо шинэчлэх">
-<!ENTITY context.editsubscription.label "Мэдээлэгч засах">
-<!ENTITY context.moveup.label "Дээшлүүлэх">
-<!ENTITY context.movedown.label "Доошлуулах">
-<!ENTITY context.movegroupup.label "Бүлгийг дээшлүүлэх">
-<!ENTITY context.movegroupdown.label "Бүлгийг доошлуулах">
-<!ENTITY context.enable.label "Нээх">
-<!ENTITY context.disable.label "Хаах">
-<!ENTITY apply.label "Хэрэглэх">
-<!ENTITY apply.accesskey "Г">

=== removed file 'chrome/locale/mn-MN/sidebar.dtd'
--- chrome/locale/mn-MN/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/mn-MN/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,30 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Хашигдахуйц зүйлс (салгагдсан)">
-<!ENTITY detach.label "Салгах">
-<!ENTITY reattach.label "Залгах">
-<!ENTITY search.label "Хайх:">
-<!ENTITY search.accesskey "Х">
-<!ENTITY type.label "Төрөл">
-<!ENTITY address.label "Хаяг">
-<!ENTITY filter.label "Шүүлтүүр">
-<!ENTITY state.label "Нөхцөл">
-<!ENTITY size.label "Хэмжээ">
-<!ENTITY noitems.label "Хашигдах зүйлс алга">
-<!ENTITY whitelisted.label "Цагаанжагсаалтын хуудас">
-<!ENTITY tooltip.address.label "Хаяг:">
-<!ENTITY tooltip.type.label "Төрөл:">
-<!ENTITY tooltip.type.blocked "(хашигдсан)">
-<!ENTITY tooltip.type.whitelisted "(цагаандсан)">
-<!ENTITY tooltip.size.label "Хэмжээ:">
-<!ENTITY tooltip.filter.label "Эффектийн шүүлтүүр:">
-<!ENTITY tooltip.filterSource.label "Шүүлтүүрийн эх:">
-<!ENTITY context.block.label "Уг зүйлийг хаших">
-<!ENTITY context.editfilter.label "Эффектийн шүүлтүүрийг засах">
-<!ENTITY context.whitelist.label "Зүйлд онцгой дүрэм нэмэх">
-<!ENTITY context.disablefilter.label "Шүүлтүүр хаах --">
-<!ENTITY context.enablefilter.label "Шүүлтүүр нээх --">
-<!ENTITY context.disablefilteronsite.label "Энэ шүүлтүүрийг хаах газар нь --">
-<!ENTITY context.open.label "Шинэ хуудсанд нээх">
-<!ENTITY context.flash.label "Flash зүйлийн хүрээнүүд">
-<!ENTITY context.copy.label "Зүйлийн хаягийг сануулах">
-<!ENTITY context.copyFilter.label "Шүүлтүүр хуулах">
-<!ENTITY context.selectAll.label "Бүгдийг сонгох">

=== removed file 'chrome/locale/mn-MN/subscription.dtd'
--- chrome/locale/mn-MN/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/mn-MN/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-<!ENTITY dialog.title "Шүүлтүүрийн мэдээлэгч засах">
-<!ENTITY dialog.newtitle "Шүүлтүүрийн мэдээлэгч нэмэх">
-<!ENTITY new.description "Вэб хаяг эсвэл Adblock Plus шүүлтүүрийн жагсаалт агуулж буй файл оруулна уу.">
-<!ENTITY edit.description "Өгсөн хаягаас татагдах уг мэдээлэгчийн шүүлтүүрийн
-	жагсаалт.">
-<!ENTITY external.description "Энэ бол гадаад шүүлтүүрийн мэдээлэгч байна. Энэ шүүлтүүрийн
-	жагсаалт нь уг мэдээлэгчийг үүсгэсэн нэмэлтийг шинэчлэх
-	хүрэтэл хадгалагдана.">
-<!ENTITY autodownload.description "Хэрэв та уг байршилд &apos;Автоматаар шинэчлэх&apos;-ийг сонгосон бол
-		шинэчлэлт нь өдөр бүр шалгагдах болно. Уг тохиргоо нь хаалттай
-		бол мэдээлэгчийн хамаарах цэсээс та гараар шинэчилж чадна..">
-<!ENTITY location.label "Шүүлтүүрийн жагсаалтын байршил:">
-<!ENTITY location.accesskey "Б">
-<!ENTITY title.label "Мэдээлэгчийн гарчиг:">
-<!ENTITY title.accesskey "Г">
-<!ENTITY autodownload.label "Автоматаар шинэчлэх">
-<!ENTITY autodownload.accesskey "В">
-<!ENTITY enabled.label "Шүүлтүүр нээлттэй">
-<!ENTITY enabled.accesskey "Н">

=== removed file 'chrome/locale/mn-MN/tip_subscriptions.dtd'
--- chrome/locale/mn-MN/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/mn-MN/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,24 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus-д тавтай морил">
-<!ENTITY description.par1 "Adblock Plus-ийг суулгасанд баярлалаа. Энэ нэмэлт нь
-	вэб дэх танд харагдах сурталчилгааны 99&#37;-ийг хасна. Гэхдээ,
-	сурталчилгаануудыг та өөрийнхөөрөө тохируулж, сонгож болно.
-	Үүнийг та өөрийнхөөр хийгээд зогсохгүй өөртөө бусдын шүүлтүүрийн
-	жагсаалтыг авах боломжтой. Энэ бол өөрийн шүүлтүүрийг нэмэх, 
-	идэвхгүй болгох, хасах гэх мэт үйлдлийг хэлнэ.">
-<!ENTITY description.par2 "Та доорх мэдээлэгчүүдийн жагсаалтаас нэгийг сонгож чадна. (илүү
-		мэдээлэгчүүдийг Adblock Plus Тохиргоогоор дараа нь нэмж болно):">
-<!ENTITY note "Тэмдэглэл: Шүүлтүүрийн жагсаалт нь эдгээр үүсгэгдсэн жагсаалтаар
-	хязгаарлагдана.">
-<!ENTITY adblock.warning "Adblock Plus нь хуучин Adblock Plus эсвэл энэ Adblock хувилбарыг суулгасныг илрүүллээ.  Adblock болон Adblock Plus нь зэрэгцэн ажиллавал хүндрэл үүсгэж болзошгүй.  Adblock-ийг устгахыг зөвлөж байна.">
-<!ENTITY adblock.uninstall "Adblovk-ийг устгах">
-<!ENTITY filterset.g.warning "It seems that you use Filterset.G. This filter list has been barely maintained in the last few years and is a common cause of problems with web sites. It is recommended that you uninstall Filterset.G now.">
-<!ENTITY filterset.g.moreinfo "Илүү мэдээлэл">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Filterset.G-г устгах">
-<!ENTITY homepage.label "Үндсэн хуудас">
-<!ENTITY subscribe.label "Авах">
-<!ENTITY subscribe.accesskey "А">
-<!ENTITY other.label "Өөр мэдээлэгч нэмэх">
-<!ENTITY other.accesskey "Ө">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Бүх мэдээлэгчийг харах">

=== added file 'chrome/locale/mn/about.dtd'
--- chrome/locale/mn/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/mn/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,14 @@
+<!ENTITY dialog.title "Adblock Plus-ийн тухай">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Хувилбар">
+<!ENTITY description "Adblock Plus нь вэб хуудас дээр таны харахыг хүсэхгүй байгааг тань шийдэж өгнө.
+	Хэрэв та хүсээгүй зүйлсээ Adblock Plus-д хэлснээр, тэдгээр сурталчилгаа, баннер
+	болон бусад зүйлсийг татах хэрэггүй болно!">
+<!ENTITY homepage.label "Adblock Plus-ийн вэб хуудас:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Зохиогч:">
+<!ENTITY contributors.label "Дэмжигчид:">
+<!ENTITY developers.label "Хөгжүүлэгчид:">
+<!ENTITY designers.label "График дизайнерүүд:">
+<!ENTITY subscriptionAuthors.label "Шүүх мэдээлэгч үүсгэгчид:">
+<!ENTITY translators.label "Орчуулагчид:">

=== added file 'chrome/locale/mn/composer.dtd'
--- chrome/locale/mn/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/mn/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Adblock Plus шүүлтүүрийн дүрэм нэмэх">
+<!ENTITY accept.label "Шүүлтүүр нэмэх">
+<!ENTITY advanced.label "Дэвшмэл харагдац">
+<!ENTITY basic.label "Үндсэн харагдац">
+<!ENTITY disabled.warning "Adblock Plus нь одоогоор хаалттай байна.  Та шүүлтүүр нэмж чадах боловч хэрэгжихгүй байх болно. [link]Adblock Plus-ийг нээх[/link].">
+<!ENTITY groupDisabled.warning "Шүүх бүлэг &quot;?1?&quot; нь одоогоор хаалттай шүүлтүүр рүү нэмэгдсэн байна. Та шүүлтүүрийг оруулсан боловч [link]шүүх бүлгийг нээх[/link] үйлдлийг хийгээгүй.">
+<!ENTITY filter.label "Шинэ шүүлтүүр:">
+<!ENTITY filter.accesskey "ш">
+<!ENTITY preferences.label "Байгаа шүүлтүүрүүдийг харах...">
+<!ENTITY preferences.accesskey "Б">
+<!ENTITY type.filter.label "Хаших шүүлтүүр">
+<!ENTITY type.filter.accesskey "Х">
+<!ENTITY type.whitelist.label "Үл хаших дүрэм">
+<!ENTITY type.whitelist.accesskey "Ү">
+<!ENTITY pattern.label "Эсгүүрийн байдал">
+<!ENTITY pattern.explanation "Эсгүүр нь хаягийн аль нэг хэсэг, * тэмдэг шиг байж болно. Энэ шүүлтүүр нь зөвхөн энэ эсгүүртэй холбогдох хаяг дээр хэрэгжинэ.">
+<!ENTITY regexp.warning "Эсгүүр нь энгийн илэрхийлэл шиг байж болно. Хэт их энгийн илэрхийлэл нь ажиллагааг удаашруулж болзошгүй. If you didn't intend to use regular expressions, add a * symbol at the end of the pattern.">
+<!ENTITY shortpattern.warning "The pattern you entered is too short to be optimized, many such patterns might slow down your browsing. It is recommended that you choose a longer string for this filter.">
+<!ENTITY custom.pattern.label "Тусгай:">
+<!ENTITY custom.pattern.accesskey "Т">
+<!ENTITY anchors.label "Эсгүүрийг зөвхөн зөвшөөрөх нь:">
+<!ENTITY anchor.start.label "хаягийн эхлэлд">
+<!ENTITY anchor.start.accesskey "э">
+<!ENTITY anchor.start.flexible.label "Домайн нэрийн эхлэлд">
+<!ENTITY anchor.start.flexible.accesskey "н">
+<!ENTITY anchor.end.label "хаягийн төгсгөлд">
+<!ENTITY anchor.end.accesskey "Д">
+<!ENTITY options.label "Сонголтууд">
+<!ENTITY domainRestriction.label "Хязгаарлах хаяг">
+<!ENTITY domainRestriction.accesskey "Я">
+<!ENTITY domainRestriction.help "Specify one or more domains separated by the symbol &quot;|&quot;, the filter will only be applied on these domains then. The symbol &quot;~&quot; before a domain name means that the filter should not be applied on that domain.">
+<!ENTITY firstParty.label "Зөвхөн эхний хэсэг">
+<!ENTITY firstParty.accesskey "з">
+<!ENTITY thirdParty.label "Зөвхөн гуравдагч хэсэг">
+<!ENTITY thirdParty.accesskey "г">
+<!ENTITY matchCase.label "Том жижиг ялгах">
+<!ENTITY matchCase.accesskey "Ж">
+<!ENTITY types.label "Хэрэглэх төрлүүд:">
+<!ENTITY selectAllTypes.label "Бүгдийг сонгох">
+<!ENTITY unselectAllTypes.label "Бүгдийг үл сонгох">
+<!ENTITY collapse.label "Хашигдсанг хураах нь:">
+<!ENTITY collapse.accesskey "у">
+<!ENTITY collapse.default.yes.label "Анхдагчийг (тийм) хэрэглэх">
+<!ENTITY collapse.default.no.label "Анхдагчийг (үгүй) хэрэглэх">
+<!ENTITY collapse.yes.label "Тийм">
+<!ENTITY collapse.no.label "Үгүй">

=== added file 'chrome/locale/mn/global.properties'
--- chrome/locale/mn/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/mn/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,65 @@
+default_dialog_title=Сурталчилгаа Хаагч
+action0_tooltip=Товшвол хамаарах цэсийг гаргана, дунд товшилтоор идэвхжүүлнэ/хаана.
+action1_tooltip=Товшвол хашигдах зүйлсийг нээнэ/хаана, дунд товшилтоор идэвхжүүлнэ/хаана.
+action2_tooltip=Товшвол тохиргоонуудыг нээн, дунд товшилтоо идэвхжүүлнэ/хаана.
+action3_tooltip=Товшилтоор Adblock Plus-ийг идэвхжүүлнэ/хаана.
+disabled_tooltip=Adblock Plus нь идэвхгүй.
+whitelisted_tooltip=Adblock Plus нь идэвхтэй боловч тухайн хуудсанд хаалттай.
+blocked_count_tooltip=?1? хэтрэлт ?2?
+no_blocking_suggestions=Тухайн хуудсанд хашигдах зүйлс алга
+whitelisted_page=Adblock Plus нь тухайн хуудсанд хаалттай байна
+whitelist_description=Онцгой дүрмүүд
+filterlist_description=Сурталчилгааны шүүлтүүр
+invalid_description=Буруу шүүлтүүр
+elemhide_description=Элемент хайх дүрмүүд
+subscription_description=Шүүлтүүр мэдээлэгч:
+subscription_wrong_version=Уг мэдээлэгч дэх зарим шүүлтүүр нь Adblock Plus-ийг шаардана ?1? зөв ажиллахын тулд!
+subscription_source=Эх сурвалж:
+subscription_status=Төлөв:
+subscription_status_autodownload=Автоаматаар шинэчлэгдсэн
+subscription_status_manualdownload=Гараар шинэчлэгдсэн
+subscription_status_externaldownload=Бусдаар (өөр нэмэлт) шинэчлэгдсэн
+subscription_status_lastdownload=Сүүлийн таталт:
+subscription_status_lastdownload_inprogress=Татаж байна...
+subscription_status_lastdownload_unknown=N/A
+remove_subscription_warning=Та үнэхээр уг мэдээлэгчийг устгамаар байна уу?
+import_filters_wrong_version=Анхааруулга: уг жагсаалт дах шүүлтүүрүүдийн зарим нь Adblock Plus-ийг шаардана ?1? зөв ажиллахын тулд. Энэ жагсаалтыг оруулахаасаа өмнө магадгүй та Adblock Plus-ийн сүүлийн байдлаарх хувилбараар шинэчлэх хэрэгтэй.
+import_filters_warning=Та тухайн шүүлтүүрүүдийг солих эсвэл шинэ шүүлтүүрүүдийг жагсаалтын төгсгөлд нэмэхийг хүсэж байна уу?
+import_filters_title=Шүүлтүүрүүд оруулах
+export_filters_title=Шүүлтүүрүүд гаргах
+invalid_filters_file=Adblock Plus-ийн шүүлтүүрийн зөв файл биш байна.
+filters_write_error=Шүүлтүүрүүдийг файл руу бичих үест алдаа гарлаа. Файл нь бичигдэх эрхтэй эсвэл өөр програм ашиглаж буй эсэхийг шалгана уу.
+clearall_warning=Та жагсаалтаас бүх шүүлтүүрүүдийг устгамаар байна уу?
+resethitcounts_warning=Та бүх шүүлтүүрийн хандалтын тоог буцааж тэг болгомоор байна уу? Уг үйлдлийг буцааж болдоггүй!
+resethitcounts_selected_warning=Та сонгогдсон шүүлтүүрийн хандалтын тоог буцааж тэг болгомоор байна уу? Уг үйлдлийг буцааж болдоггүй!
+filter_regexp_tooltip=Шүүлтүүр нь энгийн илэрхийлэл эсвэл богино байвал зохимжтой. Хэт их шүүлтүүр нь таны хөтчийг удаашруулах магадлалтай.
+filter_elemhide_duplicate_id=Нуух элементүүдийн зөвхөн нэг ID нь тодорхойлогдох боломжтой
+filter_elemhide_nocriteria=Нуух элементийг таних шалгуур тодорхойлогдоогүй байна
+subscription_notAdded_warning_addendum=Та үргэлжлүүлэх үү?
+subscription_invalid_location=Шүүлтүүрийн жагсаалтын байрлал нь буруу URL эсвэл файлын нэр буруу.
+synchronize_invalid_url=Бүтэлгүйтэв, буруу хаяг
+synchronize_connection_error=Бүтэлгүйтэв, таталтын бүтэлгүйтэл
+synchronize_invalid_data=Бүтэлгүйтэв, буруу шүүлтүүрийн жагсаалт
+synchronize_checksum_mismatch=Бүтэлгүйтлээ, шалгалт таарсангүй
+synchronize_ok=Амжилттай
+overwrite=Давхарлах
+append=Нэмэх
+new_filter_group_title=Шинэ шүүлтүүр
+type_label_other=бусад
+type_label_script=скрипт
+type_label_image=зураг
+type_label_stylesheet=stylesheet
+type_label_object=объект
+type_label_subdocument=хүрээ
+type_label_document=баримт
+type_label_background=ар дэвсгэр
+type_label_elemhide=нууц
+type_label_xbl=XBL боолт
+type_label_ping=холбоос шалгах
+type_label_xmlhttprequest=XML хүсэлт
+type_label_object_subrequest=объект дэдхүсэлт
+type_label_dtd=ДТД
+type_label_media=дуу/дүрс
+type_label_font=үсэг
+fennec_status_enabled=Adblock Идэвхтэй
+fennec_status_disabled=Adblock хаалттай

=== added file 'chrome/locale/mn/meta.properties'
--- chrome/locale/mn/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/mn/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,3 @@
+translator=Владимир Палант
+name=Adblock Plus
+description=Сурталчилгаа бол өчигдөр байлаа!

=== added file 'chrome/locale/mn/overlay.dtd'
--- chrome/locale/mn/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/mn/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Төлөв:">
+<!ENTITY blocked.tooltip "Уг хуудас дахь хашигдсан зүйлс:">
+<!ENTITY filters.tooltip "Хамгийн идэвхтэй шүүлтүүрүүд:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY toolbarbutton.label "Adblock Нэмэх">
+<!ENTITY view.blockableItems.label "Adblock Нэмэх:Хашигдахуйц зүйлс">
+<!ENTITY context.image.label "Adblock Зураг">
+<!ENTITY context.object.label "Adblock Объект">
+<!ENTITY context.frame.label "Adblock Хүрээ">
+<!ENTITY context.media.label "Adblock: Дуу/видео">
+<!ENTITY context.removeWhitelist.label "Adblock: Уг хуудсанд дахин нээх">
+<!ENTITY sidebar.title "Тухайн хуудас дахь хашигдаж болох зүйлс">
+<!ENTITY settings.label "Тохиргоонууд">
+<!ENTITY settings.accesskey "Т">
+<!ENTITY opensidebar.label "Хашигдах зүйлсийг нээх">
+<!ENTITY opensidebar.accesskey "Х">
+<!ENTITY closesidebar.label "Хашигдах зүйлсийг хаах">
+<!ENTITY closesidebar.accesskey "Х">
+<!ENTITY whitelist.site.label "Хаах нь ?1?">
+<!ENTITY whitelist.page.label "Зөвхөн уг хуудсанд хаах">
+<!ENTITY objecttab.title "Хаших">
+<!ENTITY objecttab.tooltip "Энд дарвал уг объектийг Adblock Plus-аар хаших болно">

=== added file 'chrome/locale/mn/settings.dtd'
--- chrome/locale/mn/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/mn/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,92 @@
+<!ENTITY dialog.title "Adblock Plus Тохиргоонууд">
+<!ENTITY filters.label "Шүүлтүүрүүд">
+<!ENTITY filters.accesskey "Ш">
+<!ENTITY add.label "Шүүлт нэмэх">
+<!ENTITY add.accesskey "Н">
+<!ENTITY addsubscription.label "Шүүлтүүр мэдээлэгч нэмэх">
+<!ENTITY addsubscription.accesskey "М">
+<!ENTITY synchsubscriptions.label "Бүх мэдээлэгчийг шинэчлэх">
+<!ENTITY synchsubscriptions.accesskey "Б">
+<!ENTITY import.label "Шүүлтүүр оруулах">
+<!ENTITY import.accesskey "О">
+<!ENTITY export.label "Шүүлтүүр гаргах">
+<!ENTITY export.accesskey "Г">
+<!ENTITY clearall.label "Бүх шүүлтүүрүүдийг хасах">
+<!ENTITY clearall.accesskey "С">
+<!ENTITY resethitcounts.label "Хандалтын төлвийг эхлүүлэх">
+<!ENTITY resethitcounts.accesskey "Т">
+<!ENTITY edit.label "Засвар">
+<!ENTITY edit.accesskey "З">
+<!ENTITY cut.label "Хайчлах">
+<!ENTITY cut.accesskey "Ч">
+<!ENTITY copy.label "Хуулах">
+<!ENTITY copy.accesskey "Х">
+<!ENTITY paste.label "Тавих">
+<!ENTITY paste.accesskey "Т">
+<!ENTITY remove.label "Устгах">
+<!ENTITY remove.accesskey "У">
+<!ENTITY menu.find.label "Хайх">
+<!ENTITY menu.find.accesskey "А">
+<!ENTITY menu.findagain.label "Дахин хайх">
+<!ENTITY menu.findagain.accesskey "Д">
+<!ENTITY view.label "Харах">
+<!ENTITY view.accesskey "Х">
+<!ENTITY sort.label "Эрэмбэлэх нь">
+<!ENTITY sort.accesskey "Э">
+<!ENTITY sort.none.label "Эрэмбэ үгүй">
+<!ENTITY sort.none.accesskey "Ү">
+<!ENTITY sort.ascending.label "А &gt; Я эрэмбэлэх">
+<!ENTITY sort.ascending.accesskey "А">
+<!ENTITY sort.descending.label "Я &gt; А эрэмбэлэх">
+<!ENTITY sort.descending.accesskey "Я">
+<!ENTITY options.label "Сонголтууд">
+<!ENTITY options.accesskey "О">
+<!ENTITY enable.label "Adblock Plus идэвхтэй">
+<!ENTITY enable.accesskey "И">
+<!ENTITY showintoolbar.label "Хэрэгслийн мөрт харуулах">
+<!ENTITY showintoolbar.accesskey "М">
+<!ENTITY showinstatusbar.label "Төлвийн мөрт харуулах">
+<!ENTITY showinstatusbar.accesskey "Т">
+<!ENTITY objecttabs.label "Flash болон Java-д tab харуулах">
+<!ENTITY objecttabs.accesskey "Х">
+<!ENTITY collapse.label "Хашигдсан элементийг хумих">
+<!ENTITY collapse.accesskey "Э">
+<!ENTITY help.label "Тусламж">
+<!ENTITY help.accesskey "Т">
+<!ENTITY gettingStarted.label "Эхлэл">
+<!ENTITY gettingStarted.accesskey "Э">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Түгээмэл Асуултын Хариултууд">
+<!ENTITY faq.accesskey "А">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Adblock Plus шүүлтүүрүүд бичих">
+<!ENTITY filterdoc.accesskey "Б">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Adblock Plus-ийн тухай">
+<!ENTITY about.accesskey "Т">
+<!ENTITY description "Хашихыг хүссэн хаягаа нэмэхдээ, доош унжих жагсаалтаас авч боломжтой.
+		Та * ашиглан илүү ерөнхий шүүлтүүр үүсгэж болно. Илүү хэрэглэгчид
+		энгийн илэрхийлэл (regexpression) ашиглаж чадна. Ж: /banner\d+\.gif$/.">
+<!ENTITY filter.column "Шүүх дүрэм">
+<!ENTITY filter.accesskey "Ш">
+<!ENTITY slow.column "Удаан шүүлтүүрүүд">
+<!ENTITY slow.accesskey "У">
+<!ENTITY enabled.column "Идэвхтэй">
+<!ENTITY enabled.accesskey "И">
+<!ENTITY hitcount.column "Хандалт">
+<!ENTITY hitcount.accesskey "Х">
+<!ENTITY lasthit.column "Сүүлийн хандалт">
+<!ENTITY lasthit.accesskey "С">
+<!ENTITY context.edit.label "Шүүлтүүр засах">
+<!ENTITY context.resethitcount.label "Шүүлтүүрийн хандалтын статистикийг эхлүүлэх">
+<!ENTITY context.synchsubscription.label "Мэдээлэгчийг одоо шинэчлэх">
+<!ENTITY context.editsubscription.label "Мэдээлэгч засах">
+<!ENTITY context.moveup.label "Дээшлүүлэх">
+<!ENTITY context.movedown.label "Доошлуулах">
+<!ENTITY context.movegroupup.label "Бүлгийг дээшлүүлэх">
+<!ENTITY context.movegroupdown.label "Бүлгийг доошлуулах">
+<!ENTITY context.enable.label "Нээх">
+<!ENTITY context.disable.label "Хаах">
+<!ENTITY apply.label "Хэрэглэх">
+<!ENTITY apply.accesskey "Г">
+<!ENTITY fennec.subscription.label "Шүүх мэдээлэгч">

=== added file 'chrome/locale/mn/sidebar.dtd'
--- chrome/locale/mn/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/mn/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Хашигдахуйц зүйлс (салгагдсан)">
+<!ENTITY detach.label "Салгах">
+<!ENTITY reattach.label "Залгах">
+<!ENTITY search.label "Хайх:">
+<!ENTITY search.accesskey "Х">
+<!ENTITY type.label "Төрөл">
+<!ENTITY address.label "Хаяг">
+<!ENTITY filter.label "Шүүлтүүр">
+<!ENTITY state.label "Нөхцөл">
+<!ENTITY size.label "Хэмжээ">
+<!ENTITY docDomain.label "Баримтын эх">
+<!ENTITY noitems.label "Хашигдах зүйлс алга">
+<!ENTITY whitelisted.label "Цагаанжагсаалтын хуудас">
+<!ENTITY tooltip.address.label "Хаяг:">
+<!ENTITY tooltip.type.label "Төрөл:">
+<!ENTITY tooltip.type.blocked "(хашигдсан)">
+<!ENTITY tooltip.type.whitelisted "(цагаандсан)">
+<!ENTITY tooltip.size.label "Хэмжээ:">
+<!ENTITY tooltip.docDomain.label "Баримтын эх:">
+<!ENTITY tooltip.filter.label "Эффектийн шүүлтүүр:">
+<!ENTITY tooltip.filterSource.label "Шүүлтүүрийн эх:">
+<!ENTITY context.block.label "Уг зүйлийг хаших">
+<!ENTITY context.editfilter.label "Эффектийн шүүлтүүрийг засах">
+<!ENTITY context.whitelist.label "Зүйлд онцгой дүрэм нэмэх">
+<!ENTITY context.disablefilter.label "Шүүлтүүр хаах ?1?">
+<!ENTITY context.enablefilter.label "Шүүлтүүр нээх ?1?">
+<!ENTITY context.disablefilteronsite.label "Энэ шүүлтүүрийг хаах газар нь ?1?">
+<!ENTITY context.open.label "Шинэ хуудсанд нээх">
+<!ENTITY context.flash.label "Flash зүйлийн хүрээнүүд">
+<!ENTITY context.copy.label "Зүйлийн хаягийг сануулах">
+<!ENTITY context.copyFilter.label "Шүүлтүүр хуулах">
+<!ENTITY context.selectAll.label "Бүгдийг сонгох">

=== added file 'chrome/locale/mn/subscriptionSelection.dtd'
--- chrome/locale/mn/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/mn/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,27 @@
+<!ENTITY dialog.title "Adblock Plus-д тавтай морил">
+<!ENTITY dialog.title.edit "Шүүлтүүрийн мэдээлэгч засах">
+<!ENTITY adblock.warning "Adblock Plus нь хуучин Adblock Plus эсвэл энэ Adblock хувилбарыг суулгасныг илрүүллээ.  Adblock болон Adblock Plus нь зэрэгцэн ажиллавал хүндрэл үүсгэж болзошгүй.  Adblock-ийг устгахыг зөвлөж байна.">
+<!ENTITY adblock.uninstall "Adblovk-ийг устгах">
+<!ENTITY filterset.g.warning "It seems that you use Filterset.G. This filter list has been barely maintained in the last few years and is a common cause of problems with web sites. It is recommended that you uninstall Filterset.G now.">
+<!ENTITY filterset.g.moreinfo "Илүү мэдээлэл">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Filterset.G-г устгах">
+<!ENTITY subscriptionSelector.label "Жагсаалтаас шүүх мэдээлэгч сонгоно уу:">
+<!ENTITY viewList.label "Шүүлтүүрүүд харах">
+<!ENTITY visitHomepage.label "Үндсэн хуудсанд зочлох">
+<!ENTITY addSubscription.label "Мэдээлэгч нэмэх">
+<!ENTITY saveSubscription.label "Мэдээлэгч хадгалах">
+<!ENTITY other.label "Өөр мэдээлэгч нэмэх">
+<!ENTITY other.accesskey "Ө">
+<!ENTITY list.download.failed "Adblock Plus нь мэдээлэгчийн жагсаалтыг татаж чадсангүй.">
+<!ENTITY list.download.retry "Дахиж оролдох">
+<!ENTITY list.download.website "Вэбсайтыг харах">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY title.label "Мэдээлэгчийн гарчиг:">
+<!ENTITY title.accesskey "Г">
+<!ENTITY location.label "Шүүлтүүрийн жагсаалтын байршил:">
+<!ENTITY location.accesskey "Б">
+<!ENTITY autodownload.label "Автоматаар шинэчлэх">
+<!ENTITY autodownload.accesskey "В">
+<!ENTITY addMain.label "Шүүх мэдээлэгч &quot;?1?&quot; нэмэх">
+<!ENTITY addMain.accesskey "Ш">

=== modified file 'chrome/locale/ms-MY/composer.dtd'
--- chrome/locale/ms-MY/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ms-MY/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "Tambah penapis">
 <!ENTITY advanced.label "Paparan mahir">
 <!ENTITY basic.label "Paparan biasa">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus sedang dinyahaktifkan. Anda masih boleh menambah penapis tetapi tambahan anda tidak akan aktif sehingga anda">
-<!ENTITY disabled.warning.link "aktifkan Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Kumpulan penapis &quot;&#37;S&quot; bahawa penapis ini sedah nyah aktif. Anda masih boleh menambah penapis tetapi penapis tersebut tidak akan digunakan kecuali anda">
-<!ENTITY groupDisabled.warning.link "aktifkan kumpulan penapis">
-<!ENTITY groupDisabled.warning.afterLink ".">
+<!ENTITY disabled.warning "Adblock Plus sedang dinyahaktifkan. Anda masih boleh menambah penapis tetapi tambahan anda tidak akan aktif sehingga anda [link]aktifkan Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Kumpulan penapis &quot;?1?&quot; bahawa penapis ini sedah nyah aktif. Anda masih boleh menambah penapis tetapi penapis tersebut tidak akan digunakan kecuali anda [link]aktifkan kumpulan penapis[/link].">
 <!ENTITY filter.label "Penapis baru:">
 <!ENTITY filter.accesskey "r">
 <!ENTITY preferences.label "Papar penapis sedia ada...">

=== modified file 'chrome/locale/ms-MY/global.properties'
--- chrome/locale/ms-MY/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/ms-MY/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,10 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Iklan semalam!
-status_active_label=Adblock
-status_disabled_label=Dimatikan
 action0_tooltip=Klik untuk mengeluarkan menu konteks, klik separuh untuk aktifkan atau matikan.
 action1_tooltip=Klik untuk membuka/menutup item yang boleh disekat, klik separuh untuk aktifkan atau matikan.
 action2_tooltip=Klik untuk buka tatarajah, klik separuh untuk aktifkan atau matikan.
 action3_tooltip=Klik untuk mematikan/menutup Adblock Plus.
-active_tooltip=Adblock Plus diaktifkan.
 disabled_tooltip=Adblock Plus dimatikan.
 whitelisted_tooltip=Adblock Plus aktif tetapi dimatikan pada halaman semasa.
-blocked_count_tooltip=-- dari --
+blocked_count_tooltip=?1? dari ?2?
 no_blocking_suggestions=Tiada item yang boleh disekat pada halaman semasa
 whitelisted_page=Adblock Plus telah dimatikan pada halaman semasa
 whitelist_description=Pengecualian peraturan
@@ -16,7 +12,7 @@
 invalid_description=Penapis tidak sah
 elemhide_description=Peraturan menyembunyikan elemen
 subscription_description=Langganan penapis:
-subscription_wrong_version=Bberapa penapis dalam langganan ini memerlukan Adblock Plus -- untuk berfungsi!
+subscription_wrong_version=Bberapa penapis dalam langganan ini memerlukan Adblock Plus ?1? untuk berfungsi!
 subscription_source=Sumber:
 subscription_status=Status:
 subscription_status_autodownload=Dikemaskini secara automatik
@@ -26,7 +22,7 @@
 subscription_status_lastdownload_inprogress=Memuat turun...
 subscription_status_lastdownload_unknown=N/A
 remove_subscription_warning=Adakah anda mahu membuang langganan ini?
-import_filters_wrong_version=Amaran: beberapa penapis dalam senarai ini memerlukan Adblock Plus -- untuk berfungsi dengan sempurna. Anda perlu menaiktaraf Adblock Plus kepada yang terbaru sebelum mengimport senarai ini.
+import_filters_wrong_version=Amaran: beberapa penapis dalam senarai ini memerlukan Adblock Plus ?1? untuk berfungsi dengan sempurna. Anda perlu menaiktaraf Adblock Plus kepada yang terbaru sebelum mengimport senarai ini.
 import_filters_warning=Adakah anda mahu menggantikan penapis sedia ada atau melampirkan penapis baru pada akhir senarai sedia ada?
 import_filters_title=Import penapis
 export_filters_title=Eksport penapis
@@ -38,9 +34,7 @@
 filter_regexp_tooltip=Penapis ini hanya ungkapan biasa atau terlalu pendek untuk dioptimumkan. Terlalu banyak penapis mungkin akan melambatkan penjelajahan web anda.
 filter_elemhide_duplicate_id=Hanya satu ID elemen untuk disembunyikan boleh dinyatakan
 filter_elemhide_nocriteria=Tiada kriteria yang dinyatakan untuk mengenal pasti elemen untuk disembunyikan
-subscription_no_location=Sila masukkan lokasi untuk emuat turun penapis.
 subscription_invalid_location=Lokasi senarai penapis sama ada URL atau nama fail adalah tidak sah.
-subscription_location_exists=Anda telah melanggan senarai penapis ini.
 synchronize_invalid_url=Gagal, bukan alamat yang sah
 synchronize_connection_error=Gagal, kegagalan muat turun
 synchronize_invalid_data=Gagal, bukan senarai penapis yang sah

=== added file 'chrome/locale/ms-MY/meta.properties'
--- chrome/locale/ms-MY/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ms-MY/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=Iklan semalam!

=== modified file 'chrome/locale/ms-MY/overlay.dtd'
--- chrome/locale/ms-MY/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ms-MY/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -16,7 +16,7 @@
 <!ENTITY opensidebar.accesskey "B">
 <!ENTITY closesidebar.label "Tutup item yang boleh disekat">
 <!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Matikan pada --">
+<!ENTITY whitelist.site.label "Matikan pada ?1?">
 <!ENTITY whitelist.page.label "Matikan pada halaman ini sahaja">
 <!ENTITY objecttab.title "Sekat">
 <!ENTITY objecttab.tooltip "Klik di sini untuk mennyekat objek ini dengan Adblock Plus">

=== modified file 'chrome/locale/ms-MY/sidebar.dtd'
--- chrome/locale/ms-MY/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ms-MY/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "Sekat item ini">
 <!ENTITY context.editfilter.label "Ubah penapis yang menyekat">
 <!ENTITY context.whitelist.label "Tambah perintah pengecualian untuk item">
-<!ENTITY context.disablefilter.label "Nyahaktif penapis --">
-<!ENTITY context.enablefilter.label "Aktifkan penapis --">
-<!ENTITY context.disablefilteronsite.label "Nyah aktif penapis ini pada --">
+<!ENTITY context.disablefilter.label "Nyahaktif penapis ?1?">
+<!ENTITY context.enablefilter.label "Aktifkan penapis ?1?">
+<!ENTITY context.disablefilteronsite.label "Nyah aktif penapis ini pada ?1?">
 <!ENTITY context.open.label "Buka dalam Tab Baru">
 <!ENTITY context.flash.label "Jelaskan sempadan item">
 <!ENTITY context.copy.label "Salin alamat item">

=== removed file 'chrome/locale/ms-MY/subscription.dtd'
--- chrome/locale/ms-MY/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ms-MY/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Ubah deskripsi penapis">
-<!ENTITY dialog.newtitle "Tambah langganan penapis">
-<!ENTITY new.description "Sila masukkan alamat laman web atau fail yang mengandungi penapis Adblock Plus">
-<!ENTITY edit.description "Senarai penapis langganan ini akan dimuat turun dari lokasi yang diberikan.">
-<!ENTITY external.description "Ini merupakan langganan penapis luar, senarai penapisnya akan dikemaskini oleh ekstensi yang mencipta langganan ini.">
-<!ENTITY autodownload.description "Jika anda memilih &apos;Kemaskini secara automatik&apos; lokasi ini akan disemak setiap hari. Jika fungsi ini dimatikan, anda masih boleh mengaktifkan kemaskini secara manual dari menu konteks langganan.">
-<!ENTITY location.label "Lokasi senarai penapis:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Tajuk langganan">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Kemaskini automatik">
-<!ENTITY autodownload.accesskey "K">
-<!ENTITY enabled.label "Aktifkan penapis">
-<!ENTITY enabled.accesskey "A">

=== added file 'chrome/locale/ms-MY/subscriptionSelection.dtd'
--- chrome/locale/ms-MY/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ms-MY/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,16 @@
+<!ENTITY dialog.title "Selamat datang ke Adblock Plus">
+<!ENTITY dialog.title.edit "Ubah deskripsi penapis">
+<!ENTITY adblock.warning "Adblock Plus telah mengesan Adblock atau Adblock Plus versi terdahulu telah dipasang. Menjalankan Adblock dan Adblock Plus dalam masa yang sama boleh menyebabkan masalah dan perlu dielakkan. Anda digalakkan membuang Adblock sekarang.">
+<!ENTITY adblock.uninstall "Buang Adblock">
+<!ENTITY filterset.g.warning "Anda kelihatan menggunakan Filterset.G. Penapis ini sudah jarang-jarang dikemaskini dan sering menyebabkan masalah dengan laman web. Anda digalakkan membuang Filterset.G sekarang.">
+<!ENTITY filterset.g.moreinfo "Lebih info">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Buang Filterset.G">
+<!ENTITY other.label "Tambah langganan lain">
+<!ENTITY other.accesskey "T">
+<!ENTITY title.label "Tajuk langganan">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Lokasi senarai penapis:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Kemaskini automatik">
+<!ENTITY autodownload.accesskey "K">

=== removed file 'chrome/locale/ms-MY/tip_subscriptions.dtd'
--- chrome/locale/ms-MY/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ms-MY/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Selamat datang ke Adblock Plus">
-<!ENTITY description.par1 "Terima kasih kerana memasang Adblock Plus. Ekstensi ini akan melenyapkan 99&#37; dari iklan-iklan yang anda lihat pada web. Walaubagaimanapun, tapisan iklan yang efektif memerlukan anda menakrifkan kumpulan penapis yang baik. Anda boleh lakukannya sendiri atau melanggan senarai penapis yang dicipta orang lain. Anda masih boleh menambah penapis anda sendiri, menambah dan membuang langganan apabila perlu.">
-<!ENTITY description.par2 "Anda boleh memilih satu langganan daripada senarai langganan yang dibawah (langganan yang lain boleh ditambah kemudian melalui tatarajah Adblock Plus walaupun ini tidak digalakkan):">
-<!ENTITY note "Nota: Senarai penapis akan lebih efektif apabila digunakan dari kawasan senarai penapis ini dibuat.">
-<!ENTITY adblock.warning "Adblock Plus telah mengesan Adblock atau Adblock Plus versi terdahulu telah dipasang. Menjalankan Adblock dan Adblock Plus dalam masa yang sama boleh menyebabkan masalah dan perlu dielakkan. Anda digalakkan membuang Adblock sekarang.">
-<!ENTITY adblock.uninstall "Buang Adblock">
-<!ENTITY filterset.g.warning "Anda kelihatan menggunakan Filterset.G. Penapis ini sudah jarang-jarang dikemaskini dan sering menyebabkan masalah dengan laman web. Anda digalakkan membuang Filterset.G sekarang.">
-<!ENTITY filterset.g.moreinfo "Lebih info">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Buang Filterset.G">
-<!ENTITY homepage.label "Laman web">
-<!ENTITY subscribe.label "Langgan">
-<!ENTITY subscribe.accesskey "G">
-<!ENTITY other.label "Tambah langganan lain">
-<!ENTITY other.accesskey "T">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Lihat semua langganan">

=== added file 'chrome/locale/nb-NO/.incomplete'
=== removed file 'chrome/locale/nb-NO/composer.dtd'
=== modified file 'chrome/locale/nb-NO/global.properties'
--- chrome/locale/nb-NO/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/nb-NO/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,10 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Reklame er bare SÅ i går!
-status_active_label=Adblock
-status_disabled_label=Deaktivert
 action0_tooltip=Trykk for å åpne menyen, trykk midtknapp for å Aktivere/Deaktivere.
 action1_tooltip=Trykk for å åpne/lukke elementer som kan blokkeres, trykk midtknapp for å Aktivere/Deaktivere.
 action2_tooltip=Trykk for å åpne innstillinger, trykk midtknapp for å Aktivere/Deaktivere.
 action3_tooltip=Trykk for å Aktivere/Deaktivere Adblock Plus.
-active_tooltip=Adblock Plus er aktivert.
 disabled_tooltip=Adblock Plus er deaktivert.
 whitelisted_tooltip=Adblock Plus er aktivert, men deaktivert på denne siden.
-blocked_count_tooltip=-- av --
+blocked_count_tooltip=?1? av ?2?
 no_blocking_suggestions=Ingen elementer kan blokkeres på denne siden
 whitelisted_page=Adblock Plus har blitt deaktivert på denne siden
 whitelist_description=Unntaksregler
@@ -16,7 +12,6 @@
 invalid_description=Ugyldige filtre
 elemhide_description=Regler for skjuling av elementer
 subscription_description=Filterabonnement:
-subscription_wrong_version=Noen filtre i dette abonnementet krever Adblock Plus for å virke!
 subscription_source=Kilde:
 subscription_status=Status:
 subscription_status_autodownload=Automatisk oppdatert
@@ -26,7 +21,6 @@
 subscription_status_lastdownload_inprogress=Laster ned...
 subscription_status_lastdownload_unknown=Ikke tilgjengelig
 remove_subscription_warning=Ønsker du virkelig å fjerne dette abonnementet?
-import_filters_wrong_version=Advarsel: Noen av filtrene i denne listen krever Adblock Plus for å virke. Du bør oppgradere til siste versjon av Adblock Plus før du importerer denne listen.
 import_filters_warning=Ønsker du å erstatte nåværende filtre eller legge nye filtre til i listen?
 import_filters_title=Importer filtre
 export_filters_title=Eksporter filtre
@@ -35,9 +29,7 @@
 clearall_warning=Ønsker du virkelig å fjerne alle filtrene fra listen?
 resethitcounts_warning=Ønsker du virkelig å nullstille trefftelleren for alle filtre? Dette valget kan ikke bli omgjort!
 resethitcounts_selected_warning=Ønsker du virkelig å nullstille trefftelleren for valgte filtre? Dette valget kan ikke bli omgjort!
-subscription_no_location=Vær vennlig skrive inn hvor filtre skal lastes ned fra.
 subscription_invalid_location=Filterlisten du skrev inn har enten en ugyldig URL eller et ugyldig filnavn.
-subscription_location_exists=Du abonnerer allerede på denne filterlisten.
 synchronize_invalid_url=Mislykket, ikke en gyldig adresse
 synchronize_connection_error=Mislykket, feil i nedlasting
 synchronize_invalid_data=Mislykket, ikke en gyldig filterliste

=== added file 'chrome/locale/nb-NO/meta.properties'
--- chrome/locale/nb-NO/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/nb-NO/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=Reklame er bare SÅ i går!

=== modified file 'chrome/locale/nb-NO/overlay.dtd'
--- chrome/locale/nb-NO/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nb-NO/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -13,7 +13,7 @@
 <!ENTITY opensidebar.accesskey "B">
 <!ENTITY closesidebar.label "Lukk elementer som kan blokkeres">
 <!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Deaktiver på --">
+<!ENTITY whitelist.site.label "Deaktiver på ?1?">
 <!ENTITY whitelist.page.label "Deaktiver på denne siden">
 <!ENTITY objecttab.title "Blokkér">
 <!ENTITY objecttab.tooltip "Trykk her for å blokkere dette objektet med Adblock Plus">

=== removed file 'chrome/locale/nb-NO/subscription.dtd'
--- chrome/locale/nb-NO/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nb-NO/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Endre abonnement på filter">
-<!ENTITY dialog.newtitle "Legg til filterabonnement">
-<!ENTITY new.description "Skriv inn webadressen eller angi filen som inneholder en liste over Adblock Plus filtre.">
-<!ENTITY edit.description "Filterlisten for dette abonnementet vil bli lastet ned fra den oppgitte adressen.">
-<!ENTITY external.description "Dette er et eksternt filterabonnement. Filtrene vil bli oppdatert av utvidelsen som opprettet abonnementet.">
-<!ENTITY autodownload.description "Om du velger &apos;Automatisk oppdatering&apos; vil denne adressen bli sjekket daglig for oppdateringer. Med denne muligheten avslått kan du kjøre en oppdatering manuelt fra abonnementets meny.">
-<!ENTITY location.label "Adresse til filterliste:">
-<!ENTITY location.accesskey "d">
-<!ENTITY title.label "Navn på abonnement:">
-<!ENTITY title.accesskey "v">
-<!ENTITY autodownload.label "Automatisk oppdatering">
-<!ENTITY autodownload.accesskey "t">
-<!ENTITY enabled.label "Aktivere filtre">
-<!ENTITY enabled.accesskey "k">

=== added file 'chrome/locale/nb-NO/subscriptionSelection.dtd'
--- chrome/locale/nb-NO/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/nb-NO/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,10 @@
+<!ENTITY dialog.title.edit "Endre abonnement på filter">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY other.label "Legg til abonnement">
+<!ENTITY other.accesskey "T">
+<!ENTITY title.label "Navn på abonnement:">
+<!ENTITY title.accesskey "v">
+<!ENTITY location.label "Adresse til filterliste:">
+<!ENTITY location.accesskey "d">
+<!ENTITY autodownload.label "Automatisk oppdatering">
+<!ENTITY autodownload.accesskey "t">

=== removed file 'chrome/locale/nb-NO/tip_subscriptions.dtd'
--- chrome/locale/nb-NO/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nb-NO/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,10 +0,0 @@
-<!ENTITY dialog.title "Velkommen til Adblock Plus">
-<!ENTITY description.par1 "Takk for at du installerer Adblock Plus. Dette tilleggsprogrammet kan eliminere 99&#37; av all reklame du ser på nett. Effektiv reklamefiltrering krever likevel at man har et sett med bra filtre. Du kan lage dem selv, eller enklere: Abonnere på filterlister som andre har laget. Det vil fortsatt være mulig å legg til egne filtre eller deaktivere/fjerne abonnementer når du måtte trenge det.">
-<!ENTITY description.par2 "Du kan velge ett abonnement fra listen med anbefalte abonnementer under (flere abonnementer kan legges til i Adblock Plus Innstillinger senere, men dette er som oftest ikke nødvendig):">
-<!ENTITY note "Verdt å vite: En filterliste er som regel mest effektiv når den blir brukt på websider i regionen den var laget for.">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY homepage.label "Hjemmeside">
-<!ENTITY subscribe.label "Abonnere">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "Legg til abonnement">
-<!ENTITY other.accesskey "T">

=== added directory 'chrome/locale/nl'
=== removed directory 'chrome/locale/nl-NL'
=== removed file 'chrome/locale/nl-NL/about.dtd'
--- chrome/locale/nl-NL/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nl-NL/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Over Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Versie">
-<!ENTITY description "Adblock Plus laat u zelf beslissen wat u niet wilt zien op het internet. Voortaan hoeft u niet meer alle reclames te downloaden die u toch niet wilt zien -geef ze gewoon door aan Adblock Plus!">
-<!ENTITY homepage.label "Adblock Plus website:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Auteur:">
-<!ENTITY contributors.label "Medewerkers:">

=== removed file 'chrome/locale/nl-NL/composer.dtd'
--- chrome/locale/nl-NL/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nl-NL/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,52 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus filterregel toevoegen">
-<!ENTITY accept.label "Filter toevoegen">
-<!ENTITY advanced.label "Uitgebreid">
-<!ENTITY basic.label "Eenvoudig">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus is uitgeschakeld. U kunt nog wel filters toevoegen, maar ze worden niet toegepast tot u">
-<!ENTITY disabled.warning.link "Adblock Plus weer inschakelen">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "De filtergroep &quot;&#37;S&quot; aan wordt toegevoegd is momenteel uitgeschakeld. U kunt het filter nog wel toevoegen maar het wordt niet toegepast tenzij u">
-<!ENTITY groupDisabled.warning.link "de filtergroep inschakeld">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Nieuw filter">
-<!ENTITY filter.accesskey "N">
-<!ENTITY preferences.label "Toon bestaande filters...">
-<!ENTITY preferences.accesskey "T">
-<!ENTITY type.filter.label "Blokkerend filter">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "Uitzonderingsregel">
-<!ENTITY type.whitelist.accesskey "U">
-<!ENTITY pattern.label "Zoek naar patroon">
-<!ENTITY pattern.explanation "Het patroon kan ieder gedeelte zijn van het adres, waarbij het *-symbool as joker geld. Het filter wordt alleen toegepast op adressen die met het patroon overeenkomen.">
-<!ENTITY regexp.warning "Het patroon dat u heeft gegeven zal worden behandelt als een reguliere expressie. Veel reguliere expressie kunnen uw browser traag maken. Als het niet uw bedoeling was een reguliere expressie te schrijven, voeg dan een *-symbool aan het eind van het patroon toe.">
-<!ENTITY shortpattern.warning "Het patroon dat u heeft gegeven is te kort om te worden geoptimaliseerd, veel van zulke patronen kunnen uw browser traag maken. U kunt beter een langere regel voor dit filter kiezen.">
-<!ENTITY custom.pattern.label "Anders:">
-<!ENTITY custom.pattern.accesskey "A">
-<!ENTITY anchors.label "Accepteer alleen patronen:">
-<!ENTITY anchor.start.label "aan het begin van het adres">
-<!--  Note: This access key should usually be the same as anchor.start.flexible.accesskey. It is the same checkbox with different label depending on suggested filter. -->
-<!ENTITY anchor.start.accesskey "h">
-<!ENTITY anchor.start.flexible.label "aan het begin van de domeinnaam">
-<!--  Note: This access key should usually be the same as anchor.start.accesskey. It is the same checkbox with different label depending on suggested filter. -->
-<!ENTITY anchor.start.flexible.accesskey "h">
-<!ENTITY anchor.end.label "aan het eind van het adres">
-<!ENTITY anchor.end.accesskey "e">
-<!ENTITY options.label "Opties">
-<!ENTITY domainRestriction.label "Beperk tot domein:">
-<!ENTITY domainRestriction.accesskey "p">
-<!ENTITY domainRestriction.help "Geef één of meer domeinen gescheiden met het &quot;|&quot;-teken, het filter zal dan alleen op deze domeinen worden toegepast. Het &quot;~&quot;-teken voor een domein betekend dat het filter niet moet worden toegepast op dat domein.">
-<!ENTITY firstParty.label "Alleen van eigen site">
-<!ENTITY firstParty.accesskey "l">
-<!ENTITY thirdParty.label "Alleen van derden">
-<!ENTITY thirdParty.accesskey "d">
-<!ENTITY matchCase.label "Hoofdlettergevoelig">
-<!ENTITY matchCase.accesskey "o">
-<!ENTITY types.label "Toepassen op types:">
-<!ENTITY selectAllTypes.label "Alles selecteren">
-<!ENTITY unselectAllTypes.label "Niets selecteren">
-<!ENTITY collapse.label "Geblokkeerd onderdeel inklappen:">
-<!ENTITY collapse.accesskey "G">
-<!ENTITY collapse.default.yes.label "Gebruik standaard (ja)">
-<!ENTITY collapse.default.no.label "Gebruik standaard (nee)">
-<!ENTITY collapse.yes.label "Ja">
-<!ENTITY collapse.no.label "Nee">

=== removed file 'chrome/locale/nl-NL/global.properties'
--- chrome/locale/nl-NL/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/nl-NL/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Reclames behoren tot het verleden!
-status_active_label=Adblock
-status_disabled_label=Uitgeschakeld
-action0_tooltip=Klik om het context-menu te openen, midden-klik om in/uit te schakelen.
-action1_tooltip=Klik om blokkeerbare onderdelen te openen/sluiten, midden-klik om in/uit te schakelen.
-action2_tooltip=Klik om voorkeuren te openen, midden-klik om in/uit te schakelen.
-action3_tooltip=Klik om Adblock Plus in/uit te schakelen.
-active_tooltip=Adblock Plus is ingeschakeld.
-disabled_tooltip=Adblock Plus is uitgeschakeld.
-whitelisted_tooltip=Adblock Plus is ingeschakeld maar staat uit voor deze pagina.
-blocked_count_tooltip=-- van de --
-no_blocking_suggestions=Geen blokkeerbare onderdelen op deze pagina
-whitelisted_page=Adblock Plus is uitgeschakeld voor deze pagina
-whitelist_description=Uitzonderingsregels
-filterlist_description=Reclamefilters
-invalid_description=Ongeldige filters
-elemhide_description=Mijn verbergingsregels
-subscription_description=Filter abonnement:
-subscription_wrong_version=Sommige filters in dit abonnement vereisen Adblock Plus -- om goed te werken!
-subscription_source=Bron:
-subscription_status=Status:
-subscription_status_autodownload=Automatisch bijgewerkt
-subscription_status_manualdownload=Handmatig bijgewerkt
-subscription_status_externaldownload=Extern bijgewerkt (door een andere extensie)
-subscription_status_lastdownload=Laatste download:
-subscription_status_lastdownload_inprogress=Downloaden...
-subscription_status_lastdownload_unknown=nvt
-remove_subscription_warning=Weet u zeker dat u dit abonnement wilt verwijderen?
-import_filters_wrong_version=Waarschuwing: sommige filters in dit abonnement vereisen Adblock Plus -- om goed te werken! U kunt het beste de nieuwste versie van Adblock Plus installeren voordat u deze lijst importeert.
-import_filters_warning=Wilt u uw huidige filters vervangen of de nieuwe filters aan het einde van de lijst toevoegen?
-import_filters_title=Filters importeren
-export_filters_title=Filters exporteren
-invalid_filters_file=Geen geldig bestand met Adblock Plus filters.
-filters_write_error=Er was een fout bij het schrijven van filters naar het bestand. Controleer of het bestand niet tegen schrijven beveiligd is of wordt gebruikt door een ander programma.
-clearall_warning=Weet u zeker dat u alle filters van de lijst wilt verwijderen?
-resethitcounts_warning=Weet u zeker dat u het aantal treffers voor alle filters weer op nul wilt zetten? Deze operatie kan niet ongedaan worden gemaakt!
-resethitcounts_selected_warning=Weet u zeker dat u het aantal treffers voor de geselecteerde filters weer op nul wilt zetten? Deze operatie kan niet ongedaan worden gemaakt!
-filter_regexp_tooltip=Dit filter is een reguliere expressie of te kort om te kunnen worden geoptimaliseerd. Veel van dit soort filters kunnen uw browser traag maken.
-filter_elemhide_duplicate_id=Maar een ID van het te verbergen element kan roden gevenen
-filter_elemhide_nocriteria=Geen vereisten gegeven om het te verbergen element te herkennen
-subscription_no_location=Geeft alstublieft een locatie op om filters van te downloaden.
-subscription_invalid_location=Deze locatie voor een filterlijst is geen geldige URL en ook geen geldige bestandsnaam.
-subscription_location_exists=U bent al geabonneerd op deze filterlijst.
-synchronize_invalid_url=Mislukt, geen geldig adres
-synchronize_connection_error=Mislukt, downloadprobleem
-synchronize_invalid_data=Mislukt, geen geldige filterlijst
-synchronize_checksum_mismatch=Mislukt, afwijkend controlecijfer
-synchronize_ok=Gelukt
-overwrite=Overschrijven
-append=Toevoegen
-new_filter_group_title=Nieuw filter
-type_label_other=anders
-type_label_script=script
-type_label_image=afbeelding
-type_label_stylesheet=stijlpagina
-type_label_object=object
-type_label_subdocument=deelvenster
-type_label_document=document
-type_label_background=achtergrond
-type_label_elemhide=verborgen
-type_label_xbl=XBL binding
-type_label_ping=koppeling ping
-type_label_xmlhttprequest=XML verzoek
-type_label_object_subrequest=object subverzoek
-type_label_dtd=DTD
-type_label_media=audio/video
-type_label_font=lettertype

=== removed file 'chrome/locale/nl-NL/overlay.dtd'
--- chrome/locale/nl-NL/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nl-NL/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,24 +0,0 @@
-<!ENTITY status.tooltip "Status:">
-<!ENTITY blocked.tooltip "Geblokkeerde onderdelen:">
-<!ENTITY filters.tooltip "Meest actieve filters:">
-<!ENTITY menuitem.label "Adblock Plus voorkeuren">
-<!ENTITY menuitem.accesskey "A">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Blokkeerbare onderdelen">
-<!ENTITY context.image.label "Afbeelding blokkeren">
-<!ENTITY context.object.label "Object blokkeren">
-<!ENTITY context.frame.label "Deelvenster blokkeren">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: inschakelen op deze pagina">
-<!ENTITY sidebar.title "Blokkeerbare onderdelen op deze pagina">
-<!ENTITY settings.label "Voorkeuren">
-<!ENTITY settings.accesskey "V">
-<!ENTITY opensidebar.label "Blokkeerbare onderdelen open">
-<!--  Note: This access key should usually be the same as closesidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open. -->
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "Blokkeerbare onderdelen sluiten">
-<!--  Note: This access key should usually be the same as opensidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open. -->
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Uitschakelen op --">
-<!ENTITY whitelist.page.label "Alleen op deze pagina uitschakelen">
-<!ENTITY objecttab.title "Blokkeer">
-<!ENTITY objecttab.tooltip "Klik hier om dit object te blokkeren met Adblock Plus">

=== removed file 'chrome/locale/nl-NL/settings.dtd'
--- chrome/locale/nl-NL/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nl-NL/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus Voorkeuren">
-<!ENTITY filters.label "Filters">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Filter toevoegen">
-<!ENTITY add.accesskey "g">
-<!ENTITY addsubscription.label "Abonnement toevoegen">
-<!ENTITY addsubscription.accesskey "t">
-<!ENTITY synchsubscriptions.label "Abonnementen bijwerken">
-<!ENTITY synchsubscriptions.accesskey "A">
-<!ENTITY import.label "Filters importeren">
-<!ENTITY import.accesskey "i">
-<!ENTITY export.label "Filters exporteren">
-<!ENTITY export.accesskey "x">
-<!ENTITY clearall.label "Eigen filters verwijderen">
-<!ENTITY clearall.accesskey "v">
-<!ENTITY resethitcounts.label "Trefstatistieken herstellen">
-<!ENTITY resethitcounts.accesskey "r">
-<!ENTITY edit.label "Bewerken">
-<!ENTITY edit.accesskey "W">
-<!ENTITY cut.label "Knippen">
-<!ENTITY cut.accesskey "n">
-<!ENTITY copy.label "Kopiëren">
-<!ENTITY copy.accesskey "K">
-<!ENTITY paste.label "Plakken">
-<!ENTITY paste.accesskey "P">
-<!ENTITY remove.label "Verwijderen">
-<!ENTITY remove.accesskey "V">
-<!ENTITY menu.find.label "Zoeken">
-<!ENTITY menu.find.accesskey "Z">
-<!ENTITY menu.findagain.label "Opnieuw zoeken">
-<!ENTITY menu.findagain.accesskey "w">
-<!ENTITY view.label "Beeld">
-<!ENTITY view.accesskey "l">
-<!ENTITY sort.label "Sorteer op">
-<!ENTITY sort.accesskey "S">
-<!ENTITY sort.none.label "Ongesorteerd">
-<!ENTITY sort.none.accesskey "O">
-<!ENTITY sort.ascending.label "Oplopend gesorteerd">
-<!ENTITY sort.ascending.accesskey "p">
-<!ENTITY sort.descending.label "Aflopend gesorteerd">
-<!ENTITY sort.descending.accesskey "A">
-<!ENTITY options.label "Opties">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Adblock Plus inschakelen">
-<!ENTITY enable.accesskey "A">
-<!ENTITY showintoolbar.label "Toon in werkbalk">
-<!ENTITY showintoolbar.accesskey "w">
-<!ENTITY showinstatusbar.label "Toon in statusbalk">
-<!ENTITY showinstatusbar.accesskey "s">
-<!ENTITY objecttabs.label "Tabs laten zien op Flash en Java">
-<!ENTITY objecttabs.accesskey "T">
-<!ENTITY collapse.label "Geblokkeerde elementen inklappen">
-<!ENTITY collapse.accesskey "G">
-<!ENTITY help.label "Help">
-<!ENTITY help.accesskey "H">
-<!ENTITY gettingStarted.label "Aan de slag">
-<!ENTITY gettingStarted.accesskey "s">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Veelgestelde vragen">
-<!ENTITY faq.accesskey "V">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Het schrijven van Adblock Plus filters">
-<!ENTITY filterdoc.accesskey "H">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Over Adblock Plus">
-<!ENTITY about.accesskey "A">
-<!ENTITY description "De volgende filters bepalen welke adressen geblokkeerd worden en welke worden toegestaan:">
-<!ENTITY filter.column "Filterregel">
-<!ENTITY filter.accesskey "F">
-<!ENTITY slow.column "Trage filters">
-<!ENTITY slow.accesskey "r">
-<!ENTITY enabled.column "Ingeschakeld">
-<!ENTITY enabled.accesskey "I">
-<!ENTITY hitcount.column "Treffers">
-<!ENTITY hitcount.accesskey "T">
-<!ENTITY lasthit.column "Laatste treffer">
-<!ENTITY lasthit.accesskey "L">
-<!ENTITY context.edit.label "Filter wijzigen">
-<!ENTITY context.resethitcount.label "Trefstatistieken voor filter herstellen">
-<!ENTITY context.synchsubscription.label "Abonnement nu bijwerken">
-<!ENTITY context.editsubscription.label "Abonnement wijzigen">
-<!ENTITY context.moveup.label "Omhoog verplaatsen">
-<!ENTITY context.movedown.label "Omlaag verplaatsen">
-<!ENTITY context.movegroupup.label "Groep omhoog verplaatsen">
-<!ENTITY context.movegroupdown.label "Groep omlaag verplaatsen">
-<!ENTITY context.enable.label "Inschakelen">
-<!ENTITY context.disable.label "Uitschakelen">
-<!ENTITY apply.label "Toepassen">
-<!ENTITY apply.accesskey "T">

=== removed file 'chrome/locale/nl-NL/sidebar.dtd'
--- chrome/locale/nl-NL/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nl-NL/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Blokkeerbare onderdelen (losgekoppeld)">
-<!ENTITY detach.label "Losmaken">
-<!ENTITY reattach.label "Vastmaken">
-<!ENTITY search.label "Zoeken:">
-<!ENTITY search.accesskey "Z">
-<!ENTITY type.label "Type">
-<!ENTITY address.label "Adres">
-<!ENTITY filter.label "Filter">
-<!ENTITY state.label "Status">
-<!ENTITY size.label "Grootte">
-<!ENTITY docDomain.label "Bronpagina">
-<!ENTITY noitems.label "Geen blokkeerbare onderdelen">
-<!ENTITY whitelisted.label "Toegestane pagina">
-<!ENTITY tooltip.address.label "Adres:">
-<!ENTITY tooltip.type.label "Type:">
-<!ENTITY tooltip.type.blocked "(geblokkeerd)">
-<!ENTITY tooltip.type.whitelisted "(toegestaan)">
-<!ENTITY tooltip.size.label "Grootte">
-<!ENTITY tooltip.docDomain.label "Bronbagina:">
-<!ENTITY tooltip.filter.label "Toegepast filter:">
-<!ENTITY tooltip.filterSource.label "Filter bron:">
-<!ENTITY context.block.label "Blokkeer dit onderdeel">
-<!ENTITY context.editfilter.label "Wijzig toegepast filter">
-<!ENTITY context.whitelist.label "Voeg een uitzonderingsregel voor dit onderdeel toe">
-<!ENTITY context.disablefilter.label "Filter uitschakelen --">
-<!ENTITY context.enablefilter.label "Filter inschakelen --">
-<!ENTITY context.disablefilteronsite.label "Filter uitschakelen op __">
-<!ENTITY context.open.label "Open in een nieuw tabblad">
-<!ENTITY context.flash.label "Laat randen knipperen">
-<!ENTITY context.copy.label "Adres kopiëren">
-<!ENTITY context.copyFilter.label "Filter kopiëren">
-<!ENTITY context.selectAll.label "Alles selecteren">

=== removed file 'chrome/locale/nl-NL/subscription.dtd'
--- chrome/locale/nl-NL/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nl-NL/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Filter abonnement wijzigen">
-<!ENTITY dialog.newtitle "Filter abonnement toevoegen">
-<!ENTITY new.description "Geef alstublieft het internetadres of bestand op met een Adblock Plus filterslijst.">
-<!ENTITY edit.description "De filterlijst van dit abonnement zal worden gedownload van de gegeven locatie.">
-<!ENTITY external.description "Dit is een extern filter abonnement, de filterlijst zal worden bijgewerkt door de extensie die dit abonnement heeft toegevoegd.">
-<!ENTITY autodownload.description "Als u kiest voor ‘Automatisch bijwerken’ zal deze locatie dagelijks worden gecontroleerd op nieuwe versies. Als u deze optie uitschakelt kunt u nog steeds een handmatige controle uitvoeren vanuit het context menu van het abonnement.">
-<!ENTITY location.label "Filterlijst locatie:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Abonnementnaam:">
-<!ENTITY title.accesskey "B">
-<!ENTITY autodownload.label "Automatisch bijwerken">
-<!ENTITY autodownload.accesskey "T">
-<!ENTITY enabled.label "Filters inschakelen">
-<!ENTITY enabled.accesskey "N">

=== removed file 'chrome/locale/nl-NL/tip_subscriptions.dtd'
--- chrome/locale/nl-NL/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nl-NL/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Welkom bij Adblock Plus">
-<!ENTITY description.par1 "Dank u voor het installeren van Adblock Plus. Deze extensie kan 99&#37; van alle reclames op het internet tegenhouden. Maar om reclames er goed uit te kunnen filteren, heeft u een goede set filters nodig. U kunt deze zelf maken, of eenvoudig een abonnement nemen op een filterlijst die anderen voor u onderhouden. Indien nodig kunt u hierna nog steeds uw eigen filters toevoegen of abonnementen uitschakelen/verwijderen.">
-<!ENTITY description.par2 "Hieronder kunt u een abonnement kiezen uit de lijst met aangeraden abonnementen (later kunnen nog abonnementen worden toegevoegd in de Adblock Plus voorkeuren, maar dit is normaal niet nodig):">
-<!ENTITY note "Tip: een filterlijst werk meestal het beste wanneer die wordt toegepast op websites uit de regio waar de lijst voor gemaakt is.">
-<!ENTITY adblock.warning "Adblock Plus heeft gevonden dat Adblock of een oudere versie van Adblock Plus geïnstalleerd is. Het tegelijk gebruiken van Adblock en Adblock Plus kan problemen veroorzaken en moet worden vermeden. Het is aangereden dat u Adblock nu de-installeerd.">
-<!ENTITY adblock.uninstall "Adblock de-installeren">
-<!ENTITY filterset.g.warning "Het lijkt erop dat u Filterset.G gebruikt. Deze filterlijst is de afgelopen jaren nauwelijks bijgehouden en is een veel voorkomende oorzaak van problemen met websites. Het is aangereden dat u Filterset.G nu de-installeerd.">
-<!ENTITY filterset.g.moreinfo "Meer informatie">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Filterset.G de-installeren">
-<!ENTITY homepage.label "Website">
-<!ENTITY subscribe.label "Abonneer">
-<!ENTITY subscribe.accesskey "A">
-<!ENTITY other.label "Een ander abonnement toevoegen">
-<!ENTITY other.accesskey "E">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Alle abonnementen bekijken">

=== added file 'chrome/locale/nl/about.dtd'
--- chrome/locale/nl/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/nl/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Over Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versie">
+<!ENTITY description "Adblock Plus laat u zelf beslissen wat u niet wilt zien op het internet. Voortaan hoeft u geen reclames en banners meer te downloaden; als u ze niet wilt zien - verwijder ze met Adblock Plus!">
+<!ENTITY homepage.label "Adblock Plus website:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Schrijver:">
+<!ENTITY contributors.label "Medewerkers:">
+<!ENTITY developers.label "Ontwikkelaars:">
+<!ENTITY designers.label "Grafisch ontwerpers:">
+<!ENTITY subscriptionAuthors.label "Filterabonnementschrijvers:">
+<!ENTITY translators.label "Vertalers:">

=== added file 'chrome/locale/nl/composer.dtd'
--- chrome/locale/nl/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/nl/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Adblock Plus filterregel toevoegen">
+<!ENTITY accept.label "Filter toevoegen">
+<!ENTITY advanced.label "Uitgebreid">
+<!ENTITY basic.label "Eenvoudig">
+<!ENTITY disabled.warning "Adblock Plus is momenteel uitgeschakeld. U kunt nog wel filters toevoegen, maar ze worden niet toegepast tenzij u [link]Adblock Plus weer inschakelt[/link].">
+<!ENTITY groupDisabled.warning "De filtergroep “?1?” waaraan dit filter wordt toegevoegd is momenteel uitgeschakeld. U kunt het filter nog wel toevoegen maar het wordt niet toegepast tenzij u [link]de filtergroep inschakelt[/link].">
+<!ENTITY filter.label "Nieuw filter:">
+<!ENTITY filter.accesskey "N">
+<!ENTITY preferences.label "Bestaande filters weergeven…">
+<!ENTITY preferences.accesskey "W">
+<!ENTITY type.filter.label "Blokkerend filter">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Uitzonderingsregel">
+<!ENTITY type.whitelist.accesskey "U">
+<!ENTITY pattern.label "Naar patroon zoeken">
+<!ENTITY pattern.explanation "Het patroon kan ieder gedeelte zijn van het adres, waarbij een asterisk (*) as wildcard geldt. Het filter wordt alleen toegepast op adressen die met het patroon overeenkomen.">
+<!ENTITY regexp.warning "Het patroon dat u heeft gegeven zal worden behandeld als een reguliere expressie. Deze kunnen niet efficiënt worden verwerkt door Adblock Plus en kunnen uw browser traag maken. Als het niet uw bedoeling was een reguliere expressie te schrijven, voeg dan een asterisk (*) aan het eind van het patroon toe.">
+<!ENTITY shortpattern.warning "Het patroon dat u heeft gegeven is te kort om te worden geoptimaliseerd en kan uw browser traag maken. U kunt beter een langere regel voor dit filter kiezen, zodat Adblock Plus het filter efficiënter kan toepassen.">
+<!ENTITY custom.pattern.label "Aangepast:">
+<!ENTITY custom.pattern.accesskey "A">
+<!ENTITY anchors.label "Alleen patronen accepteren:">
+<!ENTITY anchor.start.label "aan het begin van het adres">
+<!ENTITY anchor.start.accesskey "h">
+<!ENTITY anchor.start.flexible.label "aan het begin van de domeinnaam">
+<!ENTITY anchor.start.flexible.accesskey "h">
+<!ENTITY anchor.end.label "aan het eind van het adres">
+<!ENTITY anchor.end.accesskey "e">
+<!ENTITY options.label "Opties">
+<!ENTITY domainRestriction.label "Tot domein beperken:">
+<!ENTITY domainRestriction.accesskey "p">
+<!ENTITY domainRestriction.help "Gebruik deze optie om één of meer domeinen te specificeren, gescheiden door een lijn (|). Het filter zal alleen op deze domeinen worden toegepast. Een tilde (~) voor een domein betekent dat het filter niet moet worden toegepast op dat domein.">
+<!ENTITY firstParty.label "Alleen van eigen site">
+<!ENTITY firstParty.accesskey "l">
+<!ENTITY thirdParty.label "Alleen van derden">
+<!ENTITY thirdParty.accesskey "d">
+<!ENTITY matchCase.label "Hoofdlettergevoelig">
+<!ENTITY matchCase.accesskey "o">
+<!ENTITY types.label "Toepassen op types:">
+<!ENTITY selectAllTypes.label "Alles selecteren">
+<!ENTITY unselectAllTypes.label "Niets selecteren">
+<!ENTITY collapse.label "Geblokkeerd onderdeel inklappen:">
+<!ENTITY collapse.accesskey "G">
+<!ENTITY collapse.default.yes.label "Standaard gebruiken (ja)">
+<!ENTITY collapse.default.no.label "Standaard gebruiken (nee)">
+<!ENTITY collapse.yes.label "Ja">
+<!ENTITY collapse.no.label "Nee">

=== added file 'chrome/locale/nl/global.properties'
--- chrome/locale/nl/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/nl/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Klik om het contextmenu te openen, middelklik om in/uit te schakelen.
+action1_tooltip=Klik om blokkeerbare onderdelen te openen/sluiten, middelklik om in/uit te schakelen.
+action2_tooltip=Klik om voorkeuren te openen, middelklik om in/uit te schakelen.
+action3_tooltip=Klik om Adblock Plus in/uit te schakelen.
+disabled_tooltip=Adblock Plus is uitgeschakeld.
+active_tooltip=Adblock Plus is actief, ?1? filterabonnement(en) en ?2? aangepast(e) filter(s) in gebruik.
+whitelisted_tooltip=Adblock Plus is ingeschakeld maar staat uit voor deze pagina.
+blocked_count_tooltip=?1? van de ?2?
+blocked_count_addendum=(ook op witte lijst: ?1?, verborgen: ?2?)
+no_blocking_suggestions=Geen blokkeerbare onderdelen op deze pagina
+whitelisted_page=Adblock Plus is uitgeschakeld voor deze pagina
+whitelist_description=Mijn uitzonderingsregels
+filterlist_description=Mijn reclamefilters
+invalid_description=Mijn ongeldige filters
+elemhide_description=Mijn elementverbergingsregels
+subscription_description=Filterabonnement:
+subscription_wrong_version=Sommige filters in dit abonnement vereisen Adblock Plus ?1? om goed te werken!
+subscription_source=Bron:
+subscription_status=Status:
+subscription_status_autodownload=Automatisch bijgewerkt
+subscription_status_manualdownload=Handmatig bijgewerkt
+subscription_status_externaldownload=Extern bijgewerkt (door een andere extensie)
+subscription_status_lastdownload=Laatste download:
+subscription_status_lastdownload_inprogress=Downloaden…
+subscription_status_lastdownload_unknown=N.B.
+remove_subscription_warning=Weet u zeker dat u dit abonnement wilt verwijderen?
+import_filters_wrong_version=Waarschuwing: sommige filters in dit abonnement vereisen Adblock Plus ?1? om goed te werken! U kunt het beste de nieuwste versie van Adblock Plus installeren voordat u deze lijst importeert.
+import_filters_warning=Wilt u uw huidige filters vervangen of de nieuwe filters aan het einde van de lijst toevoegen?
+import_filters_title=Filters importeren
+export_filters_title=Filters exporteren
+invalid_filters_file=Geen geldig bestand met Adblock Plus-filters.
+filters_write_error=Er is een fout opgetreden bij het schrijven van filters naar het bestand. Controleer of het bestand niet tegen schrijven beveiligd is of wordt gebruikt door een ander programma.
+clearall_warning=Weet u zeker dat u alle filters van de lijst wilt verwijderen?
+resethitcounts_warning=Weet u zeker dat u het aantal treffers voor alle filters weer op nul wilt zetten? Deze operatie kan niet ongedaan worden gemaakt!
+resethitcounts_selected_warning=Weet u zeker dat u het aantal treffers voor de geselecteerde filters weer op nul wilt zetten? Deze operatie kan niet ongedaan worden gemaakt!
+filter_regexp_tooltip=Dit filter is een reguliere expressie of te kort om te kunnen worden geoptimaliseerd. Te veel van dit soort filters kan uw browser traag maken.
+filter_elemhide_duplicate_id=Er kan slechts één ID van het te verbergen element worden opgegeven
+filter_elemhide_nocriteria=Geen criteria opgegeven om het te verbergen element te herkennen
+subscription_notAdded_warning=U hebt geen filterabonnement toegevoegd. Zonder een filterabonnement dient u uw Adblock Plus-filters handmatig toe te voegen.
+subscription_notAdded_warning_addendum=Wilt u doorgaan?
+subscription_invalid_location=Deze filterlijstlocatie is geen geldige URL en ook geen geldige bestandsnaam.
+synchronize_invalid_url=Mislukt, geen geldig adres
+synchronize_connection_error=Mislukt, downloadprobleem
+synchronize_invalid_data=Mislukt, geen geldige filterlijst
+synchronize_checksum_mismatch=Mislukt, afwijkend controlecijfer
+synchronize_ok=Gelukt
+overwrite=Overschrijven
+append=Toevoegen
+new_filter_group_title=Nieuw filter
+type_label_other=anders
+type_label_script=script
+type_label_image=afbeelding
+type_label_stylesheet=stylesheet
+type_label_object=object
+type_label_subdocument=frame
+type_label_document=document
+type_label_background=achtergrond
+type_label_elemhide=verborgen
+type_label_xbl=XBL-binding
+type_label_ping=koppelingsping
+type_label_xmlhttprequest=XML-verzoek
+type_label_object_subrequest=object-subverzoek
+type_label_dtd=DTD
+type_label_media=audio/video
+type_label_font=lettertype
+fennec_status_enabled=Adblock Plus is ingeschakeld.
+fennec_status_disabled=Adblock Plus is uitgeschakeld.
+fennec_status_enabled_site=Adblock Plus is ingeschakeld op ?1?.
+fennec_status_disabled_site=Adblock Plus is uitgeschakeld op ?1?.

=== added file 'chrome/locale/nl/meta.properties'
--- chrome/locale/nl/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/nl/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=pitdicker, markh
+name=Adblock Plus
+description=Reclames behoren tot het verleden!
+description.short=Irritante reclames? Hinder van volgers? Altijd die banners? Installeer Adblock Plus nu om internet weer onder controle te krijgen en uw webervaring te veranderen.\n\nEen korte video is te zien op http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Met Adblock Plus kunt u internet weer onder controle krijgen en het web bekijken op de manier zoals u dat wilt. De add-on wordt ondersteund door meer dan veertig filterabonnementen in tientallen talen, die de extensie automatisch instellen voor doeleinden variërend van het verwijderen van online-advertenties to het blokkeren van alle bekende malwaredomeinen. Met Adblock Plus kunt u ook uw filters aanpassen met behulp van een reeks nuttige functies, inclusief een contextoptie voor afbeeldingen, een blokkeringstabblad voor Flash- en Java-objecten en een lijst met blokkeerbare items om scripts en stylesheets te verwijderen.

=== added file 'chrome/locale/nl/overlay.dtd'
--- chrome/locale/nl/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/nl/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Status:">
+<!ENTITY blocked.tooltip "Geblokkeerde onderdelen op deze pagina:">
+<!ENTITY filters.tooltip "Meest actieve filters:">
+<!ENTITY menuitem.label "Adblock Plus voorkeuren">
+<!ENTITY menuitem.accesskey "A">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Blokkeerbare onderdelen">
+<!ENTITY context.image.label "Adblock Plus: Afbeelding blokkeren">
+<!ENTITY context.object.label "Adblock Plus: Object blokkeren">
+<!ENTITY context.frame.label "Adblock Plus: Deelvenster blokkeren">
+<!ENTITY context.media.label "Adblock Plus: Audio/video blokkeren">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Opnieuw inschakelen op deze pagina">
+<!ENTITY sidebar.title "Blokkeerbare onderdelen op deze pagina">
+<!ENTITY settings.label "Voorkeuren">
+<!ENTITY settings.accesskey "V">
+<!ENTITY opensidebar.label "Blokkeerbare onderdelen open">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "Blokkeerbare onderdelen sluiten">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "Uitschakelen op ?1?">
+<!ENTITY whitelist.page.label "Alleen op deze pagina uitschakelen">
+<!ENTITY objecttab.title "Blokkeren">
+<!ENTITY objecttab.tooltip "Klik hier om dit object te blokkeren met Adblock Plus">

=== added file 'chrome/locale/nl/settings.dtd'
--- chrome/locale/nl/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/nl/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus Voorkeuren">
+<!ENTITY filters.label "Filters">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Filter toevoegen">
+<!ENTITY add.accesskey "g">
+<!ENTITY addsubscription.label "Filterabonnement toevoegen">
+<!ENTITY addsubscription.accesskey "t">
+<!ENTITY synchsubscriptions.label "Alle abonnementen bijwerken">
+<!ENTITY synchsubscriptions.accesskey "A">
+<!ENTITY import.label "Filters importeren">
+<!ENTITY import.accesskey "i">
+<!ENTITY export.label "Aangepaste filters exporteren">
+<!ENTITY export.accesskey "x">
+<!ENTITY clearall.label "Alle aangepaste filters verwijderen">
+<!ENTITY clearall.accesskey "v">
+<!ENTITY resethitcounts.label "Trefstatistieken herstellen">
+<!ENTITY resethitcounts.accesskey "r">
+<!ENTITY edit.label "Bewerken">
+<!ENTITY edit.accesskey "W">
+<!ENTITY cut.label "Knippen">
+<!ENTITY cut.accesskey "n">
+<!ENTITY copy.label "Kopiëren">
+<!ENTITY copy.accesskey "K">
+<!ENTITY paste.label "Plakken">
+<!ENTITY paste.accesskey "P">
+<!ENTITY remove.label "Verwijderen">
+<!ENTITY remove.accesskey "V">
+<!ENTITY menu.find.label "Zoeken">
+<!ENTITY menu.find.accesskey "Z">
+<!ENTITY menu.findagain.label "Opnieuw zoeken">
+<!ENTITY menu.findagain.accesskey "w">
+<!ENTITY view.label "Beeld">
+<!ENTITY view.accesskey "l">
+<!ENTITY sort.label "Sorteren op">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "Ongesorteerd">
+<!ENTITY sort.none.accesskey "O">
+<!ENTITY sort.ascending.label "A &gt; Z sortering">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Z &gt; A sortering">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Opties">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Adblock Plus inschakelen">
+<!ENTITY enable.accesskey "A">
+<!ENTITY showintoolbar.label "In werkbalk weergeven">
+<!ENTITY showintoolbar.accesskey "w">
+<!ENTITY showinstatusbar.label "In statusbalk weergeven">
+<!ENTITY showinstatusbar.accesskey "s">
+<!ENTITY objecttabs.label "Tabbladen weergeven op Flash en Java">
+<!ENTITY objecttabs.accesskey "T">
+<!ENTITY collapse.label "Geblokkeerde elementen inklappen">
+<!ENTITY collapse.accesskey "G">
+<!ENTITY help.label "Help">
+<!ENTITY help.accesskey "H">
+<!ENTITY gettingStarted.label "Aan de slag">
+<!ENTITY gettingStarted.accesskey "s">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Veelgestelde vragen">
+<!ENTITY faq.accesskey "V">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Het schrijven van Adblock Plus filters">
+<!ENTITY filterdoc.accesskey "H">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Over Adblock Plus">
+<!ENTITY about.accesskey "A">
+<!ENTITY description "De volgende filters bepalen welke adressen geblokkeerd worden en welke worden toegestaan:">
+<!ENTITY filter.column "Filterregel">
+<!ENTITY filter.accesskey "F">
+<!ENTITY slow.column "Trage filters">
+<!ENTITY slow.accesskey "r">
+<!ENTITY enabled.column "Ingeschakeld">
+<!ENTITY enabled.accesskey "I">
+<!ENTITY hitcount.column "Treffers">
+<!ENTITY hitcount.accesskey "T">
+<!ENTITY lasthit.column "Laatste treffer">
+<!ENTITY lasthit.accesskey "L">
+<!ENTITY context.edit.label "Filter bewerken">
+<!ENTITY context.resethitcount.label "Trefstatistieken voor filter herstellen">
+<!ENTITY context.synchsubscription.label "Abonnement nu bijwerken">
+<!ENTITY context.editsubscription.label "Abonnement bewerken">
+<!ENTITY context.moveup.label "Filter omhoog verplaatsen">
+<!ENTITY context.movedown.label "Filter omlaag verplaatsen">
+<!ENTITY context.movegroupup.label "Groep omhoog verplaatsen">
+<!ENTITY context.movegroupdown.label "Groep omlaag verplaatsen">
+<!ENTITY context.enable.label "Inschakelen">
+<!ENTITY context.disable.label "Uitschakelen">
+<!ENTITY apply.label "Toepassen">
+<!ENTITY apply.accesskey "T">
+<!ENTITY fennec.subscription.label "Filterabonnement">

=== added file 'chrome/locale/nl/sidebar.dtd'
--- chrome/locale/nl/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/nl/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Blokkeerbare onderdelen (losgekoppeld)">
+<!ENTITY detach.label "Loskoppelen">
+<!ENTITY reattach.label "Vastkoppelen">
+<!ENTITY search.label "Zoeken:">
+<!ENTITY search.accesskey "Z">
+<!ENTITY type.label "Type">
+<!ENTITY address.label "Adres">
+<!ENTITY filter.label "Filter">
+<!ENTITY state.label "Status">
+<!ENTITY size.label "Grootte">
+<!ENTITY docDomain.label "Documentbron">
+<!ENTITY noitems.label "Geen blokkeerbare onderdelen">
+<!ENTITY whitelisted.label "Toegestane pagina">
+<!ENTITY tooltip.address.label "Adres:">
+<!ENTITY tooltip.type.label "Type:">
+<!ENTITY tooltip.type.blocked "(geblokkeerd)">
+<!ENTITY tooltip.type.whitelisted "(toegestaan)">
+<!ENTITY tooltip.size.label "Grootte:">
+<!ENTITY tooltip.docDomain.label "Documentbron:">
+<!ENTITY tooltip.filter.label "Toegepast filter:">
+<!ENTITY tooltip.filterSource.label "Filterbron:">
+<!ENTITY context.block.label "Dit onderdeel blokkeren">
+<!ENTITY context.editfilter.label "Toegepast filter bewerken">
+<!ENTITY context.whitelist.label "Uitzonderingsregel voor dit onderdeel toevoegen">
+<!ENTITY context.disablefilter.label "Filter ?1? uitschakelen">
+<!ENTITY context.enablefilter.label "Filter ?1? inschakelen">
+<!ENTITY context.disablefilteronsite.label "Filter uitschakelen op ?1?">
+<!ENTITY context.open.label "Openen in een nieuw tabblad">
+<!ENTITY context.flash.label "Randen laten knipperen">
+<!ENTITY context.copy.label "Adres kopiëren">
+<!ENTITY context.copyFilter.label "Filter kopiëren">
+<!ENTITY context.selectAll.label "Alles selecteren">

=== added file 'chrome/locale/nl/subscriptionSelection.dtd'
--- chrome/locale/nl/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/nl/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Adblock Plus filterabonnement toevoegen">
+<!ENTITY dialog.title.edit "Filterabonnement bewerken">
+<!ENTITY description.newInstall "Adblock Plus werkt het beste als u een filterabonnement toevoegt. Filterabonnementen worden gratis door andere gebruikers van Adblock Plus aangeboden. Het voor uw taal meest geschikte abonnement is al geselecteerd.">
+<!ENTITY adblock.warning "Adblock Plus heeft gedetecteerd dat Adblock of een oudere versie van Adblock Plus is geïnstalleerd. Het tegelijkertijd gebruiken van Adblock en Adblock Plus kan problemen veroorzaken en moet worden vermeden. Het wordt aangeraden Adblock nu te deïnstalleren.">
+<!ENTITY adblock.uninstall "Adblock deïnstalleren">
+<!ENTITY filterset.g.warning "Het lijkt erop dat u Filterset.G gebruikt. Deze filterlijst is de afgelopen jaren nauwelijks bijgehouden en is een veel voorkomende oorzaak van problemen met websites. Het wordt aangeraden Filterset.G nu te deïnstalleren.">
+<!ENTITY filterset.g.moreinfo "Meer informatie">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Filterset.G deïnstalleren">
+<!ENTITY subscriptionSelector.label "Kies a.u.b. een filterabonnement uit de lijst:">
+<!ENTITY viewList.label "Filters bekijken">
+<!ENTITY visitHomepage.label "Startpagina bezoeken">
+<!ENTITY addSubscription.label "Abonneren">
+<!ENTITY saveSubscription.label "Abonnement opslaan">
+<!ENTITY other.label "Een ander abonnement toevoegen">
+<!ENTITY other.accesskey "E">
+<!ENTITY list.download.failed "Adblock Plus kan de lijst met abonnementne niet ophalen.">
+<!ENTITY list.download.retry "Opnieuw proberen">
+<!ENTITY list.download.website "Website bekijken">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Bevestig a.u.b. dat u dit filterabonnement wilt toevoegen. U kunt de abonnementstitel of -locatie wijzigen voor toevoegen.">
+<!ENTITY edit.description "U kunt de abonnementstitel of -locatie naar believen wijzigen.">
+<!ENTITY external.description "Dit is een extern filterabonnement; het wordt bijgewerkt door de extensie die dit abonnement heeft aangemaakt.">
+<!ENTITY title.label "Abonnementstitel:">
+<!ENTITY title.accesskey "b">
+<!ENTITY location.label "Filterlijstlocatie:">
+<!ENTITY location.accesskey "l">
+<!ENTITY autodownload.label "Filters automatisch bijwerken">
+<!ENTITY autodownload.accesskey "t">
+<!ENTITY supplementMessage "Dit filterabonnement is bedoeld om samen gebruikt te worden met het filterabonnement “?1?”, dat u nog niet gebruikt.">
+<!ENTITY addMain.label "Filterabonnement “?1?” ook toevoegen">
+<!ENTITY addMain.accesskey "k">

=== modified file 'chrome/locale/nn-NO/composer.dtd'
--- chrome/locale/nn-NO/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/nn-NO/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,9 +2,7 @@
 <!ENTITY accept.label "Legg til filter">
 <!ENTITY advanced.label "Avansert vising">
 <!ENTITY basic.label "Grunnleggjande vising">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus er kopla ut. Du kan like vel leggje til filtre, men desse vil ikkje bli tekne i bruk dersom du ikkje">
-<!ENTITY disabled.warning.link "koplar inn Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
+<!ENTITY disabled.warning "Adblock Plus er kopla ut. Du kan like vel leggje til filtre, men desse vil ikkje bli tekne i bruk dersom du ikkje [link]koplar inn Adblock Plus[/link].">
 <!ENTITY filter.label "Nytt filter:">
 <!ENTITY filter.accesskey "f">
 <!ENTITY preferences.label "Syn filter...">

=== removed file 'chrome/locale/nn-NO/global.properties'
=== removed file 'chrome/locale/nn-NO/overlay.dtd'
=== removed file 'chrome/locale/nn-NO/settings.dtd'
=== removed file 'chrome/locale/nn-NO/sidebar.dtd'
=== removed file 'chrome/locale/nn-NO/subscription.dtd'
=== removed file 'chrome/locale/nn-NO/tip_subscriptions.dtd'
=== added directory 'chrome/locale/pl'
=== removed directory 'chrome/locale/pl-PL'
=== removed file 'chrome/locale/pl-PL/about.dtd'
--- chrome/locale/pl-PL/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pl-PL/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,10 +0,0 @@
-<!ENTITY dialog.title "O Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Wersja">
-<!ENTITY description "Adblock Plus pozwala decydować o tym jak będą wyglądały strony w Twojej przeglądarce.
-	Nie będzie już konieczności wczytywania wszystkich reklam i banerów. Jeżeli
-	nie będziesz chciał ich oglądać - zleć to Adblock Plus!">
-<!ENTITY homepage.label "Strona domowa Adblock Plusa:">
-<!ENTITY homepage.url "http://adblockplus.org/en/">
-<!ENTITY author.label "Autor:">
-<!ENTITY contributors.label "Współtwórcy:">

=== removed file 'chrome/locale/pl-PL/composer.dtd'
--- chrome/locale/pl-PL/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pl-PL/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,52 +0,0 @@
-<!ENTITY dialog.title "Tworzenie reguły filtru">
-<!ENTITY accept.label "Dodaj filtr">
-<!ENTITY advanced.label "Widok zaawansowany">
-<!ENTITY basic.label "Widok podstawowy">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus jest wyłączony. Można dodawać filtry, ale nie będą one działały do czasu">
-<!ENTITY disabled.warning.link "włączenia Adblock Plusa">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Grupa filtrów &quot;&#37;S&quot;, do której ten filtr powinien zostać dodany jest wyłączona. Można dodać ten filtr, ale nie będzie działał do czasu">
-<!ENTITY groupDisabled.warning.link "włączenia grupy">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Nowy filtr:">
-<!ENTITY filter.accesskey "F">
-<!ENTITY preferences.label "Wyświetl istniejące filtry…">
-<!ENTITY preferences.accesskey "S">
-<!ENTITY type.filter.label "Filtr blokujący">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "Reguła wyjątku">
-<!ENTITY type.whitelist.accesskey "W">
-<!ENTITY pattern.label "Wygląd wzorca">
-<!ENTITY pattern.explanation "Wzorzec może składać się z dowolnej części adresu i symbolu * działającego jako wieloznacznik. Filtr będzie działał tylko na stronach o adresie pasującym do wzorca.">
-<!ENTITY regexp.warning "Wprowadzony wzorzec będzie interpretowany jako wyrażenie regularne. Wiele wyrażeń regularnych może spowalniać przeglądanie internetu. Jeśli nie zamierzasz używać wyrażeń regularnych, dodaj na końcu wzorca wieloznacznik *.">
-<!ENTITY shortpattern.warning "Wprowadzony wzorzec jest za krótki, aby go zoptymalizować. Duża ilość takich wzorców może spowalniać przeglądanie internetu. Zaleca się wybrać dla tego filtru nieco dłuższy ciąg znaków.">
-<!ENTITY custom.pattern.label "Dostosuj:">
-<!ENTITY custom.pattern.accesskey "D">
-<!ENTITY anchors.label "Akceptuj wzorzec tylko:">
-<!ENTITY anchor.start.label "na początku adresu">
-<!--  Note: This access key should usually be the same as anchor.start.flexible.accesskey. It is the same checkbox with different label depending on suggested filter. -->
-<!ENTITY anchor.start.accesskey "o">
-<!ENTITY anchor.start.flexible.label "na początku nazwy domeny">
-<!--  Note: This access key should usually be the same as anchor.start.accesskey. It is the same checkbox with different label depending on suggested filter. -->
-<!ENTITY anchor.start.flexible.accesskey "o">
-<!ENTITY anchor.end.label "na końcu adresu">
-<!ENTITY anchor.end.accesskey "k">
-<!ENTITY options.label "Opcje">
-<!ENTITY domainRestriction.label "Ogranicz do domeny:">
-<!ENTITY domainRestriction.accesskey "r">
-<!ENTITY domainRestriction.help "Określ jedną lub więcej domen oddzielonych symbolem &quot;|&quot;. Filtr będzie stosowany tylko dla tych domen. Symbol &quot;~&quot; przed nazwą domeny oznacza, że filtr nie powinien być stosowany w tych domenach.">
-<!ENTITY firstParty.label "Tylko pierwsza część adresu">
-<!ENTITY firstParty.accesskey "e">
-<!ENTITY thirdParty.label "Tylko trzecia część adresu">
-<!ENTITY thirdParty.accesskey "t">
-<!ENTITY matchCase.label "Uwzględniaj wielkość liter">
-<!ENTITY matchCase.accesskey "U">
-<!ENTITY types.label "Zastosuj do typów:">
-<!ENTITY selectAllTypes.label "Zaznacz wszystko">
-<!ENTITY unselectAllTypes.label "Usuń zaznaczenie">
-<!ENTITY collapse.label "Zwiń zablokowane:">
-<!ENTITY collapse.accesskey "A">
-<!ENTITY collapse.default.yes.label "Domyślnie (tak)">
-<!ENTITY collapse.default.no.label "Domyślnie (nie)">
-<!ENTITY collapse.yes.label "Tak">
-<!ENTITY collapse.no.label "Nie">

=== removed file 'chrome/locale/pl-PL/global.properties'
--- chrome/locale/pl-PL/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/pl-PL/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Powiedz NIE! reklamom
-status_active_label=Adblock
-status_disabled_label=Wyłączony
-action0_tooltip=Kliknij lpm., aby otworzyć menu kontekstowe, śpm., aby włączyć/wyłączyć
-action1_tooltip=Kliknij lpm., aby otworzyć/zamknąć listę blokowalnych elementów, śpm., aby włączyć/wyłączyć
-action2_tooltip=Kliknij lpm., aby otworzyć opcje, śpm., aby włączyć/wyłączyć
-action3_tooltip=Kliknij lpm., aby włączyć/wyłączyć Adblock Plus
-active_tooltip=Adblock Plus jest aktywny
-disabled_tooltip=Adblock Plus jest wyłączony
-whitelisted_tooltip=Adblock Plus jest aktywny, ale wyłączony na oglądanej stronie.
-blocked_count_tooltip=-- z --
-no_blocking_suggestions=Nieblokowalne elementy na aktywnej stronie
-whitelisted_page=Adblock Plus został wyłączony dla tej strony
-whitelist_description=Reguły wyjątków
-filterlist_description=Filtry reklam
-invalid_description=Nieprawidłowy filtr
-elemhide_description=Reguły ukrywanych elementów
-subscription_description=Subskrypcja filtrów:
-subscription_wrong_version=Niektóre filtry w tej subskrypcji, aby pracowały poprawnie, wymagają Adblock Plusa
-subscription_source=Źródło:
-subscription_status=Status:
-subscription_status_autodownload=Zaktualizowano automatycznie
-subscription_status_manualdownload=Zaktualizowano ręcznie
-subscription_status_externaldownload=Zaktualizowano zewnętrznie (poprzez inne rozszerzenie)
-subscription_status_lastdownload=Ostatnie pobieranie:
-subscription_status_lastdownload_inprogress=Pobieranie…
-subscription_status_lastdownload_unknown=nieznane
-remove_subscription_warning=Czy chcesz usunąć tę subskrypcję?
-import_filters_wrong_version=Ostrzeżenie! Niektóre filtry z tej listy, aby pracowały poprawnie, wymagają Adblock Plusa. Przed zaimportowaniem tej listy należy wykonać aktualizację Adblock Plusa.
-import_filters_warning=Czy chcesz zamienić obecne filtry? Naciśnij Anuluj, aby dodać filtry na końcu listy.
-import_filters_title=Import filtrów
-export_filters_title=Eksport filtrów
-invalid_filters_file=Nieprawidłowy plik filtrów Adblock Plusa
-filters_write_error=Wystąpił błąd podczas zapisu filtrów do pliku. Proszę sprawdzić, czy plik nie jest używany przez inny program lub nie ma zabezpieczenia przed zapisem.
-clearall_warning=Czy na pewno usunąć wszystkie filtry z listy?
-resethitcounts_warning=Czy na pewno wyzerować liczniki użycia wszystkich filtrów? Tej operacji nie można cofnąć!
-resethitcounts_selected_warning=Czy na pewno wyzerować liczniki użycia wybranych filtrów? Tej operacji nie można cofnąć!
-filter_regexp_tooltip=Ten filtr jest wyrażeniem regularnym albo jest za krótki, aby go zoptymalizować. Zbyt dużo filtrów tego rodzaju może powodować spowolnienie przeglądania internetu.
-filter_elemhide_duplicate_id=Może być określony tylko jeden ID elementu do ukrycia
-filter_elemhide_nocriteria=Nie określono kryteriów rozpoznania elementu do ukrycia
-subscription_no_location=Proszę wprowadzić lokalizację z jakiej będą pobierane filtry
-subscription_invalid_location=Lokalizacja listy filtrów ma niewłaściwy adres URL, albo niewłaściwą nazwę pliku
-subscription_location_exists=Subskrybujesz już tę listę filtrów
-synchronize_invalid_url=Nie powiodło się - nieprawidłowy adres.
-synchronize_connection_error=Nie powiodło się - błąd pobierania.
-synchronize_invalid_data=Nie powiodło się - nieprawidłowa lista filtrów.
-synchronize_checksum_mismatch=Nie powiodło się - niepoprawna suma kontrolna
-synchronize_ok=Zakończono
-overwrite=Nadpisz
-append=Dodaj
-new_filter_group_title=Nowy filtr
-type_label_other=inne
-type_label_script=skrypt
-type_label_image=obrazek
-type_label_stylesheet=arkusz stylów
-type_label_object=obiekt
-type_label_subdocument=ramka
-type_label_document=dokument
-type_label_background=tło
-type_label_elemhide=ukryty
-type_label_xbl=powiązanie XBL
-type_label_ping=ping odnośnika
-type_label_xmlhttprequest=żądanie XML
-type_label_object_subrequest=subżądanie obiektu
-type_label_dtd=DTD
-type_label_media=audio/wideo
-type_label_font=czcionka

=== removed file 'chrome/locale/pl-PL/overlay.dtd'
--- chrome/locale/pl-PL/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pl-PL/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,24 +0,0 @@
-<!ENTITY status.tooltip "Status:">
-<!ENTITY blocked.tooltip "Zablokowane elementy na tej stronie:">
-<!ENTITY filters.tooltip "Najczęściej stosowane filtry:">
-<!ENTITY menuitem.label "Adblock Plus - ustawienia">
-<!ENTITY menuitem.accesskey "A">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Elementy blokowalne">
-<!ENTITY context.image.label "Zablokuj obrazek">
-<!ENTITY context.object.label "Zablokuj obiekt">
-<!ENTITY context.frame.label "Zablokuj ramkę">
-<!ENTITY context.removeWhitelist.label "Włącz ponownie na tej stronie">
-<!ENTITY sidebar.title "Blokowalne elementy na aktywnej stronie">
-<!ENTITY settings.label "Ustawienia">
-<!ENTITY settings.accesskey "U">
-<!ENTITY opensidebar.label "Otwórz listę blokowalnych elementów">
-<!--  Note: This access key should usually be the same as closesidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open. -->
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "Zamknij listę blokowalnych elementów">
-<!--  Note: This access key should usually be the same as opensidebar.accesskey. It is the same menu item with different label depending on whether the sidebar is currently open. -->
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Wyłącz blokowanie na --">
-<!ENTITY whitelist.page.label "Wyłącz blokowanie tylko na tej stronie">
-<!ENTITY objecttab.title "Zablokuj">
-<!ENTITY objecttab.tooltip "Kliknij tutaj, aby zablokować ten obiekt">

=== removed file 'chrome/locale/pl-PL/settings.dtd'
--- chrome/locale/pl-PL/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pl-PL/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus - ustawienia">
-<!ENTITY filters.label "Filtry">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Dodaj filtr">
-<!ENTITY add.accesskey "D">
-<!ENTITY addsubscription.label "Dodaj subskrypcję filtrów">
-<!ENTITY addsubscription.accesskey "S">
-<!ENTITY synchsubscriptions.label "Aktualizuj wszystkie subskrypcje">
-<!ENTITY synchsubscriptions.accesskey "U">
-<!ENTITY import.label "Importuj filtry">
-<!ENTITY import.accesskey "M">
-<!ENTITY export.label "Eksportuj filtry">
-<!ENTITY export.accesskey "E">
-<!ENTITY clearall.label "Usuń wszystkie filtry">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "Wyzeruj licznik użycia filtru">
-<!ENTITY resethitcounts.accesskey "W">
-<!ENTITY edit.label "Edycja">
-<!ENTITY edit.accesskey "E">
-<!ENTITY cut.label "Wytnij">
-<!ENTITY cut.accesskey "T">
-<!ENTITY copy.label "Kopiuj">
-<!ENTITY copy.accesskey "K">
-<!ENTITY paste.label "Wklej">
-<!ENTITY paste.accesskey "E">
-<!ENTITY remove.label "Usuń">
-<!ENTITY remove.accesskey "U">
-<!ENTITY menu.find.label "Znajdź">
-<!ENTITY menu.find.accesskey "Z">
-<!ENTITY menu.findagain.label "Znajdź następne">
-<!ENTITY menu.findagain.accesskey "N">
-<!ENTITY view.label "Widok">
-<!ENTITY view.accesskey "W">
-<!ENTITY sort.label "Sortuj wg">
-<!ENTITY sort.accesskey "S">
-<!ENTITY sort.none.label "Nieposortowane">
-<!ENTITY sort.none.accesskey "N">
-<!ENTITY sort.ascending.label "Kierunek sortowania A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Kierunek sortowania Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Opcje">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Włącz Adblock Plus">
-<!ENTITY enable.accesskey "W">
-<!ENTITY showintoolbar.label "Wyświetlaj ikonę Adblock Plusa na pasku narzędzi">
-<!ENTITY showintoolbar.accesskey "D">
-<!ENTITY showinstatusbar.label "Wyświetlaj ikonę Adblock Plusa na pasku stanu">
-<!ENTITY showinstatusbar.accesskey "N">
-<!ENTITY objecttabs.label "Wyświetlaj przyciski blokowania na elementach Flasha i Javy">
-<!ENTITY objecttabs.accesskey "K">
-<!ENTITY collapse.label "Ukrywaj zablokowane elementy">
-<!ENTITY collapse.accesskey "U">
-<!ENTITY help.label "Pomoc">
-<!ENTITY help.accesskey "P">
-<!ENTITY gettingStarted.label "Wprowadzenie">
-<!ENTITY gettingStarted.accesskey "W">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Często zadawane pytania">
-<!ENTITY faq.accesskey "C">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "O tworzeniu filtrów">
-<!ENTITY filterdoc.accesskey "O">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Adblock Plus - informacje">
-<!ENTITY about.accesskey "A">
-<!ENTITY description "Poniższe filtry określają, na których witrynach reklamy są blokowane, a na których dozwolone">
-<!ENTITY filter.column "Reguła filtru">
-<!ENTITY filter.accesskey "R">
-<!ENTITY slow.column "Wolne filtry">
-<!ENTITY slow.accesskey "W">
-<!ENTITY enabled.column "Aktywny">
-<!ENTITY enabled.accesskey "K">
-<!ENTITY hitcount.column "Użycie">
-<!ENTITY hitcount.accesskey "U">
-<!ENTITY lasthit.column "Ostatnie użycie">
-<!ENTITY lasthit.accesskey "O">
-<!ENTITY context.edit.label "Edytuj filtr">
-<!ENTITY context.resethitcount.label "Wyzeruj licznik użycia dla filtru">
-<!ENTITY context.synchsubscription.label "Aktualizuj subskrypcję teraz">
-<!ENTITY context.editsubscription.label "Edytuj subskrypcję">
-<!ENTITY context.moveup.label "Przesuń w górę">
-<!ENTITY context.movedown.label "Przesuń w dół">
-<!ENTITY context.movegroupup.label "Przesuń grupę w górę">
-<!ENTITY context.movegroupdown.label "Przesuń grupę w dól">
-<!ENTITY context.enable.label "Włącz">
-<!ENTITY context.disable.label "Wyłącz">
-<!ENTITY apply.label "Zastosuj">
-<!ENTITY apply.accesskey "S">

=== removed file 'chrome/locale/pl-PL/sidebar.dtd'
--- chrome/locale/pl-PL/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pl-PL/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus - elementy blokowalne (odłączony)">
-<!ENTITY detach.label "Odłącz">
-<!ENTITY reattach.label "Przyłącz">
-<!ENTITY search.label "Szukaj:">
-<!ENTITY search.accesskey "S">
-<!ENTITY type.label "Typ">
-<!ENTITY address.label "Adres">
-<!ENTITY filter.label "Filtr">
-<!ENTITY state.label "Stan">
-<!ENTITY size.label "Rozmiar">
-<!ENTITY docDomain.label "Źródło dokumentu">
-<!ENTITY noitems.label "Elementy nieblokowalne">
-<!ENTITY whitelisted.label "Nieblokowana strona">
-<!ENTITY tooltip.address.label "Adres:">
-<!ENTITY tooltip.type.label "Typ:">
-<!ENTITY tooltip.type.blocked "(zablokowany)">
-<!ENTITY tooltip.type.whitelisted "(nieblokowane)">
-<!ENTITY tooltip.size.label "Rozmiar:">
-<!ENTITY tooltip.docDomain.label "Źródło dokumentu:">
-<!ENTITY tooltip.filter.label "Działające filtry:">
-<!ENTITY tooltip.filterSource.label "Źródło filtra:">
-<!ENTITY context.block.label "Zablokuj ten element">
-<!ENTITY context.editfilter.label "Edytuj filtr w rzeczywistości">
-<!ENTITY context.whitelist.label "Dodaj regułę wyjątku dla elementu">
-<!ENTITY context.disablefilter.label "Wyłącz filtr…">
-<!ENTITY context.enablefilter.label "Włącz filtr…">
-<!ENTITY context.disablefilteronsite.label "Wyłącz ten filtr na…">
-<!ENTITY context.open.label "Otwórz w nowej karcie">
-<!ENTITY context.flash.label "Pokaż element w mrugającej ramce">
-<!ENTITY context.copy.label "Kopiuj adres elementu">
-<!ENTITY context.copyFilter.label "Kopiuj filtr">
-<!ENTITY context.selectAll.label "Zaznacz filtr">

=== removed file 'chrome/locale/pl-PL/subscription.dtd'
--- chrome/locale/pl-PL/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pl-PL/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Edycja subskrypcji filtrów">
-<!ENTITY dialog.newtitle "Dodawanie subskrypcji filtrów">
-<!ENTITY new.description "Proszę wprowadzić adres URL strony lub pliku zawierającego filtry Adblock Plusa.">
-<!ENTITY edit.description "Lista filtrów będzie pobierana z podanej lokalizacji.">
-<!ENTITY external.description "To jest subskrypcja filtrów zewnętrznych. Lista filtrów będzie aktualizowana przez rozszerzenie, które utworzyło tę subskrypcję.">
-<!ENTITY autodownload.description "Jeżeli zostanie wybrana opcja &quot;Aktualizuj automatycznie&quot; Adblock Plus będzie
-	codziennie przeprowadzał aktualizację filtrów z tej lokalizacji.
-	Jeśli opcja ta pozostanie wyłączona, można przeprowadzać aktualizację filtrów ręcznie
-	wybierając odpowiednią opcję z menu kontekstowego subskrypcji.">
-<!ENTITY location.label "Lokalizacja listy filtrów:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Nazwa subskrypcji:">
-<!ENTITY title.accesskey "N">
-<!ENTITY autodownload.label "Aktualizuj automatycznie">
-<!ENTITY autodownload.accesskey "A">
-<!ENTITY enabled.label "Włącz filtry">
-<!ENTITY enabled.accesskey "W">

=== removed file 'chrome/locale/pl-PL/tip_subscriptions.dtd'
--- chrome/locale/pl-PL/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pl-PL/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Witaj w Adblock Plus">
-<!ENTITY description.par1 "Dziękuję za zainstalowanie Adblock Plusa. Rozszerzenie to jest w stanie wyeliminować 98&#37; reklam pojawiających się w witrynach internetowych. Jednakże efektywne filtrowanie reklam wymaga zdefiniowania dobrego zestawu filtrów. Można to zrobić samemu, lub skorzystać z subskrypcji gotowych zestawów filtrów. Korzystając z gotowych zestawów filtrów można nadal definiować swoje własne filtry lub dezaktywować/usunąć subskrypcję w dowolnym momencie.">
-<!ENTITY description.par2 "Wybierz jedną z listy polecanych poniżej subskrypcji. Więcej subskrypcji można dodać w ustawieniach Adblock Plusa w późniejszym czasie, ale zazwyczaj nie jest to konieczne.">
-<!ENTITY note "Uwaga! Filtry stworzone w danym regionie będą działały najefektywniej na stronach pochodzących z tego samego regionu.">
-<!ENTITY adblock.warning "Wykryto, że jest zainstalowany Adblock lub starsza wersja Adblock Plusa. Uruchomienie obu rozszerzeń równocześnie może spowodować problemy i należy tego unikać. Zaleca się odinstalowanie Adblocka.">
-<!ENTITY adblock.uninstall "Odinstaluj Adblocka">
-<!ENTITY filterset.g.warning "Wygląda na to, że jest używana lista Filterset.G. Ta lista filtrów jest rzadko aktualizowana i zazwyczaj jest przyczyną problemów z witrynami. Zaleca się odinstalowanie Filterset.G.">
-<!ENTITY filterset.g.moreinfo "Więcej informacji">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Odinstaluj Filterset.G">
-<!ENTITY homepage.label "Strona domowa">
-<!ENTITY subscribe.label "Subskrybuj">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "Dodaj inną subskrypcję">
-<!ENTITY other.accesskey "K">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Zobacz wszystkie subskrypcje">

=== added file 'chrome/locale/pl/about.dtd'
--- chrome/locale/pl/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/pl/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "O Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Wersja">
+<!ENTITY description "Adblock Plus pozwala decydować o tym, jak będą wyglądały strony w Twojej przeglądarce. Nie będzie już konieczności wczytywania wszystkich reklam i banerów. Jeśli nie chcesz ich oglądać - zleć to Adblock Plus!">
+<!ENTITY homepage.label "Strona domowa Adblock Plusa:">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "Autor:">
+<!ENTITY contributors.label "Współtwórcy:">
+<!ENTITY developers.label "Programiści:">
+<!ENTITY designers.label "Autorzy grafiki:">
+<!ENTITY subscriptionAuthors.label "Autorzy zestawów filtrów:">
+<!ENTITY translators.label "Tłumacze:">

=== added file 'chrome/locale/pl/composer.dtd'
--- chrome/locale/pl/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/pl/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Tworzenie reguły filtru">
+<!ENTITY accept.label "Dodaj filtr">
+<!ENTITY advanced.label "Widok zaawansowany">
+<!ENTITY basic.label "Widok podstawowy">
+<!ENTITY disabled.warning "Adblock Plus jest wyłączony. Można dodawać filtry, ale nie będą one działały do czasu [link]włączenia Adblock Plusa[/link].">
+<!ENTITY groupDisabled.warning "Grupa filtrów „?1?”, do której ten filtr powinien zostać dodany, jest wyłączona. Można dodać ten filtr, ale nie będzie działał do czasu [link]włączenia grupy[/link].">
+<!ENTITY filter.label "Nowy filtr:">
+<!ENTITY filter.accesskey "F">
+<!ENTITY preferences.label "Wyświetl istniejące filtry…">
+<!ENTITY preferences.accesskey "S">
+<!ENTITY type.filter.label "Filtr blokujący">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Reguła wyjątku">
+<!ENTITY type.whitelist.accesskey "W">
+<!ENTITY pattern.label "Wygląd wzorca">
+<!ENTITY pattern.explanation "Wzorzec może składać się z dowolnej części adresu i symbolu * działającego jako wieloznacznik. Filtr będzie działał tylko na stronach o adresie pasującym do wzorca.">
+<!ENTITY regexp.warning "Wprowadzony wzorzec będzie interpretowany jako wyrażenie regularne. Wiele wyrażeń regularnych może spowalniać przeglądanie Internetu. Jeśli nie zamierzasz używać wyrażeń regularnych, dodaj na końcu wzorca wieloznacznik *.">
+<!ENTITY shortpattern.warning "Wprowadzony wzorzec jest za krótki, by go zoptymalizować. Duża liczba takich wzorców może spowalniać przeglądanie Internetu. Zaleca się wybrać dla tego filtru nieco dłuższy ciąg znaków.">
+<!ENTITY custom.pattern.label "Dostosuj:">
+<!ENTITY custom.pattern.accesskey "D">
+<!ENTITY anchors.label "Akceptuj wzorzec tylko:">
+<!ENTITY anchor.start.label "na początku adresu">
+<!ENTITY anchor.start.accesskey "o">
+<!ENTITY anchor.start.flexible.label "na początku nazwy domeny">
+<!ENTITY anchor.start.flexible.accesskey "o">
+<!ENTITY anchor.end.label "na końcu adresu">
+<!ENTITY anchor.end.accesskey "k">
+<!ENTITY options.label "Opcje">
+<!ENTITY domainRestriction.label "Ogranicz do domeny:">
+<!ENTITY domainRestriction.accesskey "r">
+<!ENTITY domainRestriction.help "Określ jedną lub więcej domen oddzielonych symbolem „|”. Filtr będzie stosowany tylko dla tych domen. Symbol „~” przed nazwą domeny oznacza, że filtr nie powinien być stosowany w tych domenach.">
+<!ENTITY firstParty.label "Tylko pierwsza część adresu">
+<!ENTITY firstParty.accesskey "e">
+<!ENTITY thirdParty.label "Tylko trzecia część adresu">
+<!ENTITY thirdParty.accesskey "t">
+<!ENTITY matchCase.label "Uwzględniaj wielkość liter">
+<!ENTITY matchCase.accesskey "U">
+<!ENTITY types.label "Zastosuj do typów:">
+<!ENTITY selectAllTypes.label "Zaznacz wszystko">
+<!ENTITY unselectAllTypes.label "Usuń zaznaczenie">
+<!ENTITY collapse.label "Zwiń zablokowane:">
+<!ENTITY collapse.accesskey "A">
+<!ENTITY collapse.default.yes.label "Domyślnie (tak)">
+<!ENTITY collapse.default.no.label "Domyślnie (nie)">
+<!ENTITY collapse.yes.label "Tak">
+<!ENTITY collapse.no.label "Nie">

=== added file 'chrome/locale/pl/global.properties'
--- chrome/locale/pl/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/pl/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Kliknij l.p.m., aby otworzyć menu kontekstowe, ś.p.m., aby włączyć/wyłączyć
+action1_tooltip=Kliknij l.p.m., aby otworzyć/zamknąć listę blokowalnych elementów, ś.p.m., aby włączyć/wyłączyć
+action2_tooltip=Kliknij l.p.m., aby otworzyć opcje, ś.p.m., aby włączyć/wyłączyć
+action3_tooltip=Kliknij l.p.m., aby włączyć/wyłączyć Adblock Plus
+disabled_tooltip=Adblock Plus jest wyłączony
+active_tooltip=Adblock Plus jest aktywny. Subskrybowane zestawy: ?1? i własne filtry: ?2?.
+whitelisted_tooltip=Adblock Plus jest aktywny, ale wyłączony na oglądanej stronie.
+blocked_count_tooltip=?1? z ?2?
+blocked_count_addendum=(dozwolone:?1?, ukryte:?2?)
+no_blocking_suggestions=Nieblokowalne elementy na aktywnej stronie
+whitelisted_page=Adblock Plus został wyłączony dla tej strony
+whitelist_description=Reguły wyjątków
+filterlist_description=Filtry reklam
+invalid_description=Nieprawidłowy filtr
+elemhide_description=Reguły ukrywanych elementów
+subscription_description=Zestaw filtrów:
+subscription_wrong_version=Niektóre filtry z tego zestawu, aby pracowały poprawnie, wymagają Adblock Plusa ?1?
+subscription_source=Źródło:
+subscription_status=Status:
+subscription_status_autodownload=Zaktualizowano automatycznie
+subscription_status_manualdownload=Zaktualizowano ręcznie
+subscription_status_externaldownload=Zaktualizowano zewnętrznie (poprzez inne rozszerzenie)
+subscription_status_lastdownload=Ostatnie pobieranie:
+subscription_status_lastdownload_inprogress=Pobieranie…
+subscription_status_lastdownload_unknown=nieznane
+remove_subscription_warning=Czy chcesz usunąć ten zestaw?
+import_filters_wrong_version=Ostrzeżenie! Niektóre filtry z tego zestawu, aby pracowały poprawnie, wymagają Adblock Plusa ?1?. Przed zaimportowaniem tego zestawu, należy wykonać aktualizację Adblock Plusa.
+import_filters_warning=Czy chcesz zamienić obecne filtry? Naciśnij Anuluj, aby dodać filtry na końcu listy.
+import_filters_title=Import filtrów
+export_filters_title=Eksport filtrów
+invalid_filters_file=Nieprawidłowy plik filtrów Adblock Plusa
+filters_write_error=Wystąpił błąd podczas zapisu filtrów do pliku. Proszę sprawdzić czy plik nie jest używany przez inny program lub nie ma zabezpieczenia przed zapisem.
+clearall_warning=Czy na pewno chcesz usunąć wszystkie filtry z zestawu?
+resethitcounts_warning=Czy na pewno chcesz wyzerować liczniki użycia wszystkich filtrów? Tej operacji nie można cofnąć.
+resethitcounts_selected_warning=Czy na pewno chcesz wyzerować liczniki użycia wybranych filtrów? Tej operacji nie można cofnąć.
+filter_regexp_tooltip=Ten filtr jest wyrażeniem regularnym albo jest za krótki, aby go zoptymalizować. Zbyt dużo filtrów tego rodzaju może powodować spowolnienie przeglądania internetu.
+filter_elemhide_duplicate_id=Może być określony tylko jeden ID elementu do ukrycia
+filter_elemhide_nocriteria=Nie określono kryteriów rozpoznania elementu do ukrycia
+subscription_notAdded_warning=Nie dokonano zestawu filtrów. Trzeba będzie dodawać filtry ręcznie.
+subscription_notAdded_warning_addendum=\nCzy chcesz kontynuować?
+subscription_invalid_location=Lokalizacja zestawu filtrów ma niewłaściwą nazwę pliku, albo adres URL
+synchronize_invalid_url=Nie powiodło się – nieprawidłowy adres
+synchronize_connection_error=Nie powiodło się – błąd pobierania
+synchronize_invalid_data=Nie powiodło się – nieprawidłowy zestaw filtrów
+synchronize_checksum_mismatch=Nie powiodło się – niepoprawna suma kontrolna
+synchronize_ok=Zakończono
+overwrite=Nadpisz
+append=Dodaj
+new_filter_group_title=Nowy filtr
+type_label_other=inne
+type_label_script=skrypt
+type_label_image=obrazek
+type_label_stylesheet=arkusz stylów
+type_label_object=obiekt
+type_label_subdocument=ramka
+type_label_document=dokument
+type_label_background=tło
+type_label_elemhide=ukryty
+type_label_xbl=powiązanie XBL
+type_label_ping=ping odnośnika
+type_label_xmlhttprequest=żądanie XML
+type_label_object_subrequest=subżądanie obiektu
+type_label_dtd=DTD
+type_label_media=audio/wideo
+type_label_font=czcionka
+fennec_status_enabled=Adblock Plus jest włączony.
+fennec_status_disabled=Adblock Plus jest wyłączony.
+fennec_status_enabled_site=Adblock Plus jest włączony na ?1?.
+fennec_status_disabled_site=Adblock Plus jest wyłączony na ?1?.

=== added file 'chrome/locale/pl/meta.properties'
--- chrome/locale/pl/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/pl/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Leszek(teo)Życzkowski
+name=Adblock Plus
+description=Powiedz NIE! reklamom
+description.short=Masz dość oglądania denerwujących reklam i banerów, które dodatkowo wydłużają wczytywanie stron? Zainstaluj Adblock Plus i uwolnij się od nich!\n\nKrótkie wideo opisujące instalację znajduje się tutaj: http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Dzięki rozszerzeniu Adblock Plus odzyskasz kontrolę nad Internetem i będziesz móc przeglądać strony tak, jak chcesz. Dodatek jest wspierany przez ponad 40 możliwych do subskrybowania zestawów filtrów dostosowanych do różnych obszarów językowych. Filtry te automatycznie konfigurują Adblock Plus do różnych zadań, począwszy od usuwania reklam internetowych do blokowania wszystkich znanych domen ze złośliwym oprogramowaniem. Rozszerzenie umożliwia także ręczne dostosowywanie filtrów, udostępniając wiele przydatnych do tego celu funkcji takich, jak funkcje blokowania obrazków dostępne z poziomu menu kontekstowego, blokowania kart dla Flasha i obiektów Java oraz listę blokowalnych elementów służącą do usuwania skryptów i arkuszy stylów.

=== added file 'chrome/locale/pl/overlay.dtd'
--- chrome/locale/pl/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/pl/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Status:">
+<!ENTITY blocked.tooltip "Zablokowane elementy na tej stronie:">
+<!ENTITY filters.tooltip "Najczęściej stosowane filtry:">
+<!ENTITY menuitem.label "Adblock Plus - ustawienia">
+<!ENTITY menuitem.accesskey "A">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Elementy blokowalne">
+<!ENTITY context.image.label "Zablokuj obrazek">
+<!ENTITY context.object.label "Zablokuj obiekt">
+<!ENTITY context.frame.label "Zablokuj ramkę">
+<!ENTITY context.media.label "Zablokuj wideo/audio">
+<!ENTITY context.removeWhitelist.label "Włącz ponownie na tej stronie">
+<!ENTITY sidebar.title "Blokowalne elementy na aktywnej stronie">
+<!ENTITY settings.label "Ustawienia">
+<!ENTITY settings.accesskey "U">
+<!ENTITY opensidebar.label "Otwórz listę blokowalnych elementów">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "Zamknij listę blokowalnych elementów">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "Wyłącz blokowanie na ?1?">
+<!ENTITY whitelist.page.label "Wyłącz blokowanie tylko na tej stronie">
+<!ENTITY objecttab.title "Zablokuj">
+<!ENTITY objecttab.tooltip "Kliknij tutaj, aby zablokować ten obiekt">

=== added file 'chrome/locale/pl/settings.dtd'
--- chrome/locale/pl/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/pl/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus - ustawienia">
+<!ENTITY filters.label "Filtry">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Dodaj filtr">
+<!ENTITY add.accesskey "D">
+<!ENTITY addsubscription.label "Dodaj zestaw filtrów">
+<!ENTITY addsubscription.accesskey "S">
+<!ENTITY synchsubscriptions.label "Aktualizuj zestawy">
+<!ENTITY synchsubscriptions.accesskey "U">
+<!ENTITY import.label "Importuj filtry">
+<!ENTITY import.accesskey "M">
+<!ENTITY export.label "Eksportuj filtry">
+<!ENTITY export.accesskey "E">
+<!ENTITY clearall.label "Usuń wszystkie filtry">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "Wyzeruj licznik użycia filtru">
+<!ENTITY resethitcounts.accesskey "W">
+<!ENTITY edit.label "Edycja">
+<!ENTITY edit.accesskey "E">
+<!ENTITY cut.label "Wytnij">
+<!ENTITY cut.accesskey "T">
+<!ENTITY copy.label "Kopiuj">
+<!ENTITY copy.accesskey "K">
+<!ENTITY paste.label "Wklej">
+<!ENTITY paste.accesskey "E">
+<!ENTITY remove.label "Usuń">
+<!ENTITY remove.accesskey "U">
+<!ENTITY menu.find.label "Znajdź">
+<!ENTITY menu.find.accesskey "Z">
+<!ENTITY menu.findagain.label "Znajdź następne">
+<!ENTITY menu.findagain.accesskey "N">
+<!ENTITY view.label "Widok">
+<!ENTITY view.accesskey "W">
+<!ENTITY sort.label "Sortuj wg">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "Nieposortowane">
+<!ENTITY sort.none.accesskey "N">
+<!ENTITY sort.ascending.label "Kierunek sortowania A &gt; Z">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Kierunek sortowania Z &gt; A">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Opcje">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Włącz Adblock Plus">
+<!ENTITY enable.accesskey "W">
+<!ENTITY showintoolbar.label "Wyświetlaj ikonę Adblock Plusa na pasku narzędzi">
+<!ENTITY showintoolbar.accesskey "D">
+<!ENTITY showinstatusbar.label "Wyświetlaj ikonę Adblock Plusa na pasku stanu">
+<!ENTITY showinstatusbar.accesskey "N">
+<!ENTITY objecttabs.label "Wyświetlaj przyciski blokowania na elementach Flasha i Javy">
+<!ENTITY objecttabs.accesskey "K">
+<!ENTITY collapse.label "Ukrywaj zablokowane elementy">
+<!ENTITY collapse.accesskey "U">
+<!ENTITY help.label "Pomoc">
+<!ENTITY help.accesskey "P">
+<!ENTITY gettingStarted.label "Wprowadzenie">
+<!ENTITY gettingStarted.accesskey "W">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Często zadawane pytania">
+<!ENTITY faq.accesskey "C">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "O tworzeniu filtrów">
+<!ENTITY filterdoc.accesskey "O">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Adblock Plus - informacje">
+<!ENTITY about.accesskey "A">
+<!ENTITY description "Poniższe filtry określają, na których witrynach reklamy są blokowane, a na których dozwolone">
+<!ENTITY filter.column "Reguła filtru">
+<!ENTITY filter.accesskey "R">
+<!ENTITY slow.column "Wolne filtry">
+<!ENTITY slow.accesskey "W">
+<!ENTITY enabled.column "Aktywny">
+<!ENTITY enabled.accesskey "K">
+<!ENTITY hitcount.column "Użycie">
+<!ENTITY hitcount.accesskey "U">
+<!ENTITY lasthit.column "Ostatnie użycie">
+<!ENTITY lasthit.accesskey "O">
+<!ENTITY context.edit.label "Edytuj filtr">
+<!ENTITY context.resethitcount.label "Wyzeruj licznik użycia dla filtru">
+<!ENTITY context.synchsubscription.label "Aktualizuj zestaw teraz">
+<!ENTITY context.editsubscription.label "Edytuj zestaw">
+<!ENTITY context.moveup.label "Przesuń w górę">
+<!ENTITY context.movedown.label "Przesuń w dół">
+<!ENTITY context.movegroupup.label "Przesuń grupę w górę">
+<!ENTITY context.movegroupdown.label "Przesuń grupę w dól">
+<!ENTITY context.enable.label "Włącz">
+<!ENTITY context.disable.label "Wyłącz">
+<!ENTITY apply.label "Zastosuj">
+<!ENTITY apply.accesskey "S">
+<!ENTITY fennec.subscription.label "Zestawy filtrów">

=== added file 'chrome/locale/pl/sidebar.dtd'
--- chrome/locale/pl/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/pl/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus – elementy blokowalne (odłączony)">
+<!ENTITY detach.label "Odłącz">
+<!ENTITY reattach.label "Przyłącz">
+<!ENTITY search.label "Szukaj:">
+<!ENTITY search.accesskey "S">
+<!ENTITY type.label "Typ">
+<!ENTITY address.label "Adres">
+<!ENTITY filter.label "Filtr">
+<!ENTITY state.label "Stan">
+<!ENTITY size.label "Rozmiar">
+<!ENTITY docDomain.label "Źródło dokumentu">
+<!ENTITY noitems.label "Elementy nieblokowalne">
+<!ENTITY whitelisted.label "Nieblokowana strona">
+<!ENTITY tooltip.address.label "Adres:">
+<!ENTITY tooltip.type.label "Typ:">
+<!ENTITY tooltip.type.blocked "(zablokowany)">
+<!ENTITY tooltip.type.whitelisted "(nieblokowane)">
+<!ENTITY tooltip.size.label "Rozmiar:">
+<!ENTITY tooltip.docDomain.label "Źródło dokumentu:">
+<!ENTITY tooltip.filter.label "Działające filtry:">
+<!ENTITY tooltip.filterSource.label "Źródło filtra:">
+<!ENTITY context.block.label "Zablokuj ten element">
+<!ENTITY context.editfilter.label "Edytuj filtr w rzeczywistości">
+<!ENTITY context.whitelist.label "Dodaj regułę wyjątku dla elementu">
+<!ENTITY context.disablefilter.label "Wyłącz filtr ?1?">
+<!ENTITY context.enablefilter.label "Włącz filtr ?1?">
+<!ENTITY context.disablefilteronsite.label "Wyłącz ten filtr na ?1?">
+<!ENTITY context.open.label "Otwórz w nowej karcie">
+<!ENTITY context.flash.label "Pokaż element w mrugającej ramce">
+<!ENTITY context.copy.label "Kopiuj adres elementu">
+<!ENTITY context.copyFilter.label "Kopiuj filtr">
+<!ENTITY context.selectAll.label "Zaznacz filtr">

=== added file 'chrome/locale/pl/subscriptionSelection.dtd'
--- chrome/locale/pl/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/pl/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Add Adblock Plus – zestawy filtrów">
+<!ENTITY dialog.title.edit "Edycja zestawów filtrów">
+<!ENTITY description.newInstall "Dla Adblock Plusa najbardziej efektywnym sposobem pozyskania filtrów jest dodanie subskrypcji zestawu filtrów. Znajdujące się w rozwijanym menu zestawy filtrów są udostępniane przez innych użytkowników Adblock Plusa za darmo. Najodpowiedniejsze zestawy filtrów dla Twojego języka są wyróżnione.">
+<!ENTITY adblock.warning "Wykryto, że jest zainstalowany Adblock lub starsza wersja Adblock Plusa. Uruchomienie obu rozszerzeń równocześnie może spowodować problemy i należy tego unikać. Zaleca się odinstalowanie Adblocka.">
+<!ENTITY adblock.uninstall "Odinstaluj Adblocka">
+<!ENTITY filterset.g.warning "Wygląda na to, że używasz zestawu Filterset.G. Ten zestaw filtrów jest rzadko aktualizowany i zazwyczaj jest przyczyną problemów z witrynami. Zaleca się odinstalowanie Filterset.G.">
+<!ENTITY filterset.g.moreinfo "Więcej informacji">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Odinstaluj Filterset.G">
+<!ENTITY subscriptionSelector.label "Wybierz z listy zestaw filtrów:">
+<!ENTITY viewList.label "Zobacz filtry">
+<!ENTITY visitHomepage.label "Przejdź na stronę zestawu">
+<!ENTITY addSubscription.label "Subskrybuj zestaw">
+<!ENTITY saveSubscription.label "Zapisz zestaw">
+<!ENTITY other.label "Wybierz inny zestaw">
+<!ENTITY other.accesskey "W">
+<!ENTITY list.download.failed "Nie udało się pobrać listy zestawów.">
+<!ENTITY list.download.retry "Spróbuj jeszcze raz">
+<!ENTITY list.download.website "Zobacz witrynę">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Potwierdź zamiar dodania tego zestawu filtrów. Przed dodaniem zestawu możesz zmienić jego nazwę lub lokalizację.">
+<!ENTITY edit.description "Jeśli zachodzi potrzeba, możesz zmienić nazwę lub lokalizację zestawu.">
+<!ENTITY external.description "To jest zewnętrzny zestaw filtrów. Zestaw będzie aktualizowany przez rozszerzenie za pomocą, którego został utworzony.">
+<!ENTITY title.label "Nazwa zestawu:">
+<!ENTITY title.accesskey "N">
+<!ENTITY location.label "Lokalizacja zestawu:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Aktualizuj automatycznie">
+<!ENTITY autodownload.accesskey "A">
+<!ENTITY supplementMessage "Ten zestaw filtrów musi być używany z zestawem „;?1?”, który nie jest jeszcze subskrybowany.">
+<!ENTITY addMain.label "Dodaj także zestaw „;?1?”">
+<!ENTITY addMain.accesskey "S">

=== modified file 'chrome/locale/pt-BR/composer.dtd'
--- chrome/locale/pt-BR/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-BR/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "Adicionar filtro">
 <!ENTITY advanced.label "Visualização avançada">
 <!ENTITY basic.label "Visualização básica">
-<!ENTITY disabled.warning.beforeLink "O Adblock Plus está atualmente desativado. Você ainda pode adicionar filtro mas eles não serão aplicados enquanto você não">
-<!ENTITY disabled.warning.link "ativar o Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "O grupo de filtros &quot;&#37;S&quot;a que esse filtro foi adicionado está atualmente desativado. Você ainda pode adicionar o filtro, mas ele não será aplicado até que você">
-<!ENTITY groupDisabled.warning.link "ative o grupo de filtros">
-<!ENTITY groupDisabled.warning.afterLink ".">
+<!ENTITY disabled.warning "O Adblock Plus está atualmente desativado. Você ainda pode adicionar filtro mas eles não serão aplicados enquanto você não [link]ativar o Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "O grupo de filtros &quot;?1?&quot;a que esse filtro foi adicionado está atualmente desativado. Você ainda pode adicionar o filtro, mas ele não será aplicado até que você [link]ative o grupo de filtros[/link].">
 <!ENTITY filter.label "Novo filtro:">
 <!ENTITY filter.accesskey "f">
 <!ENTITY preferences.label "Mostrar filtros existentes...">

=== modified file 'chrome/locale/pt-BR/global.properties'
--- chrome/locale/pt-BR/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-BR/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,10 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Propaganda indesejada é coisa do passado!
-status_active_label=Adblock
-status_disabled_label=Desativado
 action0_tooltip=Clique para mostrar o menu de contexto, e com o botão do meio para ativar/desativar.
 action1_tooltip=Clique para abrir/fechar itens bloqueáveis, e com o botão do meio para ativar/desativar.
 action2_tooltip=Clique para abrir as preferências, e com o botão do meio para ativar/desativar.
 action3_tooltip=Clique para ativar/desativar o Adblock Plus.
-active_tooltip=O Adblock Plus está ativo.
 disabled_tooltip=O Adblock Plus está desativado.
 whitelisted_tooltip=O Adblock Plus está ativo, mas desativado na página atual.
-blocked_count_tooltip=-- de --
+blocked_count_tooltip=?1? de ?2?
 no_blocking_suggestions=Nenhum item bloqueável na página atual
 whitelisted_page=O Adblock Plus foi desativado para a página atual
 whitelist_description=Regras de exceção
@@ -16,7 +12,7 @@
 invalid_description=Filtros Inválidos
 elemhide_description=Regras para ocultar elementos
 subscription_description=Inscrição do filtro:
-subscription_wrong_version=Alguns filtros nessa inscrição requerem o Adblock Plus -- para funcionar corretamente!
+subscription_wrong_version=Alguns filtros nessa inscrição requerem o Adblock Plus ?1? para funcionar corretamente!
 subscription_source=Fonte:
 subscription_status=Status:
 subscription_status_autodownload=Atualizado automaticamente
@@ -26,7 +22,7 @@
 subscription_status_lastdownload_inprogress=Fazendo download...
 subscription_status_lastdownload_unknown=N/A
 remove_subscription_warning=Você realmente deseja remover esta inscrição?
-import_filters_wrong_version=Aviso: alguns dos filtros nessa lista requerem o Adblock Plus -- para funcionar corretamente. Você deveria provavelmente atualizar para a última versão do Adblock Plus antes de importar essa lista.
+import_filters_wrong_version=Aviso: alguns dos filtros nessa lista requerem o Adblock Plus ?1? para funcionar corretamente. Você deveria provavelmente atualizar para a última versão do Adblock Plus antes de importar essa lista.
 import_filters_warning=Você deseja substituir os seus filtros atuais ou adicionar os novos filtros no fim da lista?
 import_filters_title=Importar filtros
 export_filters_title=Exportar filtros
@@ -38,9 +34,7 @@
 filter_regexp_tooltip=Este filtro é também uma expressão regular ou curta demais para ser otimizada. Muitos desses filtros podem causar lentidão na navegação.
 filter_elemhide_duplicate_id=Somente uma ID do elemento a ser ocultado pode ser especificada
 filter_elemhide_nocriteria=Nenhum critério especificado para reconhecer o elemento a ser ocultado
-subscription_no_location=Por favor digite um local para fazer o download dos filtros.
 subscription_invalid_location=O local da lista de filtros não é nem uma URL válida nem um nome válido de arquivo.
-subscription_location_exists=Você já está inscrito nesta lista de filtros.
 synchronize_invalid_url=Falhou, não é um endereço válido
 synchronize_connection_error=Falhou, falha no download
 synchronize_invalid_data=Falhou, não é uma lista de filtros válida

=== added file 'chrome/locale/pt-BR/meta.properties'
--- chrome/locale/pt-BR/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/pt-BR/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=Propaganda indesejada é coisa do passado!

=== modified file 'chrome/locale/pt-BR/overlay.dtd'
--- chrome/locale/pt-BR/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-BR/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -16,7 +16,7 @@
 <!ENTITY opensidebar.accesskey "B">
 <!ENTITY closesidebar.label "Fechar itens bloqueáveis">
 <!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Desabilitar em --">
+<!ENTITY whitelist.site.label "Desabilitar em ?1?">
 <!ENTITY whitelist.page.label "Desabilitar somente nesta página">
 <!ENTITY objecttab.title "Bloquear">
 <!ENTITY objecttab.tooltip "Clique aqui para bloquear este objeto com o Adblock Plus">

=== modified file 'chrome/locale/pt-BR/sidebar.dtd'
--- chrome/locale/pt-BR/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-BR/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "Bloquear este item">
 <!ENTITY context.editfilter.label "Editar filtro em efeito">
 <!ENTITY context.whitelist.label "Adicionar exceção para o item">
-<!ENTITY context.disablefilter.label "Desativar filtro --">
-<!ENTITY context.enablefilter.label "Reativar filtro --">
-<!ENTITY context.disablefilteronsite.label "Desativar esse filtro em --">
+<!ENTITY context.disablefilter.label "Desativar filtro ?1?">
+<!ENTITY context.enablefilter.label "Reativar filtro ?1?">
+<!ENTITY context.disablefilteronsite.label "Desativar esse filtro em ?1?">
 <!ENTITY context.open.label "Abrir em nova aba">
 <!ENTITY context.flash.label "Realçar bordas do item">
 <!ENTITY context.copy.label "Copiar endereço do item">

=== removed file 'chrome/locale/pt-BR/subscription.dtd'
--- chrome/locale/pt-BR/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-BR/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Editar inscrição de filtro">
-<!ENTITY dialog.newtitle "Adicionar inscrição de filtro">
-<!ENTITY new.description "Por favor, digite o endereço na internet ou arquivo contendo uma lista de filtros do Adblock Plus.">
-<!ENTITY edit.description "A lista de filtros para esta inscrição será baixada do local informado.">
-<!ENTITY external.description "Esta é uma inscrição para um filtro externo, sua lista de filtros será mantida atualizada pela extensão que criou a inscrição.">
-<!ENTITY autodownload.description "Se você escolher &apos;Atualizar automaticamente&apos; este local será verificado diariamente. Com esta opção desabilitada você ainda pode fazer uma atualização manualmente no menu de contexto da inscrição.">
-<!ENTITY location.label "Localização da lista de filtros:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Título da inscrição:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Atualizar automaticamente">
-<!ENTITY autodownload.accesskey "A">
-<!ENTITY enabled.label "Ativar filtros">
-<!ENTITY enabled.accesskey "F">

=== added file 'chrome/locale/pt-BR/subscriptionSelection.dtd'
--- chrome/locale/pt-BR/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/pt-BR/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,15 @@
+<!ENTITY dialog.title.edit "Editar inscrição de filtro">
+<!ENTITY adblock.warning "O Adblock Plus detectou que o Adblock ou uma versão mais antiga do Adblock Plus está instalada. Executar simultaneamente o Adblock e o Adblock Plus pode causar problemas que deveriam ser evitados. É recomendado que você desinstale o Adblock agora.">
+<!ENTITY adblock.uninstall "Desinstalar Adblock">
+<!ENTITY filterset.g.warning "Parece que você usa o Filterset.G. Essa lista de filtros tem sido raramente atualizada nos últimos anos e é uma causa comum de problemas em sites. É recomendado que você desinstale o Filterset.G agora.">
+<!ENTITY filterset.g.moreinfo "Mais informações">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Desinstalar Filterset.G">
+<!ENTITY other.label "Adicionar outra inscrição">
+<!ENTITY other.accesskey "O">
+<!ENTITY title.label "Título da inscrição:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Localização da lista de filtros:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Atualizar automaticamente">
+<!ENTITY autodownload.accesskey "A">

=== removed file 'chrome/locale/pt-BR/tip_subscriptions.dtd'
--- chrome/locale/pt-BR/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-BR/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Bem vindo ao Adblock Plus">
-<!ENTITY description.par1 "Obrigado por instalar o Adblock Plus. Esta extensão pode eliminar 99&#37; das propagandas que você vê na internet. Entretanto, para uma filtragem eficiente de propagandas você precisa definir um bom conjunto de filtros. Você pode fazer isso sozinho, ou pode simplesmente se inscrever em listas de filtros mantidas por outras pessoas. Ainda será possível adicionar os seus próprios filtros ou desativar/remover inscrições quando necessário.">
-<!ENTITY description.par2 "Você pode escolher uma inscrição da lista de inscrições recomendadas abaixo (mais inscrições podem ser adicionadas, nas Preferências do Adblock Plus, mais tarde, mesmo que isso geralmente não seja necessário):">
-<!ENTITY note "Nota: Uma lista de filtros é tipicamente mais efetiva quando aplicada a sites da mesma região para onde o filtro foi criado.">
-<!ENTITY adblock.warning "O Adblock Plus detectou que o Adblock ou uma versão mais antiga do Adblock Plus está instalada. Executar simultaneamente o Adblock e o Adblock Plus pode causar problemas que deveriam ser evitados. É recomendado que você desinstale o Adblock agora.">
-<!ENTITY adblock.uninstall "Desinstalar Adblock">
-<!ENTITY filterset.g.warning "Parece que você usa o Filterset.G. Essa lista de filtros tem sido raramente atualizada nos últimos anos e é uma causa comum de problemas em sites. É recomendado que você desinstale o Filterset.G agora.">
-<!ENTITY filterset.g.moreinfo "Mais informações">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Desinstalar Filterset.G">
-<!ENTITY homepage.label "Página inicial">
-<!ENTITY subscribe.label "Inscrever">
-<!ENTITY subscribe.accesskey "I">
-<!ENTITY other.label "Adicionar outra inscrição">
-<!ENTITY other.accesskey "O">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Ver todas as inscrições">

=== modified file 'chrome/locale/pt-PT/about.dtd'
--- chrome/locale/pt-PT/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-PT/about.dtd	2010-05-04 14:45:07 +0000
@@ -6,3 +6,7 @@
 <!ENTITY homepage.url "http://adblockplus.org/">
 <!ENTITY author.label "Autor:">
 <!ENTITY contributors.label "Colaboradores:">
+<!ENTITY developers.label "Programadores:">
+<!ENTITY designers.label "Designers gráficos">
+<!ENTITY subscriptionAuthors.label "Autores de filtros de subscrição:">
+<!ENTITY translators.label "Tradutores:">

=== modified file 'chrome/locale/pt-PT/composer.dtd'
--- chrome/locale/pt-PT/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-PT/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "Adicionar filtro">
 <!ENTITY advanced.label "Vista avançada">
 <!ENTITY basic.label "Vista básica">
-<!ENTITY disabled.warning.beforeLink "O Adblock Plus está desactivado. Pode, mesmo assim, adicionar filtros, no entanto, estes não serão aplicados até">
-<!ENTITY disabled.warning.link "activar o Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "O grupo de filtros &quot;&#37;S&quot; a que este filtro deveria ser adicionado está inactivo. Pode adicionar o filtro mas não será aplicado até">
-<!ENTITY groupDisabled.warning.link "activar o grupo de filtros">
-<!ENTITY groupDisabled.warning.afterLink ".">
+<!ENTITY disabled.warning "O Adblock Plus está desactivado. Pode, mesmo assim, adicionar filtros, no entanto, estes não serão aplicados até [link]activar o Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "O grupo de filtros &quot;?1?&quot; a que este filtro deveria ser adicionado está inactivo. Pode adicionar o filtro mas não será aplicado até [link]activar o grupo de filtros[/link].">
 <!ENTITY filter.label "Novo filtro:">
 <!ENTITY filter.accesskey "n">
 <!ENTITY preferences.label "Mostrar filtros existentes...">

=== modified file 'chrome/locale/pt-PT/global.properties'
--- chrome/locale/pt-PT/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-PT/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,13 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Publicidade... já era!
-status_active_label=Adblock
-status_disabled_label=Desactivado
+default_dialog_title=Adblock Plus
 action0_tooltip=Clique com o botão esquerdo para mostrar menu de contexto, clique com o botão do meio para activar/ desactivar.
 action1_tooltip=Clique com o botão esquerdo para abrir/ fechar items bloqueados, clique com o botão do meio para activar/ desactivar.
 action2_tooltip=Clique com o botão esquerdo para abrir as preferências, clique com o botão do meio para activar/ desactivar.
 action3_tooltip=Clique com o botão esquerdo para activar/ desactivar o Adblock Plus.
-active_tooltip=O Adblock Plus está activo.
 disabled_tooltip=O Adblock Plus está inactivo.
+active_tooltip=O Adblock Plus está activo, ?1? subscrições de filtros e ?2? filtros pessoais em uso.
 whitelisted_tooltip=O Adblock Plus está activo mas foi desactivado nesta página.
-blocked_count_tooltip=-- de --
+blocked_count_tooltip=?1? de ?2?
+blocked_count_addendum=(também na lista branca: ?1?, escondido: ?2?)
 no_blocking_suggestions=Não há itens bloqueáveis na página actual
 whitelisted_page=O Adblock Plus foi desactivado para a página actual
 whitelist_description=Regras de excepção
@@ -16,7 +15,7 @@
 invalid_description=Filtros inválidos
 elemhide_description=Regras para esconder elementos
 subscription_description=Subscrição de filtros:
-subscription_wrong_version=Alguns filtros desta subscrição requerem o Adblock Plus -- para funcionar devidamente!
+subscription_wrong_version=Alguns filtros desta subscrição requerem o Adblock Plus ?1? para funcionar devidamente!
 subscription_source=Fonte:
 subscription_status=Estado:
 subscription_status_autodownload=Actualizado automaticamente
@@ -26,7 +25,7 @@
 subscription_status_lastdownload_inprogress=A fazer download...
 subscription_status_lastdownload_unknown=N/A
 remove_subscription_warning=Deseja, realmente, remover esta subscrição?
-import_filters_wrong_version=Aviso: alguns dos filtros desta lista requerem o Adblock Plus -- para funcionar devidamente. Provavelmente devia actualizar para a última versão do Adblock Plus antes de importar esta lista.
+import_filters_wrong_version=Aviso: alguns dos filtros desta lista requerem o Adblock Plus ?1? para funcionar devidamente. Provavelmente devia actualizar para a última versão do Adblock Plus antes de importar esta lista.
 import_filters_warning=Deseja substituir os filtros actuais ou adicionar os filtros novos ao final da lista?
 import_filters_title=Importar filtros
 export_filters_title=Exportar filtros
@@ -38,9 +37,9 @@
 filter_regexp_tooltip=Este filtro é uma expressão regular ou demasiado curto para ser optimizado. Demasiados filtros com estas características podem lentificar o browser.
 filter_elemhide_duplicate_id=Apenas uma ID do elemento a bloquear pode ser especificado.
 filter_elemhide_nocriteria=Sem critério especificado para reconhecer o elemento a bloquear.
-subscription_no_location=Por favor escolha um sítio de onde realizar download dos filtros.
+subscription_notAdded_warning=Não adicionou subscrições de filtros. Sem subscrições é necessário adicionar filtros manualmente.
+subscription_notAdded_warning_addendum=Deseja continuar?
 subscription_invalid_location=A localização da lista de filtros não é um endereço ou nome de ficheiro válido.
-subscription_location_exists=Já subscreveu esta lista de filtros.
 synchronize_invalid_url=Falhou, endereço inválido
 synchronize_connection_error=Falhou, download inválido
 synchronize_invalid_data=Falhou, lista de filtros inválida
@@ -65,3 +64,7 @@
 type_label_dtd=DTD
 type_label_media=audio/ vídeo
 type_label_font=fonte
+fennec_status_enabled=O Adblock Plus está activo.
+fennec_status_disabled=O Adblock Plus está inactivo.
+fennec_status_enabled_site=O Adblock Plus está activo em ?1?.
+fennec_status_disabled_site=O Adblock Plus está inactivo em ?1?.

=== added file 'chrome/locale/pt-PT/meta.properties'
--- chrome/locale/pt-PT/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/pt-PT/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Raul Pimentel
+name=Adblock Plus
+description=Publicidade... já era!
+description.short=Aborrecido pelos anúncios? Incomodado pela monitorização? Incomodado por banners? Instale o Adblock Plus agora para recuperar o controle da internet e mudar a maneira como vê a web.\n\nResumo em http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=O Adblock Plus permite que recupere o controlo da internet e visualizar a web da maneira que quer. A extensão é suportada por mais de quarenta subscrições de filtro em dezenas de idiomas, que a configuram automaticamente para fins que vão desde a remoção de publicidade online até o bloqueio de todos os domínios conhecidos de malware. O Adblock Plus também permite que personalize os filtros com o auxílio de uma variedade de recursos úteis, incluindo uma opção de contexto para as imagens, um separador para Flash e objectos Java, e uma lista de itens bloqueáveis para remover scripts e folhas de estilo.

=== modified file 'chrome/locale/pt-PT/overlay.dtd'
--- chrome/locale/pt-PT/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-PT/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -8,6 +8,7 @@
 <!ENTITY context.image.label "Bloquear Imagem">
 <!ENTITY context.object.label "Bloquear Objecto">
 <!ENTITY context.frame.label "Bloquear Moldura">
+<!ENTITY context.media.label "Adblock Plus: Bloquear áudio/vídeo">
 <!ENTITY context.removeWhitelist.label "Adblock Plus: Reactivar nesta página">
 <!ENTITY sidebar.title "Elementos bloqueáveis na página actual">
 <!ENTITY settings.label "Preferências">
@@ -16,7 +17,7 @@
 <!ENTITY opensidebar.accesskey "B">
 <!ENTITY closesidebar.label "Fechar lista de elementos bloqueáveis">
 <!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Desactivar em --">
+<!ENTITY whitelist.site.label "Desactivar em ?1?">
 <!ENTITY whitelist.page.label "Desactivar apenas nesta página">
 <!ENTITY objecttab.title "Bloquear">
 <!ENTITY objecttab.tooltip "Clique aqui para bloquear este objecto com o Adblock Plus">

=== modified file 'chrome/locale/pt-PT/settings.dtd'
--- chrome/locale/pt-PT/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-PT/settings.dtd	2010-05-04 14:45:07 +0000
@@ -87,3 +87,4 @@
 <!ENTITY context.disable.label "Desactivar">
 <!ENTITY apply.label "Aplicar">
 <!ENTITY apply.accesskey "P">
+<!ENTITY fennec.subscription.label "Subscripção de filtro">

=== modified file 'chrome/locale/pt-PT/sidebar.dtd'
--- chrome/locale/pt-PT/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-PT/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "Bloquear este elemento">
 <!ENTITY context.editfilter.label "Editar filtro em efeito">
 <!ENTITY context.whitelist.label "Adicionar regra de excepção para este elemento">
-<!ENTITY context.disablefilter.label "Desactivar filtro --">
-<!ENTITY context.enablefilter.label "Reactivar filtro --">
-<!ENTITY context.disablefilteronsite.label "Desactivar este filtro em --">
+<!ENTITY context.disablefilter.label "Desactivar filtro ?1?">
+<!ENTITY context.enablefilter.label "Reactivar filtro ?1?">
+<!ENTITY context.disablefilteronsite.label "Desactivar este filtro em ?1?">
 <!ENTITY context.open.label "Abrir em Novo Separador">
 <!ENTITY context.flash.label "Evidenciar contornos do elemento">
 <!ENTITY context.copy.label "Copiar endereço do elemento">

=== removed file 'chrome/locale/pt-PT/subscription.dtd'
--- chrome/locale/pt-PT/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-PT/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Editar subscrição de filtros">
-<!ENTITY dialog.newtitle "Adicionar subscrição de filtro">
-<!ENTITY new.description "Por favor adicione endereço web ou de ficheiro contendo lista de filtros para o Adblock Plus.">
-<!ENTITY edit.description "A lista de filtros para esta subscrição será copiada da localização">
-<!ENTITY external.description "Isto é uma subscrição externa de filtros, a sua lista de filtros será actualizada pela extensão que criou esta subscrição.">
-<!ENTITY autodownload.description "Se escolher &apos;Actualização automática&apos; esta localização verificará diariamente por actualizações. Com esta opção desactivada pode actualizar manualmente a subscrição no menu de contexto.">
-<!ENTITY location.label "Localização de lista de filtros:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Título da subscrição:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Actualizar automaticamente">
-<!ENTITY autodownload.accesskey "Z">
-<!ENTITY enabled.label "Activar filtros">
-<!ENTITY enabled.accesskey "V">

=== added file 'chrome/locale/pt-PT/subscriptionSelection.dtd'
--- chrome/locale/pt-PT/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/pt-PT/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Adicionar subscrição de filtro Adblock Plus">
+<!ENTITY dialog.title.edit "Editar subscrição de filtros">
+<!ENTITY description.newInstall "O Adblock Plus é mais eficaz se adicionar subscrição de filtros. As subscrições de filtros são fornecidas gratuitamente por outros utilizadores do Adblock Plus. A subscrição mais acertada para o seu idioma já está seleccionada.">
+<!ENTITY adblock.warning "O Adblock Plus detectou que o Adblock ou uma versão anterior do Adblock Plus está instalada. Correr o Adblock e o Adblock Plus em simultâneo pode causar problemas e deve ser evitado. É recomendável desinstalar o Adblock.">
+<!ENTITY adblock.uninstall "Desinstalar o Adblock">
+<!ENTITY filterset.g.warning "Parece utilizar o Filterset.G. Esta lista de filtros raramente é actualizada actualmente e é uma causa comum de problemas com websites. É recomendável desinstalar o Filterset.G agora.">
+<!ENTITY filterset.g.moreinfo "Mais informação">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Desinstalar o Filterset.G">
+<!ENTITY subscriptionSelector.label "Por favor escolha uma subscrição de filtros da lista:">
+<!ENTITY viewList.label "Ver filtros">
+<!ENTITY visitHomepage.label "Visitar página">
+<!ENTITY addSubscription.label "Adicionar subscrição">
+<!ENTITY saveSubscription.label "Guardar subscrição">
+<!ENTITY other.label "Adicionar outra subscrição">
+<!ENTITY other.accesskey "O">
+<!ENTITY list.download.failed "Adblock Plus não conseguiu recuperar a lista de subscrições.">
+<!ENTITY list.download.retry "Tentar novamente">
+<!ENTITY list.download.website "Visitar website">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Por favor confirme que deseja adicionar esta subscrição de filtros. Pode alterar o título ou a localização da subscrição antes de adicioná-la.">
+<!ENTITY edit.description "Pode alterar o título ou localização da subscrição se necessário.">
+<!ENTITY external.description "Esta é uma subscrição de filtros externa; será actualizada pela extensão que criou a subscrição.">
+<!ENTITY title.label "Título da subscrição:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Localização de lista de filtros:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Actualizar automaticamente">
+<!ENTITY autodownload.accesskey "Z">
+<!ENTITY supplementMessage "Esta subscrição de filtros deve ser usada em conjunto com a subscrição &quot;?1?&quot; que não está a usar neste momento.">
+<!ENTITY addMain.label "Adicionar subscrição de filtros &quot;?1?&quot; também">
+<!ENTITY addMain.accesskey "s">

=== removed file 'chrome/locale/pt-PT/tip_subscriptions.dtd'
--- chrome/locale/pt-PT/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/pt-PT/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Bem-vindo ao Adblock Plus">
-<!ENTITY description.par1 "Obrigado por instalar o Adblock Plus. Esta extensão consegue eliminar 99&#37; da publicidade da web. No entanto, a eficácia depende de um bom conjunto de filtros. Pode fazê-lo você mesmo ou, simplesmente, subscrever uma lista de filtros mantida por terceiros. Ainda assim será possível adicionar os seus próprios filtros ou desactivar/ remover subscrições sempre que necessário.">
-<!ENTITY description.par2 "Pode escolher uma subscrição da lista de subscrições recomendadas (podem ser adicionadas mais subscrições nas Preferências do Adblock Plus mais tarde):">
-<!ENTITY note "Nota: Uma lista de filtros é, tipicamente, mais eficaz quando aplicada a páginas da região onde essa lista foi criada.">
-<!ENTITY adblock.warning "O Adblock Plus detectou que o Adblock ou uma versão anterior do Adblock Plus está instalada. Correr o Adblock e o Adblock Plus em simultâneo pode causar problemas e deve ser evitado. É recomendável desinstalar o Adblock.">
-<!ENTITY adblock.uninstall "Desinstalar o Adblock">
-<!ENTITY filterset.g.warning "Parece utilizar o Filterset.G. Esta lista de filtros raramente é actualizada actualmente e é uma causa comum de problemas com websites. É recomendável desinstalar o Filterset.G agora.">
-<!ENTITY filterset.g.moreinfo "Mais informação">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Desinstalar o Filterset.G">
-<!ENTITY homepage.label "Página">
-<!ENTITY subscribe.label "Subscrever">
-<!ENTITY subscribe.accesskey "S">
-<!ENTITY other.label "Adicionar outra subscrição">
-<!ENTITY other.accesskey "O">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Ver todas as subscrições">

=== added directory 'chrome/locale/ro'
=== removed directory 'chrome/locale/ro-RO'
=== removed file 'chrome/locale/ro-RO/about.dtd'
--- chrome/locale/ro-RO/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ro-RO/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Despre Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Versiunea">
-<!ENTITY description "Adblock Plus vă permite să decideţi ceea ce nu doriţi să vedeţi în internet. Nu mai trebuie să descărcaţi toate reclamele şi bannerele publicitare!">
-<!ENTITY homepage.label "Pagina de start Adblock Plus:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Autor:">
-<!ENTITY contributors.label "Contributori:">

=== removed file 'chrome/locale/ro-RO/composer.dtd'
--- chrome/locale/ro-RO/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ro-RO/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Adăugare regulă de filtrare Adblock Plus">
-<!ENTITY accept.label "Adaugă filtru">
-<!ENTITY advanced.label "Vizualizare avansată">
-<!ENTITY basic.label "Vizualizare simplă">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus este inactiv. Puteţi să adăugaţi filtre, însă ele vor fi utilizate doar după ce">
-<!ENTITY disabled.warning.link "activaţi Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Grupul de filtre în care filtrul trebuie adăugat - &quot;&#37;S&quot; - este inactiv. Filtrul nu va fi folosit până nu">
-<!ENTITY groupDisabled.warning.link "activaţi grupul de filtre">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Filtru nou:">
-<!ENTITY filter.accesskey "t">
-<!ENTITY preferences.label "Arată filtrele existente...">
-<!ENTITY preferences.accesskey "A">
-<!ENTITY type.filter.label "Filtru de blocare">
-<!ENTITY type.filter.accesskey "b">
-<!ENTITY type.whitelist.label "Regulă excepţii">
-<!ENTITY type.whitelist.accesskey "x">
-<!ENTITY pattern.label "Model de căutare pentru potrivire adrese">
-<!ENTITY pattern.explanation "Filtrul va fi aplicat doar adreselor care corespund modelului definit mai jos, în care simbolul * acţionează ca joker.">
-<!ENTITY regexp.warning "Modelul introdus va fi interpretată ca o expresie regulată, ceea ce poate cauza încetinirea navigării. Dacă nu doriţi să folosiţi expresii regulate, introduceţi * la sfârşitul modelului.">
-<!ENTITY shortpattern.warning "Modelul introdus este prea scurt pentru a fi optimizat, ceea ce poate cauza încetinirea navigării. Este recomandabil să introduceţi modele mai mai lungi.">
-<!ENTITY custom.pattern.label "model individual:">
-<!ENTITY custom.pattern.accesskey "i">
-<!ENTITY anchors.label "Foloseşte modelul introdus doar:">
-<!ENTITY anchor.start.label "la începutul adresei">
-<!ENTITY anchor.start.accesskey "n">
-<!ENTITY anchor.start.flexible.label "la începutul numelui de domeniu">
-<!ENTITY anchor.start.flexible.accesskey "n">
-<!ENTITY anchor.end.label "la sfârşitul adresei">
-<!ENTITY anchor.end.accesskey "f">
-<!ENTITY options.label "Opţiuni">
-<!ENTITY domainRestriction.label "Aplică doar domeniului">
-<!ENTITY domainRestriction.accesskey "d">
-<!ENTITY domainRestriction.help "Specificaţi unul sau ma multe domenii internet, separate de către simbolul &quot;|&quot;, pentru care filtrul este valid. Simbolul &quot;~&quot; înaintea numelui domeniului va face ca regula să NU se aplice pe domniul specificat.">
-<!ENTITY firstParty.label "Doar la pagina vizitată">
-<!ENTITY firstParty.accesskey "v">
-<!ENTITY thirdParty.label "La pagini partener (3rd party)">
-<!ENTITY thirdParty.accesskey "p">
-<!ENTITY matchCase.label "Potrivire majusculă">
-<!ENTITY matchCase.accesskey "m">
-<!ENTITY types.label "Valabil pentru:">
-<!ENTITY selectAllTypes.label "Toate tipurile">
-<!ENTITY unselectAllTypes.label "Nici unul">
-<!ENTITY collapse.label "Eliberează spaţiul blocat:">
-<!ENTITY collapse.accesskey "s">
-<!ENTITY collapse.default.yes.label "Foloseşte opţiunea implicită (da)">
-<!ENTITY collapse.default.no.label "Foloseşte opţiunea implicită (nu)">
-<!ENTITY collapse.yes.label "Da">
-<!ENTITY collapse.no.label "Nu">

=== removed file 'chrome/locale/ro-RO/global.properties'
--- chrome/locale/ro-RO/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/ro-RO/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Elimină publicitatea din paginile web.
-status_active_label=Adblock
-status_disabled_label=Dezactivat
-action0_tooltip=Clic pentru a afişa meniul contextual, clic-mijloc pentru a activa/dezactiva.
-action1_tooltip=Clic pentru a deschide lista elemetelor blocabile, clic-mijloc pentru a activa/dezactiva.
-action2_tooltip=Clic pentru a modifica opţiuni, clic-mijloc pentru a activa/dezactiva.
-action3_tooltip=Clic pentru a activa/dezactiva Adblock Plus.
-active_tooltip=Adblock Plus este activ.
-disabled_tooltip=Adblock Plus este inactiv.
-whitelisted_tooltip=Adblock Plus este activ, dar inactiv în pagina curentă.
-blocked_count_tooltip=-- din --
-no_blocking_suggestions=În pagină nu se găseşte nici un element care să poată fi blocat
-whitelisted_page=Adblock Plus este inactiv pentru pagina curentă
-whitelist_description=Reguli excepţii
-filterlist_description=Filtre
-invalid_description=Filtre invalide
-elemhide_description=Reguli ascundere element
-subscription_description=Subscriere filtre:
-subscription_wrong_version=Pentru a funcţiona corespunzător, unele filtre necesită Adblock Plus.
-subscription_source=Sursa:
-subscription_status=Stare:
-subscription_status_autodownload=Actualizare automată
-subscription_status_manualdownload=Actualizare manuală
-subscription_status_externaldownload=Actualizare externă (altă extensie)
-subscription_status_lastdownload=Ultima descărcare:
-subscription_status_lastdownload_inprogress=Decărcare...
-subscription_status_lastdownload_unknown=Necunoscut
-remove_subscription_warning=Sigur doriţi să îndepărtaţi această subscriere?
-import_filters_wrong_version=Avertisment: pentru a funcţiona corespunzător, unele filtre necesită Adblock Plus. Înainte de a importa lista, este recomandat să actualizaţi extensia.
-import_filters_warning=Doriţi să suprascrieţi filtrele existente sau să le adăugaţi la sfârşitul listei?
-import_filters_title=Import filtre
-export_filters_title=Export filtre
-invalid_filters_file=Fişierul cu lista de filtre este invalid.
-filters_write_error=Eroare la scrierea filtrelor în fişier. Asiguraţi-vă fişierul nu este protejat la scriere sau blocat de alt program.
-clearall_warning=Sigur doriţi să stergeţi toate filtrele din listă?
-resethitcounts_warning=Sigur doriţi să reiniţializaţi contorul tuturor filtrelor? Această operaţie nu este reversibilă.
-resethitcounts_selected_warning=Sigur doriţi să reiniţializaţi contorul filtrului ales? Această operaţie nu este reversibilă.
-filter_regexp_tooltip=Acest filtru este bazat pe expresii regulate sau este prea scurt pentru a fi optimizat. Prea multe astfel de filtre pot duce la încetinirea navigării.
-filter_elemhide_duplicate_id=Se poate specifica doar un singur identificator de element pentru ascundere.
-filter_elemhide_nocriteria=Nu s-a specificat nici un criteriu pentru a identifica elemntul pentru ascundere.
-subscription_no_location=Introduceţi locaţia pentru descărcat filtre
-subscription_invalid_location=Locaţia pentru filtre nu este validă
-subscription_location_exists=Există deja un abonament la această listă de filtre.
-synchronize_invalid_url=Eşuat, adresa nu este validă
-synchronize_connection_error=Eşuat, descărcare nereuşită
-synchronize_invalid_data=Eşuat, lista nu este validă
-synchronize_checksum_mismatch=Eşuat, suma de control nu se potriveşte.
-synchronize_ok=Succes
-overwrite=Suprascrie
-append=Adaugă
-new_filter_group_title=Filtru nou
-type_label_other=alt element
-type_label_script=script
-type_label_image=imagine
-type_label_stylesheet=foaie de stiluri
-type_label_object=obiect
-type_label_subdocument=cadru (frame)
-type_label_document=document
-type_label_background=fundal
-type_label_elemhide=ascuns
-type_label_xbl=legare XBL
-type_label_ping=ping legătură
-type_label_xmlhttprequest=cerere XML
-type_label_object_subrequest=subcerere obiect
-type_label_dtd=DTD
-type_label_media=audio/video
-type_label_font=font

=== removed file 'chrome/locale/ro-RO/overlay.dtd'
--- chrome/locale/ro-RO/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ro-RO/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Stare:">
-<!ENTITY blocked.tooltip "Elemente blocate în pagină:">
-<!ENTITY filters.tooltip "Cele mai active filtre:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "A">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: elemente blocabile">
-<!ENTITY context.image.label "Adblock Plus: blochează imagine">
-<!ENTITY context.object.label "Adblock Plus: blochează obiect">
-<!ENTITY context.frame.label "Adblock Plus: blochează frame">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: reactivează în pagina curentă">
-<!ENTITY sidebar.title "Adblock Plus: elemente blocabile în pagină">
-<!ENTITY settings.label "Particularizare">
-<!ENTITY settings.accesskey "P">
-<!ENTITY opensidebar.label "Deschide lista elementelor blocabile">
-<!ENTITY opensidebar.accesskey "l">
-<!ENTITY closesidebar.label "Închide lista elementelor blocabile">
-<!ENTITY closesidebar.accesskey "l">
-<!ENTITY whitelist.site.label "Dezactivează Adblock Plus pe --">
-<!ENTITY whitelist.page.label "Dezactivează Adblock Plus doar pe pagina curentă">
-<!ENTITY objecttab.title "Blochează">
-<!ENTITY objecttab.tooltip "Click aici pentru a bloca obiectul utilizând Adblock Plus">

=== removed file 'chrome/locale/ro-RO/settings.dtd'
--- chrome/locale/ro-RO/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ro-RO/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Particularizare Adblock Plus">
-<!ENTITY filters.label "Filtre">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Adaugă filtru">
-<!ENTITY add.accesskey "d">
-<!ENTITY addsubscription.label "Adaugă abonament filtre">
-<!ENTITY addsubscription.accesskey "b">
-<!ENTITY synchsubscriptions.label "Actualizează toate abonamentele">
-<!ENTITY synchsubscriptions.accesskey "c">
-<!ENTITY import.label "Importă filtre">
-<!ENTITY import.accesskey "m">
-<!ENTITY export.label "Exportă filtre">
-<!ENTITY export.accesskey "x">
-<!ENTITY clearall.label "Şterge toate filtrele">
-<!ENTITY clearall.accesskey "t">
-<!ENTITY resethitcounts.label "Reiniţializează contor">
-<!ENTITY resethitcounts.accesskey "R">
-<!ENTITY edit.label "Editare">
-<!ENTITY edit.accesskey "E">
-<!ENTITY cut.label "Taie">
-<!ENTITY cut.accesskey "T">
-<!ENTITY copy.label "Copiază">
-<!ENTITY copy.accesskey "C">
-<!ENTITY paste.label "Lipeşte">
-<!ENTITY paste.accesskey "L">
-<!ENTITY remove.label "Şterge">
-<!ENTITY remove.accesskey "g">
-<!ENTITY menu.find.label "Caută">
-<!ENTITY menu.find.accesskey "u">
-<!ENTITY menu.findagain.label "Caută următorul">
-<!ENTITY menu.findagain.accesskey "m">
-<!ENTITY view.label "Vizualizare">
-<!ENTITY view.accesskey "V">
-<!ENTITY sort.label "Ordonare">
-<!ENTITY sort.accesskey "O">
-<!ENTITY sort.none.label "Neordonat">
-<!ENTITY sort.none.accesskey "N">
-<!ENTITY sort.ascending.label "Crescător (A&gt;Z)">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Descrescător (Z&gt;A)">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Opţiuni">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Activează Adblock Plus">
-<!ENTITY enable.accesskey "A">
-<!ENTITY showintoolbar.label "Arată în bara de unelte">
-<!ENTITY showintoolbar.accesskey "u">
-<!ENTITY showinstatusbar.label "Arată în bara de stare">
-<!ENTITY showinstatusbar.accesskey "s">
-<!ENTITY objecttabs.label "Arată panouri lângă Flash şi Java">
-<!ENTITY objecttabs.accesskey "p">
-<!ENTITY collapse.label "Ascunde elementele blocate">
-<!ENTITY collapse.accesskey "c">
-<!ENTITY help.label "Ajutor">
-<!ENTITY help.accesskey "A">
-<!ENTITY gettingStarted.label "Ghidul începătorului">
-<!ENTITY gettingStarted.accesskey "G">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Întrebări frecvente (FAQ)">
-<!ENTITY faq.accesskey "Q">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Sfaturi scriere filtre Adblock Plus">
-<!ENTITY filterdoc.accesskey "f">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Despre Adblock Plus">
-<!ENTITY about.accesskey "D">
-<!ENTITY description "Adăugaţi adresele pe care doriţi să le blocaţi; puteţi alege din lista derulantă. Pentru a crea filtre generice, folosiţi caracterul * ca joker. Utilizatorii avansaţi pot folosi expresii, ca de exemplu /banner\d+\.gif$/.">
-<!ENTITY filter.column "Regulă de filtrare">
-<!ENTITY filter.accesskey "R">
-<!ENTITY slow.column "Filtre lente">
-<!ENTITY slow.accesskey "l">
-<!ENTITY enabled.column "Stare">
-<!ENTITY enabled.accesskey "S">
-<!ENTITY hitcount.column "Contor">
-<!ENTITY hitcount.accesskey "C">
-<!ENTITY lasthit.column "Ultima aplicare">
-<!ENTITY lasthit.accesskey "U">
-<!ENTITY context.edit.label "Modifică filtrul">
-<!ENTITY context.resethitcount.label "Reiniţializează contorul filtrului">
-<!ENTITY context.synchsubscription.label "Actualizează abonament">
-<!ENTITY context.editsubscription.label "Modifică abonament">
-<!ENTITY context.moveup.label "Mută în sus">
-<!ENTITY context.movedown.label "Mută în jos">
-<!ENTITY context.movegroupup.label "Mută grupul în sus">
-<!ENTITY context.movegroupdown.label "Mută grupul în jos">
-<!ENTITY context.enable.label "Activează">
-<!ENTITY context.disable.label "Dezactivează">
-<!ENTITY apply.label "Aplică">
-<!ENTITY apply.accesskey "p">

=== removed file 'chrome/locale/ro-RO/sidebar.dtd'
--- chrome/locale/ro-RO/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ro-RO/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Lista elementelor blocabile în pagină  (desprinsă)">
-<!ENTITY detach.label "Desprinde">
-<!ENTITY reattach.label "Prinde la loc">
-<!ENTITY search.label "Caută:">
-<!ENTITY search.accesskey "C">
-<!ENTITY type.label "Tip">
-<!ENTITY address.label "Adresă">
-<!ENTITY filter.label "Filtru">
-<!ENTITY state.label "Stare">
-<!ENTITY size.label "Mărime">
-<!ENTITY docDomain.label "Sursă document">
-<!ENTITY noitems.label "Nici un element blocabil">
-<!ENTITY whitelisted.label "Pagini sigure">
-<!ENTITY tooltip.address.label "Adresă:">
-<!ENTITY tooltip.type.label "Tip:">
-<!ENTITY tooltip.type.blocked "(blocat)">
-<!ENTITY tooltip.type.whitelisted "(permis)">
-<!ENTITY tooltip.size.label "Mărime">
-<!ENTITY tooltip.docDomain.label "Sursă document:">
-<!ENTITY tooltip.filter.label "Filtru în acţiune:">
-<!ENTITY tooltip.filterSource.label "Sursă filtru:">
-<!ENTITY context.block.label "Blochează element">
-<!ENTITY context.editfilter.label "Modifică filtrul activ">
-<!ENTITY context.whitelist.label "Adaugă regulă excepţie pentru element">
-<!ENTITY context.disablefilter.label "Dezactivează filtru --">
-<!ENTITY context.enablefilter.label "Reactivează filtru --">
-<!ENTITY context.disablefilteronsite.label "Dezactivează acest filtru pe --">
-<!ENTITY context.open.label "Deschide în filă nouă">
-<!ENTITY context.flash.label "Evidenţiază marginile elementelor">
-<!ENTITY context.copy.label "Copiază adresa elementului">
-<!ENTITY context.copyFilter.label "Copiază filtru">
-<!ENTITY context.selectAll.label "Selectează tot">

=== removed file 'chrome/locale/ro-RO/subscription.dtd'
--- chrome/locale/ro-RO/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ro-RO/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Editare abonament filtre">
-<!ENTITY dialog.newtitle "Adăugare abonament filtre">
-<!ENTITY new.description "Introduceţi adresa web sau calea către lista cu filtre Adblock Plus.">
-<!ENTITY edit.description "Lista de filtre va fi descărcată de la locaţia de mai sus.">
-<!ENTITY external.description "Lista de filtre va fi actualizată de către extensia care a creat acest abonament.">
-<!ENTITY autodownload.description "Dacă alegeţi Actualizare automată, lista de filtre va fi verficată zilnic. Dacă nu, atunci încă mai puteţi actualiza lista manual, folosind comanda Actualizare abonament din meniul contextual.">
-<!ENTITY location.label "Locaţia listei de filtre:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Titlul abonamentului:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Actualizare automată">
-<!ENTITY autodownload.accesskey "c">
-<!ENTITY enabled.label "Activează filtre">
-<!ENTITY enabled.accesskey "A">

=== removed file 'chrome/locale/ro-RO/tip_subscriptions.dtd'
--- chrome/locale/ro-RO/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ro-RO/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Adăugare abonamente pentru filtre Adblock Plus">
-<!ENTITY description.par1 "Mulţumim pentru instalarea extensiei Adblock Plus, care poate elimina 99&#37; din publicitatea din paginile web. O filtrare eficientă necesită un set bun de filtre, pe care îl puteţi defini singur. Alternativ, vă puteţi abona la alte filtre, menţinute de alţi utilizatori (subscripţii filtre). În acest caz, încă mai puteţi crea filtrele dvs, iar abonamentele se pot dezactiva sau îndepărta în orice moment.">
-<!ENTITY description.par2 "Puteţi alege un abonament din lista de recomandări de mai jos (mai târziu, puteţi adăuga alte liste, deşi, de regulă, acest lucru nu este necesar):">
-<!ENTITY note "Notă: un set de filtre este de regulă efectiv atunci când este aplicat paginilor web din regiunea pentru care a fost creat setul.">
-<!ENTITY adblock.warning "Se pare că Adblock sau o versiune mai veche Adblock Plus este instalată, ceea ce poate cauza probleme. Este recomandabil să dezinstalaţi Adblock.">
-<!ENTITY adblock.uninstall "Dezinstaleză Adblock">
-<!ENTITY filterset.g.warning "Se pare că Filterset.G este instalat, ceea ce poate cauza probleme, dearece filtrele sunt învechite şi în multe cazuri greşite. Este recomandabil să dezinstalaţi Filterset.G acum.">
-<!ENTITY filterset.g.moreinfo "Informţii suplimentare">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Dezinstalează Filterset.G">
-<!ENTITY homepage.label "Pagina de start">
-<!ENTITY subscribe.label "Abonează">
-<!ENTITY subscribe.accesskey "A">
-<!ENTITY other.label "Adaugă alt abonament">
-<!ENTITY other.accesskey "t">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Arată toate abonamentele">

=== added file 'chrome/locale/ro/about.dtd'
--- chrome/locale/ro/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ro/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,8 @@
+<!ENTITY dialog.title "Despre Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versiunea">
+<!ENTITY description "Adblock Plus vă permite să decideţi ceea ce nu doriţi să vedeţi în internet. Nu mai trebuie să descărcaţi toate reclamele şi bannerele publicitare!">
+<!ENTITY homepage.label "Pagina de start Adblock Plus:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Autor:">
+<!ENTITY contributors.label "Contributori:">

=== added file 'chrome/locale/ro/composer.dtd'
--- chrome/locale/ro/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ro/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Adăugare regulă de filtrare Adblock Plus">
+<!ENTITY accept.label "Adaugă filtru">
+<!ENTITY advanced.label "Vizualizare avansată">
+<!ENTITY basic.label "Vizualizare simplă">
+<!ENTITY disabled.warning "Adblock Plus este inactiv. Puteţi să adăugaţi filtre, însă ele vor fi utilizate doar după ce [link]activaţi Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Grupul de filtre în care filtrul trebuie adăugat - &quot;?1?&quot; - este inactiv. Filtrul nu va fi folosit până nu [link]activaţi grupul de filtre[/link].">
+<!ENTITY filter.label "Filtru nou:">
+<!ENTITY filter.accesskey "t">
+<!ENTITY preferences.label "Arată filtrele existente...">
+<!ENTITY preferences.accesskey "A">
+<!ENTITY type.filter.label "Filtru de blocare">
+<!ENTITY type.filter.accesskey "b">
+<!ENTITY type.whitelist.label "Regulă excepţii">
+<!ENTITY type.whitelist.accesskey "x">
+<!ENTITY pattern.label "Model de căutare pentru potrivire adrese">
+<!ENTITY pattern.explanation "Filtrul va fi aplicat doar adreselor care corespund modelului definit mai jos, în care simbolul * acţionează ca joker.">
+<!ENTITY regexp.warning "Modelul introdus va fi interpretată ca o expresie regulată, ceea ce poate cauza încetinirea navigării. Dacă nu doriţi să folosiţi expresii regulate, introduceţi * la sfârşitul modelului.">
+<!ENTITY shortpattern.warning "Modelul introdus este prea scurt pentru a fi optimizat, ceea ce poate cauza încetinirea navigării. Este recomandabil să introduceţi modele mai mai lungi.">
+<!ENTITY custom.pattern.label "model individual:">
+<!ENTITY custom.pattern.accesskey "i">
+<!ENTITY anchors.label "Foloseşte modelul introdus doar:">
+<!ENTITY anchor.start.label "la începutul adresei">
+<!ENTITY anchor.start.accesskey "n">
+<!ENTITY anchor.start.flexible.label "la începutul numelui de domeniu">
+<!ENTITY anchor.start.flexible.accesskey "n">
+<!ENTITY anchor.end.label "la sfârşitul adresei">
+<!ENTITY anchor.end.accesskey "f">
+<!ENTITY options.label "Opţiuni">
+<!ENTITY domainRestriction.label "Aplică doar domeniului">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "Specificaţi unul sau ma multe domenii internet, separate de către simbolul &quot;|&quot;, pentru care filtrul este valid. Simbolul &quot;~&quot; înaintea numelui domeniului va face ca regula să NU se aplice pe domniul specificat.">
+<!ENTITY firstParty.label "Doar la pagina vizitată">
+<!ENTITY firstParty.accesskey "v">
+<!ENTITY thirdParty.label "La pagini partener (3rd party)">
+<!ENTITY thirdParty.accesskey "p">
+<!ENTITY matchCase.label "Potrivire majusculă">
+<!ENTITY matchCase.accesskey "m">
+<!ENTITY types.label "Valabil pentru:">
+<!ENTITY selectAllTypes.label "Toate tipurile">
+<!ENTITY unselectAllTypes.label "Nici unul">
+<!ENTITY collapse.label "Eliberează spaţiul blocat:">
+<!ENTITY collapse.accesskey "s">
+<!ENTITY collapse.default.yes.label "Foloseşte opţiunea implicită (da)">
+<!ENTITY collapse.default.no.label "Foloseşte opţiunea implicită (nu)">
+<!ENTITY collapse.yes.label "Da">
+<!ENTITY collapse.no.label "Nu">

=== added file 'chrome/locale/ro/global.properties'
--- chrome/locale/ro/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ro/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,59 @@
+action0_tooltip=Clic pentru a afişa meniul contextual, clic-mijloc pentru a activa/dezactiva.
+action1_tooltip=Clic pentru a deschide lista elemetelor blocabile, clic-mijloc pentru a activa/dezactiva.
+action2_tooltip=Clic pentru a modifica opţiuni, clic-mijloc pentru a activa/dezactiva.
+action3_tooltip=Clic pentru a activa/dezactiva Adblock Plus.
+disabled_tooltip=Adblock Plus este inactiv.
+whitelisted_tooltip=Adblock Plus este activ, dar inactiv în pagina curentă.
+blocked_count_tooltip=?1? din ?2?
+no_blocking_suggestions=În pagină nu se găseşte nici un element care să poată fi blocat
+whitelisted_page=Adblock Plus este inactiv pentru pagina curentă
+whitelist_description=Reguli excepţii
+filterlist_description=Filtre
+invalid_description=Filtre invalide
+elemhide_description=Reguli ascundere element
+subscription_description=Subscriere filtre:
+subscription_source=Sursa:
+subscription_status=Stare:
+subscription_status_autodownload=Actualizare automată
+subscription_status_manualdownload=Actualizare manuală
+subscription_status_externaldownload=Actualizare externă (altă extensie)
+subscription_status_lastdownload=Ultima descărcare:
+subscription_status_lastdownload_inprogress=Decărcare...
+subscription_status_lastdownload_unknown=Necunoscut
+remove_subscription_warning=Sigur doriţi să îndepărtaţi această subscriere?
+import_filters_warning=Doriţi să suprascrieţi filtrele existente sau să le adăugaţi la sfârşitul listei?
+import_filters_title=Import filtre
+export_filters_title=Export filtre
+invalid_filters_file=Fişierul cu lista de filtre este invalid.
+filters_write_error=Eroare la scrierea filtrelor în fişier. Asiguraţi-vă fişierul nu este protejat la scriere sau blocat de alt program.
+clearall_warning=Sigur doriţi să stergeţi toate filtrele din listă?
+resethitcounts_warning=Sigur doriţi să reiniţializaţi contorul tuturor filtrelor? Această operaţie nu este reversibilă.
+resethitcounts_selected_warning=Sigur doriţi să reiniţializaţi contorul filtrului ales? Această operaţie nu este reversibilă.
+filter_regexp_tooltip=Acest filtru este bazat pe expresii regulate sau este prea scurt pentru a fi optimizat. Prea multe astfel de filtre pot duce la încetinirea navigării.
+filter_elemhide_duplicate_id=Se poate specifica doar un singur identificator de element pentru ascundere.
+filter_elemhide_nocriteria=Nu s-a specificat nici un criteriu pentru a identifica elemntul pentru ascundere.
+subscription_invalid_location=Locaţia pentru filtre nu este validă
+synchronize_invalid_url=Eşuat, adresa nu este validă
+synchronize_connection_error=Eşuat, descărcare nereuşită
+synchronize_invalid_data=Eşuat, lista nu este validă
+synchronize_checksum_mismatch=Eşuat, suma de control nu se potriveşte.
+synchronize_ok=Succes
+overwrite=Suprascrie
+append=Adaugă
+new_filter_group_title=Filtru nou
+type_label_other=alt element
+type_label_script=script
+type_label_image=imagine
+type_label_stylesheet=foaie de stiluri
+type_label_object=obiect
+type_label_subdocument=cadru (frame)
+type_label_document=document
+type_label_background=fundal
+type_label_elemhide=ascuns
+type_label_xbl=legare XBL
+type_label_ping=ping legătură
+type_label_xmlhttprequest=cerere XML
+type_label_object_subrequest=subcerere obiect
+type_label_dtd=DTD
+type_label_media=audio/video
+type_label_font=font

=== added file 'chrome/locale/ro/meta.properties'
--- chrome/locale/ro/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ro/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,2 @@
+name=Adblock Plus
+description=Elimină publicitatea din paginile web.

=== added file 'chrome/locale/ro/overlay.dtd'
--- chrome/locale/ro/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ro/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,22 @@
+<!ENTITY status.tooltip "Stare:">
+<!ENTITY blocked.tooltip "Elemente blocate în pagină:">
+<!ENTITY filters.tooltip "Cele mai active filtre:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "A">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: elemente blocabile">
+<!ENTITY context.image.label "Adblock Plus: blochează imagine">
+<!ENTITY context.object.label "Adblock Plus: blochează obiect">
+<!ENTITY context.frame.label "Adblock Plus: blochează frame">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: reactivează în pagina curentă">
+<!ENTITY sidebar.title "Adblock Plus: elemente blocabile în pagină">
+<!ENTITY settings.label "Particularizare">
+<!ENTITY settings.accesskey "P">
+<!ENTITY opensidebar.label "Deschide lista elementelor blocabile">
+<!ENTITY opensidebar.accesskey "l">
+<!ENTITY closesidebar.label "Închide lista elementelor blocabile">
+<!ENTITY closesidebar.accesskey "l">
+<!ENTITY whitelist.site.label "Dezactivează Adblock Plus pe ?1?">
+<!ENTITY whitelist.page.label "Dezactivează Adblock Plus doar pe pagina curentă">
+<!ENTITY objecttab.title "Blochează">
+<!ENTITY objecttab.tooltip "Click aici pentru a bloca obiectul utilizând Adblock Plus">

=== added file 'chrome/locale/ro/settings.dtd'
--- chrome/locale/ro/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ro/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,89 @@
+<!ENTITY dialog.title "Particularizare Adblock Plus">
+<!ENTITY filters.label "Filtre">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Adaugă filtru">
+<!ENTITY add.accesskey "d">
+<!ENTITY addsubscription.label "Adaugă abonament filtre">
+<!ENTITY addsubscription.accesskey "b">
+<!ENTITY synchsubscriptions.label "Actualizează toate abonamentele">
+<!ENTITY synchsubscriptions.accesskey "c">
+<!ENTITY import.label "Importă filtre">
+<!ENTITY import.accesskey "m">
+<!ENTITY export.label "Exportă filtre">
+<!ENTITY export.accesskey "x">
+<!ENTITY clearall.label "Şterge toate filtrele">
+<!ENTITY clearall.accesskey "t">
+<!ENTITY resethitcounts.label "Reiniţializează contor">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "Editare">
+<!ENTITY edit.accesskey "E">
+<!ENTITY cut.label "Taie">
+<!ENTITY cut.accesskey "T">
+<!ENTITY copy.label "Copiază">
+<!ENTITY copy.accesskey "C">
+<!ENTITY paste.label "Lipeşte">
+<!ENTITY paste.accesskey "L">
+<!ENTITY remove.label "Şterge">
+<!ENTITY remove.accesskey "g">
+<!ENTITY menu.find.label "Caută">
+<!ENTITY menu.find.accesskey "u">
+<!ENTITY menu.findagain.label "Caută următorul">
+<!ENTITY menu.findagain.accesskey "m">
+<!ENTITY view.label "Vizualizare">
+<!ENTITY view.accesskey "V">
+<!ENTITY sort.label "Ordonare">
+<!ENTITY sort.accesskey "O">
+<!ENTITY sort.none.label "Neordonat">
+<!ENTITY sort.none.accesskey "N">
+<!ENTITY sort.ascending.label "Crescător (A&gt;Z)">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Descrescător (Z&gt;A)">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Opţiuni">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Activează Adblock Plus">
+<!ENTITY enable.accesskey "A">
+<!ENTITY showintoolbar.label "Arată în bara de unelte">
+<!ENTITY showintoolbar.accesskey "u">
+<!ENTITY showinstatusbar.label "Arată în bara de stare">
+<!ENTITY showinstatusbar.accesskey "s">
+<!ENTITY objecttabs.label "Arată panouri lângă Flash şi Java">
+<!ENTITY objecttabs.accesskey "p">
+<!ENTITY collapse.label "Ascunde elementele blocate">
+<!ENTITY collapse.accesskey "c">
+<!ENTITY help.label "Ajutor">
+<!ENTITY help.accesskey "A">
+<!ENTITY gettingStarted.label "Ghidul începătorului">
+<!ENTITY gettingStarted.accesskey "G">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Întrebări frecvente (FAQ)">
+<!ENTITY faq.accesskey "Q">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Sfaturi scriere filtre Adblock Plus">
+<!ENTITY filterdoc.accesskey "f">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Despre Adblock Plus">
+<!ENTITY about.accesskey "D">
+<!ENTITY description "Adăugaţi adresele pe care doriţi să le blocaţi; puteţi alege din lista derulantă. Pentru a crea filtre generice, folosiţi caracterul * ca joker. Utilizatorii avansaţi pot folosi expresii, ca de exemplu /banner\d+\.gif$/.">
+<!ENTITY filter.column "Regulă de filtrare">
+<!ENTITY filter.accesskey "R">
+<!ENTITY slow.column "Filtre lente">
+<!ENTITY slow.accesskey "l">
+<!ENTITY enabled.column "Stare">
+<!ENTITY enabled.accesskey "S">
+<!ENTITY hitcount.column "Contor">
+<!ENTITY hitcount.accesskey "C">
+<!ENTITY lasthit.column "Ultima aplicare">
+<!ENTITY lasthit.accesskey "U">
+<!ENTITY context.edit.label "Modifică filtrul">
+<!ENTITY context.resethitcount.label "Reiniţializează contorul filtrului">
+<!ENTITY context.synchsubscription.label "Actualizează abonament">
+<!ENTITY context.editsubscription.label "Modifică abonament">
+<!ENTITY context.moveup.label "Mută în sus">
+<!ENTITY context.movedown.label "Mută în jos">
+<!ENTITY context.movegroupup.label "Mută grupul în sus">
+<!ENTITY context.movegroupdown.label "Mută grupul în jos">
+<!ENTITY context.enable.label "Activează">
+<!ENTITY context.disable.label "Dezactivează">
+<!ENTITY apply.label "Aplică">
+<!ENTITY apply.accesskey "p">

=== added file 'chrome/locale/ro/sidebar.dtd'
--- chrome/locale/ro/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ro/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Lista elementelor blocabile în pagină  (desprinsă)">
+<!ENTITY detach.label "Desprinde">
+<!ENTITY reattach.label "Prinde la loc">
+<!ENTITY search.label "Caută:">
+<!ENTITY search.accesskey "C">
+<!ENTITY type.label "Tip">
+<!ENTITY address.label "Adresă">
+<!ENTITY filter.label "Filtru">
+<!ENTITY state.label "Stare">
+<!ENTITY size.label "Mărime">
+<!ENTITY docDomain.label "Sursă document">
+<!ENTITY noitems.label "Nici un element blocabil">
+<!ENTITY whitelisted.label "Pagini sigure">
+<!ENTITY tooltip.address.label "Adresă:">
+<!ENTITY tooltip.type.label "Tip:">
+<!ENTITY tooltip.type.blocked "(blocat)">
+<!ENTITY tooltip.type.whitelisted "(permis)">
+<!ENTITY tooltip.size.label "Mărime">
+<!ENTITY tooltip.docDomain.label "Sursă document:">
+<!ENTITY tooltip.filter.label "Filtru în acţiune:">
+<!ENTITY tooltip.filterSource.label "Sursă filtru:">
+<!ENTITY context.block.label "Blochează element">
+<!ENTITY context.editfilter.label "Modifică filtrul activ">
+<!ENTITY context.whitelist.label "Adaugă regulă excepţie pentru element">
+<!ENTITY context.disablefilter.label "Dezactivează filtru ?1?">
+<!ENTITY context.enablefilter.label "Reactivează filtru ?1?">
+<!ENTITY context.disablefilteronsite.label "Dezactivează acest filtru pe ?1?">
+<!ENTITY context.open.label "Deschide în filă nouă">
+<!ENTITY context.flash.label "Evidenţiază marginile elementelor">
+<!ENTITY context.copy.label "Copiază adresa elementului">
+<!ENTITY context.copyFilter.label "Copiază filtru">
+<!ENTITY context.selectAll.label "Selectează tot">

=== added file 'chrome/locale/ro/subscriptionSelection.dtd'
--- chrome/locale/ro/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ro/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,16 @@
+<!ENTITY dialog.title "Adăugare abonamente pentru filtre Adblock Plus">
+<!ENTITY dialog.title.edit "Editare abonament filtre">
+<!ENTITY adblock.warning "Se pare că Adblock sau o versiune mai veche Adblock Plus este instalată, ceea ce poate cauza probleme. Este recomandabil să dezinstalaţi Adblock.">
+<!ENTITY adblock.uninstall "Dezinstaleză Adblock">
+<!ENTITY filterset.g.warning "Se pare că Filterset.G este instalat, ceea ce poate cauza probleme, dearece filtrele sunt învechite şi în multe cazuri greşite. Este recomandabil să dezinstalaţi Filterset.G acum.">
+<!ENTITY filterset.g.moreinfo "Informţii suplimentare">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Dezinstalează Filterset.G">
+<!ENTITY other.label "Adaugă alt abonament">
+<!ENTITY other.accesskey "t">
+<!ENTITY title.label "Titlul abonamentului:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Locaţia listei de filtre:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Actualizare automată">
+<!ENTITY autodownload.accesskey "c">

=== added directory 'chrome/locale/ru'
=== removed directory 'chrome/locale/ru-RU'
=== removed file 'chrome/locale/ru-RU/about.dtd'
--- chrome/locale/ru-RU/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ru-RU/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title       "О Adblock Plus">
-
-<!ENTITY caption.title      "Adblock Plus">
-<!ENTITY version.title      "Версия">
-<!ENTITY description        "
-  С Adblock Plus Вы можете сами решать, что Вы хотите видеть в интернете,
-  а что - нет. Не нужно больше тратить свое время на скачивание рекламных
-  баннеров, если Вы не хотите их видеть - Adblock Plus Вам поможет!
-">
-
-<!ENTITY homepage.label     "Домашняя страница проекта:">
-<!ENTITY homepage.url       "http://adblockplus.org/">
-<!ENTITY author.label       "Разработчик:">
-<!ENTITY contributors.label "Другие участники:">

=== removed file 'chrome/locale/ru-RU/composer.dtd'
--- chrome/locale/ru-RU/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ru-RU/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,54 +0,0 @@
-<!ENTITY dialog.title             "Составление фильтра для Adblock Plus">
-<!ENTITY accept.label             "Добавить фильтр">
-<!ENTITY advanced.label           "Расширенный вид">
-<!ENTITY basic.label              "Стандартный вид">
-
-<!ENTITY disabled.warning.beforeLink  "Adblock Plus сейчас отключен. Вы можете добавить этот фильтр, но чтобы он применился нужно ">
-<!ENTITY disabled.warning.link    "включить Adblock Plus">
-<!ENTITY disabled.warning.afterLink   ".">
-
-<!ENTITY groupDisabled.warning.beforeLink  "Группа фильтров &quot;&#x25;S&quot;, в которую этот фильтр должен быть добавлен, сейчас отключена. Вы можете добавить этот фильтр, но чтобы он применился нужно ">
-<!ENTITY groupDisabled.warning.link        "включить эту группу фильтров">
-<!ENTITY groupDisabled.warning.afterLink   ".">
-
-<!ENTITY filter.label             "Новый фильтр:">
-<!ENTITY filter.accesskey         "ф">
-<!ENTITY preferences.label        "Показать существующие фильтры...">
-<!ENTITY preferences.accesskey    "щ">
-<!ENTITY type.filter.label        "Правило блокирования">
-<!ENTITY type.filter.accesskey    "б">
-<!ENTITY type.whitelist.label     "Исключение">
-<!ENTITY type.whitelist.accesskey "к">
-<!ENTITY pattern.label            "Шаблон">
-<!ENTITY pattern.explanation      "Шаблоном может быть любая часть адреса, причем звездочка (*) заменяет любое количество символов. Фильтр будет применен только к тем адресам, которые соответствуют шаблону.">
-<!ENTITY regexp.warning           "Шаблон, который Вы ввели, будет интерпретирован как регулярное выражение. Большое количество регулярных выражений может отрицательно сказаться на быстродействии Вашего браузера. Если Вы не собирались использовать регулярные выражения, просто добавьте звездочку в конце шаблона.">
-<!ENTITY shortpattern.warning     "Шаблон, который Вы ввели, слишком короткий и не будет оптимизирован. Большое количество таких шаблонов может отрицательно сказаться на быстродействии Вашего браузера. Рекомендуется по возможности использовать более длинный шаблон.">
-<!ENTITY custom.pattern.label     "Собственный:">
-<!ENTITY custom.pattern.accesskey "С">
-<!ENTITY anchors.label            "Принимать шаблон только:">
-<!ENTITY anchor.start.label       "в начале адреса">
-<!ENTITY anchor.start.accesskey   "ч">
-<!ENTITY anchor.start.flexible.label      "в начале доменного имени">
-<!ENTITY anchor.start.flexible.accesskey  "ч">
-<!ENTITY anchor.end.label         "в конце адреса">
-<!ENTITY anchor.end.accesskey     "ц">
-<!ENTITY options.label            "Дополнительные настройки">
-<!ENTITY domainRestriction.label      "Ограничить доменом:">
-<!ENTITY domainRestriction.accesskey  "д">
-<!ENTITY domainRestriction.help       "Укажите один или несколько доменов, разделенные символом &quot;|&quot;, фильтр будет применен только на этих доменах. Символ &quot;~&quot; перед именем домена означает, что фильтр не должен применяться на этом домене.">
-<!ENTITY firstParty.label         "Только элементы с того же сайта">
-<!ENTITY firstParty.accesskey     "г">
-<!ENTITY thirdParty.label         "Только элементы с другого сайта">
-<!ENTITY thirdParty.accesskey     "р">
-<!ENTITY matchCase.label          "Учитывать регистр букв">
-<!ENTITY matchCase.accesskey      "У">
-<!ENTITY types.label              "Применять к типам элементов:">
-<!ENTITY selectAllTypes.label     "Пометить все">
-<!ENTITY unselectAllTypes.label   "Убрать все">
-
-<!ENTITY collapse.label           "Сворачивать заблокированные элементы:">
-<!ENTITY collapse.accesskey       "в">
-<!ENTITY collapse.default.yes.label "Использовать стандартное значение (да)">
-<!ENTITY collapse.default.no.label  "Использовать стандартное значение (нет)">
-<!ENTITY collapse.yes.label       "Да">
-<!ENTITY collapse.no.label        "Нет">

=== removed file 'chrome/locale/ru-RU/global.properties'
--- chrome/locale/ru-RU/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/ru-RU/global.properties	1970-01-01 00:00:00 +0000
@@ -1,78 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Скажи "нет" рекламе!
-
-status_active_label=Adblock
-status_disabled_label=Отключен
-
-action0_tooltip=Щелкните здесь, чтобы открыть контекстное меню. Нажмите среднюю клавишу мышки, чтобы включить или отключить Adblock Plus.
-action1_tooltip=Щелкните здесь, чтобы открыть/закрыть список элементов. Нажмите среднюю клавишу мышки, чтобы включить или отключить Adblock Plus.
-action2_tooltip=Щелкните здесь, чтобы открыть окно установок. Нажмите среднюю клавишу мышки, чтобы включить или отключить Adblock Plus.
-action3_tooltip=Щелкните здесь, чтобы включить или отключить Adblock Plus.
-
-active_tooltip=Adblock Plus включен.
-disabled_tooltip=Adblock Plus отключен.
-whitelisted_tooltip=Adblock Plus включен, но отключен для этой страницы.
-
-blocked_count_tooltip=-- из --
-
-no_blocking_suggestions=На открытой странице нет элементов, которые можно было бы заблокировать
-whitelisted_page=Adblock Plus отключен на этой странице
-
-whitelist_description=Мои исключения
-filterlist_description=Мои правила блокирования
-invalid_description=Мои ошибочные правила
-elemhide_description=Мои правила скрытия элементов
-subscription_description=Подписка:
-subscription_wrong_version=Некоторые фильтры в этой подписке требуют как минимум Adblock Plus -- для корректной работы!
-subscription_source=Источник:
-subscription_status=Состояние:
-subscription_status_autodownload=Обновляется автоматически
-subscription_status_manualdownload=Обновляется вручную
-subscription_status_externaldownload=Обновляется другим расширением
-subscription_status_lastdownload=Последнее обновление:
-subscription_status_lastdownload_inprogress=сейчас...
-subscription_status_lastdownload_unknown=никогда
-remove_subscription_warning=Вы уверены, что хотите удалить эту подписку?
-import_filters_wrong_version=Предупреждение: Некоторые фильтры в этом списке требуют как минимум Adblock Plus -- для корректной работы. Возможно, Вам лучше обновить Вашу версию Adblock Plus, прежде чем импортировать этот список.
-import_filters_warning=Вы хотите заменить существующие фильтры или добавить импортируемые фильтры в конец?
-import_filters_title=Импорт фильтров
-export_filters_title=Экспорт фильтров
-invalid_filters_file=Файл не содержит список фильтров для Adblock Plus.
-filters_write_error=При записи фильтров в файл возникла ошибка. Возможно на файле стоит защита от записи или он используется другим приложением.
-clearall_warning=Вы уверены, что хотите удалить все фильтры?
-resethitcounts_warning=Вы уверены, что хотите обнулить статистику для всех фильтров? Учтите, что это изменение необратимо!
-resethitcounts_selected_warning=Вы уверены, что хотите обнулить статистику для отмеченных фильтров? Учтите, что это изменение необратимо!
-
-filter_regexp_tooltip=Этот фильтр либо регулярное выражение, либо слишком короткий для оптимизации. Большое количество таких фильтров может отрицательно сказаться на быстродействии Вашего браузера.
-filter_elemhide_duplicate_id=У элемента, который нужно скрыть, может быть только один идентификатор
-filter_elemhide_nocriteria=Не указано никаких признаков, чтобы опознать элемент, который нужно скрыть
-
-subscription_no_location=Пожалуйста, введите адрес, с которого должен скачиваться список фильтров.
-subscription_invalid_location=Не удалось распознать введенный адрес ни как адрес в интернете, ни как путь файлу.
-subscription_location_exists=Вы уже добавили эту подписку.
-synchronize_invalid_url=Ошибка: неверный адрес
-synchronize_connection_error=Ошибка: невозможно скачать
-synchronize_invalid_data=Ошибка: не список фильтров
-synchronize_checksum_mismatch=Ошибка: проверочная сумма не совпадает, возможно ошибка скачивания
-synchronize_ok=OK
-
-overwrite=Заменить
-append=Добавить
-
-new_filter_group_title=Новый фильтр
-
-type_label_other=Неизвестен
-type_label_script=Скрипт
-type_label_image=Изображение
-type_label_stylesheet=Стили
-type_label_object=Объект
-type_label_subdocument=Фрейм
-type_label_document=Документ
-type_label_background=Фон
-type_label_elemhide=Скрыто
-type_label_xbl=XBL
-type_label_ping=Щелчок на ссылке
-type_label_xmlhttprequest=XML-запрос
-type_label_object_subrequest=Запрос объекта
-type_label_dtd=DTD
-type_label_media=Аудио/видео
-type_label_font=Шрифт

=== removed file 'chrome/locale/ru-RU/overlay.dtd'
--- chrome/locale/ru-RU/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ru-RU/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,28 +0,0 @@
-<!ENTITY status.tooltip         "Статус:">
-<!ENTITY blocked.tooltip        "Заблокированные элементы на этой странице:">
-<!ENTITY filters.tooltip        "Наиболее часто примененные фильтры:">
-
-<!ENTITY menuitem.label         "Установки Adblock Plus">
-<!ENTITY menuitem.accesskey     "A">
-<!ENTITY toolbarbutton.label    "Adblock Plus">
-
-<!ENTITY view.blockableItems.label  "Adblock Plus: элементы открытой страницы">
-
-<!ENTITY context.image.label    "Adblock Plus: заблокировать изображение">
-<!ENTITY context.object.label   "Adblock Plus: заблокировать объект">
-<!ENTITY context.frame.label    "Adblock Plus: заблокировать фрейм">
-<!ENTITY context.removeWhitelist.label  "Adblock Plus: включить обратно на этой странице">
-
-<!ENTITY sidebar.title          "Элементы открытой страницы">
-
-<!ENTITY settings.label         "Установки">
-<!ENTITY settings.accesskey     "т">
-<!ENTITY opensidebar.label      "Открыть список элементов">
-<!ENTITY opensidebar.accesskey  "п">
-<!ENTITY closesidebar.label     "Закрыть список элементов">
-<!ENTITY closesidebar.accesskey "п">
-<!ENTITY whitelist.site.label   "Отключить: на --">
-<!ENTITY whitelist.page.label   "Отключить: только на этой странице">
-
-<!ENTITY objecttab.title        "Блокировать">
-<!ENTITY objecttab.tooltip      "Нажмите здесь, чтобы Adblock Plus заблокировал этот объект">

=== removed file 'chrome/locale/ru-RU/settings.dtd'
--- chrome/locale/ru-RU/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ru-RU/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,102 +0,0 @@
-<!ENTITY dialog.title               "Установки Adblock Plus">
-
-<!ENTITY filters.label              "Фильтры">
-<!ENTITY filters.accesskey          "Ф">
-
-<!ENTITY add.label                  "Добавить фильтр">
-<!ENTITY add.accesskey              "б">
-<!ENTITY addsubscription.label      "Добавить подписку">
-<!ENTITY addsubscription.accesskey  "п">
-<!ENTITY synchsubscriptions.label      "Скачать все подписки">
-<!ENTITY synchsubscriptions.accesskey  "ч">
-<!ENTITY import.label               "Импорт фильтров">
-<!ENTITY import.accesskey           "м">
-<!ENTITY export.label               "Экспорт пользовательских фильтров">
-<!ENTITY export.accesskey           "к">
-<!ENTITY clearall.label             "Удалить все пользовательские фильтры">
-<!ENTITY clearall.accesskey         "д">
-<!ENTITY resethitcounts.label       "Обнулить статистику попаданий">
-<!ENTITY resethitcounts.accesskey   "н">
-
-<!ENTITY edit.label                 "Правка">
-<!ENTITY edit.accesskey             "П">
-
-<!ENTITY cut.label                  "Вырезать">
-<!ENTITY cut.accesskey              "В">
-<!ENTITY copy.label                 "Копировать">
-<!ENTITY copy.accesskey             "К">
-<!ENTITY paste.label                "Вставить">
-<!ENTITY paste.accesskey            "с">
-<!ENTITY remove.label               "Удалить">
-<!ENTITY remove.accesskey           "У">
-<!ENTITY menu.find.label            "Найти фильтр">
-<!ENTITY menu.find.accesskey        "Н">
-<!ENTITY menu.findagain.label       "Найти следующий">
-<!ENTITY menu.findagain.accesskey   "й">
-
-<!ENTITY view.label                 "Вид">
-<!ENTITY view.accesskey             "и">
-
-<!ENTITY sort.label                 "Сортировка">
-<!ENTITY sort.accesskey             "р">
-<!ENTITY sort.none.label            "Без сортировки">
-<!ENTITY sort.none.accesskey        "з">
-<!ENTITY sort.ascending.label       "Сортировка по алфавиту">
-<!ENTITY sort.ascending.accesskey   "ф">
-<!ENTITY sort.descending.label      "В обратном порядке">
-<!ENTITY sort.descending.accesskey  "р">
-
-<!ENTITY options.label              "Настройки">
-<!ENTITY options.accesskey          "Н">
-
-<!ENTITY enable.label               "Включить Adblock Plus">
-<!ENTITY enable.accesskey           "к">
-<!ENTITY showintoolbar.label        "Показывать в панели инструментов">
-<!ENTITY showintoolbar.accesskey    "п">
-<!ENTITY showinstatusbar.label      "Показывать в строке состояния">
-<!ENTITY showinstatusbar.accesskey  "с">
-<!ENTITY objecttabs.label           "Показывать ярлык на Flash и Java">
-<!ENTITY objecttabs.accesskey       "я">
-<!ENTITY collapse.label             "Сворачивать заблокированные элементы">
-<!ENTITY collapse.accesskey         "в">
-<!ENTITY help.label                 "Справка">
-<!ENTITY help.accesskey             "С">
-
-<!ENTITY gettingStarted.label       "Первые шаги (английский)">
-<!ENTITY gettingStarted.accesskey   "ш">
-<!ENTITY gettingStarted.url         "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label                  "Часто задаваемые вопросы (английский)">
-<!ENTITY faq.accesskey              "Ч">
-<!ENTITY faq.url                    "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label            "Составление фильтров для Adblock Plus (английский)">
-<!ENTITY filterdoc.accesskey        "т">
-<!ENTITY filterdoc.url              "http://adblockplus.org/en/filters">
-<!ENTITY about.label                "О Adblock Plus">
-<!ENTITY about.accesskey            "О">
-
-<!ENTITY description                "Следующие фильтры определяют, к каким адресам запросы нужно блокировать, а к каким разрешать:">
-
-<!ENTITY filter.column              "Правило">
-<!ENTITY filter.accesskey           "П">
-<!ENTITY slow.column                "Медленное">
-<!ENTITY slow.accesskey             "М">
-<!ENTITY enabled.column             "Включено">
-<!ENTITY enabled.accesskey          "к">
-<!ENTITY hitcount.column            "Попаданий">
-<!ENTITY hitcount.accesskey         "д">
-<!ENTITY lasthit.column             "Последнее попадание">
-<!ENTITY lasthit.accesskey          "л">
-
-<!ENTITY context.edit.label         "Редактировать фильтр">
-<!ENTITY context.resethitcount.label      "Обнулить статистику попаданий для фильтра">
-<!ENTITY context.synchsubscription.label  "Скачать фильтры заново">
-<!ENTITY context.editsubscription.label   "Редактировать подписку">
-<!ENTITY context.moveup.label       "Сдвинуть фильтр вверх">
-<!ENTITY context.movedown.label     "Сдвинуть фильтр вниз">
-<!ENTITY context.movegroupup.label        "Сдвинуть группу вверх">
-<!ENTITY context.movegroupdown.label      "Сдвинуть группу вниз">
-<!ENTITY context.enable.label       "Включить">
-<!ENTITY context.disable.label      "Отключить">
-
-<!ENTITY apply.label                "Применить">
-<!ENTITY apply.accesskey            "р">

=== removed file 'chrome/locale/ru-RU/sidebar.dtd'
--- chrome/locale/ru-RU/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ru-RU/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,37 +0,0 @@
-<!ENTITY detached.title           "Adblock Plus: элементы открытой страницы (отсоединены)">
-
-<!ENTITY detach.label             "Отсоединить">
-<!ENTITY reattach.label           "Присоединить">
-
-<!ENTITY search.label             "Поиск:">
-<!ENTITY search.accesskey         "о">
-
-<!ENTITY type.label               "Тип">
-<!ENTITY address.label            "Адрес">
-<!ENTITY filter.label             "Фильтр">
-<!ENTITY state.label              "Статус">
-<!ENTITY size.label               "Размер">
-<!ENTITY docDomain.label          "Домен страницы">
-
-<!ENTITY noitems.label            "Блокировать нечего">
-<!ENTITY whitelisted.label        "Отключен на этой странице">
-<!ENTITY tooltip.address.label    "Адрес:">
-<!ENTITY tooltip.type.label       "Тип:">
-<!ENTITY tooltip.type.blocked     "(заблокирован)">
-<!ENTITY tooltip.type.whitelisted "(исключение)">
-<!ENTITY tooltip.size.label       "Размер:">
-<!ENTITY tooltip.docDomain.label  "Домен страницы:">
-<!ENTITY tooltip.filter.label     "Применен фильтр:">
-<!ENTITY tooltip.filterSource.label "Источник фильтра:">
-
-<!ENTITY context.block.label      "Заблокировать элемент">
-<!ENTITY context.editfilter.label "Отредактировать примененный фильтр">
-<!ENTITY context.whitelist.label  "Добавить исключение для элемента">
-<!ENTITY context.disablefilter.label  "Отключить фильтр --">
-<!ENTITY context.enablefilter.label   "Включить обратно фильтр --">
-<!ENTITY context.disablefilteronsite.label  "Отключить фильтр на --">
-<!ENTITY context.open.label       "Открыть в новой вкладке">
-<!ENTITY context.flash.label      "Показать расположение элемента">
-<!ENTITY context.copy.label       "Копировать адрес">
-<!ENTITY context.copyFilter.label "Копировать фильтр">
-<!ENTITY context.selectAll.label  "Выделить всё">

=== removed file 'chrome/locale/ru-RU/subscription.dtd'
--- chrome/locale/ru-RU/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ru-RU/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,31 +0,0 @@
-<!ENTITY dialog.title               "Редактировать подписку">
-<!ENTITY dialog.newtitle            "Добавить подписку">
-
-<!ENTITY new.description            "
-  Пожалуйста, введите адрес в интернете или путь к файлу, где расположен
-  список фильтров для Adblock Plus.
-">
-
-<!ENTITY edit.description           "
-  Список фильтров для этой подписки будет скачиваться с заданного адреса.
-">
-
-<!ENTITY external.description       "
-  Это внешняя подписка, она будет актуализироваться расширением, которое
-  ее добавило.
-">
-
-<!ENTITY autodownload.description   "
-  Если выбрано 'Обновлять автоматически', то обновления будут скачиваться
-  с этого адреса ежедневно.  Без этой опции скачивание нужно запускать
-  вручную из контекстного меню подписки.
-">
-
-<!ENTITY location.label             "Адрес списка фильтров:">
-<!ENTITY location.accesskey         "д">
-<!ENTITY title.label                "Название подписки:">
-<!ENTITY title.accesskey            "з">
-<!ENTITY autodownload.label         "Обновлять автоматически">
-<!ENTITY autodownload.accesskey     "т">
-<!ENTITY enabled.label              "Включить фильтры">
-<!ENTITY enabled.accesskey          "к">

=== removed file 'chrome/locale/ru-RU/tip_subscriptions.dtd'
--- chrome/locale/ru-RU/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/ru-RU/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,48 +0,0 @@
-<!ENTITY dialog.title               "Добавить подписку для Adblock Plus">
-
-<!ENTITY description.par1           "
-  Спасибо, что Вы решили установить Adblock Plus. Это расширение позволяет
-  заблокировать 99&#x25; рекламы в интернете. Однако для оптимальных
-  результатов требуется хороший набор фильтров. Вы можете определять эти
-  фильтры сами или просто подписаться на списки фильтров, которые
-  составляют другие. Это не лишает Вас возможности добавлять собственные
-  фильтры. Кроме того, Вы можете отключить или удалить подписки в любой
-  момент.
-">
-
-<!ENTITY description.par2           "
-  Ниже приведен список рекомендованных подписок, Вы можете выбрать одну
-  из них (добавить больше подписок можно позже через настройки Adblock Plus,
-  но обычно это не требуется):
-">
-
-<!ENTITY note                       "
-  Примечание: Список фильтров, как правило, наиболее эффективен на страницах того
-  региона, для которого он создавался.
-">
-
-<!ENTITY adblock.warning            "
-  Adblock Plus обнаружил, что в этом приложении установлен Adblock или старая версия
-  Adblock Plus. Параллельное использование Adblock и Adblock Plus может вызвать проблемы.
-  Во избежание проблем рекомендуется удалить Adblock.
-">
-<!ENTITY adblock.uninstall          "Удалить Adblock">
-
-<!ENTITY filterset.g.warning        "
-  Похоже, что Вы используете Filterset.G. Этот список фильтров последние несколько лет
-  почти не поддерживался и часто является источником проблем на веб-сайтах.
-  Во избежание проблем рекомендуется удалить Filterset.G.
-">
-<!ENTITY filterset.g.moreinfo       "Дополнительная информация">
-<!ENTITY filterset.g.moreinfo.url   "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall      "Удалить Filterset.G">
-
-<!ENTITY homepage.label             "Домашняя страница">
-
-<!ENTITY subscribe.label            "Подписаться">
-<!ENTITY subscribe.accesskey        "д">
-<!ENTITY other.label                "Добавить другую подписку">
-<!ENTITY other.accesskey            "б">
-
-<!ENTITY full-list.url              "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label            "Просмотреть все известные подписки">

=== added file 'chrome/locale/ru/about.dtd'
--- chrome/locale/ru/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ru/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,19 @@
+<!ENTITY dialog.title       "О Adblock Plus">
+
+<!ENTITY caption.title      "Adblock Plus">
+<!ENTITY version.title      "Версия">
+<!ENTITY description        "
+  С Adblock Plus Вы можете сами решать, что Вы хотите видеть в интернете,
+  а что - нет. Не нужно больше тратить свое время на скачивание рекламных
+  баннеров, если Вы не хотите их видеть - Adblock Plus Вам поможет!
+">
+
+<!ENTITY homepage.label     "Домашняя страница проекта:">
+<!ENTITY homepage.url       "http://adblockplus.org/">
+<!ENTITY author.label       "Разработчик:">
+<!ENTITY contributors.label "Другие участники:">
+
+<!ENTITY developers.label   "Разработчики:">
+<!ENTITY designers.label    "Дизайнеры:">
+<!ENTITY subscriptionAuthors.label    "Авторы списков фильтров:">
+<!ENTITY translators.label  "Переводчики:">

=== added file 'chrome/locale/ru/composer.dtd'
--- chrome/locale/ru/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ru/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,48 @@
+<!ENTITY dialog.title             "Составление фильтра для Adblock Plus">
+<!ENTITY accept.label             "Добавить фильтр">
+<!ENTITY advanced.label           "Расширенный вид">
+<!ENTITY basic.label              "Стандартный вид">
+
+<!ENTITY disabled.warning "Adblock Plus сейчас отключен. Вы можете добавить этот фильтр, но чтобы он применился нужно [link]включить Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Группа фильтров &quot;?1?&quot;, в которую этот фильтр должен быть добавлен, сейчас отключена. Вы можете добавить этот фильтр, но чтобы он применился нужно [link]включить эту группу фильтров[/link].">
+<!ENTITY filter.label             "Новый фильтр:">
+<!ENTITY filter.accesskey         "ф">
+<!ENTITY preferences.label        "Показать существующие фильтры...">
+<!ENTITY preferences.accesskey    "щ">
+<!ENTITY type.filter.label        "Правило блокирования">
+<!ENTITY type.filter.accesskey    "б">
+<!ENTITY type.whitelist.label     "Исключение">
+<!ENTITY type.whitelist.accesskey "к">
+<!ENTITY pattern.label            "Шаблон">
+<!ENTITY pattern.explanation      "Шаблоном может быть любая часть адреса, причем звездочка (*) заменяет любое количество символов. Фильтр будет применен только к тем адресам, которые соответствуют шаблону.">
+<!ENTITY regexp.warning           "Шаблон, который Вы ввели, будет интерпретирован как регулярное выражение. Большое количество регулярных выражений может отрицательно сказаться на быстродействии Вашего браузера. Если Вы не собирались использовать регулярные выражения, просто добавьте звездочку в конце шаблона.">
+<!ENTITY shortpattern.warning     "Шаблон, который Вы ввели, слишком короткий и не будет оптимизирован. Большое количество таких шаблонов может отрицательно сказаться на быстродействии Вашего браузера. Рекомендуется по возможности использовать более длинный шаблон.">
+<!ENTITY custom.pattern.label     "Собственный:">
+<!ENTITY custom.pattern.accesskey "С">
+<!ENTITY anchors.label            "Принимать шаблон только:">
+<!ENTITY anchor.start.label       "в начале адреса">
+<!ENTITY anchor.start.accesskey   "ч">
+<!ENTITY anchor.start.flexible.label      "в начале доменного имени">
+<!ENTITY anchor.start.flexible.accesskey  "ч">
+<!ENTITY anchor.end.label         "в конце адреса">
+<!ENTITY anchor.end.accesskey     "ц">
+<!ENTITY options.label            "Дополнительные настройки">
+<!ENTITY domainRestriction.label      "Ограничить доменом:">
+<!ENTITY domainRestriction.accesskey  "д">
+<!ENTITY domainRestriction.help       "Укажите один или несколько доменов, разделенные символом &quot;|&quot;, фильтр будет применен только на этих доменах. Символ &quot;~&quot; перед именем домена означает, что фильтр не должен применяться на этом домене.">
+<!ENTITY firstParty.label         "Только элементы с того же сайта">
+<!ENTITY firstParty.accesskey     "г">
+<!ENTITY thirdParty.label         "Только элементы с другого сайта">
+<!ENTITY thirdParty.accesskey     "р">
+<!ENTITY matchCase.label          "Учитывать регистр букв">
+<!ENTITY matchCase.accesskey      "У">
+<!ENTITY types.label              "Применять к типам элементов:">
+<!ENTITY selectAllTypes.label     "Пометить все">
+<!ENTITY unselectAllTypes.label   "Убрать все">
+
+<!ENTITY collapse.label           "Сворачивать заблокированные элементы:">
+<!ENTITY collapse.accesskey       "в">
+<!ENTITY collapse.default.yes.label "Использовать стандартное значение (да)">
+<!ENTITY collapse.default.no.label  "Использовать стандартное значение (нет)">
+<!ENTITY collapse.yes.label       "Да">
+<!ENTITY collapse.no.label        "Нет">

=== added file 'chrome/locale/ru/global.properties'
--- chrome/locale/ru/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ru/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,81 @@
+default_dialog_title=Adblock Plus
+
+action0_tooltip=Щелкните здесь, чтобы открыть контекстное меню. Нажмите среднюю клавишу мышки, чтобы включить или отключить Adblock Plus.
+action1_tooltip=Щелкните здесь, чтобы открыть/закрыть список элементов. Нажмите среднюю клавишу мышки, чтобы включить или отключить Adblock Plus.
+action2_tooltip=Щелкните здесь, чтобы открыть окно установок. Нажмите среднюю клавишу мышки, чтобы включить или отключить Adblock Plus.
+action3_tooltip=Щелкните здесь, чтобы включить или отключить Adblock Plus.
+
+disabled_tooltip=Adblock Plus отключен.
+active_tooltip=Adblock Plus включен, используются ?1? подписка/подписки и ?2? собственных фильтров.
+whitelisted_tooltip=Adblock Plus отключен на этой странице.
+
+blocked_count_tooltip=?1? из ?2?
+blocked_count_addendum=(также исключений: ?1?, спрятано: ?2?)
+
+no_blocking_suggestions=На открытой странице нет элементов, которые можно было бы заблокировать
+whitelisted_page=Adblock Plus отключен на этой странице
+
+whitelist_description=Мои исключения
+filterlist_description=Мои правила блокирования
+invalid_description=Мои ошибочные правила
+elemhide_description=Мои правила скрытия элементов
+subscription_description=Подписка:
+subscription_wrong_version=Некоторые фильтры в этой подписке требуют как минимум Adblock Plus ?1? для корректной работы!
+subscription_source=Источник:
+subscription_status=Состояние:
+subscription_status_autodownload=Обновляется автоматически
+subscription_status_manualdownload=Обновляется вручную
+subscription_status_externaldownload=Обновляется другим расширением
+subscription_status_lastdownload=Последнее обновление:
+subscription_status_lastdownload_inprogress=сейчас...
+subscription_status_lastdownload_unknown=никогда
+remove_subscription_warning=Вы уверены, что хотите удалить эту подписку?
+import_filters_wrong_version=Предупреждение: Некоторые фильтры в этом списке требуют как минимум Adblock Plus ?1? для корректной работы. Возможно, Вам лучше обновить Вашу версию Adblock Plus, прежде чем импортировать этот список.
+import_filters_warning=Вы хотите заменить существующие фильтры или добавить импортируемые фильтры в конец?
+import_filters_title=Импорт фильтров
+export_filters_title=Экспорт фильтров
+invalid_filters_file=Файл не содержит список фильтров для Adblock Plus.
+filters_write_error=При записи фильтров в файл возникла ошибка. Возможно на файле стоит защита от записи или он используется другим приложением.
+clearall_warning=Вы уверены, что хотите удалить все фильтры?
+resethitcounts_warning=Вы уверены, что хотите обнулить статистику для всех фильтров? Учтите, что это изменение необратимо!
+resethitcounts_selected_warning=Вы уверены, что хотите обнулить статистику для отмеченных фильтров? Учтите, что это изменение необратимо!
+
+filter_regexp_tooltip=Этот фильтр либо регулярное выражение, либо слишком короткий для оптимизации. Большое количество таких фильтров может отрицательно сказаться на быстродействии Вашего браузера.
+filter_elemhide_duplicate_id=У элемента, который нужно скрыть, может быть только один идентификатор
+filter_elemhide_nocriteria=Не указано никаких признаков, чтобы опознать элемент, который нужно скрыть
+
+subscription_notAdded_warning=Вы не добавили подписку на список фильтров. Без подписки вам придется добавлять фильтры для Adblock Plus вручную.
+subscription_notAdded_warning_addendum=Продолжить, не добавляя подписку?
+subscription_invalid_location=Не удалось распознать введенный адрес ни как адрес в интернете, ни как путь файлу.
+synchronize_invalid_url=Ошибка: неверный адрес
+synchronize_connection_error=Ошибка: невозможно скачать
+synchronize_invalid_data=Ошибка: не список фильтров
+synchronize_checksum_mismatch=Ошибка: проверочная сумма не совпадает, возможно ошибка скачивания
+synchronize_ok=OK
+
+overwrite=Заменить
+append=Добавить
+
+new_filter_group_title=Новый фильтр
+
+type_label_other=Неизвестен
+type_label_script=Скрипт
+type_label_image=Изображение
+type_label_stylesheet=Стили
+type_label_object=Объект
+type_label_subdocument=Фрейм
+type_label_document=Документ
+type_label_background=Фон
+type_label_elemhide=Скрыто
+type_label_xbl=XBL
+type_label_ping=Щелчок на ссылке
+type_label_xmlhttprequest=XML-запрос
+type_label_object_subrequest=Запрос объекта
+type_label_dtd=DTD
+type_label_media=Аудио/видео
+type_label_font=Шрифт
+
+fennec_status_enabled=Adblock Plus включен.
+fennec_status_disabled=Adblock Plus отключен.
+fennec_status_enabled_site=Adblock Plus включен на ?1?.
+fennec_status_disabled_site=Adblock Plus отключен на ?1?.

=== added file 'chrome/locale/ru/meta.properties'
--- chrome/locale/ru/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/ru/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Wladimir Palant
+name=Adblock Plus
+description=Скажи "нет" рекламе!
+description.short=Надоела реклама? Тормозит интернет? Слишком много баннеров? Установи Adblock Plus, чтобы вернуть себе контроль над интернетом и видеть лишь то, что хочется.
+description.long=Adblock Plus даст вам вернуть себе контроль над интернетом и видеть его таким, как хочется вам. Для расширения существует более сорока списков фильтров для десятков языков, которые автоматически настроят его для различных целей, от блокировки рекламы до блокировки всех известных опасных доменов. Adblock Plus также позволит вам добавлять собственные фильтры с помощью различных полезных инструментов, включая контекстное меню для блокировки картинок, ярлык для блокировки Flash-роликов и Java-апплетов и список элементов для удаления невидимых элементов (к примеру, скриптов или стилей).

=== added file 'chrome/locale/ru/overlay.dtd'
--- chrome/locale/ru/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ru/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,29 @@
+<!ENTITY status.tooltip         "Статус:">
+<!ENTITY blocked.tooltip        "Заблокированные элементы на этой странице:">
+<!ENTITY filters.tooltip        "Наиболее часто примененные фильтры:">
+
+<!ENTITY menuitem.label         "Установки Adblock Plus">
+<!ENTITY menuitem.accesskey     "A">
+<!ENTITY toolbarbutton.label    "Adblock Plus">
+
+<!ENTITY view.blockableItems.label  "Adblock Plus: элементы открытой страницы">
+
+<!ENTITY context.image.label    "Adblock Plus: заблокировать изображение">
+<!ENTITY context.object.label   "Adblock Plus: заблокировать объект">
+<!ENTITY context.frame.label    "Adblock Plus: заблокировать фрейм">
+<!ENTITY context.media.label    "Adblock Plus: заблокировать аудио/видео">
+<!ENTITY context.removeWhitelist.label  "Adblock Plus: включить обратно на этой странице">
+
+<!ENTITY sidebar.title          "Элементы открытой страницы">
+
+<!ENTITY settings.label         "Установки">
+<!ENTITY settings.accesskey     "т">
+<!ENTITY opensidebar.label      "Открыть список элементов">
+<!ENTITY opensidebar.accesskey  "п">
+<!ENTITY closesidebar.label     "Закрыть список элементов">
+<!ENTITY closesidebar.accesskey "п">
+<!ENTITY whitelist.site.label   "Отключить: на ?1?">
+<!ENTITY whitelist.page.label   "Отключить: только на этой странице">
+
+<!ENTITY objecttab.title        "Блокировать">
+<!ENTITY objecttab.tooltip      "Нажмите здесь, чтобы Adblock Plus заблокировал этот объект">

=== added file 'chrome/locale/ru/settings.dtd'
--- chrome/locale/ru/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ru/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,104 @@
+<!ENTITY dialog.title               "Установки Adblock Plus">
+
+<!ENTITY filters.label              "Фильтры">
+<!ENTITY filters.accesskey          "Ф">
+
+<!ENTITY add.label                  "Добавить фильтр">
+<!ENTITY add.accesskey              "б">
+<!ENTITY addsubscription.label      "Добавить подписку">
+<!ENTITY addsubscription.accesskey  "п">
+<!ENTITY synchsubscriptions.label      "Обновить все подписки">
+<!ENTITY synchsubscriptions.accesskey  "в">
+<!ENTITY import.label               "Импорт фильтров">
+<!ENTITY import.accesskey           "м">
+<!ENTITY export.label               "Экспорт пользовательских фильтров">
+<!ENTITY export.accesskey           "к">
+<!ENTITY clearall.label             "Удалить все пользовательские фильтры">
+<!ENTITY clearall.accesskey         "д">
+<!ENTITY resethitcounts.label       "Обнулить статистику попаданий">
+<!ENTITY resethitcounts.accesskey   "н">
+
+<!ENTITY edit.label                 "Правка">
+<!ENTITY edit.accesskey             "П">
+
+<!ENTITY cut.label                  "Вырезать">
+<!ENTITY cut.accesskey              "В">
+<!ENTITY copy.label                 "Копировать">
+<!ENTITY copy.accesskey             "К">
+<!ENTITY paste.label                "Вставить">
+<!ENTITY paste.accesskey            "с">
+<!ENTITY remove.label               "Удалить">
+<!ENTITY remove.accesskey           "У">
+<!ENTITY menu.find.label            "Найти фильтр">
+<!ENTITY menu.find.accesskey        "Н">
+<!ENTITY menu.findagain.label       "Найти следующий">
+<!ENTITY menu.findagain.accesskey   "й">
+
+<!ENTITY view.label                 "Вид">
+<!ENTITY view.accesskey             "и">
+
+<!ENTITY sort.label                 "Сортировка">
+<!ENTITY sort.accesskey             "р">
+<!ENTITY sort.none.label            "Без сортировки">
+<!ENTITY sort.none.accesskey        "з">
+<!ENTITY sort.ascending.label       "Сортировка по алфавиту">
+<!ENTITY sort.ascending.accesskey   "ф">
+<!ENTITY sort.descending.label      "В обратном порядке">
+<!ENTITY sort.descending.accesskey  "р">
+
+<!ENTITY options.label              "Настройки">
+<!ENTITY options.accesskey          "Н">
+
+<!ENTITY enable.label               "Включить Adblock Plus">
+<!ENTITY enable.accesskey           "к">
+<!ENTITY showintoolbar.label        "Показывать в панели инструментов">
+<!ENTITY showintoolbar.accesskey    "п">
+<!ENTITY showinstatusbar.label      "Показывать в строке состояния">
+<!ENTITY showinstatusbar.accesskey  "с">
+<!ENTITY objecttabs.label           "Показывать ярлык на Flash и Java">
+<!ENTITY objecttabs.accesskey       "я">
+<!ENTITY collapse.label             "Сворачивать заблокированные элементы">
+<!ENTITY collapse.accesskey         "в">
+<!ENTITY help.label                 "Справка">
+<!ENTITY help.accesskey             "С">
+
+<!ENTITY gettingStarted.label       "Первые шаги (английский)">
+<!ENTITY gettingStarted.accesskey   "ш">
+<!ENTITY gettingStarted.url         "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label                  "Часто задаваемые вопросы (английский)">
+<!ENTITY faq.accesskey              "Ч">
+<!ENTITY faq.url                    "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label            "Составление фильтров для Adblock Plus (английский)">
+<!ENTITY filterdoc.accesskey        "т">
+<!ENTITY filterdoc.url              "http://adblockplus.org/en/filters">
+<!ENTITY about.label                "О Adblock Plus">
+<!ENTITY about.accesskey            "О">
+
+<!ENTITY description                "Следующие фильтры определяют, к каким адресам запросы нужно блокировать, а к каким разрешать:">
+
+<!ENTITY filter.column              "Правило">
+<!ENTITY filter.accesskey           "П">
+<!ENTITY slow.column                "Медленное">
+<!ENTITY slow.accesskey             "М">
+<!ENTITY enabled.column             "Включено">
+<!ENTITY enabled.accesskey          "к">
+<!ENTITY hitcount.column            "Попаданий">
+<!ENTITY hitcount.accesskey         "д">
+<!ENTITY lasthit.column             "Последнее попадание">
+<!ENTITY lasthit.accesskey          "л">
+
+<!ENTITY context.edit.label         "Редактировать фильтр">
+<!ENTITY context.resethitcount.label      "Обнулить статистику попаданий для фильтра">
+<!ENTITY context.synchsubscription.label  "Обновить фильтры подписки">
+<!ENTITY context.editsubscription.label   "Редактировать подписку">
+<!ENTITY context.moveup.label       "Сдвинуть фильтр вверх">
+<!ENTITY context.movedown.label     "Сдвинуть фильтр вниз">
+<!ENTITY context.movegroupup.label        "Сдвинуть группу вверх">
+<!ENTITY context.movegroupdown.label      "Сдвинуть группу вниз">
+<!ENTITY context.enable.label       "Включить">
+<!ENTITY context.disable.label      "Отключить">
+
+<!ENTITY apply.label                "Применить">
+<!ENTITY apply.accesskey            "р">
+
+<!ENTITY fennec.subscription.label  "Подписка на список фильтров">

=== added file 'chrome/locale/ru/sidebar.dtd'
--- chrome/locale/ru/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ru/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,37 @@
+<!ENTITY detached.title           "Adblock Plus: элементы открытой страницы (отсоединены)">
+
+<!ENTITY detach.label             "Отсоединить">
+<!ENTITY reattach.label           "Присоединить">
+
+<!ENTITY search.label             "Поиск:">
+<!ENTITY search.accesskey         "о">
+
+<!ENTITY type.label               "Тип">
+<!ENTITY address.label            "Адрес">
+<!ENTITY filter.label             "Фильтр">
+<!ENTITY state.label              "Статус">
+<!ENTITY size.label               "Размер">
+<!ENTITY docDomain.label          "Домен страницы">
+
+<!ENTITY noitems.label            "Блокировать нечего">
+<!ENTITY whitelisted.label        "Отключен на этой странице">
+<!ENTITY tooltip.address.label    "Адрес:">
+<!ENTITY tooltip.type.label       "Тип:">
+<!ENTITY tooltip.type.blocked     "(заблокирован)">
+<!ENTITY tooltip.type.whitelisted "(исключение)">
+<!ENTITY tooltip.size.label       "Размер:">
+<!ENTITY tooltip.docDomain.label  "Домен страницы:">
+<!ENTITY tooltip.filter.label     "Применен фильтр:">
+<!ENTITY tooltip.filterSource.label "Источник фильтра:">
+
+<!ENTITY context.block.label      "Заблокировать элемент">
+<!ENTITY context.editfilter.label "Отредактировать примененный фильтр">
+<!ENTITY context.whitelist.label  "Добавить исключение для элемента">
+<!ENTITY context.disablefilter.label  "Отключить фильтр ?1?">
+<!ENTITY context.enablefilter.label   "Включить обратно фильтр ?1?">
+<!ENTITY context.disablefilteronsite.label  "Отключить фильтр на ?1?">
+<!ENTITY context.open.label       "Открыть в новой вкладке">
+<!ENTITY context.flash.label      "Показать расположение элемента">
+<!ENTITY context.copy.label       "Копировать адрес">
+<!ENTITY context.copyFilter.label "Копировать фильтр">
+<!ENTITY context.selectAll.label  "Выделить всё">

=== added file 'chrome/locale/ru/subscriptionSelection.dtd'
--- chrome/locale/ru/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/ru/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,56 @@
+<!ENTITY dialog.title               "Добавить подписку для Adblock Plus">
+<!ENTITY dialog.title.edit          "Редактировать подписку">
+
+<!ENTITY description.newInstall     "
+  Adblock Plus будет работать наиболее эффективно, если вы добавите подписку на
+  список фильтров. Эти списки фильтров предоставляются бесплатно другими
+  пользователями Adblock Plus. Самая подходящая подписка для вашего языка уже
+  выбрана.
+">
+
+<!ENTITY adblock.warning            "
+  Adblock Plus обнаружил, что в этом приложении установлен Adblock или старая версия
+  Adblock Plus. Параллельное использование Adblock и Adblock Plus может вызвать проблемы.
+  Во избежание проблем рекомендуется удалить Adblock.
+">
+<!ENTITY adblock.uninstall          "Удалить Adblock">
+
+<!ENTITY filterset.g.warning        "
+  Похоже, что Вы используете Filterset.G. Этот список фильтров последние несколько лет
+  почти не поддерживался и часто является источником проблем на веб-сайтах.
+  Во избежание проблем рекомендуется удалить Filterset.G.
+">
+<!ENTITY filterset.g.moreinfo       "Дополнительная информация">
+<!ENTITY filterset.g.moreinfo.url   "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall      "Удалить Filterset.G">
+
+<!ENTITY subscriptionSelector.label "Пожалуйста, выберите подписку из списка:">
+
+<!ENTITY viewList.label             "Просмотреть фильтры">
+<!ENTITY visitHomepage.label        "Посетить домашнюю страницу списка">
+
+<!ENTITY addSubscription.label      "Добавить подписку">
+<!ENTITY saveSubscription.label     "Сохранить изменения">
+
+<!ENTITY list.download.failed       "При скачивании списка подписок произошла ошибка.">
+<!ENTITY list.download.retry        "Попробовать еще раз">
+<!ENTITY list.download.website      "Открыть страницу с подписками">
+<!ENTITY list.website.url           "http://adblockplus.org/en/subscriptions">
+
+<!ENTITY other.label                "Добавить другую подписку">
+<!ENTITY other.accesskey            "б">
+
+<!ENTITY fromWeb.description        "Пожалуйста, подтвердите, что вы действительно хотите добавить подписку на этот список фильтров. Вы можете изменить название и адрес подписки перед добавлением.">
+<!ENTITY edit.description           "Вы можете изменить название и адрес подписки по надобности.">
+<!ENTITY external.description       "Это внешняя подписка, эти фильтры обновляются расширением, которое добавило эту подписку.">
+
+<!ENTITY location.label             "Адрес списка фильтров:">
+<!ENTITY location.accesskey         "д">
+<!ENTITY title.label                "Название подписки:">
+<!ENTITY title.accesskey            "з">
+<!ENTITY autodownload.label         "Обновлять автоматически">
+<!ENTITY autodownload.accesskey     "т">
+
+<!ENTITY supplementMessage          "Этот список фильтров должен использоваться в комбинации со списком фильтров &quot;?1?&quot;, который вы не используете.">
+<!ENTITY addMain.label              "Добавить подписку на список фильтров &quot;?1?&quot;">
+<!ENTITY addMain.accesskey          "в">

=== added directory 'chrome/locale/sk'
=== removed directory 'chrome/locale/sk-SK'
=== removed file 'chrome/locale/sk-SK/about.dtd'
--- chrome/locale/sk-SK/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sk-SK/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-<!ENTITY dialog.title "O rozšírení Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Verzia">
-<!ENTITY description "Adblock Plus vám umožní rozhodnúť sa, čo si neprajete zobrazovať na stránkach.
-	Nepotrebujete preberať všetky reklamy a titulky, ak ich nechcete - povedzte to Adblock Plus!">
-<!ENTITY homepage.label "Domovská stránka Adblock Plus:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Autor:">
-<!ENTITY contributors.label "Prispievatelia:">

=== removed file 'chrome/locale/sk-SK/composer.dtd'
--- chrome/locale/sk-SK/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sk-SK/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Pridať pravidlo filtra">
-<!ENTITY accept.label "Pridať filter">
-<!ENTITY advanced.label "Pokročilý náhľad">
-<!ENTITY basic.label "Jednoduchý náhľad">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus je aktuálne vypnutý. Môžete pridávať filtre, ale tie nebudú aplikované pokiaľ">
-<!ENTITY disabled.warning.link "nezapnete Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Skupina filtrov &quot;&#37;S&quot;, ktorá mala tento filter pridať, je aktuálne vypnutá. Stále ho však môžete pridať, ale nebude aplikovaný skôr, než">
-<!ENTITY groupDisabled.warning.link "zapnete skupinu filtrov">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Nový filter:">
-<!ENTITY filter.accesskey "f">
-<!ENTITY preferences.label "Zobraziť existujúce filtre...">
-<!ENTITY preferences.accesskey "Z">
-<!ENTITY type.filter.label "Blokovanie filtra">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "Základné pravidlo">
-<!ENTITY type.whitelist.accesskey "k">
-<!ENTITY pattern.label "Vyhľadať vzor">
-<!ENTITY pattern.explanation "Vzor môže byť nejaká časť adresy, symbol * ako divoká karta. Filter ešte len bude aplikovaný na adresy zodpovedajúce vzoru.">
-<!ENTITY regexp.warning "Vzor, ktorý ste vložili bude interpretovaný ako regulárny výraz. Mnoho regulárnych výrazov môže spomaliť prehliadanie. Ak ste nemali v úmysle používať regulárne výrazy, pridajte symbol * na koniec vzoru.">
-<!ENTITY shortpattern.warning "Vzor, ktorý ste vložili je príliš krátky, aby mohol byť optimalizovaný, mnoho takýchto schém môže spomaliť prehliadanie. Odporúčame, aby ste vybrali dlhší reťazec pre tento filter.">
-<!ENTITY custom.pattern.label "Vlastné:">
-<!ENTITY custom.pattern.accesskey "V">
-<!ENTITY anchors.label "Prijať vzor len:">
-<!ENTITY anchor.start.label "na začiatku adresy">
-<!ENTITY anchor.start.accesskey "n">
-<!ENTITY anchor.start.flexible.label "na začiatku názvu domény">
-<!ENTITY anchor.start.flexible.accesskey "n">
-<!ENTITY anchor.end.label "na konci adresy">
-<!ENTITY anchor.end.accesskey "d">
-<!ENTITY options.label "Možnosti">
-<!ENTITY domainRestriction.label "Obmedziť na doménu:">
-<!ENTITY domainRestriction.accesskey "e">
-<!ENTITY domainRestriction.help "Špecifikujte jednu alebo viac domén oddelených značkou &quot;|&quot;, filter bude obmedzený len pre tieto domény. Symbol &quot;~&quot; pred názvom domény znamená, že filter by nemal byť aplikovaný na tejto doméne.">
-<!ENTITY firstParty.label "Len prvá strana">
-<!ENTITY firstParty.accesskey "L">
-<!ENTITY thirdParty.label "Len tretie strany">
-<!ENTITY thirdParty.accesskey "t">
-<!ENTITY matchCase.label "Modelový prípad">
-<!ENTITY matchCase.accesskey "M">
-<!ENTITY types.label "Aplikovať na typy:">
-<!ENTITY selectAllTypes.label "Vybrať všetko">
-<!ENTITY unselectAllTypes.label "Nezvoliť nič">
-<!ENTITY collapse.label "Pád zablokovaný::">
-<!ENTITY collapse.accesskey "o">
-<!ENTITY collapse.default.yes.label "Použiť pôvodné (áno)">
-<!ENTITY collapse.default.no.label "Použiť pôvodné (nie)">
-<!ENTITY collapse.yes.label "Áno">
-<!ENTITY collapse.no.label "Nie">

=== removed file 'chrome/locale/sk-SK/global.properties'
--- chrome/locale/sk-SK/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/sk-SK/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Reklamy sú minulosťou!
-status_active_label=Adblock
-status_disabled_label=Zakázaný
-action0_tooltip=Kliknúť na vyvolanie kontextovej ponuky, kliknutie prostredným pre Zapnúť/Vypnúť.
-action1_tooltip=Kliknúť pre Otvoriť/Zavrieť blokovateľné položky, kliknutie prostredným pre Zapnúť/Vypnúť.
-action2_tooltip=Kliknúť pre otvorenie nastavení, kliknutie prostredným pre Zapnúť/Vypnúť.
-action3_tooltip=Kliknúť pre Otvoriť/Zavrieť Adblock Plus.
-active_tooltip=Adblock Plus je aktívny.
-disabled_tooltip=Adblock Plus je vypnutý.
-whitelisted_tooltip=Adblock Plus je aktívny, ale vypnutý na aktuálnej stránke.
-blocked_count_tooltip=-- mimo --
-no_blocking_suggestions=Na aktuálnej stránke nie sú blokovateľné položky
-whitelisted_page=Adblock Plus bol zakázaný pre aktuálnu stránku
-whitelist_description=Výnimky
-filterlist_description=Filtre reklám
-invalid_description=Nesprávne filtre
-elemhide_description=Skryté pravidlá prvkov
-subscription_description=Povolený filter:
-subscription_wrong_version=Niektoré filtre v tomto povolení vyžadujú Adblock Plus -- k správnej činnosti!
-subscription_source=Zdroj:
-subscription_status=Stav:
-subscription_status_autodownload=Aktualizovaný automaticky
-subscription_status_manualdownload=Aktualizovaný manuálne
-subscription_status_externaldownload=Aktualizovaný externe (iné rozšírenie)
-subscription_status_lastdownload=Posledné prevzatie:
-subscription_status_lastdownload_inprogress=Preberanie...
-subscription_status_lastdownload_unknown=N/A
-remove_subscription_warning=Naozaj si želáte odstrániť toto povolenie?
-import_filters_wrong_version=Upozornenie: Niektoré filtre v tomto zozname vyžadujú Adblock Plus -- k správnej činnosti. Pred importovaním tohto zoznamu by ste mal aktualizovať Adblock Plus na poslednú verziu.
-import_filters_warning=Želáte si nahradiť vaše aktuálne filtre alebo pridať nové filtre na koniec zoznamu?
-import_filters_title=Importovať filtre
-export_filters_title=Exportovať filtre
-invalid_filters_file=Neplatný súbor filtrov Adblock Plus.
-filters_write_error=Pri zapisovaní filtrov do súboru bola zistená chyba. Presvedčte sa, že súbor nie je chránený proti zapisovaniu alebo zvoľte iný program.
-clearall_warning=Naozaj si želáte odstrániť všetky filtre zo zoznamu?
-resethitcounts_warning=Naozaj si prajete obnoviť počty aktívnych záznamov všetkých filtrov na nulu? Táto operácia sa nedá vrátiť späť!
-resethitcounts_selected_warning=Naozaj si prajete resetovať počty aktívnych záznamov vybraných filtrov na nulu? Táto operácia sa nedá vrátiť späť!
-filter_regexp_tooltip=Tento filter je buď regulárny výraz alebo je príliš krátky, aby mohol byť optimalizovaný. Príliš mnoho z týchto filtrov môžu spomaliť prehliadanie.
-filter_elemhide_duplicate_id=Len jedno ID prvku na skrytie môže byť špecifikované
-filter_elemhide_nocriteria=Žiadne kritéria neboli špecifikované pre rozpoznanie prvku na skrytie
-subscription_no_location=Prosím zadajte umiestnenie na stiahnutie filtrov.
-subscription_invalid_location=Umiestnenie zoznamu filtrov nemá platnú URL alebo platný názov súboru.
-subscription_location_exists=Už ste povolili tento zoznam filtrov.
-synchronize_invalid_url=Zlyhanie, neplatná adresa
-synchronize_connection_error=Zlyhanie, sťahovanie neúspešné
-synchronize_invalid_data=Zlyhanie, neplatný zoznam filtrov
-synchronize_checksum_mismatch=Zlyhalo, chybné prispôsobenie kontrolného súčtu
-synchronize_ok=Úspešné
-overwrite=Prepísať
-append=Pridať
-new_filter_group_title=Nový filter
-type_label_other=iný
-type_label_script=skript
-type_label_image=obrázok
-type_label_stylesheet=stylesheet
-type_label_object=predmet
-type_label_subdocument=rámec
-type_label_document=dokument
-type_label_background=pozadie
-type_label_elemhide=skrytý
-type_label_xbl=XBL väzba
-type_label_ping=ping odkazu
-type_label_xmlhttprequest=XML požiadavka
-type_label_object_subrequest=podžiadosť predmetu
-type_label_dtd=DTD
-type_label_media=zvuk/video
-type_label_font=písmo

=== removed file 'chrome/locale/sk-SK/overlay.dtd'
--- chrome/locale/sk-SK/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sk-SK/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Stav:">
-<!ENTITY blocked.tooltip "Blokovať položky na tejto stránke:">
-<!ENTITY filters.tooltip "Najaktívnejšie filtre:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "A">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Blokovateľné položky">
-<!ENTITY context.image.label "Adblock obrázok">
-<!ENTITY context.object.label "Adblock objekt">
-<!ENTITY context.frame.label "Adblock rámec">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Znovu zapnúť túto stránku">
-<!ENTITY sidebar.title "Blokovateľné položky na aktuálnej stránke">
-<!ENTITY settings.label "Nastavenia">
-<!ENTITY settings.accesskey "N">
-<!ENTITY opensidebar.label "Otvoriť blokovateľné položky">
-<!ENTITY opensidebar.accesskey "b">
-<!ENTITY closesidebar.label "Zatvoriť blokovateľné položky">
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Vypnúť na --">
-<!ENTITY whitelist.page.label "Vypnúť len na tejto stránke">
-<!ENTITY objecttab.title "Blokovať">
-<!ENTITY objecttab.tooltip "Kliknúť sem pre blokovanie tohto objektu s Adblock Plus">

=== removed file 'chrome/locale/sk-SK/settings.dtd'
--- chrome/locale/sk-SK/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sk-SK/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,91 +0,0 @@
-<!ENTITY dialog.title "Nastavenia Adblock Plus">
-<!ENTITY filters.label "Filtre">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Pridať filter">
-<!ENTITY add.accesskey "D">
-<!ENTITY addsubscription.label "Pridať povolenie filtra">
-<!ENTITY addsubscription.accesskey "P">
-<!ENTITY synchsubscriptions.label "Aktualizovať všetky povolenia">
-<!ENTITY synchsubscriptions.accesskey "T">
-<!ENTITY import.label "Importovať filtre">
-<!ENTITY import.accesskey "M">
-<!ENTITY export.label "Exportovať filtre">
-<!ENTITY export.accesskey "X">
-<!ENTITY clearall.label "Odstrániť všetky filtre">
-<!ENTITY clearall.accesskey "V">
-<!ENTITY resethitcounts.label "Resetovať štatistiku počítadla">
-<!ENTITY resethitcounts.accesskey "R">
-<!ENTITY edit.label "Upraviť">
-<!ENTITY edit.accesskey "U">
-<!ENTITY cut.label "Vystrihnúť">
-<!ENTITY cut.accesskey "V">
-<!ENTITY copy.label "Kopírovať">
-<!ENTITY copy.accesskey "K">
-<!ENTITY paste.label "Prilepiť">
-<!ENTITY paste.accesskey "E">
-<!ENTITY remove.label "Odstrániť">
-<!ENTITY remove.accesskey "O">
-<!ENTITY menu.find.label "Nájsť">
-<!ENTITY menu.find.accesskey "N">
-<!ENTITY menu.findagain.label "Nájsť znova">
-<!ENTITY menu.findagain.accesskey "Z">
-<!ENTITY view.label "Zobraziť">
-<!ENTITY view.accesskey "Z">
-<!ENTITY sort.label "Triediť podľa">
-<!ENTITY sort.accesskey "T">
-<!ENTITY sort.none.label "Netriedené">
-<!ENTITY sort.none.accesskey "N">
-<!ENTITY sort.ascending.label "Triediť od A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Triediť od Z &gt; A">
-<!ENTITY sort.descending.accesskey "d">
-<!ENTITY options.label "Možnosti">
-<!ENTITY options.accesskey "M">
-<!ENTITY enable.label "Zapnúť Adblock Plus">
-<!ENTITY enable.accesskey "A">
-<!ENTITY showintoolbar.label "Zobraziť v paneli nástrojov">
-<!ENTITY showintoolbar.accesskey "B">
-<!ENTITY showinstatusbar.label "Zobraziť v stavovom riadku">
-<!ENTITY showinstatusbar.accesskey "S">
-<!ENTITY objecttabs.label "Zobraziť karty pre Flash a Java">
-<!ENTITY objecttabs.accesskey "F">
-<!ENTITY collapse.label "Usporiadať blokované prvky">
-<!ENTITY collapse.accesskey "U">
-<!ENTITY help.label "Pomocník">
-<!ENTITY help.accesskey "P">
-<!ENTITY gettingStarted.label "Začíname">
-<!ENTITY gettingStarted.accesskey "m">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Často kladené otázky">
-<!ENTITY faq.accesskey "K">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Písanie filtrov Adblock Plus">
-<!ENTITY filterdoc.accesskey "F">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "O rozšírení Adblock Plus">
-<!ENTITY about.accesskey "O">
-<!ENTITY description "Pridať adresu,ktorú chcete blokovať, návrhy skontrolujte v rozbaľovacej ponuke.
-		Môžete použiť * ako divokú kartu na vytvorenie všeobecných filtrov. Pokročilí používatelia môžu
-		použiť regulárne výrazy ako /banner\d+\.gif$/.">
-<!ENTITY filter.column "Pravidlo filtra">
-<!ENTITY filter.accesskey "f">
-<!ENTITY slow.column "Voľné filtre">
-<!ENTITY slow.accesskey "V">
-<!ENTITY enabled.column "Zapnuté">
-<!ENTITY enabled.accesskey "Z">
-<!ENTITY hitcount.column "Počítadlá">
-<!ENTITY hitcount.accesskey "P">
-<!ENTITY lasthit.column "Posledný zápis">
-<!ENTITY lasthit.accesskey "s">
-<!ENTITY context.edit.label "Upraviť filter">
-<!ENTITY context.resethitcount.label "Resetovať štatistiku počítadla pre filter">
-<!ENTITY context.synchsubscription.label "Aktualizovať povolenia teraz">
-<!ENTITY context.editsubscription.label "Upraviť povolené">
-<!ENTITY context.moveup.label "Posunúť hore">
-<!ENTITY context.movedown.label "Posunúť dole">
-<!ENTITY context.movegroupup.label "Posunúť skupinu hore">
-<!ENTITY context.movegroupdown.label "Posunúť skupinu dole">
-<!ENTITY context.enable.label "Zapnúť">
-<!ENTITY context.disable.label "Vypnúť">
-<!ENTITY apply.label "Potvrdiť">
-<!ENTITY apply.accesskey "V">

=== removed file 'chrome/locale/sk-SK/sidebar.dtd'
--- chrome/locale/sk-SK/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sk-SK/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Blokovateľné položky (oddelený)">
-<!ENTITY detach.label "Oddeliť">
-<!ENTITY reattach.label "Znovu pripojiť">
-<!ENTITY search.label "Hľadať:">
-<!ENTITY search.accesskey "H">
-<!ENTITY type.label "Typ">
-<!ENTITY address.label "Adresa">
-<!ENTITY filter.label "Filter">
-<!ENTITY state.label "Stav">
-<!ENTITY size.label "Veľkosť">
-<!ENTITY docDomain.label "Zdroj dokumentu">
-<!ENTITY noitems.label "Neblokovateľné položky">
-<!ENTITY whitelisted.label "Povolené stránky">
-<!ENTITY tooltip.address.label "Adresa:">
-<!ENTITY tooltip.type.label "Typ:">
-<!ENTITY tooltip.type.blocked "(blokovaný)">
-<!ENTITY tooltip.type.whitelisted "(povolený)">
-<!ENTITY tooltip.size.label "Veľkosť:">
-<!ENTITY tooltip.docDomain.label "Zdroj dokumentu:">
-<!ENTITY tooltip.filter.label "Platný filter:">
-<!ENTITY tooltip.filterSource.label "Zdroj filtra:">
-<!ENTITY context.block.label "Blokovať túto položku">
-<!ENTITY context.editfilter.label "Upraviť filter v skutočnosti">
-<!ENTITY context.whitelist.label "Pridať výnimku pre položku">
-<!ENTITY context.disablefilter.label "Vypnúť filter --">
-<!ENTITY context.enablefilter.label "Znovu zapnúť filter --">
-<!ENTITY context.disablefilteronsite.label "Vypnúť tento filter na...">
-<!ENTITY context.open.label "Otvoriť na novej karte">
-<!ENTITY context.flash.label "Ohraničenie flashových položiek">
-<!ENTITY context.copy.label "Kopírovať adresu položiek">
-<!ENTITY context.copyFilter.label "Kopírovať filter">
-<!ENTITY context.selectAll.label "Vybrať všetko">

=== removed file 'chrome/locale/sk-SK/subscription.dtd'
--- chrome/locale/sk-SK/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sk-SK/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,20 +0,0 @@
-<!ENTITY dialog.title "Upraviť povolenie filtra">
-<!ENTITY dialog.newtitle "Pridať povolenie filtra">
-<!ENTITY new.description "Zadajte, prosím, webovú adresu alebo súbor obsahujúci zoznam
-	Adblock Plus filtrov.">
-<!ENTITY edit.description "Zoznam filtrov pre toto povolenie bude prevzatý
-	z daného umiestnenia.">
-<!ENTITY external.description "Toto je externý filter povolenia, jeho zoznam
-	bude zahrnutý v najnovšom rozšírení, ktoré vytvorilo toto
-	povolenie.">
-<!ENTITY autodownload.description "Ak zvolíte &apos;Automatická aktualizácia&apos;, toto umiestnenie bude
-	zahrnuté do dennej aktualizácie. Ak túto možnosť vypnete, stále môžete
-	aktualizovať ručne z kontextovej ponuky povolení.">
-<!ENTITY location.label "Umiestnenie zoznamu filtrov:">
-<!ENTITY location.accesskey "M">
-<!ENTITY title.label "Názov povolenia:">
-<!ENTITY title.accesskey "Z">
-<!ENTITY autodownload.label "Automatická aktualizácia">
-<!ENTITY autodownload.accesskey "T">
-<!ENTITY enabled.label "Zapnúť filtre">
-<!ENTITY enabled.accesskey "N">

=== removed file 'chrome/locale/sk-SK/tip_subscriptions.dtd'
--- chrome/locale/sk-SK/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sk-SK/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,18 +0,0 @@
-<!ENTITY dialog.title "Vitajte na Adblock Plus">
-<!ENTITY description.par1 "Ďakujeme za nainštalovanie Adblock Plus. Toto rozšírenie môže eliminovať 99&#37; reklám, ktoré sa zobrazujú na webe. Pravdupovediac, efektívne blokovanie reklám vyžaduje, aby ste nadefinovali dobrý filter reklám. Môžete to urobiť sám, alebo si  môžete jednoducho vybrať zo zoznamov filtrov od tých, ktorí ich robia za vás. Stále si však budete môcť filtre pridávať sami, alebo ukončiť odoberanie, kedykoľvek budete chcieť.">
-<!ENTITY description.par2 "Môžete si vybrať jednu z možností zo zoznamu dole(viac možností môže byť pridaných do Nastavení Adblock Plus neskôr, aj keď to nie je potrebné):">
-<!ENTITY note "Poznámka: Zoznam filtrov je najefektívnejší, keď je na stránke použitý
-	zoznam filtrov z regiónu, v ktorom bol vytvorený.">
-<!ENTITY adblock.warning "Adblock Plus zistil, že máte nainštalovaný Adblock alebo staršiu verziu Adblock Plus. Súbežné používanie Adblock a Adblock Plus môže viesť k problémom a mali by ste sa tomu vyhnúť. Odporúčame, aby ste Adblock odinštalovali.">
-<!ENTITY adblock.uninstall "Odinštalovať Adblock">
-<!ENTITY filterset.g.warning "Zdá sa, že používate Filterset.G. Tento zoznam filtrov bol sotva obnovovaný posledných pár rokov a je bežnou príčinou problémov so stránkami na webe. Odporúčame, aby ste odinštalovali Filterset.G.">
-<!ENTITY filterset.g.moreinfo "Viac informácií">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Odinštalovať Filterset.G">
-<!ENTITY homepage.label "Domovská stránka">
-<!ENTITY subscribe.label "Odoberať">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "Pridať iné odoberania">
-<!ENTITY other.accesskey "P">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Zobraziť všetky odbery">

=== added file 'chrome/locale/sk/about.dtd'
--- chrome/locale/sk/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sk/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,13 @@
+<!ENTITY dialog.title "O rozšírení Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Verzia">
+<!ENTITY description "Adblock Plus vám umožní rozhodnúť sa, čo si neprajete zobrazovať na stránkach.
+	Nepotrebujete preberať všetky reklamy a titulky, ak ich nechcete - povedzte to Adblock Plus!">
+<!ENTITY homepage.label "Domovská stránka Adblock Plus:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Autor:">
+<!ENTITY contributors.label "Prispievatelia:">
+<!ENTITY developers.label "Vývojári:">
+<!ENTITY designers.label "Grafický dizajnéri:">
+<!ENTITY subscriptionAuthors.label "Autori povolení filtrov:">
+<!ENTITY translators.label "Prekladatalia:">

=== added file 'chrome/locale/sk/composer.dtd'
--- chrome/locale/sk/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sk/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Pridať pravidlo filtra">
+<!ENTITY accept.label "Pridať filter">
+<!ENTITY advanced.label "Pokročilý náhľad">
+<!ENTITY basic.label "Jednoduchý náhľad">
+<!ENTITY disabled.warning "Adblock Plus je aktuálne vypnutý. Môžete pridávať filtre, ale tie nebudú aplikované pokiaľ [link]nezapnete Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Skupina filtrov &quot;?1?&quot;, ktorá mala tento filter pridať, je aktuálne vypnutá. Stále ho však môžete pridať, ale nebude aplikovaný skôr, než [link]zapnete skupinu filtrov[/link].">
+<!ENTITY filter.label "Nový filter:">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "Zobraziť existujúce filtre...">
+<!ENTITY preferences.accesskey "Z">
+<!ENTITY type.filter.label "Blokovanie filtra">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Základné pravidlo">
+<!ENTITY type.whitelist.accesskey "k">
+<!ENTITY pattern.label "Vyhľadať vzor">
+<!ENTITY pattern.explanation "Vzor môže byť nejaká časť adresy, symbol * ako divoká karta. Filter ešte len bude aplikovaný na adresy zodpovedajúce vzoru.">
+<!ENTITY regexp.warning "Vzor, ktorý ste vložili bude interpretovaný ako regulárny výraz. Mnoho regulárnych výrazov môže spomaliť prehliadanie. Ak ste nemali v úmysle používať regulárne výrazy, pridajte symbol * na koniec vzoru.">
+<!ENTITY shortpattern.warning "Vzor, ktorý ste vložili je príliš krátky, aby mohol byť optimalizovaný, mnoho takýchto schém môže spomaliť prehliadanie. Odporúčame, aby ste vybrali dlhší reťazec pre tento filter.">
+<!ENTITY custom.pattern.label "Vlastné:">
+<!ENTITY custom.pattern.accesskey "V">
+<!ENTITY anchors.label "Prijať vzor len:">
+<!ENTITY anchor.start.label "na začiatku adresy">
+<!ENTITY anchor.start.accesskey "n">
+<!ENTITY anchor.start.flexible.label "na začiatku názvu domény">
+<!ENTITY anchor.start.flexible.accesskey "n">
+<!ENTITY anchor.end.label "na konci adresy">
+<!ENTITY anchor.end.accesskey "d">
+<!ENTITY options.label "Možnosti">
+<!ENTITY domainRestriction.label "Obmedziť na doménu:">
+<!ENTITY domainRestriction.accesskey "e">
+<!ENTITY domainRestriction.help "Špecifikujte jednu alebo viac domén oddelených značkou &quot;|&quot;, filter bude obmedzený len pre tieto domény. Symbol &quot;~&quot; pred názvom domény znamená, že filter by nemal byť aplikovaný na tejto doméne.">
+<!ENTITY firstParty.label "Len prvá strana">
+<!ENTITY firstParty.accesskey "L">
+<!ENTITY thirdParty.label "Len tretie strany">
+<!ENTITY thirdParty.accesskey "t">
+<!ENTITY matchCase.label "Modelový prípad">
+<!ENTITY matchCase.accesskey "M">
+<!ENTITY types.label "Aplikovať na typy:">
+<!ENTITY selectAllTypes.label "Vybrať všetko">
+<!ENTITY unselectAllTypes.label "Nezvoliť nič">
+<!ENTITY collapse.label "Pád zablokovaný::">
+<!ENTITY collapse.accesskey "o">
+<!ENTITY collapse.default.yes.label "Použiť pôvodné (áno)">
+<!ENTITY collapse.default.no.label "Použiť pôvodné (nie)">
+<!ENTITY collapse.yes.label "Áno">
+<!ENTITY collapse.no.label "Nie">

=== added file 'chrome/locale/sk/global.properties'
--- chrome/locale/sk/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/sk/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Kliknúť na vyvolanie kontextovej ponuky, kliknutie prostredným pre Zapnúť/Vypnúť.
+action1_tooltip=Kliknúť pre Otvoriť/Zavrieť blokovateľné položky, kliknutie prostredným pre Zapnúť/Vypnúť.
+action2_tooltip=Kliknúť pre otvorenie nastavení, kliknutie prostredným pre Zapnúť/Vypnúť.
+action3_tooltip=Kliknúť pre Otvoriť/Zavrieť Adblock Plus.
+disabled_tooltip=Adblock Plus je vypnutý.
+active_tooltip=Adblock Plus  je aktívny,?1? popis filtra(ov) a ?2? vlastný filtr(e) sa používa .
+whitelisted_tooltip=Adblock Plus je aktívny, ale vypnutý na aktuálnej stránke.
+blocked_count_tooltip=?1? mimo ?2?
+blocked_count_addendum=(tiež biely zoznam: ?1?, skrytý: ?2?)
+no_blocking_suggestions=Na aktuálnej stránke nie sú blokovateľné položky
+whitelisted_page=Adblock Plus bol zakázaný pre aktuálnu stránku
+whitelist_description=Výnimky
+filterlist_description=Filtre reklám
+invalid_description=Nesprávne filtre
+elemhide_description=Skryté pravidlá prvkov
+subscription_description=Povolený filter:
+subscription_wrong_version=Niektoré filtre v tomto povolení vyžadujú Adblock Plus ?1? k správnej činnosti!
+subscription_source=Zdroj:
+subscription_status=Stav:
+subscription_status_autodownload=Aktualizovaný automaticky
+subscription_status_manualdownload=Aktualizovaný manuálne
+subscription_status_externaldownload=Aktualizovaný externe (iné rozšírenie)
+subscription_status_lastdownload=Posledné prevzatie:
+subscription_status_lastdownload_inprogress=Preberanie...
+subscription_status_lastdownload_unknown=N/A
+remove_subscription_warning=Naozaj si želáte odstrániť toto povolenie?
+import_filters_wrong_version=Upozornenie: Niektoré filtre v tomto zozname vyžadujú Adblock Plus ?1? k správnej činnosti. Pred importovaním tohto zoznamu by ste mal aktualizovať Adblock Plus na poslednú verziu.
+import_filters_warning=Želáte si nahradiť vaše aktuálne filtre alebo pridať nové filtre na koniec zoznamu?
+import_filters_title=Importovať filtre
+export_filters_title=Exportovať filtre
+invalid_filters_file=Neplatný súbor filtrov Adblock Plus.
+filters_write_error=Pri zapisovaní filtrov do súboru bola zistená chyba. Presvedčte sa, že súbor nie je chránený proti zapisovaniu alebo zvoľte iný program.
+clearall_warning=Naozaj si želáte odstrániť všetky filtre zo zoznamu?
+resethitcounts_warning=Naozaj si prajete obnoviť počty aktívnych záznamov všetkých filtrov na nulu? Táto operácia sa nedá vrátiť späť!
+resethitcounts_selected_warning=Naozaj si prajete resetovať počty aktívnych záznamov vybraných filtrov na nulu? Táto operácia sa nedá vrátiť späť!
+filter_regexp_tooltip=Tento filter je buď regulárny výraz alebo je príliš krátky, aby mohol byť optimalizovaný. Príliš mnoho z týchto filtrov môžu spomaliť prehliadanie.
+filter_elemhide_duplicate_id=Len jedno ID prvku na skrytie môže byť špecifikované
+filter_elemhide_nocriteria=Žiadne kritéria neboli špecifikované pre rozpoznanie prvku na skrytie
+subscription_notAdded_warning=Nepridali ste popis filtra. Bez popisu filtra budete musieť pridať Adblock Plus filtre manuálne.
+subscription_notAdded_warning_addendum=Chcete pokračovať?
+subscription_invalid_location=Umiestnenie zoznamu filtrov nemá platnú URL alebo platný názov súboru.
+synchronize_invalid_url=Zlyhanie, neplatná adresa
+synchronize_connection_error=Zlyhanie, sťahovanie neúspešné
+synchronize_invalid_data=Zlyhanie, neplatný zoznam filtrov
+synchronize_checksum_mismatch=Zlyhalo, chybné prispôsobenie kontrolného súčtu
+synchronize_ok=Úspešné
+overwrite=Prepísať
+append=Pridať
+new_filter_group_title=Nový filter
+type_label_other=iný
+type_label_script=skript
+type_label_image=obrázok
+type_label_stylesheet=stylesheet
+type_label_object=predmet
+type_label_subdocument=rámec
+type_label_document=dokument
+type_label_background=pozadie
+type_label_elemhide=skrytý
+type_label_xbl=XBL väzba
+type_label_ping=ping odkazu
+type_label_xmlhttprequest=XML požiadavka
+type_label_object_subrequest=podžiadosť predmetu
+type_label_dtd=DTD
+type_label_media=zvuk/video
+type_label_font=písmo
+fennec_status_enabled=Adblock Plus je zapnutý.
+fennec_status_disabled=Adblock Plus je vypnutý
+fennec_status_enabled_site=Adblock Plus je zapnutý na  ?1?.
+fennec_status_disabled_site=Adblock Plus je vypnutý na ?1?.

=== added file 'chrome/locale/sk/meta.properties'
--- chrome/locale/sk/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/sk/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Ján Kendi (Jacen)
+name=Adblock Plus
+description=Reklamy sú minulosťou!
+description.short=Ste otrávení reklamami? Máte problémy so sledovaním? Obťažovaní banermi? Nainštalujte si Adblock Plus teraz pre znovu získanie kontroly na internete a zmeňte pohľad na web.\n\n Krátke video je dostupné na http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus umožňuje znovu získanie kontroly na internete a pohľad na web aký chcete. Rozšírenie je podporované viac ako štyridsiatimi skupinami filtrov v niekoľkých jazykoch, ktoré sa automaticky konfigurujú v rozsahu od odstraňovania online reklamy po blokovanie známych domén malware. Adblock Plus tiež umožňuje upravovať vaše filtre pomocou rôznych užitočných vlastností, vrátane kontextovej možnosti pre obrázky, blokovacie karty pre Flash a Java objekty a zoznam blokovateľných položiek na odstránenie skriptov a štýlov.

=== added file 'chrome/locale/sk/overlay.dtd'
--- chrome/locale/sk/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sk/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Stav:">
+<!ENTITY blocked.tooltip "Blokovať položky na tejto stránke:">
+<!ENTITY filters.tooltip "Najaktívnejšie filtre:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "A">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Blokovateľné položky">
+<!ENTITY context.image.label "Adblock obrázok">
+<!ENTITY context.object.label "Adblock objekt">
+<!ENTITY context.frame.label "Adblock rámec">
+<!ENTITY context.media.label "Adblock Plus: Blokovať audio/video">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Znovu zapnúť túto stránku">
+<!ENTITY sidebar.title "Blokovateľné položky na aktuálnej stránke">
+<!ENTITY settings.label "Nastavenia">
+<!ENTITY settings.accesskey "N">
+<!ENTITY opensidebar.label "Otvoriť blokovateľné položky">
+<!ENTITY opensidebar.accesskey "b">
+<!ENTITY closesidebar.label "Zatvoriť blokovateľné položky">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "Vypnúť na ?1?">
+<!ENTITY whitelist.page.label "Vypnúť len na tejto stránke">
+<!ENTITY objecttab.title "Blokovať">
+<!ENTITY objecttab.tooltip "Kliknúť sem pre blokovanie tohto objektu s Adblock Plus">

=== added file 'chrome/locale/sk/settings.dtd'
--- chrome/locale/sk/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sk/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,92 @@
+<!ENTITY dialog.title "Nastavenia Adblock Plus">
+<!ENTITY filters.label "Filtre">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Pridať filter">
+<!ENTITY add.accesskey "D">
+<!ENTITY addsubscription.label "Pridať povolenie filtra">
+<!ENTITY addsubscription.accesskey "P">
+<!ENTITY synchsubscriptions.label "Aktualizovať všetky povolenia">
+<!ENTITY synchsubscriptions.accesskey "T">
+<!ENTITY import.label "Importovať filtre">
+<!ENTITY import.accesskey "M">
+<!ENTITY export.label "Exportovať filtre">
+<!ENTITY export.accesskey "X">
+<!ENTITY clearall.label "Odstrániť všetky filtre">
+<!ENTITY clearall.accesskey "V">
+<!ENTITY resethitcounts.label "Resetovať štatistiku počítadla">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "Upraviť">
+<!ENTITY edit.accesskey "U">
+<!ENTITY cut.label "Vystrihnúť">
+<!ENTITY cut.accesskey "V">
+<!ENTITY copy.label "Kopírovať">
+<!ENTITY copy.accesskey "K">
+<!ENTITY paste.label "Prilepiť">
+<!ENTITY paste.accesskey "E">
+<!ENTITY remove.label "Odstrániť">
+<!ENTITY remove.accesskey "O">
+<!ENTITY menu.find.label "Nájsť">
+<!ENTITY menu.find.accesskey "N">
+<!ENTITY menu.findagain.label "Nájsť znova">
+<!ENTITY menu.findagain.accesskey "Z">
+<!ENTITY view.label "Zobraziť">
+<!ENTITY view.accesskey "Z">
+<!ENTITY sort.label "Triediť podľa">
+<!ENTITY sort.accesskey "T">
+<!ENTITY sort.none.label "Netriedené">
+<!ENTITY sort.none.accesskey "N">
+<!ENTITY sort.ascending.label "Triediť od A &gt; Z">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Triediť od Z &gt; A">
+<!ENTITY sort.descending.accesskey "d">
+<!ENTITY options.label "Možnosti">
+<!ENTITY options.accesskey "M">
+<!ENTITY enable.label "Zapnúť Adblock Plus">
+<!ENTITY enable.accesskey "A">
+<!ENTITY showintoolbar.label "Zobraziť v paneli nástrojov">
+<!ENTITY showintoolbar.accesskey "B">
+<!ENTITY showinstatusbar.label "Zobraziť v stavovom riadku">
+<!ENTITY showinstatusbar.accesskey "S">
+<!ENTITY objecttabs.label "Zobraziť karty pre Flash a Java">
+<!ENTITY objecttabs.accesskey "F">
+<!ENTITY collapse.label "Usporiadať blokované prvky">
+<!ENTITY collapse.accesskey "U">
+<!ENTITY help.label "Pomocník">
+<!ENTITY help.accesskey "P">
+<!ENTITY gettingStarted.label "Začíname">
+<!ENTITY gettingStarted.accesskey "m">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Často kladené otázky">
+<!ENTITY faq.accesskey "K">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Písanie filtrov Adblock Plus">
+<!ENTITY filterdoc.accesskey "F">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "O rozšírení Adblock Plus">
+<!ENTITY about.accesskey "O">
+<!ENTITY description "Pridať adresu,ktorú chcete blokovať, návrhy skontrolujte v rozbaľovacej ponuke.
+		Môžete použiť * ako divokú kartu na vytvorenie všeobecných filtrov. Pokročilí používatelia môžu
+		použiť regulárne výrazy ako /banner\d+\.gif$/.">
+<!ENTITY filter.column "Pravidlo filtra">
+<!ENTITY filter.accesskey "f">
+<!ENTITY slow.column "Voľné filtre">
+<!ENTITY slow.accesskey "V">
+<!ENTITY enabled.column "Zapnuté">
+<!ENTITY enabled.accesskey "Z">
+<!ENTITY hitcount.column "Počítadlá">
+<!ENTITY hitcount.accesskey "P">
+<!ENTITY lasthit.column "Posledný zápis">
+<!ENTITY lasthit.accesskey "s">
+<!ENTITY context.edit.label "Upraviť filter">
+<!ENTITY context.resethitcount.label "Resetovať štatistiku počítadla pre filter">
+<!ENTITY context.synchsubscription.label "Aktualizovať povolenia teraz">
+<!ENTITY context.editsubscription.label "Upraviť povolené">
+<!ENTITY context.moveup.label "Posunúť hore">
+<!ENTITY context.movedown.label "Posunúť dole">
+<!ENTITY context.movegroupup.label "Posunúť skupinu hore">
+<!ENTITY context.movegroupdown.label "Posunúť skupinu dole">
+<!ENTITY context.enable.label "Zapnúť">
+<!ENTITY context.disable.label "Vypnúť">
+<!ENTITY apply.label "Potvrdiť">
+<!ENTITY apply.accesskey "V">
+<!ENTITY fennec.subscription.label "Popis filtra">

=== added file 'chrome/locale/sk/sidebar.dtd'
--- chrome/locale/sk/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sk/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Blokovateľné položky (oddelený)">
+<!ENTITY detach.label "Oddeliť">
+<!ENTITY reattach.label "Znovu pripojiť">
+<!ENTITY search.label "Hľadať:">
+<!ENTITY search.accesskey "H">
+<!ENTITY type.label "Typ">
+<!ENTITY address.label "Adresa">
+<!ENTITY filter.label "Filter">
+<!ENTITY state.label "Stav">
+<!ENTITY size.label "Veľkosť">
+<!ENTITY docDomain.label "Zdroj dokumentu">
+<!ENTITY noitems.label "Neblokovateľné položky">
+<!ENTITY whitelisted.label "Povolené stránky">
+<!ENTITY tooltip.address.label "Adresa:">
+<!ENTITY tooltip.type.label "Typ:">
+<!ENTITY tooltip.type.blocked "(blokovaný)">
+<!ENTITY tooltip.type.whitelisted "(povolený)">
+<!ENTITY tooltip.size.label "Veľkosť:">
+<!ENTITY tooltip.docDomain.label "Zdroj dokumentu:">
+<!ENTITY tooltip.filter.label "Platný filter:">
+<!ENTITY tooltip.filterSource.label "Zdroj filtra:">
+<!ENTITY context.block.label "Blokovať túto položku">
+<!ENTITY context.editfilter.label "Upraviť filter v skutočnosti">
+<!ENTITY context.whitelist.label "Pridať výnimku pre položku">
+<!ENTITY context.disablefilter.label "Vypnúť filter ?1?">
+<!ENTITY context.enablefilter.label "Znovu zapnúť filter ?1?">
+<!ENTITY context.disablefilteronsite.label "Vypnúť tento filter na ?1?">
+<!ENTITY context.open.label "Otvoriť na novej karte">
+<!ENTITY context.flash.label "Ohraničenie flashových položiek">
+<!ENTITY context.copy.label "Kopírovať adresu položiek">
+<!ENTITY context.copyFilter.label "Kopírovať filter">
+<!ENTITY context.selectAll.label "Vybrať všetko">

=== added file 'chrome/locale/sk/subscriptionSelection.dtd'
--- chrome/locale/sk/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sk/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Odoberanie Add Adblock Plus filtrov">
+<!ENTITY dialog.title.edit "Upraviť povolenie filtra">
+<!ENTITY description.newInstall "Adblock Plus bude efektívnejší ak pridáte odber filtra. Odber filtrov sú voľne poskytované inými používateľmi Adblock Plus. Najvhodnejší odber pre váš jazyk je už zvolený.">
+<!ENTITY adblock.warning "Adblock Plus zistil, že máte nainštalovaný Adblock alebo staršiu verziu Adblock Plus. Súbežné používanie Adblock a Adblock Plus môže viesť k problémom a mali by ste sa tomu vyhnúť. Odporúčame, aby ste Adblock odinštalovali.">
+<!ENTITY adblock.uninstall "Odinštalovať Adblock">
+<!ENTITY filterset.g.warning "Zdá sa, že používate Filterset.G. Tento zoznam filtrov bol sotva obnovovaný posledných pár rokov a je bežnou príčinou problémov so stránkami na webe. Odporúčame, aby ste odinštalovali Filterset.G.">
+<!ENTITY filterset.g.moreinfo "Viac informácií">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Odinštalovať Filterset.G">
+<!ENTITY subscriptionSelector.label "Prosím, zvoľte odber zo zoznamu:">
+<!ENTITY viewList.label "Zobraziť filtre">
+<!ENTITY visitHomepage.label "Navštíviť domovskú stránku">
+<!ENTITY addSubscription.label "Pridať odber">
+<!ENTITY saveSubscription.label "Uložiť odber">
+<!ENTITY other.label "Pridať iné odoberania">
+<!ENTITY other.accesskey "P">
+<!ENTITY list.download.failed "Adblock Plus zlyhal pri získavaní zoznamu odberov.">
+<!ENTITY list.download.retry "Skúsiť znova">
+<!ENTITY list.download.website "Zobraziť webovú stránku">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Prosím, potvrďte, že chcete pridať tento filter odberu.">
+<!ENTITY edit.description "Môžete zmeniť názov odberu alebo umiestnenie ak je to potrebné.">
+<!ENTITY external.description "Toto je externý filter odberu;bude aktualizovaný podľa prípony, ktorý vytvoril tento odber.">
+<!ENTITY title.label "Názov povolenia:">
+<!ENTITY title.accesskey "Z">
+<!ENTITY location.label "Umiestnenie zoznamu filtrov:">
+<!ENTITY location.accesskey "M">
+<!ENTITY autodownload.label "Automatická aktualizácia">
+<!ENTITY autodownload.accesskey "T">
+<!ENTITY supplementMessage "Tento filter odberu je určený pre použitie s filtrom odberu &quot;?1?&quot;ktorý ešte nepoužívate.">
+<!ENTITY addMain.label "Pridať tiež filter odberu &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "o">

=== added directory 'chrome/locale/sl'
=== removed directory 'chrome/locale/sl-SI'
=== removed file 'chrome/locale/sl-SI/about.dtd'
--- chrome/locale/sl-SI/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sl-SI/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "O Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "različice">
-<!ENTITY description "Adblock Plus daje moč, da izključite tisto, česar na spletu ne želite videti. Nič več vam ni treba gledati oglasov in pasic, če tega nočete - povejte to razširitvi Adblock Plus!">
-<!ENTITY homepage.label "Domača stran Adblock Plus:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Avtor:">
-<!ENTITY contributors.label "Avtorji prispevkov:">

=== removed file 'chrome/locale/sl-SI/composer.dtd'
--- chrome/locale/sl-SI/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sl-SI/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Dodaj pravilo filtra Adblock Plus">
-<!ENTITY accept.label "Dodaj filter">
-<!ENTITY advanced.label "Napredni pogled">
-<!ENTITY basic.label "Osnovni pogled">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus je trenutno onemogočen. Še vedno lahko dodajate filtre, vendar ne bodo veljali, če ne">
-<!ENTITY disabled.warning.link "omogočite Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Skupina filtrov &quot;&#37;S&quot;, kateri naj bo dodan ta filter, je trenutno onemogočena. Še vedno ji lahko dodate filter, vendar ne bo deloval, razen če ne">
-<!ENTITY groupDisabled.warning.link "omogočite skupine filtrov">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Nov filter:">
-<!ENTITY filter.accesskey "f">
-<!ENTITY preferences.label "Pokaži obstoječe filtre ...">
-<!ENTITY preferences.accesskey "ž">
-<!ENTITY type.filter.label "Filter blokade">
-<!ENTITY type.filter.accesskey "b">
-<!ENTITY type.whitelist.label "Pravilo izjem">
-<!ENTITY type.whitelist.accesskey "l">
-<!ENTITY pattern.label "Išči vzorec">
-<!ENTITY pattern.explanation "Vzorec je lahko kateri koli del naslova, simbol * velja kot poljuben znak. Filter bo le za naslove, ki ustrezajo vzorcu.">
-<!ENTITY regexp.warning "Vneseni vzorec bo obravnavan kot regularni izraz. Številni regularni izrazi lahko upočasnijo vaše brskanje. Če ne nameravate uporabljati regularnih izrazov, dodajte simbol * na konec vzorca.">
-<!ENTITY shortpattern.warning "Vzorec, ki ste ga vnesli, je prekratek za optimizacijo, številni tovrstni vzorci lahko upočasnijo vaše brskanje. Priporočamo, da izberete daljši niz za ta filter.">
-<!ENTITY custom.pattern.label "Po meri:">
-<!ENTITY custom.pattern.accesskey "m">
-<!ENTITY anchors.label "Sprejmi le vzorec:">
-<!ENTITY anchor.start.label "na začetku naslova">
-<!ENTITY anchor.start.accesskey "z">
-<!ENTITY anchor.start.flexible.label "na začetku imena domene">
-<!ENTITY anchor.start.flexible.accesskey "z">
-<!ENTITY anchor.end.label "na koncu naslova">
-<!ENTITY anchor.end.accesskey "k">
-<!ENTITY options.label "Možnosti">
-<!ENTITY domainRestriction.label "Omeji na domeno:">
-<!ENTITY domainRestriction.accesskey "d">
-<!ENTITY domainRestriction.help "Navedite eno ali več domen, ločenih s simbolom &quot;|&quot;, filter bo veljal le za te domene. Simbol &quot;~&quot; pred imenom domene pomeni, da filter za to domeno ne sme veljati.">
-<!ENTITY firstParty.label "Samo prve stranke">
-<!ENTITY firstParty.accesskey "p">
-<!ENTITY thirdParty.label "Samo zunanje stranke">
-<!ENTITY thirdParty.accesskey "n">
-<!ENTITY matchCase.label "Razlikuj velike/male črke">
-<!ENTITY matchCase.accesskey "č">
-<!ENTITY types.label "Uporabi za vrste:">
-<!ENTITY selectAllTypes.label "Izberi vse">
-<!ENTITY unselectAllTypes.label "Nič ne izberi">
-<!ENTITY collapse.label "Strni blokirane:">
-<!ENTITY collapse.accesskey "r">
-<!ENTITY collapse.default.yes.label "Uporabi privzeto (da)">
-<!ENTITY collapse.default.no.label "Uporabi privzeto (ne)">
-<!ENTITY collapse.yes.label "Da">
-<!ENTITY collapse.no.label "Ne">

=== removed file 'chrome/locale/sl-SI/global.properties'
--- chrome/locale/sl-SI/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/sl-SI/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Oglasi so preteklost!
-status_active_label=Adblock
-status_disabled_label=Onemogočen
-action0_tooltip=Kliknite za pojavni meni, s srednjim klikom vključite/izključite.
-action1_tooltip=Kliknite za odprtje/zaprtje blokiranih elementov, s srednjim klikom vključite/izključite.
-action2_tooltip=Kliknite za nastavitve, s srednjim klikom vključite/izključite.
-action3_tooltip=Kliknite za vključitev/izključitev Adblock Plus.
-active_tooltip=Adblock Plus je aktiven.
-disabled_tooltip=Adblock Plus je izključen.
-whitelisted_tooltip=Adblock Plus je aktiven, vendar je za trenutno stran izključen.
-blocked_count_tooltip=-- zmanjkalo --
-no_blocking_suggestions=Na trenutni strani ni elementov blokad
-whitelisted_page=Za trenutno stran je bil Adblock Plus izključen
-whitelist_description=Pravila izjem
-filterlist_description=Filtri za oglase
-invalid_description=Neveljavni filtri
-elemhide_description=Pravila skrivanja elementov
-subscription_description=Naročnina na filter:
-subscription_wrong_version=Nekateri filtri v tej naročnini zahtevajo Adblock Plus, da bi delovali pravilno!
-subscription_source=Vir:
-subscription_status=Stanje:
-subscription_status_autodownload=Samodejno posodobljeno
-subscription_status_manualdownload=Ročno posodobljeno
-subscription_status_externaldownload=Zunanje posodobljeno (druga razširitev)
-subscription_status_lastdownload=Zadnji prenos:
-subscription_status_lastdownload_inprogress=Prenos s strežnika ...
-subscription_status_lastdownload_unknown=Ni na voljo
-remove_subscription_warning=Želite res odpovedati naročnino?
-import_filters_wrong_version=Opozorilo: nekateri od filtrov v tem seznamu za pravilno delovanje zahtevajo Adblock Plus. Najverjetneje morate nadgraditi razširitev na zadnjo izdajo Adblock Plus, preden uvozite ta seznam.
-import_filters_warning=Želite zamenjati obstoječe filtre ali dodati nove filtre na dno seznama?
-import_filters_title=Uvozi filtre
-export_filters_title=Izvozi filtre
-invalid_filters_file=Ni veljavna datoteka filtra Adblock Plus.
-filters_write_error=Pri pisanju filtrov v datoteko je prišlo do napake. Preverite, da datoteka ni zaščitena pred pisanjem ali odprta v drugem programu.
-clearall_warning=Resnično želite odstraniti vse filtre s seznama?
-resethitcounts_warning=Resnično želite ponastaviti števce za vse filtre na nič? Tega ni mogoče popraviti!
-resethitcounts_selected_warning=Resnično želite ponastaviti števce za izbrane filtre na nič? Tega ni mogoče popraviti!
-filter_regexp_tooltip=Ta filter je regularni izraz ali pa je prekratek za optimizacijo. Preveč filtrov lahko upočasni brskanje.
-filter_elemhide_duplicate_id=Navedete lahko le eno identiteto elementa, ki naj bo skrit
-filter_elemhide_nocriteria=Za razpoznavo elementa, ki naj bo skrit, ni navedenih pogojev
-subscription_no_location=Vnesite mesto za prenos filtrov.
-subscription_invalid_location=Mesto seznama filtrov ni niti veljaven URL niti veljavno ime datoteke.
-subscription_location_exists=Na ta seznam filtrov ste že naročeni.
-synchronize_invalid_url=Neuspešno, ni veljaven naslov
-synchronize_connection_error=Neuspešno, napaka prenosa
-synchronize_invalid_data=Neuspešno, ni veljaven seznam filtrov
-synchronize_checksum_mismatch=Neuspešno, kontrolna vsota se ne ujema
-synchronize_ok=Uspešno
-overwrite=Prepiši
-append=Dodaj
-new_filter_group_title=Nov filter
-type_label_other=drugo
-type_label_script=skript
-type_label_image=sliko
-type_label_stylesheet=predlogo strani
-type_label_object=predmet
-type_label_subdocument=okvir
-type_label_document=dokument
-type_label_background=ozadje
-type_label_elemhide=skrito
-type_label_xbl=Vezava XBL
-type_label_ping=poveži ping
-type_label_xmlhttprequest=Zahteva XML
-type_label_object_subrequest=podzahteva predmeta
-type_label_dtd=DTD
-type_label_media=zvok/video
-type_label_font=pisava

=== removed file 'chrome/locale/sl-SI/overlay.dtd'
--- chrome/locale/sl-SI/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sl-SI/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Stanje:">
-<!ENTITY blocked.tooltip "Blokirani elementi na tej strani:">
-<!ENTITY filters.tooltip "Najbolj aktivni filtri:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: elementi za blokiranje">
-<!ENTITY context.image.label "Adblock - slike">
-<!ENTITY context.object.label "Adblock - predmeti">
-<!ENTITY context.frame.label "Adblock - okviri">
-<!ENTITY context.removeWhitelist.label "Adblock Plus - ponovno omogoči na tej strani">
-<!ENTITY sidebar.title "Elementi blokad na trenutni strani">
-<!ENTITY settings.label "Nastavitve">
-<!ENTITY settings.accesskey "N">
-<!ENTITY opensidebar.label "Odpri elemente blokad">
-<!ENTITY opensidebar.accesskey "e">
-<!ENTITY closesidebar.label "Zapri elemente blokad">
-<!ENTITY closesidebar.accesskey "e">
-<!ENTITY whitelist.site.label "Onemogoči na --">
-<!ENTITY whitelist.page.label "Onemogoči samo na tej strani">
-<!ENTITY objecttab.title "Blokiraj">
-<!ENTITY objecttab.tooltip "Kliknite sem za blokiranje tega predmeta z Adblock Plus">

=== removed file 'chrome/locale/sl-SI/settings.dtd'
--- chrome/locale/sl-SI/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sl-SI/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Nastavitve Adblock Plus">
-<!ENTITY filters.label "Filtri">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Dodaj filter">
-<!ENTITY add.accesskey "D">
-<!ENTITY addsubscription.label "Dodaj naročnino filtra">
-<!ENTITY addsubscription.accesskey "n">
-<!ENTITY synchsubscriptions.label "Posodobi vse naročnine">
-<!ENTITY synchsubscriptions.accesskey "P">
-<!ENTITY import.label "Uvozi filtre">
-<!ENTITY import.accesskey "U">
-<!ENTITY export.label "Izvozi filtre">
-<!ENTITY export.accesskey "I">
-<!ENTITY clearall.label "Odstrani vse filtre">
-<!ENTITY clearall.accesskey "O">
-<!ENTITY resethitcounts.label "Ponastavi statistiko zadetkov">
-<!ENTITY resethitcounts.accesskey "z">
-<!ENTITY edit.label "Uredi">
-<!ENTITY edit.accesskey "e">
-<!ENTITY cut.label "Izreži">
-<!ENTITY cut.accesskey "i">
-<!ENTITY copy.label "Kopiraj">
-<!ENTITY copy.accesskey "K">
-<!ENTITY paste.label "Prilepi">
-<!ENTITY paste.accesskey "P">
-<!ENTITY remove.label "Izbriši">
-<!ENTITY remove.accesskey "b">
-<!ENTITY menu.find.label "Najdi">
-<!ENTITY menu.find.accesskey "d">
-<!ENTITY menu.findagain.label "Ponovno najdi">
-<!ENTITY menu.findagain.accesskey "j">
-<!ENTITY view.label "Pogled">
-<!ENTITY view.accesskey "o">
-<!ENTITY sort.label "Razvrsti">
-<!ENTITY sort.accesskey "v">
-<!ENTITY sort.none.label "Nerazvrščeno">
-<!ENTITY sort.none.accesskey "š">
-<!ENTITY sort.ascending.label "od A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "od Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Možnosti">
-<!ENTITY options.accesskey "ž">
-<!ENTITY enable.label "Omogoči Adblock Plus">
-<!ENTITY enable.accesskey "O">
-<!ENTITY showintoolbar.label "Pokaži v orodni vrstici">
-<!ENTITY showintoolbar.accesskey "k">
-<!ENTITY showinstatusbar.label "Pokaži v vrstici stanja">
-<!ENTITY showinstatusbar.accesskey "v">
-<!ENTITY objecttabs.label "Pokaži zavihke za Flash in Javo">
-<!ENTITY objecttabs.accesskey "z">
-<!ENTITY collapse.label "Zloži blokirane elemente">
-<!ENTITY collapse.accesskey "l">
-<!ENTITY help.label "Pomoč">
-<!ENTITY help.accesskey "m">
-<!ENTITY gettingStarted.label "Prvi koraki">
-<!ENTITY gettingStarted.accesskey "k">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Pogosto zastavljena vprašanja">
-<!ENTITY faq.accesskey "P">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Pisanje filtrov Adblock Plus">
-<!ENTITY filterdoc.accesskey "s">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "O Adblock Plus">
-<!ENTITY about.accesskey "b">
-<!ENTITY description "Dodajte naslove, ki bi jih radi blokirali, za nasvete preverite seznamsko polje. Uporabite lahko * za izdelavo bolj splošnih filtrov. Napredni uporabniki lahko uporabite regularne izraze kot je /banner\d+\.gif$/.">
-<!ENTITY filter.column "Pravilo filtra">
-<!ENTITY filter.accesskey "f">
-<!ENTITY slow.column "Počasni filtri">
-<!ENTITY slow.accesskey "č">
-<!ENTITY enabled.column "Omogočeno">
-<!ENTITY enabled.accesskey "m">
-<!ENTITY hitcount.column "Zadetki">
-<!ENTITY hitcount.accesskey "d">
-<!ENTITY lasthit.column "Zadnji zadetek">
-<!ENTITY lasthit.accesskey "n">
-<!ENTITY context.edit.label "Uredi filter">
-<!ENTITY context.resethitcount.label "Ponastavi statistiko zadetkov za filter">
-<!ENTITY context.synchsubscription.label "Posodobi naročnino zdaj">
-<!ENTITY context.editsubscription.label "Uredi naročnino">
-<!ENTITY context.moveup.label "Premakni navzgor">
-<!ENTITY context.movedown.label "Premakni navzdol">
-<!ENTITY context.movegroupup.label "Premakni skupino navzgor">
-<!ENTITY context.movegroupdown.label "Premakni skupino navzdol">
-<!ENTITY context.enable.label "Omogoči">
-<!ENTITY context.disable.label "Onemogoči">
-<!ENTITY apply.label "Uporabi">
-<!ENTITY apply.accesskey "U">

=== removed file 'chrome/locale/sl-SI/sidebar.dtd'
--- chrome/locale/sl-SI/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sl-SI/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: elementi blokad (odpeti)">
-<!ENTITY detach.label "Odpni">
-<!ENTITY reattach.label "Pripni">
-<!ENTITY search.label "Najdi:">
-<!ENTITY search.accesskey "N">
-<!ENTITY type.label "Vrsta">
-<!ENTITY address.label "Naslov">
-<!ENTITY filter.label "Filter">
-<!ENTITY state.label "Stanje">
-<!ENTITY size.label "Velikost">
-<!ENTITY docDomain.label "Vir dokumenta">
-<!ENTITY noitems.label "Ni elementov blokiranja">
-<!ENTITY whitelisted.label "Dovoljena stran">
-<!ENTITY tooltip.address.label "Naslov:">
-<!ENTITY tooltip.type.label "Vrsta:">
-<!ENTITY tooltip.type.blocked "(blokirano)">
-<!ENTITY tooltip.type.whitelisted "(dovoljeno)">
-<!ENTITY tooltip.size.label "Velikost:">
-<!ENTITY tooltip.docDomain.label "Vir dokumenta:">
-<!ENTITY tooltip.filter.label "Trenutni filter:">
-<!ENTITY tooltip.filterSource.label "Vir filtra:">
-<!ENTITY context.block.label "Blokiraj ta element">
-<!ENTITY context.editfilter.label "Uredi trenutni filter">
-<!ENTITY context.whitelist.label "Dodaj pravilo izjem za element">
-<!ENTITY context.disablefilter.label "Onemogoči filter ...">
-<!ENTITY context.enablefilter.label "Ponovno omogoči filter ...">
-<!ENTITY context.disablefilteronsite.label "Onemogoči ta filter na --">
-<!ENTITY context.open.label "Odpri v novem zavihku">
-<!ENTITY context.flash.label "Obrobe elementa naj utripajo">
-<!ENTITY context.copy.label "Kopiraj naslov elementa">
-<!ENTITY context.copyFilter.label "Kopiraj filter">
-<!ENTITY context.selectAll.label "Izberi vse">

=== removed file 'chrome/locale/sl-SI/subscription.dtd'
--- chrome/locale/sl-SI/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sl-SI/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Uredi naročnino filtra">
-<!ENTITY dialog.newtitle "Dodaj naročnino filtra">
-<!ENTITY new.description "Vnesite spletni naslov ali datoteko, ki vsebuje seznam filtrov Adblock Plus.">
-<!ENTITY edit.description "Seznam filtrov za to naročnino bo prenesen z danega mesta.">
-<!ENTITY external.description "To je naročnina na zunanji filter, ta seznam filtrov bo posodobljen z razširitvijo, ki je to naročnino ustvarila.">
-<!ENTITY autodownload.description "Če izberete &apos;Samodejno posodobi&apos;, bo to mesto vsakodnevno preverjeno za posodobitve. Z izključeno možnostjo še vedno lahko sprožite ročno posodobitev iz pojavnega menija naročnine.">
-<!ENTITY location.label "Mesto seznama filtriranja:">
-<!ENTITY location.accesskey "M">
-<!ENTITY title.label "Naslov naročnine:">
-<!ENTITY title.accesskey "N">
-<!ENTITY autodownload.label "Samodejno posodobi">
-<!ENTITY autodownload.accesskey "S">
-<!ENTITY enabled.label "Omogoči filtre">
-<!ENTITY enabled.accesskey "O">

=== removed file 'chrome/locale/sl-SI/tip_subscriptions.dtd'
--- chrome/locale/sl-SI/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sl-SI/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,18 +0,0 @@
-<!ENTITY dialog.title "Dobrodošli v Adblock Plus">
-<!ENTITY description.par1 "Hvala, ker ste namestili Adblock Plus. Ta razširitev lahko odstrani 99&#37; oglasov, ki jih vidite na spletu. Vendar pa učinkovito filtriranje oglasov zahteva nastavitev kar velikega števila filtrov. To lahko storite sami ali pa se enostavno naročite na sezname filtrov, ki jih vzdržujejo drugi. Še vedno boste lahko dodali svoje lastne filtre ali deaktivirali/odstranili naročnine, če boste to želeli.">
-<!ENTITY description.par2 "S spodnjega seznama priporočenih naročnin lahko izberete eno naročnino (dodatne naročnine lahko dodate v nastavitvah Adblock Plus kasneje, čeprav to ponavadi ni potrebno):">
-<!ENTITY note "Opomba: seznam filtrov je ponavadi najbolj učinkovit, če je uporabljen
-za spletišča iz področja, za katere je bil seznam filtriranja narejen.">
-<!ENTITY adblock.warning "Adblock Plus je zaznal, da je nameščen Adblock ali stara različica Adblock Plus. Vzporedno poganjanje Adblocka in Adblocka Plus lahko povzroča težave in ni priporočljivo. Priporočamo, da zdaj odstranite Adblock.">
-<!ENTITY adblock.uninstall "Odstrani Adblock">
-<!ENTITY filterset.g.warning "Zdi se, da uporabljate Filterset.G. Ta seznam filtrov je komaj vzdrževan zadnja leta in je pogost razlog težav s spletnimi mesti. Priporočamo, da zdaj odstranite Filterset.G.">
-<!ENTITY filterset.g.moreinfo "Več informacij">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Odstrani Filterset.g">
-<!ENTITY homepage.label "Domača stran">
-<!ENTITY subscribe.label "Naroči">
-<!ENTITY subscribe.accesskey "N">
-<!ENTITY other.label "Dodaj novo naročnino">
-<!ENTITY other.accesskey "D">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Pokaži vse naročnine">

=== added file 'chrome/locale/sl/about.dtd'
--- chrome/locale/sl/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sl/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "O Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "različice">
+<!ENTITY description "Adblock Plus daje moč, da izključite tisto, česar na spletu ne želite videti. Nič več vam ni treba gledati oglasov in pasic, če tega nočete - povejte to razširitvi Adblock Plus!">
+<!ENTITY homepage.label "Domača stran Adblock Plus:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Avtor:">
+<!ENTITY contributors.label "Avtorji prispevkov:">
+<!ENTITY developers.label "Razvijalci:">
+<!ENTITY designers.label "Grafični oblikovalci:">
+<!ENTITY subscriptionAuthors.label "Avtorji naročnin na filtre:">
+<!ENTITY translators.label "Prevajalci:">

=== added file 'chrome/locale/sl/composer.dtd'
--- chrome/locale/sl/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sl/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Dodaj pravilo filtra Adblock Plus">
+<!ENTITY accept.label "Dodaj filter">
+<!ENTITY advanced.label "Napredni pogled">
+<!ENTITY basic.label "Osnovni pogled">
+<!ENTITY disabled.warning "Adblock Plus je trenutno onemogočen. Še vedno lahko dodajate filtre, vendar ne bodo veljali, če ne [link]omogočite Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Skupina filtrov &quot;?1?&quot;, kateri naj bo dodan ta filter, je trenutno onemogočena. Še vedno ji lahko dodate filter, vendar ne bo deloval, razen če ne [link]omogočite skupine filtrov[/link].">
+<!ENTITY filter.label "Nov filter:">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "Pokaži obstoječe filtre ...">
+<!ENTITY preferences.accesskey "ž">
+<!ENTITY type.filter.label "Filter blokade">
+<!ENTITY type.filter.accesskey "b">
+<!ENTITY type.whitelist.label "Pravilo izjem">
+<!ENTITY type.whitelist.accesskey "l">
+<!ENTITY pattern.label "Išči vzorec">
+<!ENTITY pattern.explanation "Vzorec je lahko kateri koli del naslova, simbol * velja kot poljuben znak. Filter bo le za naslove, ki ustrezajo vzorcu.">
+<!ENTITY regexp.warning "Vneseni vzorec bo obravnavan kot regularni izraz. Številni regularni izrazi lahko upočasnijo vaše brskanje. Če ne nameravate uporabljati regularnih izrazov, dodajte simbol * na konec vzorca.">
+<!ENTITY shortpattern.warning "Vzorec, ki ste ga vnesli, je prekratek za optimizacijo, številni tovrstni vzorci lahko upočasnijo vaše brskanje. Priporočamo, da izberete daljši niz za ta filter.">
+<!ENTITY custom.pattern.label "Po meri:">
+<!ENTITY custom.pattern.accesskey "m">
+<!ENTITY anchors.label "Sprejmi le vzorec:">
+<!ENTITY anchor.start.label "na začetku naslova">
+<!ENTITY anchor.start.accesskey "z">
+<!ENTITY anchor.start.flexible.label "na začetku imena domene">
+<!ENTITY anchor.start.flexible.accesskey "z">
+<!ENTITY anchor.end.label "na koncu naslova">
+<!ENTITY anchor.end.accesskey "k">
+<!ENTITY options.label "Možnosti">
+<!ENTITY domainRestriction.label "Omeji na domeno:">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "Navedite eno ali več domen, ločenih s simbolom &quot;|&quot;, filter bo veljal le za te domene. Simbol &quot;~&quot; pred imenom domene pomeni, da filter za to domeno ne sme veljati.">
+<!ENTITY firstParty.label "Samo prve stranke">
+<!ENTITY firstParty.accesskey "p">
+<!ENTITY thirdParty.label "Samo zunanje stranke">
+<!ENTITY thirdParty.accesskey "n">
+<!ENTITY matchCase.label "Razlikuj velike/male črke">
+<!ENTITY matchCase.accesskey "č">
+<!ENTITY types.label "Uporabi za vrste:">
+<!ENTITY selectAllTypes.label "Izberi vse">
+<!ENTITY unselectAllTypes.label "Nič ne izberi">
+<!ENTITY collapse.label "Strni blokirane:">
+<!ENTITY collapse.accesskey "r">
+<!ENTITY collapse.default.yes.label "Uporabi privzeto (da)">
+<!ENTITY collapse.default.no.label "Uporabi privzeto (ne)">
+<!ENTITY collapse.yes.label "Da">
+<!ENTITY collapse.no.label "Ne">

=== added file 'chrome/locale/sl/global.properties'
--- chrome/locale/sl/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/sl/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Kliknite za pojavni meni, s srednjim klikom vključite/izključite.
+action1_tooltip=Kliknite za odprtje/zaprtje blokiranih elementov, s srednjim klikom vključite/izključite.
+action2_tooltip=Kliknite za nastavitve, s srednjim klikom vključite/izključite.
+action3_tooltip=Kliknite za vključitev/izključitev Adblock Plus.
+disabled_tooltip=Adblock Plus je izključen.
+active_tooltip=Adblock Plus je aktiven, ?1? naročnine na filtre in ?2? filtri po meri so v rabi.
+whitelisted_tooltip=Adblock Plus je aktiven, vendar je za trenutno stran izključen.
+blocked_count_tooltip=?1? izmed ?2?
+blocked_count_addendum=(prav tako prikriti: ?1?, skriti: ?2?)
+no_blocking_suggestions=Na trenutni strani ni elementov blokad
+whitelisted_page=Za trenutno stran je bil Adblock Plus izključen
+whitelist_description=Pravila izjem
+filterlist_description=Filtri za oglase
+invalid_description=Neveljavni filtri
+elemhide_description=Pravila skrivanja elementov
+subscription_description=Naročnina na filter:
+subscription_wrong_version=Nekateri filtri v tej naročnini zahtevajo Adblock Plus ?1?, da bi delovali pravilno!
+subscription_source=Vir:
+subscription_status=Stanje:
+subscription_status_autodownload=Samodejno posodobljeno
+subscription_status_manualdownload=Ročno posodobljeno
+subscription_status_externaldownload=Zunanje posodobljeno (druga razširitev)
+subscription_status_lastdownload=Zadnji prenos:
+subscription_status_lastdownload_inprogress=Prenos s strežnika ...
+subscription_status_lastdownload_unknown=Ni na voljo
+remove_subscription_warning=Želite res odpovedati naročnino?
+import_filters_wrong_version=Opozorilo: nekateri od filtrov v tem seznamu za pravilno delovanje zahtevajo Adblock Plus ?1?. Najverjetneje morate nadgraditi razširitev na zadnjo izdajo Adblock Plus, preden uvozite ta seznam.
+import_filters_warning=Želite zamenjati obstoječe filtre ali dodati nove filtre na dno seznama?
+import_filters_title=Uvozi filtre
+export_filters_title=Izvozi filtre
+invalid_filters_file=Ni veljavna datoteka filtra Adblock Plus.
+filters_write_error=Pri pisanju filtrov v datoteko je prišlo do napake. Preverite, da datoteka ni zaščitena pred pisanjem ali odprta v drugem programu.
+clearall_warning=Resnično želite odstraniti vse filtre s seznama?
+resethitcounts_warning=Resnično želite ponastaviti števce za vse filtre na nič? Tega ni mogoče popraviti!
+resethitcounts_selected_warning=Resnično želite ponastaviti števce za izbrane filtre na nič? Tega ni mogoče popraviti!
+filter_regexp_tooltip=Ta filter je regularni izraz ali pa je prekratek za optimizacijo. Preveč filtrov lahko upočasni brskanje.
+filter_elemhide_duplicate_id=Navedete lahko le eno identiteto elementa, ki naj bo skrit
+filter_elemhide_nocriteria=Za razpoznavo elementa, ki naj bo skrit, ni navedenih pogojev
+subscription_notAdded_warning=Naročnine na filter niste dodali. Brez naročnine na filter boste morali filtre Adblock Plus dodati ročno.
+subscription_notAdded_warning_addendum=Želite nadaljevati?
+subscription_invalid_location=Mesto seznama filtrov ni niti veljaven URL niti veljavno ime datoteke.
+synchronize_invalid_url=Neuspešno, ni veljaven naslov
+synchronize_connection_error=Neuspešno, napaka prenosa
+synchronize_invalid_data=Neuspešno, ni veljaven seznam filtrov
+synchronize_checksum_mismatch=Neuspešno, kontrolna vsota se ne ujema
+synchronize_ok=Uspešno
+overwrite=Prepiši
+append=Dodaj
+new_filter_group_title=Nov filter
+type_label_other=drugo
+type_label_script=skript
+type_label_image=sliko
+type_label_stylesheet=predlogo strani
+type_label_object=predmet
+type_label_subdocument=okvir
+type_label_document=dokument
+type_label_background=ozadje
+type_label_elemhide=skrito
+type_label_xbl=Vezava XBL
+type_label_ping=poveži ping
+type_label_xmlhttprequest=Zahteva XML
+type_label_object_subrequest=podzahteva predmeta
+type_label_dtd=DTD
+type_label_media=zvok/video
+type_label_font=pisava
+fennec_status_enabled=Adblock Plus je vključen.
+fennec_status_disabled=Adblock Plus je izključen.
+fennec_status_enabled_site=Adblock Plus je vključen na ?1?.
+fennec_status_disabled_site=Adblock Plus je izključen na ?1?.

=== added file 'chrome/locale/sl/meta.properties'
--- chrome/locale/sl/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/sl/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Martin Srebotnjak
+name=Adblock Plus
+description=Oglasi so preteklost!
+description.short=Vas motijo reklame? Vam teži sledenje? Na živce vam gredo pasice? Namestite Adblock Plus takoj in prevzemite nadzor nad internetom in spremenite svoj pogled na splet.
+description.long=Adblock Plus omogoča ponoven prevzem nadzora nad internetom in ogledovanje spleta, kot to sami želite. Dodatek podpira več kot štirideset naročnin na filtre v ducatu jezikov, ki ga samodejno prilagodija za namene od odstranjevanja spletnega oglaševanja do blokiranja vseh znanih domen s škodljivimi vsebinami. Adblock Plus vam omogoča tudi prilagajanje filtrov s pomočjo številnih uporabnih funkcij, vključno s kontekstno možnostjo za slike,  bločni zavihek za predmete Flash in Java, ter seznam blokiranih elementov za odstranjanje skript in oblikovnih predlog.

=== added file 'chrome/locale/sl/overlay.dtd'
--- chrome/locale/sl/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sl/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Stanje:">
+<!ENTITY blocked.tooltip "Blokirani elementi na tej strani:">
+<!ENTITY filters.tooltip "Najbolj aktivni filtri:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: elementi za blokiranje">
+<!ENTITY context.image.label "Adblock - slike">
+<!ENTITY context.object.label "Adblock - predmeti">
+<!ENTITY context.frame.label "Adblock - okviri">
+<!ENTITY context.media.label "Adblock Plus: Blokiraj zvok/video">
+<!ENTITY context.removeWhitelist.label "Adblock Plus - ponovno omogoči na tej strani">
+<!ENTITY sidebar.title "Elementi blokad na trenutni strani">
+<!ENTITY settings.label "Nastavitve">
+<!ENTITY settings.accesskey "N">
+<!ENTITY opensidebar.label "Odpri elemente blokad">
+<!ENTITY opensidebar.accesskey "e">
+<!ENTITY closesidebar.label "Zapri elemente blokad">
+<!ENTITY closesidebar.accesskey "e">
+<!ENTITY whitelist.site.label "Onemogoči na ?1?">
+<!ENTITY whitelist.page.label "Onemogoči samo na tej strani">
+<!ENTITY objecttab.title "Blokiraj">
+<!ENTITY objecttab.tooltip "Kliknite sem za blokiranje tega predmeta z Adblock Plus">

=== added file 'chrome/locale/sl/settings.dtd'
--- chrome/locale/sl/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sl/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Nastavitve Adblock Plus">
+<!ENTITY filters.label "Filtri">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Dodaj filter">
+<!ENTITY add.accesskey "D">
+<!ENTITY addsubscription.label "Dodaj naročnino filtra">
+<!ENTITY addsubscription.accesskey "n">
+<!ENTITY synchsubscriptions.label "Posodobi vse naročnine">
+<!ENTITY synchsubscriptions.accesskey "P">
+<!ENTITY import.label "Uvozi filtre">
+<!ENTITY import.accesskey "U">
+<!ENTITY export.label "Izvozi filtre">
+<!ENTITY export.accesskey "I">
+<!ENTITY clearall.label "Odstrani vse filtre">
+<!ENTITY clearall.accesskey "O">
+<!ENTITY resethitcounts.label "Ponastavi statistiko zadetkov">
+<!ENTITY resethitcounts.accesskey "z">
+<!ENTITY edit.label "Uredi">
+<!ENTITY edit.accesskey "e">
+<!ENTITY cut.label "Izreži">
+<!ENTITY cut.accesskey "i">
+<!ENTITY copy.label "Kopiraj">
+<!ENTITY copy.accesskey "K">
+<!ENTITY paste.label "Prilepi">
+<!ENTITY paste.accesskey "P">
+<!ENTITY remove.label "Izbriši">
+<!ENTITY remove.accesskey "b">
+<!ENTITY menu.find.label "Najdi">
+<!ENTITY menu.find.accesskey "d">
+<!ENTITY menu.findagain.label "Ponovno najdi">
+<!ENTITY menu.findagain.accesskey "j">
+<!ENTITY view.label "Pogled">
+<!ENTITY view.accesskey "o">
+<!ENTITY sort.label "Razvrsti">
+<!ENTITY sort.accesskey "v">
+<!ENTITY sort.none.label "Nerazvrščeno">
+<!ENTITY sort.none.accesskey "š">
+<!ENTITY sort.ascending.label "od A &gt; Z">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "od Z &gt; A">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Možnosti">
+<!ENTITY options.accesskey "ž">
+<!ENTITY enable.label "Omogoči Adblock Plus">
+<!ENTITY enable.accesskey "O">
+<!ENTITY showintoolbar.label "Pokaži v orodni vrstici">
+<!ENTITY showintoolbar.accesskey "k">
+<!ENTITY showinstatusbar.label "Pokaži v vrstici stanja">
+<!ENTITY showinstatusbar.accesskey "v">
+<!ENTITY objecttabs.label "Pokaži zavihke za Flash in Javo">
+<!ENTITY objecttabs.accesskey "z">
+<!ENTITY collapse.label "Zloži blokirane elemente">
+<!ENTITY collapse.accesskey "l">
+<!ENTITY help.label "Pomoč">
+<!ENTITY help.accesskey "m">
+<!ENTITY gettingStarted.label "Prvi koraki">
+<!ENTITY gettingStarted.accesskey "k">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Pogosto zastavljena vprašanja">
+<!ENTITY faq.accesskey "P">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Pisanje filtrov Adblock Plus">
+<!ENTITY filterdoc.accesskey "s">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "O Adblock Plus">
+<!ENTITY about.accesskey "b">
+<!ENTITY description "Dodajte naslove, ki bi jih radi blokirali, za nasvete preverite seznamsko polje. Uporabite lahko * za izdelavo bolj splošnih filtrov. Napredni uporabniki lahko uporabite regularne izraze kot je /banner\d+\.gif$/.">
+<!ENTITY filter.column "Pravilo filtra">
+<!ENTITY filter.accesskey "f">
+<!ENTITY slow.column "Počasni filtri">
+<!ENTITY slow.accesskey "č">
+<!ENTITY enabled.column "Omogočeno">
+<!ENTITY enabled.accesskey "m">
+<!ENTITY hitcount.column "Zadetki">
+<!ENTITY hitcount.accesskey "d">
+<!ENTITY lasthit.column "Zadnji zadetek">
+<!ENTITY lasthit.accesskey "n">
+<!ENTITY context.edit.label "Uredi filter">
+<!ENTITY context.resethitcount.label "Ponastavi statistiko zadetkov za filter">
+<!ENTITY context.synchsubscription.label "Posodobi naročnino zdaj">
+<!ENTITY context.editsubscription.label "Uredi naročnino">
+<!ENTITY context.moveup.label "Premakni navzgor">
+<!ENTITY context.movedown.label "Premakni navzdol">
+<!ENTITY context.movegroupup.label "Premakni skupino navzgor">
+<!ENTITY context.movegroupdown.label "Premakni skupino navzdol">
+<!ENTITY context.enable.label "Omogoči">
+<!ENTITY context.disable.label "Onemogoči">
+<!ENTITY apply.label "Uporabi">
+<!ENTITY apply.accesskey "U">
+<!ENTITY fennec.subscription.label "Naročnina na filter">

=== added file 'chrome/locale/sl/sidebar.dtd'
--- chrome/locale/sl/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sl/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: elementi blokad (odpeti)">
+<!ENTITY detach.label "Odpni">
+<!ENTITY reattach.label "Pripni">
+<!ENTITY search.label "Najdi:">
+<!ENTITY search.accesskey "N">
+<!ENTITY type.label "Vrsta">
+<!ENTITY address.label "Naslov">
+<!ENTITY filter.label "Filter">
+<!ENTITY state.label "Stanje">
+<!ENTITY size.label "Velikost">
+<!ENTITY docDomain.label "Vir dokumenta">
+<!ENTITY noitems.label "Ni elementov blokiranja">
+<!ENTITY whitelisted.label "Dovoljena stran">
+<!ENTITY tooltip.address.label "Naslov:">
+<!ENTITY tooltip.type.label "Vrsta:">
+<!ENTITY tooltip.type.blocked "(blokirano)">
+<!ENTITY tooltip.type.whitelisted "(dovoljeno)">
+<!ENTITY tooltip.size.label "Velikost:">
+<!ENTITY tooltip.docDomain.label "Vir dokumenta:">
+<!ENTITY tooltip.filter.label "Trenutni filter:">
+<!ENTITY tooltip.filterSource.label "Vir filtra:">
+<!ENTITY context.block.label "Blokiraj ta element">
+<!ENTITY context.editfilter.label "Uredi trenutni filter">
+<!ENTITY context.whitelist.label "Dodaj pravilo izjem za element">
+<!ENTITY context.disablefilter.label "Onemogoči filter ?1?">
+<!ENTITY context.enablefilter.label "Ponovno omogoči filter ?1?">
+<!ENTITY context.disablefilteronsite.label "Onemogoči ta filter na ?1?">
+<!ENTITY context.open.label "Odpri v novem zavihku">
+<!ENTITY context.flash.label "Obrobe elementa naj utripajo">
+<!ENTITY context.copy.label "Kopiraj naslov elementa">
+<!ENTITY context.copyFilter.label "Kopiraj filter">
+<!ENTITY context.selectAll.label "Izberi vse">

=== added file 'chrome/locale/sl/subscriptionSelection.dtd'
--- chrome/locale/sl/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sl/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Dodaj naročnino na filtre Adblock Plus">
+<!ENTITY dialog.title.edit "Uredi naročnino filtra">
+<!ENTITY description.newInstall "Da bi bil Adblock Plus kar najbolj učinkovit, dodajte naročnino na filtre. Te naročnine na filtre ponujajo drugi uporabniki Adblock Plusa brezplačno. Najprimernejše naročnine na filtre za vaš jezik so že izbrane.">
+<!ENTITY adblock.warning "Adblock Plus je zaznal, da je nameščen Adblock ali stara različica Adblock Plus. Vzporedno poganjanje Adblocka in Adblocka Plus lahko povzroča težave in ni priporočljivo. Priporočamo, da zdaj odstranite Adblock.">
+<!ENTITY adblock.uninstall "Odstrani Adblock">
+<!ENTITY filterset.g.warning "Zdi se, da uporabljate Filterset.G. Ta seznam filtrov je komaj vzdrževan zadnja leta in je pogost razlog težav s spletnimi mesti. Priporočamo, da zdaj odstranite Filterset.G.">
+<!ENTITY filterset.g.moreinfo "Več informacij">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Odstrani Filterset.g">
+<!ENTITY subscriptionSelector.label "Izberite naročnino na filter s seznama:">
+<!ENTITY viewList.label "Pokaži filtre">
+<!ENTITY visitHomepage.label "Obišči domačo stran">
+<!ENTITY addSubscription.label "Dodaj naročnino">
+<!ENTITY saveSubscription.label "Shrani naročnino">
+<!ENTITY other.label "Dodaj novo naročnino">
+<!ENTITY other.accesskey "D">
+<!ENTITY list.download.failed "Pridobivanje seznama naročnin ni uspelo.">
+<!ENTITY list.download.retry "Poskusi znova">
+<!ENTITY list.download.website "Pokaži spletno mesto">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Potrdite, da želite dodati to naročnino na filter. Naslov ali kraj naročnine lahko spremenite še pred dodajanjem.">
+<!ENTITY edit.description "Po potrebi lahko spremenite naslov ali mesto naročnine.">
+<!ENTITY external.description "To je zunanja naročnina na filter, seznam filtrov bo posodobljen z razširitvijo, ki je ustvarila to naročnino.">
+<!ENTITY title.label "Naslov naročnine:">
+<!ENTITY title.accesskey "N">
+<!ENTITY location.label "Mesto seznama filtriranja:">
+<!ENTITY location.accesskey "M">
+<!ENTITY autodownload.label "Samodejno posodobi">
+<!ENTITY autodownload.accesskey "S">
+<!ENTITY supplementMessage "Naročnina na filter je mišljena za rabo z naročnino na filter ?1?, ki je še ne uporabljate.">
+<!ENTITY addMain.label "Dodaj tudi naročnino na filter ?1?">
+<!ENTITY addMain.accesskey "d">

=== added directory 'chrome/locale/sq'
=== removed directory 'chrome/locale/sq-AL'
=== removed file 'chrome/locale/sq-AL/.incomplete'
=== removed file 'chrome/locale/sq-AL/about.dtd'
--- chrome/locale/sq-AL/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sq-AL/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Rreth Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Versioni">
-<!ENTITY description "Adblock ju lejon të vendosni çfarë doni të shihni në faqen që hapni. Nuk ka nevojë të ju hapen të gjitha reklamat më, nëse nuk i doni!">
-<!ENTITY homepage.label "Adblock Plus internet faqja">
-<!ENTITY homepage.url "http://adblockplus.org/en/">
-<!ENTITY author.label "Autori">
-<!ENTITY contributors.label "Kontribuuesit">

=== removed file 'chrome/locale/sq-AL/composer.dtd'
--- chrome/locale/sq-AL/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sq-AL/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,35 +0,0 @@
-<!ENTITY advanced.label "Pamja e avancuar">
-<!ENTITY basic.label "Pamja e zakonshme">
-<!ENTITY disabled.warning.link "aktivizo Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.link "aktivizo grupin e filtrimit">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Filtrues i ri:">
-<!ENTITY filter.accesskey "f">
-<!ENTITY preferences.label "Trego filtruesit ekzistues...">
-<!ENTITY preferences.accesskey "S">
-<!ENTITY type.filter.label "Blloko filtruesin">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "Mos përfill">
-<!ENTITY type.whitelist.accesskey "x">
-<!ENTITY custom.pattern.label "Përshtatja:">
-<!ENTITY custom.pattern.accesskey "C">
-<!ENTITY anchor.start.accesskey "g">
-<!ENTITY anchor.start.flexible.accesskey "g">
-<!ENTITY anchor.end.label "në fund të adresës">
-<!ENTITY anchor.end.accesskey "n">
-<!ENTITY options.label "Mundësitë">
-<!ENTITY domainRestriction.accesskey "d">
-<!ENTITY firstParty.label "Vetëm pjesa e parë">
-<!ENTITY firstParty.accesskey "r">
-<!ENTITY thirdParty.label "Vetëm pjesa e tretë">
-<!ENTITY thirdParty.accesskey "T">
-<!ENTITY matchCase.accesskey "M">
-<!ENTITY types.label "Apliko në llojet:">
-<!ENTITY selectAllTypes.label "Selekto të gjitha">
-<!ENTITY unselectAllTypes.label "Mos selekto asnjë">
-<!ENTITY collapse.accesskey "I">
-<!ENTITY collapse.default.yes.label "Përdor të parazgjedhurën (po):">
-<!ENTITY collapse.default.no.label "Përdor të parazgjedhurën (jo):">
-<!ENTITY collapse.yes.label "Po">
-<!ENTITY collapse.no.label "Jo">

=== removed file 'chrome/locale/sq-AL/global.properties'
--- chrome/locale/sq-AL/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/sq-AL/global.properties	1970-01-01 00:00:00 +0000
@@ -1,38 +0,0 @@
-status_active_label=Adblock
-status_disabled_label=Ç'aktivizuar
-action3_tooltip=Aktivizim/çaktivizo Adblock Plus.
-active_tooltip=Adblock Plus është aktiv.
-disabled_tooltip=Adblock Plus është ç'aktiv.
-whitelisted_tooltip=Adblock Plus është aktiv por i pasivizuar në këtë faqe.
-blocked_count_tooltip=--jasht nga --
-no_blocking_suggestions=S'ka elemente bllokuese në këtë faqe
-whitelist_description=Rregullat personale të përjashtimit
-filterlist_description=Rregullat personale të bllokimit
-invalid_description=Rregullat personale jo valide
-elemhide_description=Rregullat personale të fshehjes së elementeve
-subscription_source=Burimi:
-subscription_status=Gjendja:
-subscription_status_autodownload=Freskimi automatik
-subscription_status_manualdownload=Freskimi manual
-subscription_status_externaldownload=Freskuar nga jashtë (shtesë tjetër)
-subscription_status_lastdownload=Shkarkimi i fundit:
-subscription_status_lastdownload_inprogress=Duke u shkarkuar...
-subscription_status_lastdownload_unknown=N/D
-import_filters_title=Importo filtrues
-export_filters_title=Eksporto filtrues
-synchronize_ok=Sukses
-overwrite=Rishkruaj
-new_filter_group_title=Filtrues i ri
-type_label_other=tjera
-type_label_script=skripta
-type_label_image=figura
-type_label_stylesheet=stilet
-type_label_object=objekti
-type_label_subdocument=ndarja
-type_label_document=dokumenti
-type_label_background=prapavia
-type_label_elemhide=fshehur
-type_label_xmlhttprequest=kerkimi për XML
-type_label_dtd=DTD
-type_label_media=audio/video
-type_label_font=shkronjat

=== removed file 'chrome/locale/sq-AL/overlay.dtd'
--- chrome/locale/sq-AL/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sq-AL/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-<!ENTITY status.tooltip "Gjendja:">
-<!ENTITY filters.tooltip "Filtruesit më aktivë:">
-<!ENTITY menuitem.label "Parapëlqimet e Adblock Plus">
-<!ENTITY menuitem.accesskey "B">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Gjërat e bllokuara">
-<!ENTITY context.image.label "Adblock Plus: Figurat e bllokuara">
-<!ENTITY context.object.label "Adblock Plus: Objektet e bllokuara">
-<!ENTITY context.frame.label "Adblock Plus: Pjesët e bllokuara">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Rilejo në këtë faqe">
-<!ENTITY settings.label "Parapëlqimet">
-<!ENTITY settings.accesskey "F">
-<!ENTITY opensidebar.label "Hap elementet bllokuese">
-<!ENTITY opensidebar.accesskey "B">
-<!ENTITY closesidebar.label "Mbyll elementet bllokuese">
-<!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Çaktivizo në --">
-<!ENTITY whitelist.page.label "Çaktivizo vetëm në këtë faqe">
-<!ENTITY objecttab.title "Blloko">

=== removed file 'chrome/locale/sq-AL/settings.dtd'
--- chrome/locale/sq-AL/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sq-AL/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,79 +0,0 @@
-<!ENTITY dialog.title "Parapëlqimet e Adblock Plus">
-<!ENTITY filters.label "Filtruesit">
-<!ENTITY filters.accesskey "F">
-<!ENTITY add.label "Vendos filtrues">
-<!ENTITY add.accesskey "A">
-<!ENTITY addsubscription.accesskey "S">
-<!ENTITY synchsubscriptions.accesskey "D">
-<!ENTITY import.label "Importo filtrues">
-<!ENTITY import.accesskey "M">
-<!ENTITY export.label "Eksporto filtruesit ekzistues">
-<!ENTITY export.accesskey "X">
-<!ENTITY clearall.label "Largo të gjithë filtruesit ekxistues">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "Rishkruaj statistikat">
-<!ENTITY resethitcounts.accesskey "R">
-<!ENTITY edit.label "Redakto">
-<!ENTITY edit.accesskey "E">
-<!ENTITY cut.label "Kopjo-largo">
-<!ENTITY cut.accesskey "T">
-<!ENTITY copy.label "Kopjo">
-<!ENTITY copy.accesskey "C">
-<!ENTITY paste.label "Hedh">
-<!ENTITY paste.accesskey "P">
-<!ENTITY remove.label "Fshijë">
-<!ENTITY remove.accesskey "D">
-<!ENTITY menu.find.label "Kërko">
-<!ENTITY menu.find.accesskey "F">
-<!ENTITY menu.findagain.label "Kërko përsëri">
-<!ENTITY menu.findagain.accesskey "G">
-<!ENTITY view.label "Shih">
-<!ENTITY view.accesskey "V">
-<!ENTITY sort.label "Radhit sipas">
-<!ENTITY sort.accesskey "S">
-<!ENTITY sort.none.label "Pa radhitur">
-<!ENTITY sort.none.accesskey "U">
-<!ENTITY sort.ascending.label "A &gt; Z radhitje">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Z &gt; A radhitje">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Mundësitë">
-<!ENTITY options.accesskey "O">
-<!ENTITY enable.label "Aktivizo Adblock Plus">
-<!ENTITY enable.accesskey "N">
-<!ENTITY showintoolbar.accesskey "B">
-<!ENTITY showinstatusbar.accesskey "S">
-<!ENTITY objecttabs.accesskey "T">
-<!ENTITY collapse.accesskey "L">
-<!ENTITY help.label "Ndihmë">
-<!ENTITY help.accesskey "H">
-<!ENTITY gettingStarted.label "Fillo">
-<!ENTITY gettingStarted.accesskey "s">
-<!ENTITY gettingStarted.url "http://adblockplus.org/getting_started">
-<!ENTITY faq.label "Pyetje e zakonshme">
-<!ENTITY faq.accesskey "F">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Duke shkruar filtruesit e Adblock Plus">
-<!ENTITY filterdoc.accesskey "R">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Rreth Adblock Plus">
-<!ENTITY about.accesskey "B">
-<!ENTITY filter.column "Rregulla e filtrimit">
-<!ENTITY filter.accesskey "F">
-<!ENTITY slow.column "Filtruesit e ngadalshëm">
-<!ENTITY slow.accesskey "w">
-<!ENTITY enabled.column "Aktivizo">
-<!ENTITY enabled.accesskey "n">
-<!ENTITY hitcount.column "Shtypje">
-<!ENTITY hitcount.accesskey "H">
-<!ENTITY lasthit.column "Shtypja e fundit">
-<!ENTITY lasthit.accesskey "L">
-<!ENTITY context.edit.label "Redakto filtruesin">
-<!ENTITY context.moveup.label "Zhvendos filtruesin sipër">
-<!ENTITY context.movedown.label "Zhvendos filtruesin poshtë">
-<!ENTITY context.movegroupup.label "Zhvendos grupin sipër">
-<!ENTITY context.movegroupdown.label "Zhvendos grupin poshtë">
-<!ENTITY context.enable.label "Aktivizo">
-<!ENTITY context.disable.label "Ç'aktivizoj">
-<!ENTITY apply.label "Ruaji">
-<!ENTITY apply.accesskey "p">

=== removed file 'chrome/locale/sq-AL/sidebar.dtd'
--- chrome/locale/sq-AL/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sq-AL/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,26 +0,0 @@
-<!ENTITY search.label "Kërko">
-<!ENTITY search.accesskey "S">
-<!ENTITY type.label "Lloji">
-<!ENTITY address.label "Adresa">
-<!ENTITY filter.label "Filtruesi">
-<!ENTITY state.label "Gjendja">
-<!ENTITY size.label "Madhësia">
-<!ENTITY docDomain.label "Burimi i dokumentit">
-<!ENTITY noitems.label "S'ka elemente bllokuese">
-<!ENTITY tooltip.address.label "Adresa:">
-<!ENTITY tooltip.type.label "Lloji:">
-<!ENTITY tooltip.type.blocked "(bllokuar)">
-<!ENTITY tooltip.type.whitelisted "(lejuar)">
-<!ENTITY tooltip.size.label "Madhësia:">
-<!ENTITY tooltip.docDomain.label "Burimi i dokumentit:">
-<!ENTITY tooltip.filter.label "Filtruesi efektiv:">
-<!ENTITY tooltip.filterSource.label "Burimi i filtruesit:">
-<!ENTITY context.block.label "Blloko këtë send">
-<!ENTITY context.editfilter.label "Vendos filtruesin në veprim">
-<!ENTITY context.disablefilter.label "Çaktivizo filtruesin --">
-<!ENTITY context.enablefilter.label "Ri mundëso filtruesin --">
-<!ENTITY context.disablefilteronsite.label "Pamundëso filtruesin në --">
-<!ENTITY context.open.label "Hape një një lidhje të re">
-<!ENTITY context.copy.label "Kopjo adresën e elementit">
-<!ENTITY context.copyFilter.label "Kopjo filtruesin">
-<!ENTITY context.selectAll.label "Selekto të gjitha">

=== removed file 'chrome/locale/sq-AL/subscription.dtd'
--- chrome/locale/sq-AL/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sq-AL/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,7 +0,0 @@
-<!ENTITY location.label "Vendi i listës së filtruesit">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Fresko Automatikisht">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.label "Aktivizo filtruesit">
-<!ENTITY enabled.accesskey "N">

=== removed file 'chrome/locale/sq-AL/tip_subscriptions.dtd'
--- chrome/locale/sq-AL/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sq-AL/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,7 +0,0 @@
-<!ENTITY adblock.uninstall "Largo Adblock">
-<!ENTITY filterset.g.moreinfo "Më shumë informata">
-<!ENTITY filterset.g.uninstall "Ç'instalo Filterset.G">
-<!ENTITY homepage.label "Faqja e internetit">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.accesskey "f">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">

=== added file 'chrome/locale/sq/.incomplete'
=== added file 'chrome/locale/sq/about.dtd'
--- chrome/locale/sq/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sq/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,8 @@
+<!ENTITY dialog.title "Rreth Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Versioni">
+<!ENTITY description "Adblock ju lejon të vendosni çfarë doni të shihni në faqen që hapni. Nuk ka nevojë të ju hapen të gjitha reklamat më, nëse nuk i doni!">
+<!ENTITY homepage.label "Adblock Plus internet faqja">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "Autori">
+<!ENTITY contributors.label "Kontribuuesit">

=== added file 'chrome/locale/sq/composer.dtd'
--- chrome/locale/sq/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sq/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,31 @@
+<!ENTITY advanced.label "Pamja e avancuar">
+<!ENTITY basic.label "Pamja e zakonshme">
+<!ENTITY filter.label "Filtrues i ri:">
+<!ENTITY filter.accesskey "f">
+<!ENTITY preferences.label "Trego filtruesit ekzistues...">
+<!ENTITY preferences.accesskey "S">
+<!ENTITY type.filter.label "Blloko filtruesin">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Mos përfill">
+<!ENTITY type.whitelist.accesskey "x">
+<!ENTITY custom.pattern.label "Përshtatja:">
+<!ENTITY custom.pattern.accesskey "C">
+<!ENTITY anchor.start.accesskey "g">
+<!ENTITY anchor.start.flexible.accesskey "g">
+<!ENTITY anchor.end.label "në fund të adresës">
+<!ENTITY anchor.end.accesskey "n">
+<!ENTITY options.label "Mundësitë">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY firstParty.label "Vetëm pjesa e parë">
+<!ENTITY firstParty.accesskey "r">
+<!ENTITY thirdParty.label "Vetëm pjesa e tretë">
+<!ENTITY thirdParty.accesskey "T">
+<!ENTITY matchCase.accesskey "M">
+<!ENTITY types.label "Apliko në llojet:">
+<!ENTITY selectAllTypes.label "Selekto të gjitha">
+<!ENTITY unselectAllTypes.label "Mos selekto asnjë">
+<!ENTITY collapse.accesskey "I">
+<!ENTITY collapse.default.yes.label "Përdor të parazgjedhurën (po):">
+<!ENTITY collapse.default.no.label "Përdor të parazgjedhurën (jo):">
+<!ENTITY collapse.yes.label "Po">
+<!ENTITY collapse.no.label "Jo">

=== added file 'chrome/locale/sq/global.properties'
--- chrome/locale/sq/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/sq/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,35 @@
+action3_tooltip=Aktivizim/çaktivizo Adblock Plus.
+disabled_tooltip=Adblock Plus është ç'aktiv.
+whitelisted_tooltip=Adblock Plus është aktiv por i pasivizuar në këtë faqe.
+blocked_count_tooltip=?1?jasht nga ?2?
+no_blocking_suggestions=S'ka elemente bllokuese në këtë faqe
+whitelist_description=Rregullat personale të përjashtimit
+filterlist_description=Rregullat personale të bllokimit
+invalid_description=Rregullat personale jo valide
+elemhide_description=Rregullat personale të fshehjes së elementeve
+subscription_source=Burimi:
+subscription_status=Gjendja:
+subscription_status_autodownload=Freskimi automatik
+subscription_status_manualdownload=Freskimi manual
+subscription_status_externaldownload=Freskuar nga jashtë (shtesë tjetër)
+subscription_status_lastdownload=Shkarkimi i fundit:
+subscription_status_lastdownload_inprogress=Duke u shkarkuar...
+subscription_status_lastdownload_unknown=N/D
+import_filters_title=Importo filtrues
+export_filters_title=Eksporto filtrues
+synchronize_ok=Sukses
+overwrite=Rishkruaj
+new_filter_group_title=Filtrues i ri
+type_label_other=tjera
+type_label_script=skripta
+type_label_image=figura
+type_label_stylesheet=stilet
+type_label_object=objekti
+type_label_subdocument=ndarja
+type_label_document=dokumenti
+type_label_background=prapavia
+type_label_elemhide=fshehur
+type_label_xmlhttprequest=kerkimi për XML
+type_label_dtd=DTD
+type_label_media=audio/video
+type_label_font=shkronjat

=== added file 'chrome/locale/sq/overlay.dtd'
--- chrome/locale/sq/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sq/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,19 @@
+<!ENTITY status.tooltip "Gjendja:">
+<!ENTITY filters.tooltip "Filtruesit më aktivë:">
+<!ENTITY menuitem.label "Parapëlqimet e Adblock Plus">
+<!ENTITY menuitem.accesskey "B">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Gjërat e bllokuara">
+<!ENTITY context.image.label "Adblock Plus: Figurat e bllokuara">
+<!ENTITY context.object.label "Adblock Plus: Objektet e bllokuara">
+<!ENTITY context.frame.label "Adblock Plus: Pjesët e bllokuara">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Rilejo në këtë faqe">
+<!ENTITY settings.label "Parapëlqimet">
+<!ENTITY settings.accesskey "F">
+<!ENTITY opensidebar.label "Hap elementet bllokuese">
+<!ENTITY opensidebar.accesskey "B">
+<!ENTITY closesidebar.label "Mbyll elementet bllokuese">
+<!ENTITY closesidebar.accesskey "B">
+<!ENTITY whitelist.site.label "Çaktivizo në ?1?">
+<!ENTITY whitelist.page.label "Çaktivizo vetëm në këtë faqe">
+<!ENTITY objecttab.title "Blloko">

=== added file 'chrome/locale/sq/settings.dtd'
--- chrome/locale/sq/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sq/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,79 @@
+<!ENTITY dialog.title "Parapëlqimet e Adblock Plus">
+<!ENTITY filters.label "Filtruesit">
+<!ENTITY filters.accesskey "F">
+<!ENTITY add.label "Vendos filtrues">
+<!ENTITY add.accesskey "A">
+<!ENTITY addsubscription.accesskey "S">
+<!ENTITY synchsubscriptions.accesskey "D">
+<!ENTITY import.label "Importo filtrues">
+<!ENTITY import.accesskey "M">
+<!ENTITY export.label "Eksporto filtruesit ekzistues">
+<!ENTITY export.accesskey "X">
+<!ENTITY clearall.label "Largo të gjithë filtruesit ekxistues">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "Rishkruaj statistikat">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "Redakto">
+<!ENTITY edit.accesskey "E">
+<!ENTITY cut.label "Kopjo-largo">
+<!ENTITY cut.accesskey "T">
+<!ENTITY copy.label "Kopjo">
+<!ENTITY copy.accesskey "C">
+<!ENTITY paste.label "Hedh">
+<!ENTITY paste.accesskey "P">
+<!ENTITY remove.label "Fshijë">
+<!ENTITY remove.accesskey "D">
+<!ENTITY menu.find.label "Kërko">
+<!ENTITY menu.find.accesskey "F">
+<!ENTITY menu.findagain.label "Kërko përsëri">
+<!ENTITY menu.findagain.accesskey "G">
+<!ENTITY view.label "Shih">
+<!ENTITY view.accesskey "V">
+<!ENTITY sort.label "Radhit sipas">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "Pa radhitur">
+<!ENTITY sort.none.accesskey "U">
+<!ENTITY sort.ascending.label "A &gt; Z radhitje">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Z &gt; A radhitje">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Mundësitë">
+<!ENTITY options.accesskey "O">
+<!ENTITY enable.label "Aktivizo Adblock Plus">
+<!ENTITY enable.accesskey "N">
+<!ENTITY showintoolbar.accesskey "B">
+<!ENTITY showinstatusbar.accesskey "S">
+<!ENTITY objecttabs.accesskey "T">
+<!ENTITY collapse.accesskey "L">
+<!ENTITY help.label "Ndihmë">
+<!ENTITY help.accesskey "H">
+<!ENTITY gettingStarted.label "Fillo">
+<!ENTITY gettingStarted.accesskey "s">
+<!ENTITY gettingStarted.url "http://adblockplus.org/getting_started">
+<!ENTITY faq.label "Pyetje e zakonshme">
+<!ENTITY faq.accesskey "F">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Duke shkruar filtruesit e Adblock Plus">
+<!ENTITY filterdoc.accesskey "R">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Rreth Adblock Plus">
+<!ENTITY about.accesskey "B">
+<!ENTITY filter.column "Rregulla e filtrimit">
+<!ENTITY filter.accesskey "F">
+<!ENTITY slow.column "Filtruesit e ngadalshëm">
+<!ENTITY slow.accesskey "w">
+<!ENTITY enabled.column "Aktivizo">
+<!ENTITY enabled.accesskey "n">
+<!ENTITY hitcount.column "Shtypje">
+<!ENTITY hitcount.accesskey "H">
+<!ENTITY lasthit.column "Shtypja e fundit">
+<!ENTITY lasthit.accesskey "L">
+<!ENTITY context.edit.label "Redakto filtruesin">
+<!ENTITY context.moveup.label "Zhvendos filtruesin sipër">
+<!ENTITY context.movedown.label "Zhvendos filtruesin poshtë">
+<!ENTITY context.movegroupup.label "Zhvendos grupin sipër">
+<!ENTITY context.movegroupdown.label "Zhvendos grupin poshtë">
+<!ENTITY context.enable.label "Aktivizo">
+<!ENTITY context.disable.label "Ç'aktivizoj">
+<!ENTITY apply.label "Ruaji">
+<!ENTITY apply.accesskey "p">

=== added file 'chrome/locale/sq/sidebar.dtd'
--- chrome/locale/sq/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sq/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,26 @@
+<!ENTITY search.label "Kërko">
+<!ENTITY search.accesskey "S">
+<!ENTITY type.label "Lloji">
+<!ENTITY address.label "Adresa">
+<!ENTITY filter.label "Filtruesi">
+<!ENTITY state.label "Gjendja">
+<!ENTITY size.label "Madhësia">
+<!ENTITY docDomain.label "Burimi i dokumentit">
+<!ENTITY noitems.label "S'ka elemente bllokuese">
+<!ENTITY tooltip.address.label "Adresa:">
+<!ENTITY tooltip.type.label "Lloji:">
+<!ENTITY tooltip.type.blocked "(bllokuar)">
+<!ENTITY tooltip.type.whitelisted "(lejuar)">
+<!ENTITY tooltip.size.label "Madhësia:">
+<!ENTITY tooltip.docDomain.label "Burimi i dokumentit:">
+<!ENTITY tooltip.filter.label "Filtruesi efektiv:">
+<!ENTITY tooltip.filterSource.label "Burimi i filtruesit:">
+<!ENTITY context.block.label "Blloko këtë send">
+<!ENTITY context.editfilter.label "Vendos filtruesin në veprim">
+<!ENTITY context.disablefilter.label "Çaktivizo filtruesin ?1?">
+<!ENTITY context.enablefilter.label "Ri mundëso filtruesin ?1?">
+<!ENTITY context.disablefilteronsite.label "Pamundëso filtruesin në ?1?">
+<!ENTITY context.open.label "Hape një një lidhje të re">
+<!ENTITY context.copy.label "Kopjo adresën e elementit">
+<!ENTITY context.copyFilter.label "Kopjo filtruesin">
+<!ENTITY context.selectAll.label "Selekto të gjitha">

=== added file 'chrome/locale/sq/subscriptionSelection.dtd'
--- chrome/locale/sq/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sq/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,9 @@
+<!ENTITY adblock.uninstall "Largo Adblock">
+<!ENTITY filterset.g.moreinfo "Më shumë informata">
+<!ENTITY filterset.g.uninstall "Ç'instalo Filterset.G">
+<!ENTITY other.accesskey "f">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Vendi i listës së filtruesit">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Fresko Automatikisht">
+<!ENTITY autodownload.accesskey "P">

=== added directory 'chrome/locale/sr'
=== removed directory 'chrome/locale/sr-RS'
=== removed file 'chrome/locale/sr-RS/about.dtd'
--- chrome/locale/sr-RS/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sr-RS/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-<!ENTITY dialog.title "О Adblock Plus-у">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Издање">
-<!ENTITY description "Adblock Plus Вам дозвољава да изаберете шта желите да видите на мрежи.
-Више није потребно да преузимате све оне банере и рекламе, уколико их не желите ту је Adblock Plus.">
-<!ENTITY homepage.label "Интернет страна Adblock Plus-а:">
-<!ENTITY homepage.url "http://adblockplus.org/en/">
-<!ENTITY author.label "Аутор:">
-<!ENTITY contributors.label "Сарадници:">

=== removed file 'chrome/locale/sr-RS/composer.dtd'
--- chrome/locale/sr-RS/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sr-RS/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,52 +0,0 @@
-<!ENTITY dialog.title "Додавање Adblock Plus филтера">
-<!ENTITY accept.label "Додај филтер">
-<!ENTITY advanced.label "Напредни изглед">
-<!ENTITY basic.label "Основни изглед">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus је тренутно искључен. И даље можете додавати филтере, али ће они бити примењени тек по">
-<!ENTITY disabled.warning.link "укључивању Adblock Plus-а">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Група филтера &quot;&#37;S&quot; у коју желите да додате овај филтер је тренутно искључена. Можете додати филтер, али ће он бити примењен тек по">
-<!ENTITY groupDisabled.warning.link "поновном укључењу групе филтера">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Нови филтер">
-<!ENTITY filter.accesskey "ф">
-<!ENTITY preferences.label "Прикажи постојеће филтере...">
-<!ENTITY preferences.accesskey "П">
-<!ENTITY type.filter.label "Филтер за блокирање">
-<!ENTITY type.filter.accesskey "л">
-<!ENTITY type.whitelist.label "Изузетак">
-<!ENTITY type.whitelist.accesskey "з">
-<!ENTITY pattern.label "Потражи образац">
-<!ENTITY pattern.explanation "Образац може бити било који део адресе, симбол * се користи као џокер. Филтер ће бити коришћен једино ако се адреса слаже са обрасцем.">
-<!ENTITY regexp.warning "Образац који сте унели ће бити коришћен као регуларни израз. Превише регуларних израза може успорити прегледач интернет страна. Уколико не намеравате да користите регуларне изразе, додајте симбол * на крају обрасца.">
-<!ENTITY shortpattern.warning "Образац који сте унели је прекратак за оптимизацију, превише таквих образаца може успорити прегледач интернет страна. Препоручљиво је да користите дуже изразе као филтере.">
-<!ENTITY custom.pattern.label "Прилагођен:">
-<!ENTITY custom.pattern.accesskey "И">
-<!ENTITY anchors.label "Прихвати образац само:">
-<!ENTITY anchor.start.label "на почетку адресе">
-<!ENTITY anchor.start.accesskey "н">
-<!ENTITY anchor.start.flexible.label "на почетку назива домена">
-<!ENTITY anchor.start.flexible.accesskey "н">
-<!ENTITY anchor.end.label "на крају адресе">
-<!ENTITY anchor.end.accesskey "а">
-<!ENTITY options.label "Опције">
-<!ENTITY domainRestriction.label "Ограничи на домен:">
-<!ENTITY domainRestriction.accesskey "д">
-<!ENTITY domainRestriction.help "Наведите један или више домена раздвојених знаком &quot;|&quot;.
-Филтер ће бити употребљен једино за ове домене.
-Знак &quot;~&quot; испред домена значи да ће домен бити изузет од филтрирања.">
-<!ENTITY firstParty.label "Само са ове адресе">
-<!ENTITY firstParty.accesskey "в">
-<!ENTITY thirdParty.label "Само са других адреса">
-<!ENTITY thirdParty.accesskey "х">
-<!ENTITY matchCase.label "Битност величине слова">
-<!ENTITY matchCase.accesskey "Б">
-<!ENTITY types.label "Примени на врсте:">
-<!ENTITY selectAllTypes.label "Изабери све">
-<!ENTITY unselectAllTypes.label "Поништи избор">
-<!ENTITY collapse.label "Сажми блокирано:">
-<!ENTITY collapse.accesskey "С">
-<!ENTITY collapse.default.yes.label "Користи подразумевано (да)">
-<!ENTITY collapse.default.no.label "Користи подразумевано(не)">
-<!ENTITY collapse.yes.label "Да">
-<!ENTITY collapse.no.label "Не">

=== removed file 'chrome/locale/sr-RS/global.properties'
--- chrome/locale/sr-RS/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/sr-RS/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Рекламе су прошлост!
-status_active_label=Adblock
-status_disabled_label=Искључен
-action0_tooltip=Клик за отварање помоћног менија, средњи клик за укључивање/искључивање.
-action1_tooltip=Клик за отварање ставки које се могу блокирати, средњи клик за укључивање/искључивање.
-action2_tooltip=Клик за отварање подешавања, средњи клик за укључивање/искључивање.
-action3_tooltip=Клик за укључивање/искључивање Adblock Plus-а.
-active_tooltip=Adblock Plus је активан.
-disabled_tooltip=Adblock Plus је искључен.
-whitelisted_tooltip=Adblock Plus је активан, али искључен на тренутној страни.
-blocked_count_tooltip=-- од --
-no_blocking_suggestions=На овој страни нема ставки за блокирање
-whitelisted_page=Adblock Plus је искључен за ову страну
-whitelist_description=Моји изузеци
-filterlist_description=Моја правила за блокирање реклама
-invalid_description=Моји неисправна правила
-elemhide_description=Моја правила за сакривање елемената
-subscription_description=Претплата на филтер:
-subscription_wrong_version=За исправан рад неки филтери у овој претплати захтевају Adblock Plus!
-subscription_source=Извор:
-subscription_status=Статус:
-subscription_status_autodownload=Аутоматски ажуриран
-subscription_status_manualdownload=Ручно ажуриран
-subscription_status_externaldownload=Ажуриран споља (неки други додатак)
-subscription_status_lastdownload=Последње преузимање:
-subscription_status_lastdownload_inprogress=Преузимање...
-subscription_status_lastdownload_unknown=Непознато
-remove_subscription_warning=Да ли заиста желите да уклоните ову претплату?
-import_filters_wrong_version=Упозорење: како би исправно радили, неки од филтера захтевају Adblock Plus. Највероватније је потребно да пре увоза листе филтера, ажурирате Adblock Plus.
-import_filters_warning=Да ли желите да замените тренутну листу филтера или да додате нове на крају листе?
-import_filters_title=Увези филтере
-export_filters_title=Извези филтере
-invalid_filters_file=Неисправна Adblock Plus датотека филтера.
-filters_write_error=Дошло је до грешке приликом записивања филтера у датотеку. Проверите да датотека није заштићена од измена или је коришћена од стране неког другог програма.
-clearall_warning=Да ли заиста желите да уклоните све филтере са листе?
-resethitcounts_warning=Да ли заиста желите да поништите бројач погодака за све филтере? Ова операција је неповратна!
-resethitcounts_selected_warning=Да ли заиста желите да поништите бројач погодака за изабране филтере? Ова операција је неповратна!
-filter_regexp_tooltip=Филтер је или регуларан израз или је прекратак за оптимизацију. Превише таквих филтера може успорити ваш прегледач интернет страна.
-filter_elemhide_duplicate_id=Да би сте сакрили елеменат, морате дати само један идентитет елемента
-filter_elemhide_nocriteria=Није пронађен критеријум за препознавање елемента који ће бити сакривен
-subscription_no_location=Молим унесите адресу локације одакле ће филтери бити преузети.
-subscription_invalid_location=Неисправна адреса и име датотеке са листом филтера.
-subscription_location_exists=Већ сте претплаћени на ову листу филтера.
-synchronize_invalid_url=Неуспело, неисправна адреса
-synchronize_connection_error=Неуспело, грешка у преузимању
-synchronize_invalid_data=Неуспело, није листа филтера
-synchronize_checksum_mismatch=Неуспело, неслагање извештаја
-synchronize_ok=Успех
-overwrite=Препиши
-append=Додај
-new_filter_group_title=Нови филтер
-type_label_other=друго
-type_label_script=скрипт
-type_label_image=слика
-type_label_stylesheet=стил
-type_label_object=објекат
-type_label_subdocument=оквир
-type_label_document=документ
-type_label_background=позадинска слика
-type_label_elemhide=сакривен
-type_label_xbl=везивни XBL
-type_label_ping=пинг везе
-type_label_xmlhttprequest=XML захтев
-type_label_object_subrequest=подзахтев за објектом
-type_label_dtd=DTD
-type_label_media=аудио/видео
-type_label_font=фонт

=== removed file 'chrome/locale/sr-RS/overlay.dtd'
--- chrome/locale/sr-RS/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sr-RS/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Статус:">
-<!ENTITY blocked.tooltip "Блокиране ставке на овој страни:">
-<!ENTITY filters.tooltip "Најактивнији филтер:">
-<!ENTITY menuitem.label "Подешавања Adblock Plus-а">
-<!ENTITY menuitem.accesskey "в">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus:Ставке које се могу блокирати">
-<!ENTITY context.image.label "Блокирај слику">
-<!ENTITY context.object.label "Блокирај објекат">
-<!ENTITY context.frame.label "Блокирај оквир">
-<!ENTITY context.removeWhitelist.label "Поново укључи на овој страни">
-<!ENTITY sidebar.title "Ставке које се могу блокирати на овој страни">
-<!ENTITY settings.label "Подешавања">
-<!ENTITY settings.accesskey "д">
-<!ENTITY opensidebar.label "Отвори ставке које се могу блокирати">
-<!ENTITY opensidebar.accesskey "т">
-<!ENTITY closesidebar.label "Затвори ставке које се могу блокирати">
-<!ENTITY closesidebar.accesskey "т">
-<!ENTITY whitelist.site.label "Искључи на --">
-<!ENTITY whitelist.page.label "Искључи само на овој страни">
-<!ENTITY objecttab.title "Блокирај">
-<!ENTITY objecttab.tooltip "Кликните овде како би сте блокирали ставку помоћу Adblock Plus-а">

=== removed file 'chrome/locale/sr-RS/settings.dtd'
--- chrome/locale/sr-RS/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sr-RS/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Подешавања Adblock Plus-а">
-<!ENTITY filters.label "Филтери">
-<!ENTITY filters.accesskey "Ф">
-<!ENTITY add.label "Додај филтер">
-<!ENTITY add.accesskey "а">
-<!ENTITY addsubscription.label "Додај претплату на филтер">
-<!ENTITY addsubscription.accesskey "л">
-<!ENTITY synchsubscriptions.label "Ажурирај све претплате">
-<!ENTITY synchsubscriptions.accesskey "ј">
-<!ENTITY import.label "Увези филтере">
-<!ENTITY import.accesskey "з">
-<!ENTITY export.label "Извези прилагођене филтере">
-<!ENTITY export.accesskey "г">
-<!ENTITY clearall.label "Уклони све прилагођене филтере">
-<!ENTITY clearall.accesskey "е">
-<!ENTITY resethitcounts.label "Поништи статистику погодака">
-<!ENTITY resethitcounts.accesskey "д">
-<!ENTITY edit.label "Уређивање">
-<!ENTITY edit.accesskey "У">
-<!ENTITY cut.label "Исеци">
-<!ENTITY cut.accesskey "ц">
-<!ENTITY copy.label "Умножи">
-<!ENTITY copy.accesskey "м">
-<!ENTITY paste.label "Убаци">
-<!ENTITY paste.accesskey "б">
-<!ENTITY remove.label "Обриши">
-<!ENTITY remove.accesskey "р">
-<!ENTITY menu.find.label "Нађи">
-<!ENTITY menu.find.accesskey "н">
-<!ENTITY menu.findagain.label "Тражи поново">
-<!ENTITY menu.findagain.accesskey "Т">
-<!ENTITY view.label "Приказ">
-<!ENTITY view.accesskey "р">
-<!ENTITY sort.label "Сортирај по">
-<!ENTITY sort.accesskey "С">
-<!ENTITY sort.none.label "Несортирано">
-<!ENTITY sort.none.accesskey "е">
-<!ENTITY sort.ascending.label "A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Опције">
-<!ENTITY options.accesskey "О">
-<!ENTITY enable.label "Укључи Adblock Plus">
-<!ENTITY enable.accesskey "У">
-<!ENTITY showintoolbar.label "Прикажи у алатној траци">
-<!ENTITY showintoolbar.accesskey "т">
-<!ENTITY showinstatusbar.label "Прикажи у статусној линији">
-<!ENTITY showinstatusbar.accesskey "с">
-<!ENTITY objecttabs.label "Прикажи језичак на Flash и Java објектима">
-<!ENTITY objecttabs.accesskey "к">
-<!ENTITY collapse.label "Сажми блокиране елементе">
-<!ENTITY collapse.accesskey "б">
-<!ENTITY help.label "Помоћ">
-<!ENTITY help.accesskey "П">
-<!ENTITY gettingStarted.label "Како почети">
-<!ENTITY gettingStarted.accesskey "К">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Најчешће постављана питања">
-<!ENTITY faq.accesskey "Н">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Писање филтера за Adblock Plus">
-<!ENTITY filterdoc.accesskey "P">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "О Adblock Plus-у">
-<!ENTITY about.accesskey "О">
-<!ENTITY description "Следећи филтери одређују које ће адресе бити блокиране, а које дозвољене:">
-<!ENTITY filter.column "Правило филтера">
-<!ENTITY filter.accesskey "ф">
-<!ENTITY slow.column "Спори филтери">
-<!ENTITY slow.accesskey "п">
-<!ENTITY enabled.column "Укључен">
-<!ENTITY enabled.accesskey "н">
-<!ENTITY hitcount.column "Број погодака">
-<!ENTITY hitcount.accesskey "ј">
-<!ENTITY lasthit.column "Последњи погодак">
-<!ENTITY lasthit.accesskey "л">
-<!ENTITY context.edit.label "Уреди филтер">
-<!ENTITY context.resethitcount.label "Поништи статистику о броју погодака">
-<!ENTITY context.synchsubscription.label "Ажурирај претплату">
-<!ENTITY context.editsubscription.label "Уреди претплату">
-<!ENTITY context.moveup.label "Премести филтер навише">
-<!ENTITY context.movedown.label "Премести филтер наниже">
-<!ENTITY context.movegroupup.label "Премести групу навише">
-<!ENTITY context.movegroupdown.label "Премести групу наниже">
-<!ENTITY context.enable.label "Укључи">
-<!ENTITY context.disable.label "Искључи">
-<!ENTITY apply.label "Примени">
-<!ENTITY apply.accesskey "и">

=== removed file 'chrome/locale/sr-RS/sidebar.dtd'
--- chrome/locale/sr-RS/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sr-RS/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus:Ставке које се могу блокирати (одвојено">
-<!ENTITY detach.label "Одвоји">
-<!ENTITY reattach.label "Поново споји">
-<!ENTITY search.label "Тражи:">
-<!ENTITY search.accesskey "Т">
-<!ENTITY type.label "Врста">
-<!ENTITY address.label "Адреса">
-<!ENTITY filter.label "Филтер">
-<!ENTITY state.label "Статус">
-<!ENTITY size.label "Величина">
-<!ENTITY docDomain.label "Извор документа">
-<!ENTITY noitems.label "Нема ставки за блокирање">
-<!ENTITY whitelisted.label "Бела листа">
-<!ENTITY tooltip.address.label "Адреса:">
-<!ENTITY tooltip.type.label "Врста:">
-<!ENTITY tooltip.type.blocked "(блокирано)">
-<!ENTITY tooltip.type.whitelisted "(на белој листи)">
-<!ENTITY tooltip.size.label "Величина:">
-<!ENTITY tooltip.docDomain.label "Извор документа:">
-<!ENTITY tooltip.filter.label "Коришћени филтер:">
-<!ENTITY tooltip.filterSource.label "Извор филтера:">
-<!ENTITY context.block.label "Блокирај ову ставку">
-<!ENTITY context.editfilter.label "Уреди коришћени филтер">
-<!ENTITY context.whitelist.label "Додај изузетак за ставку">
-<!ENTITY context.disablefilter.label "Искључи филтер --">
-<!ENTITY context.enablefilter.label "Поново укључи филтер --">
-<!ENTITY context.disablefilteronsite.label "Искључи овај филтер на --">
-<!ENTITY context.open.label "Отвори на новом листу">
-<!ENTITY context.flash.label "Осветли границе ставке">
-<!ENTITY context.copy.label "Умножи адресу ставке">
-<!ENTITY context.copyFilter.label "Умножи филтер">
-<!ENTITY context.selectAll.label "Изабери све">

=== removed file 'chrome/locale/sr-RS/subscription.dtd'
--- chrome/locale/sr-RS/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sr-RS/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Уређивање претплате на филтер">
-<!ENTITY dialog.newtitle "Претплата на филтер">
-<!ENTITY new.description "Молимо унесите интернет адресу или датотеку која садржи листу Adblock Plus филтера.">
-<!ENTITY edit.description "Листа филтера ће бити преузета са дате локације.">
-<!ENTITY external.description "Ово је вањска претплата на филтер. Листа филтера ће бити ажурирана од стране проширења које је извршило претплату.">
-<!ENTITY autodownload.description "Уколико изаберете &apos;Аутоматско ажурирање&apos;, на овој локација ће свакодневно бити проверавано постојање унапређења. Искључивањем ове опције и даље можете вршити ручно унапређење.">
-<!ENTITY location.label "Локација листе са филтерима:">
-<!ENTITY location.accesskey "Л">
-<!ENTITY title.label "Назив претплате:">
-<!ENTITY title.accesskey "Н">
-<!ENTITY autodownload.label "Аутоматско ажурирање">
-<!ENTITY autodownload.accesskey "А">
-<!ENTITY enabled.label "Омогући филтере">
-<!ENTITY enabled.accesskey "О">

=== removed file 'chrome/locale/sr-RS/tip_subscriptions.dtd'
--- chrome/locale/sr-RS/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sr-RS/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Претплата на филтере Adblock Plus-а">
-<!ENTITY description.par1 "Хвала што користите Adblock Plus. Овај додатак може елиминисати 99&#37; реклама на интернету. Међутим, за успешно филтрирање потребно је прављење добре комбинације филтера. Ово можете урадити сами или се једноставно можете претплатити на листу филтера коју други одржавају за вас. И даље ће бити могуће додавање сопствених филтера или искључивање/уклањање претплате уколико је то неопходно.">
-<!ENTITY description.par2 "Имате могућност претплате на једну од испод понуђених и препоручених листи(касније се можете претплатити на још листи, кроз подешавања Adblock Plus-а, али ово није неопходно):">
-<!ENTITY note "Савет: Листа филтера је најефектнија када се примењује на интернет стране из региона за који је листа и направљена.">
-<!ENTITY adblock.warning "Adblock Plus је детектовао да на вашем систему постоји Adblock или старије издање Adblock Plus-а. Истовремено коришћење Adblock и Adblock Plus-а може изазвати проблеме. Препоручено је да уклоните Adblock одмах.">
-<!ENTITY adblock.uninstall "Уклони Adblock">
-<!ENTITY filterset.g.warning "Изгледа да користите Filterset.G. Овај филтер се више не ажурира и често изазива проблеме са интернет странама. Препоручено је да уклоните Filterset.G одмах.">
-<!ENTITY filterset.g.moreinfo "Више информација">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Уклони Filterset.G">
-<!ENTITY homepage.label "Интернет страна">
-<!ENTITY subscribe.label "Претплати се">
-<!ENTITY subscribe.accesskey "П">
-<!ENTITY other.label "Додавање другачије претплате">
-<!ENTITY other.accesskey "д">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Прикажи све претплате">

=== added file 'chrome/locale/sr/about.dtd'
--- chrome/locale/sr/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sr/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,13 @@
+<!ENTITY dialog.title "О Adblock Plus-у">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "издање">
+<!ENTITY description "Adblock Plus вам дозвољава да изаберете што желите да видите на мрежи.
+Више није потребно да преузимате све оне банере и рекламе; уколико их не желите, ту је Adblock Plus.">
+<!ENTITY homepage.label "Интернетса страна Adblock Plus-а:">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "Аутор:">
+<!ENTITY contributors.label "Сарадници:">
+<!ENTITY developers.label "Програмери:">
+<!ENTITY designers.label "Графички дизајнери:">
+<!ENTITY subscriptionAuthors.label "Аутори претплата на филтере:">
+<!ENTITY translators.label "Преводиоци:">

=== added file 'chrome/locale/sr/composer.dtd'
--- chrome/locale/sr/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sr/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,48 @@
+<!ENTITY dialog.title "Додавање Adblock Plus филтера">
+<!ENTITY accept.label "Додај филтер">
+<!ENTITY advanced.label "Напредни изглед">
+<!ENTITY basic.label "Основни изглед">
+<!ENTITY disabled.warning "Adblock Plus је тренутно искључен. И даље можете додавати филтере, али ће они бити примењени тек по [link]укључивању Adblock Plus-а[/link].">
+<!ENTITY groupDisabled.warning "Група филтера &quot;?1?&quot; у коју желите да додате овај филтер је тренутно искључена. Можете додати филтер, али ће он бити примењен тек по [link]поновном укључењу групе филтера[/link].">
+<!ENTITY filter.label "Нови филтер">
+<!ENTITY filter.accesskey "ф">
+<!ENTITY preferences.label "Прикажи постојеће филтере...">
+<!ENTITY preferences.accesskey "П">
+<!ENTITY type.filter.label "Филтер за блокирање">
+<!ENTITY type.filter.accesskey "л">
+<!ENTITY type.whitelist.label "Изузетак">
+<!ENTITY type.whitelist.accesskey "з">
+<!ENTITY pattern.label "Потражи образац">
+<!ENTITY pattern.explanation "Образац може бити било који део адресе, симбол * се користи као џокер. Филтер ће бити коришћен једино ако се адреса слаже са обрасцем.">
+<!ENTITY regexp.warning "Образац који сте унели ће бити коришћен као регуларни израз. Превише регуларних израза може успорити прегледач интернет страна. Уколико не намеравате да користите регуларне изразе, додајте симбол * на крају обрасца.">
+<!ENTITY shortpattern.warning "Образац који сте унели је прекратак за оптимизацију, превише таквих образаца може успорити прегледач интернет страна. Препоручљиво је да користите дуже изразе као филтере.">
+<!ENTITY custom.pattern.label "Прилагођен:">
+<!ENTITY custom.pattern.accesskey "И">
+<!ENTITY anchors.label "Прихвати образац само:">
+<!ENTITY anchor.start.label "на почетку адресе">
+<!ENTITY anchor.start.accesskey "н">
+<!ENTITY anchor.start.flexible.label "на почетку назива домена">
+<!ENTITY anchor.start.flexible.accesskey "н">
+<!ENTITY anchor.end.label "на крају адресе">
+<!ENTITY anchor.end.accesskey "а">
+<!ENTITY options.label "Опције">
+<!ENTITY domainRestriction.label "Ограничи на домен:">
+<!ENTITY domainRestriction.accesskey "д">
+<!ENTITY domainRestriction.help "Наведите један или више домена раздвојених знаком &quot;|&quot;.
+Филтер ће бити употребљен једино за ове домене.
+Знак &quot;~&quot; испред домена значи да ће домен бити изузет од филтрирања.">
+<!ENTITY firstParty.label "Само са ове адресе">
+<!ENTITY firstParty.accesskey "в">
+<!ENTITY thirdParty.label "Само са других адреса">
+<!ENTITY thirdParty.accesskey "х">
+<!ENTITY matchCase.label "Битност величине слова">
+<!ENTITY matchCase.accesskey "Б">
+<!ENTITY types.label "Примени на врсте:">
+<!ENTITY selectAllTypes.label "Изабери све">
+<!ENTITY unselectAllTypes.label "Поништи избор">
+<!ENTITY collapse.label "Сажми блокирано:">
+<!ENTITY collapse.accesskey "С">
+<!ENTITY collapse.default.yes.label "Користи подразумевано (да)">
+<!ENTITY collapse.default.no.label "Користи подразумевано(не)">
+<!ENTITY collapse.yes.label "Да">
+<!ENTITY collapse.no.label "Не">

=== added file 'chrome/locale/sr/global.properties'
--- chrome/locale/sr/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/sr/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Кликните да бисте отворили помоћни мени, а средњи клик за укључивање/искључивање.
+action1_tooltip=Кликните да бисте отворили ставке које се могу блокирати, а средњи клик за укључивање/искључивање.
+action2_tooltip=Кликните да бисте отворили подешавања, а средњи клик за укључивање/искључивање.
+action3_tooltip=Кликните да бисте укључили/искључили Adblock Plus.
+disabled_tooltip=Adblock Plus је искључен.
+active_tooltip=Adblock Plus је активан, ?1? претплате на филтере и ?2?- прилагођени филтер(и) у употреби.
+whitelisted_tooltip=Adblock Plus је активан, али искључен на тренутној страни.
+blocked_count_tooltip=?1? од ?2?
+blocked_count_addendum=(такође проверено: ?1?, сакривено: ?2?)
+no_blocking_suggestions=На овој страни нема ставки које могу да се блокирају
+whitelisted_page=Adblock Plus је искључен за ову страну
+whitelist_description=Моји изузеци
+filterlist_description=Моја правила за блокирање реклама
+invalid_description=Моји неисправна правила
+elemhide_description=Моја правила за сакривање елемената
+subscription_description=Претплата на филтер:
+subscription_wrong_version=Неки филтери у овој претплати захтевају Adblock Plus ?1? да би радили исправно.
+subscription_source=Извор:
+subscription_status=Статус:
+subscription_status_autodownload=Аутоматски ажуриран
+subscription_status_manualdownload=Ручно ажуриран
+subscription_status_externaldownload=Ажуриран споља (неки други додатак)
+subscription_status_lastdownload=Последње преузимање:
+subscription_status_lastdownload_inprogress=Преузимање...
+subscription_status_lastdownload_unknown=Непознато
+remove_subscription_warning=Да ли заиста желите да уклоните ову претплату?
+import_filters_wrong_version=Упозорење: неки од филтера захтевају Adblock Plus ?1? да би исправно радили. Највероватније је потребно да пре увожења списка филтера ажурирате Adblock Plus.
+import_filters_warning=Да ли желите да замените тренутни списак филтера или да додате нове на крај списка?
+import_filters_title=Увези филтере
+export_filters_title=Извези филтере
+invalid_filters_file=Неисправна Adblock Plus датотека филтера.
+filters_write_error=Дошло је до грешке приликом записивања филтера у датотеку. Проверите да датотека није заштићена од измена или је коришћена од стране неког другог програма.
+clearall_warning=Да ли заиста желите да уклоните све филтере са списка?
+resethitcounts_warning=Да ли заиста желите да поништите бројач погодака за све филтере? Ова операција је неопозива!
+resethitcounts_selected_warning=Да ли заиста желите да поништите бројач погодака за изабране филтере? Ова операција је неопозива!
+filter_regexp_tooltip=Филтер је или регуларан израз или је прекратак за оптимизацију. Превише таквих филтера може успорити ваш прегледач интернет страна.
+filter_elemhide_duplicate_id=Да би сте сакрили елеменат, морате дати само један идентитет елемента
+filter_elemhide_nocriteria=Није пронађен критеријум за препознавање елемента који ће бити сакривен
+subscription_notAdded_warning=Нисте додали претплату на филтер. Без претплате на филтер морате да ручно додате филтере за Adblock Plus.
+subscription_notAdded_warning_addendum=Да ли желите да наставите?
+subscription_invalid_location=Неисправна адреса и име датотеке са списком филтера.
+synchronize_invalid_url=Неуспело, неисправна адреса
+synchronize_connection_error=Неуспело, грешка у преузимању
+synchronize_invalid_data=Неуспело, није листа филтера
+synchronize_checksum_mismatch=Неуспело, неслагање извештаја
+synchronize_ok=Успех
+overwrite=Препиши
+append=Додај
+new_filter_group_title=Нови филтер
+type_label_other=друго
+type_label_script=скрипт
+type_label_image=слика
+type_label_stylesheet=стил
+type_label_object=објекат
+type_label_subdocument=оквир
+type_label_document=документ
+type_label_background=позадинска слика
+type_label_elemhide=сакривен
+type_label_xbl=везивни XBL
+type_label_ping=пинг везе
+type_label_xmlhttprequest=XML захтев
+type_label_object_subrequest=подзахтев за објектом
+type_label_dtd=DTD
+type_label_media=аудио/видео
+type_label_font=фонт
+fennec_status_enabled=Adblock Plus је укључен.
+fennec_status_disabled=Adblock Plus је искључен.
+fennec_status_enabled_site=Adblock Plus је укључен на ?1?.
+fennec_status_disabled_site=Adblock Plus је искључен на ?1?.

=== added file 'chrome/locale/sr/meta.properties'
--- chrome/locale/sr/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/sr/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=kapetance, ДакСРБИЈА
+name=Adblock Plus
+description=Рекламе су прошлост!
+description.short=Досадиле су вам рекламе? Доста вам је наметнутих објеката? Смарају вас банери? Инсталирајте Adblock Plus да бисте преузели контролу над Интернетом и стекли другачији поглед на њега.
+description.long=Адблоцк Плус вам омогућава да поново стекнете контролу над Интернетом и изгледом страница. Додатак подржава преко четрдесет претплата на филтере на многим језицима који се аутоматски подешавају како би уклонили све: од уклањана нежељених реклама до блокирања познатих злонамерних домена. Adblock Plus такође дозвољава прилагођавање филтера и помоћ за разноврсне могућности, као што су садржајне опције за слике, језичак за блокирање Flash и Java објеката и списак ставки које је могуће блокирати ради уклањања скрипти и стилова.

=== added file 'chrome/locale/sr/overlay.dtd'
--- chrome/locale/sr/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sr/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Статус:">
+<!ENTITY blocked.tooltip "Блокиране ставке на овој страни:">
+<!ENTITY filters.tooltip "Најактивнији филтер:">
+<!ENTITY menuitem.label "Подешавања Adblock Plus-а">
+<!ENTITY menuitem.accesskey "в">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: ставке које се могу блокирати">
+<!ENTITY context.image.label "Блокирај слику">
+<!ENTITY context.object.label "Блокирај објекат">
+<!ENTITY context.frame.label "Блокирај оквир">
+<!ENTITY context.media.label "Блокирај аудио/видео">
+<!ENTITY context.removeWhitelist.label "Поново укључи на овој страни">
+<!ENTITY sidebar.title "Ставке које се могу блокирати на овој страни">
+<!ENTITY settings.label "Подешавања">
+<!ENTITY settings.accesskey "д">
+<!ENTITY opensidebar.label "Отвори ставке које се могу блокирати">
+<!ENTITY opensidebar.accesskey "т">
+<!ENTITY closesidebar.label "Затвори ставке које се могу блокирати">
+<!ENTITY closesidebar.accesskey "т">
+<!ENTITY whitelist.site.label "Искључи на ?1?">
+<!ENTITY whitelist.page.label "Искључи само на овој страни">
+<!ENTITY objecttab.title "Блокирај">
+<!ENTITY objecttab.tooltip "Кликните овде да бисте блокирали објекат помоћу Adblock Plus-а">

=== added file 'chrome/locale/sr/settings.dtd'
--- chrome/locale/sr/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sr/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Подешавања Adblock Plus-а">
+<!ENTITY filters.label "Филтери">
+<!ENTITY filters.accesskey "Ф">
+<!ENTITY add.label "Додај филтер">
+<!ENTITY add.accesskey "а">
+<!ENTITY addsubscription.label "Додај претплату на филтер">
+<!ENTITY addsubscription.accesskey "л">
+<!ENTITY synchsubscriptions.label "Ажурирај све претплате">
+<!ENTITY synchsubscriptions.accesskey "ј">
+<!ENTITY import.label "Увези филтере">
+<!ENTITY import.accesskey "з">
+<!ENTITY export.label "Извези прилагођене филтере">
+<!ENTITY export.accesskey "г">
+<!ENTITY clearall.label "Уклони све прилагођене филтере">
+<!ENTITY clearall.accesskey "е">
+<!ENTITY resethitcounts.label "Поништи статистику погодака">
+<!ENTITY resethitcounts.accesskey "д">
+<!ENTITY edit.label "Уређивање">
+<!ENTITY edit.accesskey "У">
+<!ENTITY cut.label "Исеци">
+<!ENTITY cut.accesskey "ц">
+<!ENTITY copy.label "Умножи">
+<!ENTITY copy.accesskey "м">
+<!ENTITY paste.label "Убаци">
+<!ENTITY paste.accesskey "б">
+<!ENTITY remove.label "Обриши">
+<!ENTITY remove.accesskey "р">
+<!ENTITY menu.find.label "Нађи">
+<!ENTITY menu.find.accesskey "н">
+<!ENTITY menu.findagain.label "Тражи поново">
+<!ENTITY menu.findagain.accesskey "Т">
+<!ENTITY view.label "Приказ">
+<!ENTITY view.accesskey "р">
+<!ENTITY sort.label "Сортирај по">
+<!ENTITY sort.accesskey "С">
+<!ENTITY sort.none.label "Несортирано">
+<!ENTITY sort.none.accesskey "е">
+<!ENTITY sort.ascending.label "Од А до Ш">
+<!ENTITY sort.ascending.accesskey "А">
+<!ENTITY sort.descending.label "Од Ш до А">
+<!ENTITY sort.descending.accesskey "Ш">
+<!ENTITY options.label "Опције">
+<!ENTITY options.accesskey "О">
+<!ENTITY enable.label "Укључи Adblock Plus">
+<!ENTITY enable.accesskey "У">
+<!ENTITY showintoolbar.label "Прикажи у траци са алаткама">
+<!ENTITY showintoolbar.accesskey "т">
+<!ENTITY showinstatusbar.label "Прикажи у статусној траци">
+<!ENTITY showinstatusbar.accesskey "с">
+<!ENTITY objecttabs.label "Прикажи језичак на Flash и Java објектима">
+<!ENTITY objecttabs.accesskey "к">
+<!ENTITY collapse.label "Сажми блокиране елементе">
+<!ENTITY collapse.accesskey "б">
+<!ENTITY help.label "Помоћ">
+<!ENTITY help.accesskey "П">
+<!ENTITY gettingStarted.label "Како почети">
+<!ENTITY gettingStarted.accesskey "К">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Најчешће постављана питања">
+<!ENTITY faq.accesskey "Н">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Писање филтера за Adblock Plus">
+<!ENTITY filterdoc.accesskey "P">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "О Adblock Plus-у">
+<!ENTITY about.accesskey "О">
+<!ENTITY description "Следећи филтери одређују које ће адресе бити блокиране, а које дозвољене:">
+<!ENTITY filter.column "Правило филтера">
+<!ENTITY filter.accesskey "ф">
+<!ENTITY slow.column "Спори филтери">
+<!ENTITY slow.accesskey "п">
+<!ENTITY enabled.column "Укључен">
+<!ENTITY enabled.accesskey "н">
+<!ENTITY hitcount.column "Број погодака">
+<!ENTITY hitcount.accesskey "ј">
+<!ENTITY lasthit.column "Последњи погодак">
+<!ENTITY lasthit.accesskey "л">
+<!ENTITY context.edit.label "Уреди филтер">
+<!ENTITY context.resethitcount.label "Поништи статистику о броју погодака">
+<!ENTITY context.synchsubscription.label "Ажурирај претплату">
+<!ENTITY context.editsubscription.label "Уреди претплату">
+<!ENTITY context.moveup.label "Премести филтер навише">
+<!ENTITY context.movedown.label "Премести филтер наниже">
+<!ENTITY context.movegroupup.label "Премести групу навише">
+<!ENTITY context.movegroupdown.label "Премести групу наниже">
+<!ENTITY context.enable.label "Укључи">
+<!ENTITY context.disable.label "Искључи">
+<!ENTITY apply.label "Примени">
+<!ENTITY apply.accesskey "и">
+<!ENTITY fennec.subscription.label "Претплата на филтере">

=== added file 'chrome/locale/sr/sidebar.dtd'
--- chrome/locale/sr/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sr/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus:Ставке које се могу блокирати (одвојено">
+<!ENTITY detach.label "Одвоји">
+<!ENTITY reattach.label "Поново споји">
+<!ENTITY search.label "Тражи:">
+<!ENTITY search.accesskey "Т">
+<!ENTITY type.label "Врста">
+<!ENTITY address.label "Адреса">
+<!ENTITY filter.label "Филтер">
+<!ENTITY state.label "Статус">
+<!ENTITY size.label "Величина">
+<!ENTITY docDomain.label "Извор документа">
+<!ENTITY noitems.label "Нема ставки за блокирање">
+<!ENTITY whitelisted.label "Бела листа">
+<!ENTITY tooltip.address.label "Адреса:">
+<!ENTITY tooltip.type.label "Врста:">
+<!ENTITY tooltip.type.blocked "(блокирано)">
+<!ENTITY tooltip.type.whitelisted "(на белој листи)">
+<!ENTITY tooltip.size.label "Величина:">
+<!ENTITY tooltip.docDomain.label "Извор документа:">
+<!ENTITY tooltip.filter.label "Коришћени филтер:">
+<!ENTITY tooltip.filterSource.label "Извор филтера:">
+<!ENTITY context.block.label "Блокирај ову ставку">
+<!ENTITY context.editfilter.label "Уреди коришћени филтер">
+<!ENTITY context.whitelist.label "Додај изузетак за ставку">
+<!ENTITY context.disablefilter.label "Искључи филтер ?1?">
+<!ENTITY context.enablefilter.label "Поново укључи филтер ?1?">
+<!ENTITY context.disablefilteronsite.label "Искључи овај филтер на ?1?">
+<!ENTITY context.open.label "Отвори на новом листу">
+<!ENTITY context.flash.label "Осветли границе ставке">
+<!ENTITY context.copy.label "Умножи адресу ставке">
+<!ENTITY context.copyFilter.label "Умножи филтер">
+<!ENTITY context.selectAll.label "Изабери све">

=== added file 'chrome/locale/sr/subscriptionSelection.dtd'
--- chrome/locale/sr/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sr/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Претплата на филтере Adblock Plus-а">
+<!ENTITY dialog.title.edit "Уређивање претплате на филтер">
+<!ENTITY description.newInstall "Adblock Plus ће бити најучинковитији ако додате претплату на филтер. Претплате на филтере бесплатно омогућавају други корисници Adblock Plus-а. Одабрана је претплата која је најприкладнија вашем језику.">
+<!ENTITY adblock.warning "Adblock Plus је детектовао да на вашем систему постоји Adblock или старије издање Adblock Plus-а. Истовремено коришћење Adblock и Adblock Plus-а може изазвати проблеме. Препоручено је да уклоните Adblock одмах.">
+<!ENTITY adblock.uninstall "Уклони Adblock">
+<!ENTITY filterset.g.warning "Изгледа да користите Filterset.G. Овај филтер се више не ажурира и често изазива проблеме са интернет странама. Препоручено је да уклоните Filterset.G одмах.">
+<!ENTITY filterset.g.moreinfo "Више информација">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Уклони Filterset.G">
+<!ENTITY subscriptionSelector.label "Изаберите једну претплату на филтер са списка:">
+<!ENTITY viewList.label "Погледај филтере">
+<!ENTITY visitHomepage.label "Посети матичну страницу">
+<!ENTITY addSubscription.label "Додај претплату">
+<!ENTITY saveSubscription.label "Сачувај претплату">
+<!ENTITY other.label "Додај другу претплату">
+<!ENTITY other.accesskey "д">
+<!ENTITY list.download.failed "Adblock Plus није успео да набави нови списак претплата.">
+<!ENTITY list.download.retry "Покушај поново">
+<!ENTITY list.download.website "Посети интернетску страницу">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Потврдите да желите додати претплату на овај филтерт">
+<!ENTITY edit.description "По потреби, можете да промените назив или локацију претплате.">
+<!ENTITY external.description "Ово је претплата на спољни филтер; биће ажуриран са додатком који је направио ову претплату.">
+<!ENTITY title.label "Назив претплате:">
+<!ENTITY title.accesskey "Н">
+<!ENTITY location.label "Локација списка са филтерима:">
+<!ENTITY location.accesskey "Л">
+<!ENTITY autodownload.label "Аутоматско ажурирање">
+<!ENTITY autodownload.accesskey "А">
+<!ENTITY supplementMessage "Ова претплата на филтер је предвиђена за коришћење са филтером „?1?” који још увек не користите.">
+<!ENTITY addMain.label "Додај и претплату на филтер „?1?”">
+<!ENTITY addMain.accesskey "о">

=== modified file 'chrome/locale/sv-SE/composer.dtd'
--- chrome/locale/sv-SE/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sv-SE/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "Lägg till filter">
 <!ENTITY advanced.label "Avancerat">
 <!ENTITY basic.label "Standard">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus är inaktiverad. Du kan lägga till filter men kan inte användas förrän du">
-<!ENTITY disabled.warning.link "aktiverar Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Filtergruppen &quot;&#37;S&quot; som detta filter skall läggas till i är f.n. inaktiverat. Du kan lägga till det men kommer inte att användas förrän du">
-<!ENTITY groupDisabled.warning.link "aktiverar denna filtergrupp.">
-<!ENTITY groupDisabled.warning.afterLink ".">
+<!ENTITY disabled.warning "Adblock Plus är inaktiverad. Du kan lägga till filter men kan inte användas förrän du [link]aktiverar Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Filtergruppen &quot;?1?&quot; som detta filter skall läggas till i är f.n. inaktiverat. Du kan lägga till det men kommer inte att användas förrän du [link]aktiverar denna filtergrupp.[/link].">
 <!ENTITY filter.label "Nytt filter:">
 <!ENTITY filter.accesskey "N">
 <!ENTITY preferences.label "Visa filter...">

=== modified file 'chrome/locale/sv-SE/global.properties'
--- chrome/locale/sv-SE/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/sv-SE/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,13 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Säg farväl till all reklam! Med Adblock Plus kan du välja att filtrera bort all reklam - reklam som tar både tid och kapacitet att ladda ner...
-status_active_label=Adblock
-status_disabled_label=Avstängd
+default_dialog_title=Adblock Plus
 action0_tooltip=Klicka för meny, mittenklicka för att slå på/av Adblock Plus.
 action1_tooltip=Klicka för att öppna/stänga listan med blockerbara objekt, mittenklicka för att slå på/av Adblock Plus.
 action2_tooltip=Klicka för att öppna inställningar, mittenklicka för att slå på/av Adblock Plus.
 action3_tooltip=Klicka för att slå på/av Adblock Plus.
-active_tooltip=Adblock Plus är på.
 disabled_tooltip=Adblock Plus är av.
+active_tooltip=Adblock Plus är aktivt, ?1? filterprenumeration(er) och ?2? egna filter används.
 whitelisted_tooltip=Adblock Plus är på men avaktiverad för denna sida.
-blocked_count_tooltip=-- av --
+blocked_count_tooltip=?1? av ?2?
+blocked_count_addendum=(vitlistade: ?1?, dolda: ?2?)
 no_blocking_suggestions=Det finns inget att blockera på denna sida
 whitelisted_page=Adblock Plus har stängts av för denna sida
 whitelist_description=Mina Regler för undantag
@@ -16,7 +15,7 @@
 invalid_description=Mina Ogiltiga regler
 elemhide_description=Mina Regler för att dölja reklam
 subscription_description=Filterprenumeration:
-subscription_wrong_version=Vissa filter i denna prenumeration måste ha Adblock Plus installerat, för att uppnå full effekt.
+subscription_wrong_version=Vissa filter i denna prenumeration måste ha Adblock Plus ?1? installerat för att fungera.
 subscription_source=Källa:
 subscription_status=Status:
 subscription_status_autodownload=Uppdaterad automatiskt
@@ -26,7 +25,7 @@
 subscription_status_lastdownload_inprogress=Laddar ner...
 subscription_status_lastdownload_unknown=Okänd
 remove_subscription_warning=Vill du verkligen ta bort denna prenumeration?
-import_filters_wrong_version=Varning: vissa filter i listan kräver Adblock Plus för full effekt. Du bör uppgradera till senaste versionen av Adblock Plus innan du importerar denna lista.
+import_filters_wrong_version=Varning: vissa filter i listan kräver Adblock Plus ?1? för full effekt. Du bör uppgradera till senaste versionen av Adblock Plus innan du importerar denna lista.
 import_filters_warning=Vill du ersätta nuvarande filter eller lägga till dom i listan?
 import_filters_title=Importera filter
 export_filters_title=Exportera filter
@@ -38,9 +37,9 @@
 filter_regexp_tooltip=Detta filter är ett reguljärt uttryck eller för kort för optimal funktion. För många av dessa filter kan göra din surfning långsam.
 filter_elemhide_duplicate_id=Endast ett ID för elementet att dölja kan anges
 filter_elemhide_nocriteria=Inget kriteria uppfyllt för att gömma element
-subscription_no_location=Ange sökväg att ladda ner filter från.
+subscription_notAdded_warning=Ingen filterprenumeration lades till. Utan filterprenumeration måste filter läggas till manuellt.
+subscription_notAdded_warning_addendum=Vill du fortsätta ändå?
 subscription_invalid_location=Platsen du angivit är inte giltig eller så har du angivit ett felaktigt filnamn.
-subscription_location_exists=Du prenumererar redan på detta filter.
 synchronize_invalid_url=Ej giltig adress
 synchronize_connection_error=Fel vid nerladdning
 synchronize_invalid_data=Fel vid validering av filter

=== added file 'chrome/locale/sv-SE/meta.properties'
--- chrome/locale/sv-SE/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/sv-SE/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,4 @@
+name=Adblock Plus
+description=Säg farväl till all reklam! Med Adblock Plus kan du välja att filtrera bort all reklam - reklam som tar både tid och kapacitet att ladda ner...
+description.short=
+description.long=

=== modified file 'chrome/locale/sv-SE/overlay.dtd'
--- chrome/locale/sv-SE/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sv-SE/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -8,6 +8,7 @@
 <!ENTITY context.image.label "Adblock Bild">
 <!ENTITY context.object.label "Adblock Objekt">
 <!ENTITY context.frame.label "Adblock Ram">
+<!ENTITY context.media.label "Adblock Plus: Blockera audio/video">
 <!ENTITY context.removeWhitelist.label "Adblock Plus: Återaktivera på denna sida">
 <!ENTITY sidebar.title "Objekt att blockera på denna sida">
 <!ENTITY settings.label "Inställningar">
@@ -16,7 +17,7 @@
 <!ENTITY opensidebar.accesskey "B">
 <!ENTITY closesidebar.label "Stäng objekt att blockera">
 <!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "Använd inte på --">
+<!ENTITY whitelist.site.label "Använd inte på ?1?">
 <!ENTITY whitelist.page.label "Använd inte på denna sida">
 <!ENTITY objecttab.title "Blockera">
 <!ENTITY objecttab.tooltip "Klicka här för att blockera detta objekt med Adblock Plus">

=== modified file 'chrome/locale/sv-SE/settings.dtd'
--- chrome/locale/sv-SE/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sv-SE/settings.dtd	2010-05-04 14:45:07 +0000
@@ -87,3 +87,4 @@
 <!ENTITY context.disable.label "Inaktivera">
 <!ENTITY apply.label "Verkställ">
 <!ENTITY apply.accesskey "V">
+<!ENTITY fennec.subscription.label "Filterprenumeration">

=== modified file 'chrome/locale/sv-SE/sidebar.dtd'
--- chrome/locale/sv-SE/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sv-SE/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "Blockera detta objekt">
 <!ENTITY context.editfilter.label "Blockeringsfilter är på">
 <!ENTITY context.whitelist.label "Lägg till undantag för objekt">
-<!ENTITY context.disablefilter.label "Inaktivera filter --">
-<!ENTITY context.enablefilter.label "Re-aktivera filter --">
-<!ENTITY context.disablefilteronsite.label "Inaktivera detta filter på --">
+<!ENTITY context.disablefilter.label "Inaktivera filter ?1?">
+<!ENTITY context.enablefilter.label "Re-aktivera filter ?1?">
+<!ENTITY context.disablefilteronsite.label "Inaktivera detta filter på ?1?">
 <!ENTITY context.open.label "Öppna i ny flik">
 <!ENTITY context.flash.label "Markera objektets ram">
 <!ENTITY context.copy.label "Kopiera objektets adress">

=== removed file 'chrome/locale/sv-SE/subscription.dtd'
--- chrome/locale/sv-SE/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sv-SE/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Ändra filterprenumeration">
-<!ENTITY dialog.newtitle "Lägg till filterprenumeration">
-<!ENTITY new.description "Ange URL eller filnamn med Adblock Plus filter.">
-<!ENTITY edit.description "Filter för denna prenumeration laddas ner från angiven adress.">
-<!ENTITY external.description "Detta är en extern filterprenumeration, vars filter uppdateras av det tillägg som skapade prenumerationen.">
-<!ENTITY autodownload.description "Välj &apos;Uppdatera automatiskt&apos; om daglig uppdatering önskas. Om funktionen är avstängd kan du, via menyn, uppdatera manuellt.">
-<!ENTITY location.label "Plats för filter:">
-<!ENTITY location.accesskey "F">
-<!ENTITY title.label "Titel för prenumeration:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Uppdatera automatiskt">
-<!ENTITY autodownload.accesskey "a">
-<!ENTITY enabled.label "Filter på">
-<!ENTITY enabled.accesskey "p">

=== added file 'chrome/locale/sv-SE/subscriptionSelection.dtd'
--- chrome/locale/sv-SE/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/sv-SE/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Lägg till Adblock Plus filterprenumeration">
+<!ENTITY dialog.title.edit "Ändra filterprenumeration">
+<!ENTITY description.newInstall "Adblock Plus är mest effektiv om du lägger till en filterprenumeration. Filterprenumerationer underhålls kostnadsfritt av andra användare. Den mest användbara prenumerationen för ditt språk är redan valt.">
+<!ENTITY adblock.warning "Adblock Plus har upptäckt en tidigare version av Adblock Plus eller Adblock. Att köra Adblock och Adblock Plus samtidigt kan orsaka problem och bör undvikas. Vi rekommenderar att du avinstallerar Adblock nu.">
+<!ENTITY adblock.uninstall "Avinstallera Adblock">
+<!ENTITY filterset.g.warning "Det verkar som om du andvänder Filterset.G. Denna filterlista har knappt uppdaterats de senaste åren och har återkommande orsakat problem med hemsidor. Vi rekommenderar att du avinstallerar Filterset.G nu.">
+<!ENTITY filterset.g.moreinfo "Mer information">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Avinstallera Filterset.G">
+<!ENTITY subscriptionSelector.label "Vänligen välj en filterprenumeration från listan:">
+<!ENTITY viewList.label "Visa filter">
+<!ENTITY visitHomepage.label "Besök hemsidan">
+<!ENTITY addSubscription.label "Lägg till filterprenumeration">
+<!ENTITY saveSubscription.label "Spara filterprenumeration">
+<!ENTITY other.label "Lägg till en ny prenumeration">
+<!ENTITY other.accesskey "t">
+<!ENTITY list.download.failed "Adblock Plus kunde inte hämta listan med filterprenumerationer.">
+<!ENTITY list.download.retry "Försök igen">
+<!ENTITY list.download.website "Visa webbsidan">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Vänligen godkänn att du vill lägga till denna filterprenumeration. Du kan ändra titel eller plats innan du lägger till den.">
+<!ENTITY edit.description "Om du önskar kan du ändra titel eller plats för filterprenumerationen.">
+<!ENTITY external.description "Detta är en externa filterprenumeration och kommer uppdateras av tillägget som skapat den.">
+<!ENTITY title.label "Titel för prenumeration:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Plats för filter:">
+<!ENTITY location.accesskey "F">
+<!ENTITY autodownload.label "Uppdatera automatiskt">
+<!ENTITY autodownload.accesskey "a">
+<!ENTITY supplementMessage "Denna filterprenumeration bör användas med filterprenumeration &quot;?1?&quot; som för närvarande ej används.">
+<!ENTITY addMain.label "Lägg till filterprenumeration &quot;?1?&quot; också">
+<!ENTITY addMain.accesskey "s">

=== removed file 'chrome/locale/sv-SE/tip_subscriptions.dtd'
--- chrome/locale/sv-SE/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/sv-SE/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Välkommen till Adblock Plus filterprenumeration">
-<!ENTITY description.par1 "Tack för att du installerade Adblock Plus. Detta tillägg kan eliminera 99&#37; av all reklam du ser på Internet. I kombination med filterprenumerationer tillsammans med egna filter, får du absolut bästa resultat. Även om du prenumererar på filter, kan du alltid lägga till eller ta bort dina egna filter.">
-<!ENTITY description.par2 "Du kan välja en av den rekommenderade prenumerationerna nedan (fler prenumerationer kan läggas till i Adblock Plus Inställningar vid ett senare tillfälle):">
-<!ENTITY note "Notera att en filterlista är mest effektiv om det är skapat för en sida i det land filtret var skapat.">
-<!ENTITY adblock.warning "Adblock Plus har upptäckt en tidigare version av Adblock Plus eller Adblock. Att köra Adblock och Adblock Plus samtidigt kan orsaka problem och bör undvikas. Vi rekommenderar att du avinstallerar Adblock nu.">
-<!ENTITY adblock.uninstall "Avinstallera Adblock">
-<!ENTITY filterset.g.warning "Det verkar som om du andvänder Filterset.G. Denna filterlista har knappt uppdaterats de senaste åren och har återkommande orsakat problem med hemsidor. Vi rekommenderar att du avinstallerar Filterset.G nu.">
-<!ENTITY filterset.g.moreinfo "Mer information">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Avinstallera Filterset.G">
-<!ENTITY homepage.label "Hemsida">
-<!ENTITY subscribe.label "Prenumerera">
-<!ENTITY subscribe.accesskey "r">
-<!ENTITY other.label "Lägg till en ny prenumeration">
-<!ENTITY other.accesskey "t">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Visa alla prenumerationer">

=== added directory 'chrome/locale/th'
=== removed directory 'chrome/locale/th-TH'
=== removed file 'chrome/locale/th-TH/about.dtd'
--- chrome/locale/th-TH/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/th-TH/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "เกี่ยวกับ Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "รุ่น">
-<!ENTITY description "Adblock Plus อนุญาตให้คุณเลือกเองว่าสิ่งที่คุณไม่ต้องการจะเห็นบนเว็บ คุณไม่จำเป็นต้องดาวน์โหลดโฆษณาและป้ายประกาศอีกต่อไป ถ้าคุณไม่ต้องการพวกมัน - บอก Adblock Plus!">
-<!ENTITY homepage.label "โฮมเพจ Adblock Plus:">
-<!ENTITY homepage.url "http://adblockplus.org/en/">
-<!ENTITY author.label "ผู้พัฒนา:">
-<!ENTITY contributors.label "ผู้ร่วมสมทบงาน:">

=== removed file 'chrome/locale/th-TH/composer.dtd'
--- chrome/locale/th-TH/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/th-TH/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "เพิ่มกฎตัวกรอง Adblock Plus">
-<!ENTITY accept.label "เพิ่มตัวกรอง">
-<!ENTITY advanced.label "มุมมองละเอียด">
-<!ENTITY basic.label "มุมมองพื้นฐาน">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus ถูกปิดใช้งานอยู่ คุณยังคงสามารถเพิ่มตัวกรองได้แต่จะไม่ถูกใช้งานจนกว่าคุณ">
-<!ENTITY disabled.warning.link "เปิดใช้งาน Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "กลุ่มตัวกรอง &quot;&#37;S&quot; ว่าตัวกรองที่เพิ่มกำลังถูกปิดการใช้งาน คุณยังคงสามารถเพิ่มตัวกรองได้แต่จะไม่ใช้งานจนกว่า">
-<!ENTITY groupDisabled.warning.link "เปิดใช้งานกลุ่มตัวกรอง">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "ตัวกรองใหม่:">
-<!ENTITY filter.accesskey "ต">
-<!ENTITY preferences.label "แสดงตัวกรองที่มีอยู่...">
-<!ENTITY preferences.accesskey "ส">
-<!ENTITY type.filter.label "ตัวกรองบล็อก">
-<!ENTITY type.filter.accesskey "บ">
-<!ENTITY type.whitelist.label "กฎข้อยกเว้น">
-<!ENTITY type.whitelist.accesskey "ก">
-<!ENTITY pattern.label "ดูรูปแบบ">
-<!ENTITY pattern.explanation "รูปแบบสามารถเป็นส่วนใดส่วนหนึ่งของที่อยู่ สัญลักษณ์ * เป็นอักขระใดๆ ตัวกรองจะถูกใช้งานกับที่อยู่ที่เหมาะสมกับตัวกรองเท่านั้น">
-<!ENTITY regexp.warning "รูปแบบที่คุณป้อนเข้าจะถูกแปลเป็นการแสดงออกทั่วไป การแสดงออกทั่วไปมากๆจะทำให้การเข้าเว็บช้าลง ถ้าคุณไม่ตั้งใจจะใช้การแสดงออกทั่วไปให้ใส่สัญลักษณ์ * ที่ท้ายรูปแบบ">
-<!ENTITY shortpattern.warning "รูปแบบที่คุณป้อนเข้าสั้นเกินกว่าจะใช้ให้เหมาะสม รูปแบบมากๆจะทำให้เข้าเว็บช้า แนะนำให้ใช้รูปแบบยาวๆสำหรับตัวกรองนี้">
-<!ENTITY custom.pattern.label "ปรับเอง:">
-<!ENTITY custom.pattern.accesskey "ป">
-<!ENTITY anchors.label "รับเฉพาะรูปแบบ:">
-<!ENTITY anchor.start.label "ที่หน้าๆของที่อยู่">
-<!ENTITY anchor.start.accesskey "น">
-<!ENTITY anchor.start.flexible.label "ส่วนต้นของชื่อโดเมน">
-<!ENTITY anchor.start.flexible.accesskey "น">
-<!ENTITY anchor.end.label "ที่ท้ายๆของที่อยู่">
-<!ENTITY anchor.end.accesskey "ท">
-<!ENTITY options.label "ตัวเลือก">
-<!ENTITY domainRestriction.label "จำกัดโดเมน:">
-<!ENTITY domainRestriction.accesskey "ด">
-<!ENTITY domainRestriction.help "ระบุโดเมนหนึ่งหรือหลายแห่งให้คั่นด้วยสัญลักษณ์ &quot;|&quot; ตัวกรองจะใช้งานบนโดเมนเหล่านี้เท่านั้น ถ้าไม่ต้องการใช้โดเมนใดให้ใส่สัญลักษณ์ &quot;~&quot; หน้าชื่อโดเมน">
-<!ENTITY firstParty.label "First-party เท่านั้น">
-<!ENTITY firstParty.accesskey "r">
-<!ENTITY thirdParty.label "Third-party เท่านั้น">
-<!ENTITY thirdParty.accesskey "T">
-<!ENTITY matchCase.label "จับคู่">
-<!ENTITY matchCase.accesskey "จ">
-<!ENTITY types.label "ใช้งานกับชนิด:">
-<!ENTITY selectAllTypes.label "เลือกทั้งหมด">
-<!ENTITY unselectAllTypes.label "ไม่เลือก">
-<!ENTITY collapse.label "การบล็อกที่ล้มเหลว:">
-<!ENTITY collapse.accesskey "ม">
-<!ENTITY collapse.default.yes.label "ใช้ค่าเริ่มต้น(ใช่)">
-<!ENTITY collapse.default.no.label "ใช้ค่าเริ่มต้น(ไม่ใช่)">
-<!ENTITY collapse.yes.label "ใช่">
-<!ENTITY collapse.no.label "ไม่ใช่">

=== removed file 'chrome/locale/th-TH/global.properties'
--- chrome/locale/th-TH/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/th-TH/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=ลาก่อนพวกโฆษณา!
-status_active_label=Adblock
-status_disabled_label=ถูกปิดการใช้งาน
-action0_tooltip=คลิกเพื่อนำไปที่เมนูบริบท คลิกเมาส์กลางเพื่อเปิดหรือปิดใช้งาน
-action1_tooltip=คลิกเพื่อเปิดหรือปิดสิ่งของ คลิกเมาส์กลางเพื่อเปิดหรือปิดใช้งาน
-action2_tooltip=คลิกเพื่อเปิดการปรับแต่ง คลิกเมาส์กลางเพื่อเปิดหรือปิดใช้งาน
-action3_tooltip=คลิกเพื่อเปิดหรือปิดใช้งาน Adblock Plus
-active_tooltip=Adblock Plus เปิดอยู่
-disabled_tooltip=Adblock Plus เปิดอยู่
-whitelisted_tooltip=Adblock Plus เปิดอยู่แต่ไม่ใช้กับหน้านี้
-blocked_count_tooltip=-- ออกจาก --
-no_blocking_suggestions=ไม่มีรายการที่บล็อกได้ในหน้าล่าสุด
-whitelisted_page=Adblock Plus ถูกปิดการใช้งานในหน้าล่าสุด
-whitelist_description=ข้อยกเว้น
-filterlist_description=ตัวกรองนักโฆษณา
-invalid_description=ตัวกรองไม่ถูกต้อง
-elemhide_description=กฎการซ่อนส่วนย่อย
-subscription_description=นามข้างท้ายตัวกรอง:
-subscription_wrong_version=ตัวกรองบางตัวในนามข้างท้ายนี้ต้องการ Adblock Plus เพื่อใช้งานอย่างเหมาะสม!
-subscription_source=ต้นฉบับ:
-subscription_status=สถานะ:
-subscription_status_autodownload=อัปเดตอัตโนมัติแล้ว
-subscription_status_manualdownload=อัปเดตด้วยตัวเองแล้ว
-subscription_status_externaldownload=อัปเดตจากภายนอกแล้ว (ส่วนขยายอื่น)
-subscription_status_lastdownload=ดาวน์โหลดล่าสุด:
-subscription_status_lastdownload_inprogress=กำลังดาวน์โหลด...
-subscription_status_lastdownload_unknown=ไม่มี
-remove_subscription_warning=คุณแน่ใจหรือว่าต้องการลบนามข้างท้ายนี้
-import_filters_wrong_version=คำเตือน: ตัวกรองบางตัวในรายชื่อนี้ต้องการ Adblock Plus เพื่อใช้งานอย่างเหมาะสม คุณควรอัปเกรด Adblock Plus เป็นรุ่นล่าสุดก่อนนำเข้ารายชื่อนี้
-import_filters_warning=คุณต้องการแทนที่ตัวกรองล่าสุดหรือผนวกตัวกรองใหม่ที่ข้างล่างสุดของรายชื่อ
-import_filters_title=นำเข้าตัวกรอง
-export_filters_title=ส่งออกตัวกรอง
-invalid_filters_file=ไม่มีแฟ้มตัวกรอง Adblock Plus ที่ถูกต้อง
-filters_write_error=มีข้อผิดพลาดเมื่อกำลังเขียนตัวกรองไปยังแฟ้ม ขอให้แน่ใจว่าแฟ้มไม่ถูกป้องกันการเขียนหรือมีโปรแกรมอื่นใช้อยู่
-clearall_warning=คุณแน่ใจหรือว่าต้องการลบตัวกรองทั้งหมดจากรายชื่อ
-resethitcounts_warning=คุณแน่ใจหรือว่าต้องการเริ่มการนับใหม่สำหรับตัวกรองทั้งหมดกลับไปยังศูนย์ คำสั่งนี้ไม่สามารถย้อนกลับ!
-resethitcounts_selected_warning=คุณแน่ใจหรือว่าต้องการเริ่มการนับใหม่สำหรับตัวกรองที่เลือกกลับไปยังศูนย์ คำสั่งนี้ไม่สามารถย้อนกลับ!
-filter_regexp_tooltip=ตัวกรองนี้ก็เป็นการแสดงออกทั่วไปหรือสั้นเกินกว่าจะใช้ให้เหมาะสม ถ้ามีตัวกรองประเภทนี้มากเกินไปจะทำให้การเข้าเว็บช้าได้
-filter_elemhide_duplicate_id=มีเฉพาะรหัสประจำตัววัตถุเดียวเท่านั้นที่ซ่อนที่สามารถระบุได้
-filter_elemhide_nocriteria=ไม่มีเกณฑ์ที่ระบุที่จำวัตถุที่จะซ่อน
-subscription_no_location=กรุณาใส่ตำแหน่งเพื่อดาวน์โหลดตัวกรองจาก
-subscription_invalid_location=ตำแหน่งรายชื่อตัวกรองไม่ใช่ทั้งยูอาร์แอลที่ถูกต้องและชื่อแฟ้มที่ถูกต้อง
-subscription_location_exists=คุณเขียนนามข้างท้ายไปยังรายชื่อตัวกรองนี้แล้ว
-synchronize_invalid_url=ล้มเหลว ไม่มีที่อยู่ที่ถูกต้อง
-synchronize_connection_error=ล้มเหลว การดาวน์โหลดล้มเหลว
-synchronize_invalid_data=ล้มเหลว ไม่มีรายชื่อตัวกรองที่ถูกต้อง
-synchronize_checksum_mismatch=ล้มเหลว checksum จับผิดคู่
-synchronize_ok=สำเร็จ
-overwrite=บันทึกทับ
-append=ผนวก
-new_filter_group_title=ตัวกรองใหม่
-type_label_other=อื่นๆ
-type_label_script=สคริปต์
-type_label_image=รูปภาพ
-type_label_stylesheet=รูปแบบเอกสาร
-type_label_object=วัตถุ
-type_label_subdocument=กรอบความ
-type_label_document=เอกสาร
-type_label_background=พื้นหลัง
-type_label_elemhide=ซ่อน
-type_label_xbl=การยึดเหนี่ยวเอกซ์บีแอล
-type_label_ping=ปิงลิงก์
-type_label_xmlhttprequest=คำร้องขอเอกซ์บีแอล
-type_label_object_subrequest=subrequest วัตถุ
-type_label_dtd=ดีทีดี
-type_label_media=เสียง/ภาพ
-type_label_font=แบบอักษร

=== removed file 'chrome/locale/th-TH/overlay.dtd'
--- chrome/locale/th-TH/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/th-TH/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "สถานะ:">
-<!ENTITY blocked.tooltip "สิ่งที่บล็อกในหน้านี้:">
-<!ENTITY filters.tooltip "ตัวกรองที่ใช้งานมากที่สุด:">
-<!ENTITY menuitem.label "ปรับแต่ง Adblock Plus">
-<!ENTITY menuitem.accesskey "ป">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: วัตถุที่บล็อกได้">
-<!ENTITY context.image.label "Adblock รูปภาพ">
-<!ENTITY context.object.label "Adblock สิ่งของ">
-<!ENTITY context.frame.label "Adblock กรอบความ">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: เปิดใช้งานอีกครั้งในหน้านี้">
-<!ENTITY sidebar.title "รายการที่บล็อกได้ในหน้าล่าสุด">
-<!ENTITY settings.label "ปรับแต่ง">
-<!ENTITY settings.accesskey "ป">
-<!ENTITY opensidebar.label "เปิดรายการที่บล็อกได้">
-<!ENTITY opensidebar.accesskey "ไ">
-<!ENTITY closesidebar.label "ปิดรายการที่บล็อกได้">
-<!ENTITY closesidebar.accesskey "ไ">
-<!ENTITY whitelist.site.label "ปิดการใช้งาน --">
-<!ENTITY whitelist.page.label "ปิดการใช้งานเฉพาะหน้านี้">
-<!ENTITY objecttab.title "บล็อก">
-<!ENTITY objecttab.tooltip "คลิกที่นี่เพื่อบล็อกวัตถุนี้ด้วย Adblock Plus">

=== removed file 'chrome/locale/th-TH/settings.dtd'
--- chrome/locale/th-TH/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/th-TH/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "ปรับแต่ง Adblock Plus">
-<!ENTITY filters.label "ตัวกรอง">
-<!ENTITY filters.accesskey "ต">
-<!ENTITY add.label "เพิ่มตัวกรอง">
-<!ENTITY add.accesskey "พ">
-<!ENTITY addsubscription.label "เพิ่มนามข้างท้ายตัวกรอง">
-<!ENTITY addsubscription.accesskey "น">
-<!ENTITY synchsubscriptions.label "อัปเดตนามข้างท้ายทั้งหมด">
-<!ENTITY synchsubscriptions.accesskey "ด">
-<!ENTITY import.label "นำเข้าตัวกรอง">
-<!ENTITY import.accesskey "ข">
-<!ENTITY export.label "ส่งออกตัวกรอง">
-<!ENTITY export.accesskey "อ">
-<!ENTITY clearall.label "ลบตัวกรองทั้งหมด">
-<!ENTITY clearall.accesskey "ล">
-<!ENTITY resethitcounts.label "เริ่มสถิติใหม่">
-<!ENTITY resethitcounts.accesskey "ร">
-<!ENTITY edit.label "แก้ไข">
-<!ENTITY edit.accesskey "ก">
-<!ENTITY cut.label "ตัด">
-<!ENTITY cut.accesskey "ต">
-<!ENTITY copy.label "คัดลอก">
-<!ENTITY copy.accesskey "ค">
-<!ENTITY paste.label "วาง">
-<!ENTITY paste.accesskey "ว">
-<!ENTITY remove.label "ลบ">
-<!ENTITY remove.accesskey "บ">
-<!ENTITY menu.find.label "ค้นหา">
-<!ENTITY menu.find.accesskey "ห">
-<!ENTITY menu.findagain.label "ค้นหาอีกครั้ง">
-<!ENTITY menu.findagain.accesskey "ง">
-<!ENTITY view.label "มุมมอง">
-<!ENTITY view.accesskey "ม">
-<!ENTITY sort.label "จัดลำดับ">
-<!ENTITY sort.accesskey "จ">
-<!ENTITY sort.none.label "ไม่จัดลำดับ">
-<!ENTITY sort.none.accesskey "บ">
-<!ENTITY sort.ascending.label "จัดลำดับ A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "จัดลำดับ Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "ตัวเลือก">
-<!ENTITY options.accesskey "เ">
-<!ENTITY enable.label "เปิดการใช้งาน Adblock Plus">
-<!ENTITY enable.accesskey "ก">
-<!ENTITY showintoolbar.label "แสดงในแถบเครื่องมือ">
-<!ENTITY showintoolbar.accesskey "ค">
-<!ENTITY showinstatusbar.label "แสดงในแถบสถานะ">
-<!ENTITY showinstatusbar.accesskey "ส">
-<!ENTITY objecttabs.label "แสดงแท็บบนแฟลชและจาวา">
-<!ENTITY objecttabs.accesskey "ฟ">
-<!ENTITY collapse.label "ย่อเก็บส่วนย่อยที่ถูกบล็อก">
-<!ENTITY collapse.accesskey "ย">
-<!ENTITY help.label "ช่วยเหลือ">
-<!ENTITY help.accesskey "ห">
-<!ENTITY gettingStarted.label "เริ่มต้นใช้งาน">
-<!ENTITY gettingStarted.accesskey "ร">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "คำถามพบบ่อย">
-<!ENTITY faq.accesskey "พ">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "การเขียนตัวกรอง Adblock Plus">
-<!ENTITY filterdoc.accesskey "ข">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "เกี่ยวกับ Adblock Plus">
-<!ENTITY about.accesskey "ก">
-<!ENTITY description "ตัวกรองต่อไปนี้ระบุว่าที่อยู่ใดควรจะถูกบล็อกและที่อยู่ใดควรให้ผ่าน:">
-<!ENTITY filter.column "กฎตัวกรอง">
-<!ENTITY filter.accesskey "ต">
-<!ENTITY slow.column "ทำให้ตัวกรองช้าลง">
-<!ENTITY slow.accesskey "ง">
-<!ENTITY enabled.column "เปิดการใช้งาน">
-<!ENTITY enabled.accesskey "ป">
-<!ENTITY hitcount.column "นับ">
-<!ENTITY hitcount.accesskey "น">
-<!ENTITY lasthit.column "กดล่าสุด">
-<!ENTITY lasthit.accesskey "ล">
-<!ENTITY context.edit.label "แก้ไขตัวกรอง">
-<!ENTITY context.resethitcount.label "เริ่มนับสถิติสำหรับตัวกรองใหม่">
-<!ENTITY context.synchsubscription.label "อัปเดตนามข้างท้าย">
-<!ENTITY context.editsubscription.label "แก้ไขนามข้างท้าย">
-<!ENTITY context.moveup.label "เลื่อนขึ้น">
-<!ENTITY context.movedown.label "เลื่อนลง">
-<!ENTITY context.movegroupup.label "เลื่อนกลุ่มขึ้น">
-<!ENTITY context.movegroupdown.label "เลื่อนกลุ่มลง">
-<!ENTITY context.enable.label "เปิดใช้งาน">
-<!ENTITY context.disable.label "ปิดใช้งาน">
-<!ENTITY apply.label "ใช้งาน">
-<!ENTITY apply.accesskey "ช">

=== removed file 'chrome/locale/th-TH/sidebar.dtd'
--- chrome/locale/th-TH/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/th-TH/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: รายการที่บล็อกได้ (ถูกแยกออก)">
-<!ENTITY detach.label "แยกออก">
-<!ENTITY reattach.label "แนบกลับ">
-<!ENTITY search.label "ค้นหา:">
-<!ENTITY search.accesskey "ค">
-<!ENTITY type.label "ชนิด">
-<!ENTITY address.label "ที่อยู่">
-<!ENTITY filter.label "ตัวกรอง">
-<!ENTITY state.label "สถานะ">
-<!ENTITY size.label "ขนาด">
-<!ENTITY docDomain.label "แหล่งที่มาเอกสาร">
-<!ENTITY noitems.label "ไม่มีรายการที่บล็อคได้">
-<!ENTITY whitelisted.label "หน้าที่ถูกขึ้นบัญชีขาว">
-<!ENTITY tooltip.address.label "ที่อยู่:">
-<!ENTITY tooltip.type.label "ชนิด:">
-<!ENTITY tooltip.type.blocked "(ถูกบล็อค)">
-<!ENTITY tooltip.type.whitelisted "(ขึ้นบัญชีขาว)">
-<!ENTITY tooltip.size.label "ขนาด:">
-<!ENTITY tooltip.docDomain.label "แหล่งที่มาเอกสาร:">
-<!ENTITY tooltip.filter.label "เป็นผลมาจากตัวกรอง:">
-<!ENTITY tooltip.filterSource.label "ตัวกรองแหล่งที่มา:">
-<!ENTITY context.block.label "บล็อครายการนี้">
-<!ENTITY context.editfilter.label "แก้ไขตัวกรองที่มีผล">
-<!ENTITY context.whitelist.label "เพิ่มข้อยกเว้นสำหรับรายการ">
-<!ENTITY context.disablefilter.label "ปิดตัวกรอง --">
-<!ENTITY context.enablefilter.label "เปิดตัวกรองอีกครั้ง --">
-<!ENTITY context.disablefilteronsite.label "ปิดตัวกรองนี้บน --">
-<!ENTITY context.open.label "เปิดในแท็บใหม่">
-<!ENTITY context.flash.label "ขอบของรายการแฟลช">
-<!ENTITY context.copy.label "คัดลอกที่อยู่รายการ">
-<!ENTITY context.copyFilter.label "คัดลอกตัวกรอง">
-<!ENTITY context.selectAll.label "เลือกทั้งหมด">

=== removed file 'chrome/locale/th-TH/subscription.dtd'
--- chrome/locale/th-TH/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/th-TH/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "แก้ไขการเป็นสมาชิกบอกรับรายการตัวกรอง">
-<!ENTITY dialog.newtitle "เพิ่มการบอกรับรายการตัวกรอง">
-<!ENTITY new.description "กรุณาใส่ที่อยู่เว็บหรือแฟ้มที่มีรายชื่อตัวกรอง Adblock Plus">
-<!ENTITY edit.description "รายการตัวกรองสำหรับการบอกรับนี้จะถูกดาวน์โหลดจากตำแหน่งที่ให้มา">
-<!ENTITY external.description "นี่คือการบอกรับตัวกรองภายนอก รายการตัวกรองจะถูกปรับปรุงให้ทันสมัยโดยส่วนขยายที่สร้างการบอกรับนี้">
-<!ENTITY autodownload.description "ถ้าคุณเลือก &quot;ปรับปรุงอัตโนมัติ&quot; จะมีการตรวจสอบที่อยู่นี้เพื่อปรับปรุงให้ทันสมัยทุกวัน แม้ตัวเลือกนี้ถูกปิดการใช้งานคุณก็ยังคงสามารถเรียกการปรับปรุงด้วยตัวเองจากเมนูบริบทของการบอกรับ">
-<!ENTITY location.label "ที่อยู่รายชื่อตัวกรอง:">
-<!ENTITY location.accesskey "ร">
-<!ENTITY title.label "ชื่อ:">
-<!ENTITY title.accesskey "ช">
-<!ENTITY autodownload.label "ปรับปรุงอัตโนมัติ">
-<!ENTITY autodownload.accesskey "อ">
-<!ENTITY enabled.label "เปิดใช้งานตัวกรอง">
-<!ENTITY enabled.accesskey "ป">

=== removed file 'chrome/locale/th-TH/tip_subscriptions.dtd'
--- chrome/locale/th-TH/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/th-TH/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "ยินดีต้อนรับสู่ Adblock Plus">
-<!ENTITY description.par1 "ขอบคุณที่ติดตั้ง Adblock Plus ส่วนเสริมนี้สามารถกำจัด 99&#37; จากโฆษณาบนเว็บ อย่างไรก็ตาม ตัวกรองโฆษณาตาดำๆต้องการให้คุณตั้งค่าที่เหมาะสมเสียก่อน คุณจะทำเองก็ได้หรือใส่นามข้างท้ายในรายชื่อตัวกรอง ยังคงเป็นไปได้ที่จะเพิ่มตัวกรองของคุณหรือปิดการใช้หรือลบนามข้างท้ายเมื่อจำเป็น">
-<!ENTITY description.par2 "คุณสามารถเลือกนามข้างท้ายจากรายชื่อที่แนะนำต่อไปนี้(อันอื่นสามารถเพิ่มในการปรับแต่ง Adblock Plus ภายหลังถ้าไม่จำเป็น)">
-<!ENTITY note "บันทึก: รา่ยชื่อตัวกรองได้ผลดีที่สุดเมื่อใช้งานเว็บไซต์ภายในเขต รายชื่อตัวกรองนี้สร้างเพื่อ:">
-<!ENTITY adblock.warning "Adblock Plus พบว่าคุณติดตั้ง Adblock หรือ Adblock Plus เวอร์ชันเก่า การใช้งานทั้ง Adblock และ Adblock Plus พร้อมกันอาจเกิดปัญหาได้ คุณควรยอกเลิกการติดตั้ง Adblock">
-<!ENTITY adblock.uninstall "ยอกเลิกการติดตั้ง Adblock">
-<!ENTITY filterset.g.warning "ดูเหมือนว่าคุณจะใช้ Filterset.G ตัวกรองนี้ไม่ได้ปรับปรุงมานานและอาจเกิดปัญหาได้ คุณควรยกเลิกการติดตั้ง Filterset.G">
-<!ENTITY filterset.g.moreinfo "ข้อมูลเพิ่มเติม">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "ยกเลิกการติดตั้ง Filterset.G">
-<!ENTITY homepage.label "โฮมเพจ">
-<!ENTITY subscribe.label "นามข้างท้าย">
-<!ENTITY subscribe.accesskey "น">
-<!ENTITY other.label "เพิ่มนามข้างท้าย">
-<!ENTITY other.accesskey "พ">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "ดูนามข้างท้ายทั้งหมด">

=== added file 'chrome/locale/th/about.dtd'
--- chrome/locale/th/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/th/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "เกี่ยวกับ Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "รุ่น">
+<!ENTITY description "Adblock Plus อนุญาตให้คุณเลือกเองว่าสิ่งที่คุณไม่ต้องการจะเห็นบนเว็บ คุณไม่จำเป็นต้องดาวน์โหลดโฆษณาและป้ายประกาศอีกต่อไป ถ้าคุณไม่ต้องการพวกมัน - บอก Adblock Plus!">
+<!ENTITY homepage.label "โฮมเพจ Adblock Plus:">
+<!ENTITY homepage.url "http://adblockplus.org/en/">
+<!ENTITY author.label "ผู้พัฒนา:">
+<!ENTITY contributors.label "ผู้ร่วมสมทบงาน:">
+<!ENTITY developers.label "ผู้พัฒนา:">
+<!ENTITY designers.label "ผู้ออกแบบกราฟิก:">
+<!ENTITY subscriptionAuthors.label "เจ้าของนามข้างท้ายตัวกรอง:">
+<!ENTITY translators.label "ผู้แปล:">

=== added file 'chrome/locale/th/composer.dtd'
--- chrome/locale/th/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/th/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "เพิ่มกฎตัวกรอง Adblock Plus">
+<!ENTITY accept.label "เพิ่มตัวกรอง">
+<!ENTITY advanced.label "มุมมองละเอียด">
+<!ENTITY basic.label "มุมมองพื้นฐาน">
+<!ENTITY disabled.warning "Adblock Plus ถูกปิดใช้งานอยู่ คุณยังคงสามารถเพิ่มตัวกรองได้แต่จะไม่ถูกใช้งานจนกว่าคุณ[link]เปิดใช้งาน Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "กลุ่มตัวกรอง &quot;?1?&quot; ว่าตัวกรองที่เพิ่มกำลังถูกปิดการใช้งาน คุณยังคงสามารถเพิ่มตัวกรองได้แต่จะไม่ใช้งานจนกว่า[link]เปิดใช้งานกลุ่มตัวกรอง[/link].">
+<!ENTITY filter.label "ตัวกรองใหม่:">
+<!ENTITY filter.accesskey "ต">
+<!ENTITY preferences.label "แสดงตัวกรองที่มีอยู่...">
+<!ENTITY preferences.accesskey "ส">
+<!ENTITY type.filter.label "ตัวกรองบล็อก">
+<!ENTITY type.filter.accesskey "บ">
+<!ENTITY type.whitelist.label "กฎข้อยกเว้น">
+<!ENTITY type.whitelist.accesskey "ก">
+<!ENTITY pattern.label "ดูรูปแบบ">
+<!ENTITY pattern.explanation "รูปแบบสามารถเป็นส่วนใดส่วนหนึ่งของที่อยู่ สัญลักษณ์ * เป็นอักขระใดๆ ตัวกรองจะถูกใช้งานกับที่อยู่ที่เหมาะสมกับตัวกรองเท่านั้น">
+<!ENTITY regexp.warning "รูปแบบที่คุณป้อนเข้าจะถูกแปลเป็นการแสดงออกทั่วไป การแสดงออกทั่วไปมากๆจะทำให้การเข้าเว็บช้าลง ถ้าคุณไม่ตั้งใจจะใช้การแสดงออกทั่วไปให้ใส่สัญลักษณ์ * ที่ท้ายรูปแบบ">
+<!ENTITY shortpattern.warning "รูปแบบที่คุณป้อนเข้าสั้นเกินกว่าจะใช้ให้เหมาะสม รูปแบบมากๆจะทำให้เข้าเว็บช้า แนะนำให้ใช้รูปแบบยาวๆสำหรับตัวกรองนี้">
+<!ENTITY custom.pattern.label "ปรับเอง:">
+<!ENTITY custom.pattern.accesskey "ป">
+<!ENTITY anchors.label "รับเฉพาะรูปแบบ:">
+<!ENTITY anchor.start.label "ที่หน้าๆของที่อยู่">
+<!ENTITY anchor.start.accesskey "น">
+<!ENTITY anchor.start.flexible.label "ส่วนต้นของชื่อโดเมน">
+<!ENTITY anchor.start.flexible.accesskey "น">
+<!ENTITY anchor.end.label "ที่ท้ายๆของที่อยู่">
+<!ENTITY anchor.end.accesskey "ท">
+<!ENTITY options.label "ตัวเลือก">
+<!ENTITY domainRestriction.label "จำกัดโดเมน:">
+<!ENTITY domainRestriction.accesskey "ด">
+<!ENTITY domainRestriction.help "ระบุโดเมนหนึ่งหรือหลายแห่งให้คั่นด้วยสัญลักษณ์ &quot;|&quot; ตัวกรองจะใช้งานบนโดเมนเหล่านี้เท่านั้น ถ้าไม่ต้องการใช้โดเมนใดให้ใส่สัญลักษณ์ &quot;~&quot; หน้าชื่อโดเมน">
+<!ENTITY firstParty.label "First-party เท่านั้น">
+<!ENTITY firstParty.accesskey "r">
+<!ENTITY thirdParty.label "Third-party เท่านั้น">
+<!ENTITY thirdParty.accesskey "T">
+<!ENTITY matchCase.label "จับคู่">
+<!ENTITY matchCase.accesskey "จ">
+<!ENTITY types.label "ใช้งานกับชนิด:">
+<!ENTITY selectAllTypes.label "เลือกทั้งหมด">
+<!ENTITY unselectAllTypes.label "ไม่เลือก">
+<!ENTITY collapse.label "การบล็อกที่ล้มเหลว:">
+<!ENTITY collapse.accesskey "ม">
+<!ENTITY collapse.default.yes.label "ใช้ค่าเริ่มต้น(ใช่)">
+<!ENTITY collapse.default.no.label "ใช้ค่าเริ่มต้น(ไม่ใช่)">
+<!ENTITY collapse.yes.label "ใช่">
+<!ENTITY collapse.no.label "ไม่ใช่">

=== added file 'chrome/locale/th/global.properties'
--- chrome/locale/th/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/th/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=คลิกเพื่อนำไปที่เมนูบริบท คลิกเมาส์กลางเพื่อเปิดหรือปิดใช้งาน
+action1_tooltip=คลิกเพื่อเปิดหรือปิดสิ่งของ คลิกเมาส์กลางเพื่อเปิดหรือปิดใช้งาน
+action2_tooltip=คลิกเพื่อเปิดการปรับแต่ง คลิกเมาส์กลางเพื่อเปิดหรือปิดใช้งาน
+action3_tooltip=คลิกเพื่อเปิดหรือปิดใช้งาน Adblock Plus
+disabled_tooltip=Adblock Plus เปิดอยู่
+active_tooltip=Adblock Plus เปิดใช้งานอยู่ นามข้างท้ายตัวกรอง ?1? อย่าง และตัวกรองทำเอง ?2? ตัวเปิดใช้งานอยู่
+whitelisted_tooltip=Adblock Plus เปิดอยู่แต่ไม่ใช้กับหน้านี้
+blocked_count_tooltip=?1? จาก ?2?
+blocked_count_addendum=(และยังมีบัญชีขาว ?1? อย่าง ซ่อนอยู่ ?2? อย่าง)
+no_blocking_suggestions=ไม่มีรายการที่บล็อกได้ในหน้าล่าสุด
+whitelisted_page=Adblock Plus ถูกปิดการใช้งานในหน้าล่าสุด
+whitelist_description=ข้อยกเว้น
+filterlist_description=ตัวกรองนักโฆษณา
+invalid_description=ตัวกรองไม่ถูกต้อง
+elemhide_description=กฎการซ่อนส่วนย่อย
+subscription_description=นามข้างท้ายตัวกรอง:
+subscription_wrong_version=ตัวกรองบางตัวในนามข้างท้ายนี้ต้องการ Adblock Plus ?1? เพื่อให้ทำงานได้ดี
+subscription_source=ต้นฉบับ:
+subscription_status=สถานะ:
+subscription_status_autodownload=อัปเดตอัตโนมัติแล้ว
+subscription_status_manualdownload=อัปเดตด้วยตัวเองแล้ว
+subscription_status_externaldownload=อัปเดตจากภายนอกแล้ว (ส่วนขยายอื่น)
+subscription_status_lastdownload=ดาวน์โหลดล่าสุด:
+subscription_status_lastdownload_inprogress=กำลังดาวน์โหลด...
+subscription_status_lastdownload_unknown=ไม่มี
+remove_subscription_warning=คุณแน่ใจหรือว่าต้องการลบนามข้างท้ายนี้
+import_filters_wrong_version=คำเตือน: ตัวกรองบางตัวในรายชื่อนี้ต้องการ Adblock Plus ?1? เพื่อใช้งานอย่างเหมาะสม คุณควรอัปเกรด Adblock Plus เป็นรุ่นล่าสุดก่อนนำเข้ารายชื่อนี้
+import_filters_warning=คุณต้องการแทนที่ตัวกรองล่าสุดหรือผนวกตัวกรองใหม่ที่ข้างล่างสุดของรายชื่อ
+import_filters_title=นำเข้าตัวกรอง
+export_filters_title=ส่งออกตัวกรอง
+invalid_filters_file=ไม่มีแฟ้มตัวกรอง Adblock Plus ที่ถูกต้อง
+filters_write_error=มีข้อผิดพลาดเมื่อกำลังเขียนตัวกรองไปยังแฟ้ม ขอให้แน่ใจว่าแฟ้มไม่ถูกป้องกันการเขียนหรือมีโปรแกรมอื่นใช้อยู่
+clearall_warning=คุณแน่ใจหรือว่าต้องการลบตัวกรองทั้งหมดจากรายชื่อ
+resethitcounts_warning=คุณแน่ใจหรือว่าต้องการเริ่มการนับใหม่สำหรับตัวกรองทั้งหมดกลับไปยังศูนย์ คำสั่งนี้ไม่สามารถย้อนกลับ!
+resethitcounts_selected_warning=คุณแน่ใจหรือว่าต้องการเริ่มการนับใหม่สำหรับตัวกรองที่เลือกกลับไปยังศูนย์ คำสั่งนี้ไม่สามารถย้อนกลับ!
+filter_regexp_tooltip=ตัวกรองนี้ก็เป็นการแสดงออกทั่วไปหรือสั้นเกินกว่าจะใช้ให้เหมาะสม ถ้ามีตัวกรองประเภทนี้มากเกินไปจะทำให้การเข้าเว็บช้าได้
+filter_elemhide_duplicate_id=มีเฉพาะรหัสประจำตัววัตถุเดียวเท่านั้นที่ซ่อนที่สามารถระบุได้
+filter_elemhide_nocriteria=ไม่มีเกณฑ์ที่ระบุที่จำวัตถุที่จะซ่อน
+subscription_notAdded_warning=คุณไม่ได้ใส่นามข้างท้ายตัวกรอง ถ้าไม่มีนามข้างท้ายตัวกรองคุณก็ต้องเพิ่มตัวกรอง Adblock Plus เอง
+subscription_notAdded_warning_addendum=ต้องการทำต่อหรือไม่
+subscription_invalid_location=ตำแหน่งรายชื่อตัวกรองไม่ใช่ทั้งยูอาร์แอลที่ถูกต้องและชื่อแฟ้มที่ถูกต้อง
+synchronize_invalid_url=ล้มเหลว ไม่มีที่อยู่ที่ถูกต้อง
+synchronize_connection_error=ล้มเหลว การดาวน์โหลดล้มเหลว
+synchronize_invalid_data=ล้มเหลว ไม่มีรายชื่อตัวกรองที่ถูกต้อง
+synchronize_checksum_mismatch=ล้มเหลว checksum จับผิดคู่
+synchronize_ok=สำเร็จ
+overwrite=บันทึกทับ
+append=ผนวก
+new_filter_group_title=ตัวกรองใหม่
+type_label_other=อื่นๆ
+type_label_script=สคริปต์
+type_label_image=รูปภาพ
+type_label_stylesheet=รูปแบบเอกสาร
+type_label_object=วัตถุ
+type_label_subdocument=กรอบความ
+type_label_document=เอกสาร
+type_label_background=พื้นหลัง
+type_label_elemhide=ซ่อน
+type_label_xbl=การยึดเหนี่ยวเอกซ์บีแอล
+type_label_ping=ปิงลิงก์
+type_label_xmlhttprequest=คำร้องขอเอกซ์บีแอล
+type_label_object_subrequest=subrequest วัตถุ
+type_label_dtd=ดีทีดี
+type_label_media=เสียง/ภาพ
+type_label_font=แบบอักษร
+fennec_status_enabled=Adblock Plus เปิดใช้งานอยู่
+fennec_status_disabled=Adblock Plus ปิดการใช้งานอยู่
+fennec_status_enabled_site=Adblock Plus เปิดใช้งานอยู่ที่ ?1?
+fennec_status_disabled_site=Adblock Plus ปิดการใช้งานอยู่ที่ ?1?

=== added file 'chrome/locale/th/meta.properties'
--- chrome/locale/th/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/th/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,3 @@
+translator=Ken,
+name=Adblock Plus
+description=ลาก่อนพวกโฆษณา!

=== added file 'chrome/locale/th/overlay.dtd'
--- chrome/locale/th/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/th/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "สถานะ:">
+<!ENTITY blocked.tooltip "สิ่งที่บล็อกในหน้านี้:">
+<!ENTITY filters.tooltip "ตัวกรองที่ใช้งานมากที่สุด:">
+<!ENTITY menuitem.label "ปรับแต่ง Adblock Plus">
+<!ENTITY menuitem.accesskey "ป">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: วัตถุที่บล็อกได้">
+<!ENTITY context.image.label "Adblock รูปภาพ">
+<!ENTITY context.object.label "Adblock สิ่งของ">
+<!ENTITY context.frame.label "Adblock กรอบความ">
+<!ENTITY context.media.label "Adblock Plus: บล็อกเสียง/วีดิทัศน์">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: เปิดใช้งานอีกครั้งในหน้านี้">
+<!ENTITY sidebar.title "รายการที่บล็อกได้ในหน้าล่าสุด">
+<!ENTITY settings.label "ปรับแต่ง">
+<!ENTITY settings.accesskey "ป">
+<!ENTITY opensidebar.label "เปิดรายการที่บล็อกได้">
+<!ENTITY opensidebar.accesskey "ไ">
+<!ENTITY closesidebar.label "ปิดรายการที่บล็อกได้">
+<!ENTITY closesidebar.accesskey "ไ">
+<!ENTITY whitelist.site.label "ปิดการใช้งาน ?1?">
+<!ENTITY whitelist.page.label "ปิดการใช้งานเฉพาะหน้านี้">
+<!ENTITY objecttab.title "บล็อก">
+<!ENTITY objecttab.tooltip "คลิกที่นี่เพื่อบล็อกวัตถุนี้ด้วย Adblock Plus">

=== added file 'chrome/locale/th/settings.dtd'
--- chrome/locale/th/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/th/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "ปรับแต่ง Adblock Plus">
+<!ENTITY filters.label "ตัวกรอง">
+<!ENTITY filters.accesskey "ต">
+<!ENTITY add.label "เพิ่มตัวกรอง">
+<!ENTITY add.accesskey "พ">
+<!ENTITY addsubscription.label "เพิ่มนามข้างท้ายตัวกรอง">
+<!ENTITY addsubscription.accesskey "น">
+<!ENTITY synchsubscriptions.label "อัปเดตนามข้างท้ายทั้งหมด">
+<!ENTITY synchsubscriptions.accesskey "ด">
+<!ENTITY import.label "นำเข้าตัวกรอง">
+<!ENTITY import.accesskey "ข">
+<!ENTITY export.label "ส่งออกตัวกรอง">
+<!ENTITY export.accesskey "อ">
+<!ENTITY clearall.label "ลบตัวกรองทั้งหมด">
+<!ENTITY clearall.accesskey "ล">
+<!ENTITY resethitcounts.label "เริ่มสถิติใหม่">
+<!ENTITY resethitcounts.accesskey "ร">
+<!ENTITY edit.label "แก้ไข">
+<!ENTITY edit.accesskey "ก">
+<!ENTITY cut.label "ตัด">
+<!ENTITY cut.accesskey "ต">
+<!ENTITY copy.label "คัดลอก">
+<!ENTITY copy.accesskey "ค">
+<!ENTITY paste.label "วาง">
+<!ENTITY paste.accesskey "ว">
+<!ENTITY remove.label "ลบ">
+<!ENTITY remove.accesskey "บ">
+<!ENTITY menu.find.label "ค้นหา">
+<!ENTITY menu.find.accesskey "ห">
+<!ENTITY menu.findagain.label "ค้นหาอีกครั้ง">
+<!ENTITY menu.findagain.accesskey "ง">
+<!ENTITY view.label "มุมมอง">
+<!ENTITY view.accesskey "ม">
+<!ENTITY sort.label "จัดลำดับ">
+<!ENTITY sort.accesskey "จ">
+<!ENTITY sort.none.label "ไม่จัดลำดับ">
+<!ENTITY sort.none.accesskey "บ">
+<!ENTITY sort.ascending.label "จัดลำดับ A &gt; Z">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "จัดลำดับ Z &gt; A">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "ตัวเลือก">
+<!ENTITY options.accesskey "เ">
+<!ENTITY enable.label "เปิดการใช้งาน Adblock Plus">
+<!ENTITY enable.accesskey "ก">
+<!ENTITY showintoolbar.label "แสดงในแถบเครื่องมือ">
+<!ENTITY showintoolbar.accesskey "ค">
+<!ENTITY showinstatusbar.label "แสดงในแถบสถานะ">
+<!ENTITY showinstatusbar.accesskey "ส">
+<!ENTITY objecttabs.label "แสดงแท็บบนแฟลชและจาวา">
+<!ENTITY objecttabs.accesskey "ฟ">
+<!ENTITY collapse.label "ย่อเก็บส่วนย่อยที่ถูกบล็อก">
+<!ENTITY collapse.accesskey "ย">
+<!ENTITY help.label "ช่วยเหลือ">
+<!ENTITY help.accesskey "ห">
+<!ENTITY gettingStarted.label "เริ่มต้นใช้งาน">
+<!ENTITY gettingStarted.accesskey "ร">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "คำถามพบบ่อย">
+<!ENTITY faq.accesskey "พ">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "การเขียนตัวกรอง Adblock Plus">
+<!ENTITY filterdoc.accesskey "ข">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "เกี่ยวกับ Adblock Plus">
+<!ENTITY about.accesskey "ก">
+<!ENTITY description "ตัวกรองต่อไปนี้ระบุว่าที่อยู่ใดควรจะถูกบล็อกและที่อยู่ใดควรให้ผ่าน:">
+<!ENTITY filter.column "กฎตัวกรอง">
+<!ENTITY filter.accesskey "ต">
+<!ENTITY slow.column "ทำให้ตัวกรองช้าลง">
+<!ENTITY slow.accesskey "ง">
+<!ENTITY enabled.column "เปิดการใช้งาน">
+<!ENTITY enabled.accesskey "ป">
+<!ENTITY hitcount.column "นับ">
+<!ENTITY hitcount.accesskey "น">
+<!ENTITY lasthit.column "กดล่าสุด">
+<!ENTITY lasthit.accesskey "ล">
+<!ENTITY context.edit.label "แก้ไขตัวกรอง">
+<!ENTITY context.resethitcount.label "เริ่มนับสถิติสำหรับตัวกรองใหม่">
+<!ENTITY context.synchsubscription.label "อัปเดตนามข้างท้าย">
+<!ENTITY context.editsubscription.label "แก้ไขนามข้างท้าย">
+<!ENTITY context.moveup.label "เลื่อนขึ้น">
+<!ENTITY context.movedown.label "เลื่อนลง">
+<!ENTITY context.movegroupup.label "เลื่อนกลุ่มขึ้น">
+<!ENTITY context.movegroupdown.label "เลื่อนกลุ่มลง">
+<!ENTITY context.enable.label "เปิดใช้งาน">
+<!ENTITY context.disable.label "ปิดใช้งาน">
+<!ENTITY apply.label "ใช้งาน">
+<!ENTITY apply.accesskey "ช">
+<!ENTITY fennec.subscription.label "คำอธิบายตัวกรอง">

=== added file 'chrome/locale/th/sidebar.dtd'
--- chrome/locale/th/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/th/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: รายการที่บล็อกได้ (ถูกแยกออก)">
+<!ENTITY detach.label "แยกออก">
+<!ENTITY reattach.label "แนบกลับ">
+<!ENTITY search.label "ค้นหา:">
+<!ENTITY search.accesskey "ค">
+<!ENTITY type.label "ชนิด">
+<!ENTITY address.label "ที่อยู่">
+<!ENTITY filter.label "ตัวกรอง">
+<!ENTITY state.label "สถานะ">
+<!ENTITY size.label "ขนาด">
+<!ENTITY docDomain.label "แหล่งที่มาเอกสาร">
+<!ENTITY noitems.label "ไม่มีรายการที่บล็อคได้">
+<!ENTITY whitelisted.label "หน้าที่ถูกขึ้นบัญชีขาว">
+<!ENTITY tooltip.address.label "ที่อยู่:">
+<!ENTITY tooltip.type.label "ชนิด:">
+<!ENTITY tooltip.type.blocked "(ถูกบล็อค)">
+<!ENTITY tooltip.type.whitelisted "(ขึ้นบัญชีขาว)">
+<!ENTITY tooltip.size.label "ขนาด:">
+<!ENTITY tooltip.docDomain.label "แหล่งที่มาเอกสาร:">
+<!ENTITY tooltip.filter.label "เป็นผลมาจากตัวกรอง:">
+<!ENTITY tooltip.filterSource.label "ตัวกรองแหล่งที่มา:">
+<!ENTITY context.block.label "บล็อครายการนี้">
+<!ENTITY context.editfilter.label "แก้ไขตัวกรองที่มีผล">
+<!ENTITY context.whitelist.label "เพิ่มข้อยกเว้นสำหรับรายการ">
+<!ENTITY context.disablefilter.label "ปิดตัวกรอง ?1?">
+<!ENTITY context.enablefilter.label "เปิดตัวกรอง ?1? อีกครั้ง">
+<!ENTITY context.disablefilteronsite.label "ปิดตัวกรองนี้บน ?1?">
+<!ENTITY context.open.label "เปิดในแท็บใหม่">
+<!ENTITY context.flash.label "ขอบของรายการแฟลช">
+<!ENTITY context.copy.label "คัดลอกที่อยู่รายการ">
+<!ENTITY context.copyFilter.label "คัดลอกตัวกรอง">
+<!ENTITY context.selectAll.label "เลือกทั้งหมด">

=== added file 'chrome/locale/th/subscriptionSelection.dtd'
--- chrome/locale/th/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/th/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "เพิ่มนามข้างท้ายตัวกรอง Adblock Plus">
+<!ENTITY dialog.title.edit "แก้ไขการเป็นสมาชิกบอกรับรายการตัวกรอง">
+<!ENTITY description.newInstall "Adblock Plus จะทำงานได้อย่างเต็มที่ถ้าคุณใส่นามข้างท้ายตัวกรอง มีผู้ใช้ Adblock Plus เชียนนามข้างท้ายตัวกรองแจกฟรี นามข้างท้ายที่เหมาะสมกับภาษาของคุณที่สุดได้เลือกไว้แล้ว">
+<!ENTITY adblock.warning "Adblock Plus พบว่าคุณติดตั้ง Adblock หรือ Adblock Plus เวอร์ชันเก่า การใช้งานทั้ง Adblock และ Adblock Plus พร้อมกันอาจเกิดปัญหาได้ คุณควรยอกเลิกการติดตั้ง Adblock">
+<!ENTITY adblock.uninstall "ยอกเลิกการติดตั้ง Adblock">
+<!ENTITY filterset.g.warning "ดูเหมือนว่าคุณจะใช้ Filterset.G ตัวกรองนี้ไม่ได้ปรับปรุงมานานและอาจเกิดปัญหาได้ คุณควรยกเลิกการติดตั้ง Filterset.G">
+<!ENTITY filterset.g.moreinfo "ข้อมูลเพิ่มเติม">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "ยกเลิกการติดตั้ง Filterset.G">
+<!ENTITY subscriptionSelector.label "กรุณาเลือกนามข้างท้ายตัวกรองจากรายชื่อ:">
+<!ENTITY viewList.label "ดูตัวกรอง">
+<!ENTITY visitHomepage.label "เยี่ยมชมโฮมเพจ">
+<!ENTITY addSubscription.label "เพิ่มนามข้างท้ายตัวกรอง">
+<!ENTITY saveSubscription.label "บันทึกนามข้างท้ายตัวกรอง">
+<!ENTITY other.label "เพิ่มนามข้างท้าย">
+<!ENTITY other.accesskey "พ">
+<!ENTITY list.download.failed "Adblock Plus ไม่สามารถกู้คืนรายการนามข้างท้ายได้">
+<!ENTITY list.download.retry "ลองอีกครั้ง">
+<!ENTITY list.download.website "ดูเว็บไซต์">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "กรุณายืนยันว่าคุณต้องการเพิ่มนามข้างท้ายตัวกรองนี้ คุณสามารถเปลี่ยนหัวเรื่องนามข้างท้ายหรือตำแหน่งก่อนเพิ่มเข้ามาได้">
+<!ENTITY edit.description "คุณสามารถเปลี่ยนหัวเรื่องนามข้างท้ายหรือตำแหน่งตามความจำเป็น">
+<!ENTITY external.description "นี่คือนามข้างท้ายตัวกรองภายนอก มันจะอัปเดตโดยใช้ส่วนเสริมที่สร้างนามข้างท้ายนี้">
+<!ENTITY title.label "ชื่อ:">
+<!ENTITY title.accesskey "ช">
+<!ENTITY location.label "ที่อยู่รายชื่อตัวกรอง:">
+<!ENTITY location.accesskey "ร">
+<!ENTITY autodownload.label "ปรับปรุงอัตโนมัติ">
+<!ENTITY autodownload.accesskey "อ">
+<!ENTITY supplementMessage "นามข้างท้ายตัวกรองนี้ตั้งใจไว้ใช้กับนามข้างท้ายตัวกรอง &quot;?1?&quot; ซึ่งคุณยังไม่ได้ใช้">
+<!ENTITY addMain.label "เพิ่มนามข้างท้ายตัวกรอง &quot;?1?&quot; ด้วย">
+<!ENTITY addMain.accesskey "ว">

=== added directory 'chrome/locale/tr'
=== removed directory 'chrome/locale/tr-TR'
=== removed file 'chrome/locale/tr-TR/about.dtd'
--- chrome/locale/tr-TR/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/tr-TR/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus Hakkında">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Sürüm">
-<!ENTITY description "Adblock Plus size internette neyi görmek istediğinize karar verme şansı sunar. Artık reklamları ve tanıtımları izlemek zorunda değilsiniz. Görmek istemediklerinizi Adblock Plus&apos;a bildirin yeter!">
-<!ENTITY homepage.label "Adblock Plus ana sayfası:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Yazar:">
-<!ENTITY contributors.label "Katkıda bulunanlar:">

=== removed file 'chrome/locale/tr-TR/composer.dtd'
--- chrome/locale/tr-TR/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/tr-TR/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus süzgeç kuralı ekle">
-<!ENTITY accept.label "Süzgeç ekle">
-<!ENTITY advanced.label "Gelişmiş görünüm">
-<!ENTITY basic.label "Temel görünüm">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus şu an devre dışı. Yine de süzgeç ekleyebilirsiniz, ancak bunlar">
-<!ENTITY disabled.warning.link "Adblock Plus etkinleştirilene kadar">
-<!ENTITY disabled.warning.afterLink "uygulanmayacaktır.">
-<!ENTITY groupDisabled.warning.beforeLink "Süzgecin eklenmesi gereken &quot;&#37;S&quot; süzgeç grubu şu an devre dışı. Süzgeci şu an ekleyebilirsiniz ancak">
-<!ENTITY groupDisabled.warning.link "süzgeç grubunu devreye soktuğunuzda">
-<!ENTITY groupDisabled.warning.afterLink "kullanılabilecektir.">
-<!ENTITY filter.label "Yeni süzgeç:">
-<!ENTITY filter.accesskey "y">
-<!ENTITY preferences.label "Mevcut süzgeçleri göster...">
-<!ENTITY preferences.accesskey "S">
-<!ENTITY type.filter.label "Engelleyen süzgeç">
-<!ENTITY type.filter.accesskey "l">
-<!ENTITY type.whitelist.label "Hariç tutma kuralı">
-<!ENTITY type.whitelist.accesskey "h">
-<!ENTITY pattern.label "Aranacak örnek">
-<!ENTITY pattern.explanation "Bu örnek adresin herhangi bir bölümü olabilir ve * işareti joker görevi yapar. Süzgeç sadece örneğe uyan adreslere uygulanacak.">
-<!ENTITY regexp.warning "Girdiğiniz örnek düzenli ifade olarak yorumlanacak. Çok fazla düzenli ifade, taramayı yavaşlatabilir. Gerçekten düzenli ifade kullanmak istediğinizden emin değilseniz örneğin sonuna * işareti koyun.">
-<!ENTITY shortpattern.warning "Girdiğiniz örnek en iyileştirmek için çok kısa ve bu tür örnekler taramayı yavaşlatabilir. Bu süzgeç için daha uzun bir satır seçmeniz tavsiye edilir.">
-<!ENTITY custom.pattern.label "Özel:">
-<!ENTITY custom.pattern.accesskey "z">
-<!ENTITY anchors.label "Örneği sadece burada kabul et:">
-<!ENTITY anchor.start.label "adresin başında">
-<!ENTITY anchor.start.accesskey "b">
-<!ENTITY anchor.start.flexible.label "alan adının başında">
-<!ENTITY anchor.start.flexible.accesskey "b">
-<!ENTITY anchor.end.label "adresin sonunda">
-<!ENTITY anchor.end.accesskey "o">
-<!ENTITY options.label "Seçenekler">
-<!ENTITY domainRestriction.label "Alan adına kısıtlama:">
-<!ENTITY domainRestriction.accesskey "d">
-<!ENTITY domainRestriction.help "Aralarına &quot;|&quot; simgesi koyarak bir ya da daha fazla alan adı belirtin. Böylece süzgeç sadece bu sitelerde uygulanacaktır. Alan adından önce &quot;~&quot; simgesi kullanılması, süzgecin o alan adında kullanılmaması gerektiği anlamına gelir.">
-<!ENTITY firstParty.label "Sadece birinci kişilerden">
-<!ENTITY firstParty.accesskey "i">
-<!ENTITY thirdParty.label "Sadece üçüncü kişilerden">
-<!ENTITY thirdParty.accesskey "c">
-<!ENTITY matchCase.label "Birebir eşleşme">
-<!ENTITY matchCase.accesskey "e">
-<!ENTITY types.label "Bu türlere uygula:">
-<!ENTITY selectAllTypes.label "Tümünü seç">
-<!ENTITY unselectAllTypes.label "Hiçbirini seçme">
-<!ENTITY collapse.label "Engellenenleri kapat:">
-<!ENTITY collapse.accesskey "p">
-<!ENTITY collapse.default.yes.label "Öntanımlı kullan (evet)">
-<!ENTITY collapse.default.no.label "Öntanımlı kullan (hayır)">
-<!ENTITY collapse.yes.label "Evet">
-<!ENTITY collapse.no.label "Hayır">

=== removed file 'chrome/locale/tr-TR/global.properties'
--- chrome/locale/tr-TR/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/tr-TR/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Reklamlar geçmişte kaldı!
-status_active_label=Adblock
-status_disabled_label=Devre dışı
-action0_tooltip=İçerik menüsünü açmak için tıklayın; etkinleştirmek ya da etkisizleştirmek için orta düğmeye tıklayın.
-action1_tooltip=Engellenebilir öğeleri açmak ya da kapatmak için tıklayın; etkinleştirmek ya da etkisizleştirmek için orta düğmeye tıklayın.
-action2_tooltip=Tercihler penceresini açmak için tıklayın; etkinleştirmek ya da etkisizleştirmek için orta düğmeye tıklayın.
-action3_tooltip=Adblock Plus'ı etkinleştirmek ya da etkisizleştirmek için orta düğmeye tıklayın.
-active_tooltip=Adblock Plus etkin.
-disabled_tooltip=Adblock Plus etkin değil.
-whitelisted_tooltip=Adblock Plus etkin, ancak bu sayfada devre dışı.
-blocked_count_tooltip=-- toplam --
-no_blocking_suggestions=Bakılan sayfada engellenebilecek bir öğe bulunmuyor
-whitelisted_page=Adblock Plus bakılan sayfa için devre dışı bırakıldı
-whitelist_description=Ayrıcalıklar
-filterlist_description=Reklam süzgeçleri
-invalid_description=Geçersiz süzgeçler
-elemhide_description=Öğe engelleme kuralları
-subscription_description=Süzgeç abonelikleri:
-subscription_wrong_version=Bazı süzgeçlerin düzgün çalışabilmesi için Adblock Plus gerekiyor!
-subscription_source=Kaynak:
-subscription_status=Durum:
-subscription_status_autodownload=Otomatik olarak güncellendi
-subscription_status_manualdownload=Elle güncellendi
-subscription_status_externaldownload=Dışarıdan güncellendi (başka bir eklenti tarafından)
-subscription_status_lastdownload=En son indiriş:
-subscription_status_lastdownload_inprogress=İndiriliyor...
-subscription_status_lastdownload_unknown=Yok
-remove_subscription_warning=Gerçekten abonelikten çıkmak istiyor musunuz?
-import_filters_wrong_version=Uyarı: Bazı süzgeçlerin düzgün çalışabilmesi için Adblock Plus gerekiyor. Bu listeyi içe aktarmadan önce büyük olasılıkla en güncel Adblock Plus sürümüne yükselmeniz gerekiyor.
-import_filters_warning=Geçerli süzgeçlerinizi değiştirmek mi yoksa yeni gelecekleri şu anki süzgeçlerin sonuna eklemek mi istersiniz?
-import_filters_title=Süzgeçleri içe aktar
-export_filters_title=Süzgeçleri dışa aktar
-invalid_filters_file=Bu geçerli bir Adblock Plus süzgeç dosyası değil.
-filters_write_error=Süzgeçler dosyaya yazılırken hatayla karşılaşıldı. Dosyanın yazmaya karşı korunup korunmadığından ve başka bir program tarafından kullanılıp kullanılmadığından emin olun.
-clearall_warning=Gerçekten listedeki bütün süzgeçleri kaldırmak istiyor musunuz?
-resethitcounts_warning=Bütün süzgeçlerin isabet istatistiklerini gerçekten sıfırlamak istiyor musunuz? Bu işlemden geri adım atılamaz!
-resethitcounts_selected_warning=Seçilen süzgeçlerin isabet istatistiklerini gerçekten sıfırlamak istiyor musunuz? Bu işlemden geri adım atılamaz!
-filter_regexp_tooltip=Süzgeç ya düzenli ifade ya da en iyileştirmek için çok kısa. Bu süzgeçlerden çok fazlası, taramanızı yavaşlatabilir.
-filter_elemhide_duplicate_id=Gizlenecek sadece bir bileşen kimliği belirtilebilir
-filter_elemhide_nocriteria=Gizlenecek bileşeni anlamak için hiçbir ölçüt belirtilmedi
-subscription_no_location=Lütfen süzgeçlerin indirileceği konumu girin.
-subscription_invalid_location=Dosya listesi konumu ne düzgün bir URL ne de düzgün bir ada sahip.
-subscription_location_exists=Bu süzgeç listesine zaten abonesiniz.
-synchronize_invalid_url=Olmadı. Bu geçerli bir adres değil.
-synchronize_connection_error=Olmadı. İndirmede sorun var.
-synchronize_invalid_data=Olmadı. Bu düzgün bir süzgeç listesi değil.
-synchronize_checksum_mismatch=Başarısız, checksum eşleşmedi
-synchronize_ok=Eşleme başarılı oldu.
-overwrite=Üstüne Yaz
-append=Ekle
-new_filter_group_title=Yeni süzgeç
-type_label_other=diğer
-type_label_script=betik
-type_label_image=resim
-type_label_stylesheet=biçem yaprağı
-type_label_object=nesne
-type_label_subdocument=çerçeve
-type_label_document=belge
-type_label_background=arka plan
-type_label_elemhide=gizli
-type_label_xbl=XBL bağlantısı
-type_label_ping=bağlantı yoklaması
-type_label_xmlhttprequest=XML isteği
-type_label_object_subrequest=nesne alt isteği
-type_label_dtd=DTD
-type_label_media=ses/görüntü
-type_label_font=yazıtipi

=== removed file 'chrome/locale/tr-TR/overlay.dtd'
--- chrome/locale/tr-TR/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/tr-TR/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Durum:">
-<!ENTITY blocked.tooltip "Bu sayfada engellenen öğeler:">
-<!ENTITY filters.tooltip "En etkin süzgeçler:">
-<!ENTITY menuitem.label "Adblock Plus">
-<!ENTITY menuitem.accesskey "A">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Engellenebilir öğeler">
-<!ENTITY context.image.label "Resmi engelle">
-<!ENTITY context.object.label "Nesneyi engelle">
-<!ENTITY context.frame.label "Çerçeveyi engelle">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Bu sayfada devreye sok">
-<!ENTITY sidebar.title "Bu sayfadaki engellenebilecek öğeler">
-<!ENTITY settings.label "Tercihler">
-<!ENTITY settings.accesskey "T">
-<!ENTITY opensidebar.label "Engellenebilecek öğeleri göster">
-<!ENTITY opensidebar.accesskey "E">
-<!ENTITY closesidebar.label "Engellenebilecek öğeleri gizle">
-<!ENTITY closesidebar.accesskey "E">
-<!ENTITY whitelist.site.label "Bu sitedeyken devre dışı kal">
-<!ENTITY whitelist.page.label "Bu sayfada devre dışı kal">
-<!ENTITY objecttab.title "Engelle">
-<!ENTITY objecttab.tooltip "Bu nesneyi Adblock Plus ile engellemek için buraya tıklayın.">

=== removed file 'chrome/locale/tr-TR/settings.dtd'
--- chrome/locale/tr-TR/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/tr-TR/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus Tercihleri">
-<!ENTITY filters.label "Süzgeçler">
-<!ENTITY filters.accesskey "G">
-<!ENTITY add.label "Süzgeç ekle">
-<!ENTITY add.accesskey "K">
-<!ENTITY addsubscription.label "Süzgeç aboneliği ekle">
-<!ENTITY addsubscription.accesskey "E">
-<!ENTITY synchsubscriptions.label "Tüm abonelikleri güncelle">
-<!ENTITY synchsubscriptions.accesskey "C">
-<!ENTITY import.label "Süzgeçleri içe aktar">
-<!ENTITY import.accesskey "Z">
-<!ENTITY export.label "Süzgeçleri dışa aktar">
-<!ENTITY export.accesskey "D">
-<!ENTITY clearall.label "Tüm süzgeçleri kaldır">
-<!ENTITY clearall.accesskey "L">
-<!ENTITY resethitcounts.label "İstatistikleri sıfırla">
-<!ENTITY resethitcounts.accesskey "R">
-<!ENTITY edit.label "Düzen">
-<!ENTITY edit.accesskey "z">
-<!ENTITY cut.label "Kes">
-<!ENTITY cut.accesskey "e">
-<!ENTITY copy.label "Kopyala">
-<!ENTITY copy.accesskey "K">
-<!ENTITY paste.label "Yapıştır">
-<!ENTITY paste.accesskey "Y">
-<!ENTITY remove.label "Sil">
-<!ENTITY remove.accesskey "S">
-<!ENTITY menu.find.label "Bul">
-<!ENTITY menu.find.accesskey "B">
-<!ENTITY menu.findagain.label "Sonrakini bul">
-<!ENTITY menu.findagain.accesskey "A">
-<!ENTITY view.label "Görünüm">
-<!ENTITY view.accesskey "r">
-<!ENTITY sort.label "Sırala">
-<!ENTITY sort.accesskey "S">
-<!ENTITY sort.none.label "Sıralanmamış">
-<!ENTITY sort.none.accesskey "m">
-<!ENTITY sort.ascending.label "A&apos;da Z&apos;ye sıralama">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Z&apos;den A&apos;ya sıralama">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Seçenekler">
-<!ENTITY options.accesskey "S">
-<!ENTITY enable.label "Adblock Plus&apos;ı etkinleştir">
-<!ENTITY enable.accesskey "A">
-<!ENTITY showintoolbar.label "Araç çubuğunda göster">
-<!ENTITY showintoolbar.accesskey "R">
-<!ENTITY showinstatusbar.label "Durum çubuğunda göster">
-<!ENTITY showinstatusbar.accesskey "D">
-<!ENTITY objecttabs.label "Flash ve Java&apos;yı kulakçıklarla belirt">
-<!ENTITY objecttabs.accesskey "J">
-<!ENTITY collapse.label "Öğeleri kapat">
-<!ENTITY collapse.accesskey "T">
-<!ENTITY help.label "Yardım">
-<!ENTITY help.accesskey "A">
-<!ENTITY gettingStarted.label "İlk adım">
-<!ENTITY gettingStarted.accesskey "k">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Sıkça sorulan sorular">
-<!ENTITY faq.accesskey "S">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Adblock Plus süzgeç yazımı">
-<!ENTITY filterdoc.accesskey "z">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Adblock Plus hakkında">
-<!ENTITY about.accesskey "O">
-<!ENTITY description "Engellemek istediğiniz adresleri yazın. Öneriler için açılır menüye bakın. Daha genel süzgeçler tanımlamak için * işaretini kullanabilirsiniz. İleri düzeyde bilgiye sahip kullanıcılar düzenli ifadelere de (ör. /reklam\d+\.gif$/) başvurabilirler.">
-<!ENTITY filter.column "Süzgeç kuralı">
-<!ENTITY filter.accesskey "k">
-<!ENTITY slow.column "Süzgeçleri göster">
-<!ENTITY slow.accesskey "g">
-<!ENTITY enabled.column "Etkinlik">
-<!ENTITY enabled.accesskey "n">
-<!ENTITY hitcount.column "İsabet">
-<!ENTITY hitcount.accesskey "e">
-<!ENTITY lasthit.column "Son isabet">
-<!ENTITY lasthit.accesskey "i">
-<!ENTITY context.edit.label "Süzgeci düzenle">
-<!ENTITY context.resethitcount.label "İstabet istatistiği sıfırlanacak olan süzgeç:">
-<!ENTITY context.synchsubscription.label "Aboneliği eşle">
-<!ENTITY context.editsubscription.label "Aboneliği düzenle">
-<!ENTITY context.moveup.label "Yukarıya taşı">
-<!ENTITY context.movedown.label "Aşağıya taşı">
-<!ENTITY context.movegroupup.label "Öbeği yukarıya taşı">
-<!ENTITY context.movegroupdown.label "Öbeği aşağıya taşı">
-<!ENTITY context.enable.label "Devreye sok">
-<!ENTITY context.disable.label "Devreden çıkar">
-<!ENTITY apply.label "Uygula">
-<!ENTITY apply.accesskey "u">

=== removed file 'chrome/locale/tr-TR/sidebar.dtd'
--- chrome/locale/tr-TR/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/tr-TR/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: Engellenebilecek öğeler (ayrıldı)">
-<!ENTITY detach.label "Ayır">
-<!ENTITY reattach.label "Birleştir">
-<!ENTITY search.label "Ara">
-<!ENTITY search.accesskey "A">
-<!ENTITY type.label "Tür">
-<!ENTITY address.label "Adres">
-<!ENTITY filter.label "Süzgeç">
-<!ENTITY state.label "Durum">
-<!ENTITY size.label "Boyut">
-<!ENTITY docDomain.label "Belge kaynağı">
-<!ENTITY noitems.label "Engellenebilecek öğe yok">
-<!ENTITY whitelisted.label "Ak listeye dahil bir sayfa">
-<!ENTITY tooltip.address.label "Konum:">
-<!ENTITY tooltip.type.label "Tür:">
-<!ENTITY tooltip.type.blocked "(engellendi)">
-<!ENTITY tooltip.type.whitelisted "(ak listede)">
-<!ENTITY tooltip.size.label "Boyut">
-<!ENTITY tooltip.docDomain.label "Belge kaynağı:">
-<!ENTITY tooltip.filter.label "Yürürlükteki süzgeç:">
-<!ENTITY tooltip.filterSource.label "Süzgeç kaynağı:">
-<!ENTITY context.block.label "Bu öğeyi engelle">
-<!ENTITY context.editfilter.label "Yürürlükteki süzgeci düzelt">
-<!ENTITY context.whitelist.label "Öğeye ayrıcalık tanı">
-<!ENTITY context.disablefilter.label "Süzgeci devre dışı bırak --">
-<!ENTITY context.enablefilter.label "Süzgeci devreye sok --">
-<!ENTITY context.disablefilteronsite.label "Bu süzgeci burada kullanma --">
-<!ENTITY context.open.label "Yeni sekmede aç">
-<!ENTITY context.flash.label "Flash öğesinin sınırları">
-<!ENTITY context.copy.label "Öğenin konumunu kopyala">
-<!ENTITY context.copyFilter.label "Süzgeci kopyala">
-<!ENTITY context.selectAll.label "Tümünü seç">

=== removed file 'chrome/locale/tr-TR/subscription.dtd'
--- chrome/locale/tr-TR/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/tr-TR/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Süzgeç aboneliklerini düzenle">
-<!ENTITY dialog.newtitle "Süzgeç aboneliği ekle">
-<!ENTITY new.description "Adblock Plus süzgeç listesi barındıran sitenin ya da dosyanın adresini girin.">
-<!ENTITY edit.description "Abone olunan süzgeç listesi verilen adresten indirilecek.">
-<!ENTITY external.description "Bu dışsal bir abonelik. Süzgeçler abone olunan liste sayesinde güncel kalacak.">
-<!ENTITY autodownload.description "Eğer &apos;Otomatik olarak güncelle&apos; seçeneğini tercih ederseniz güncelleme olup olmadığına her gün bakılacak. Bunu seçmeseniz de içerik menüsü aracılığıyla güncellemeyi elle yapabilirsiniz.">
-<!ENTITY location.label "Süzgeç listesi konumu:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "Aboneliğin adı:">
-<!ENTITY title.accesskey "A">
-<!ENTITY autodownload.label "Otomatik olarak güncelle">
-<!ENTITY autodownload.accesskey "O">
-<!ENTITY enabled.label "Süzgeçleri etkinleştir">
-<!ENTITY enabled.accesskey "E">

=== removed file 'chrome/locale/tr-TR/tip_subscriptions.dtd'
--- chrome/locale/tr-TR/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/tr-TR/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus&apos;a Hoş Geldiniz">
-<!ENTITY description.par1 "Adblock Plus eklentisini kurduğunuz için teşekkür ederiz. Bu eklenti internette gördüğünüz reklamların &#37;99&apos;unu ortadan kaldırabilir. Ancak, başarılı bir reklam süzme işlemi sizin kaliteli süzgeçler kullanmanızı gerektirir. Bunu kendiniz de yapabilirsiniz, başkaları tarafından hazırlanan süzgeçleri kullanarak da yapabilirsiniz. İhtiyaç duyulduğunda aboneliği devre dışı bırakabilir, abonelikten ayrılabilir ya da kendi süzgeçlerinizi ekleyebilirsiniz.">
-<!ENTITY description.par2 "Aşağıda tavsiye edilen aboneliklerden birini seçebilirsiniz. (Her ne kadar genelde pek ihtiyaç duyulmasa da, Adblock Plus tercihlerine daha sonra diğer abonelikler de eklenebilir.)">
-<!ENTITY note "Açıklama: Süzgeç listesi en etkin olarak, hedef alınan sitelere karşı kullanılır.">
-<!ENTITY adblock.warning "Adblock Plus, Adblock ya da Adblock Plus&apos;un eski bir sürümünün kurulu olduğunu farketti. Aynı anda Adblock ve Adblock Plus&apos;ı kullanmak sorunlara neden olabileceğinden bundan kaçınılmalıdır. Şimdi Adblock&apos;u kaldırmanız tavsiye edilir.">
-<!ENTITY adblock.uninstall "Adblock&apos;u kaldır">
-<!ENTITY filterset.g.warning "Filterset.G&apos;yi kullandığınız anlaşılıyor. Bu süzgeç son birkaç yıldır pek fazla geliştirilmedi ve sitelerde sorun yaratıyor. Şimdi Filterset.G&apos;yi kaldırmanız tavsiye edilir.">
-<!ENTITY filterset.g.moreinfo "Daha fazla bilgi">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Filterset.G&apos;yi kaldır">
-<!ENTITY homepage.label "Başlangıç sayfası">
-<!ENTITY subscribe.label "Abone ol">
-<!ENTITY subscribe.accesskey "O">
-<!ENTITY other.label "Başka abonelik ekle">
-<!ENTITY other.accesskey "B">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Tüm aboneliklere bak">

=== added file 'chrome/locale/tr/about.dtd'
--- chrome/locale/tr/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/tr/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Adblock Plus Hakkında">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Sürüm">
+<!ENTITY description "Adblock Plus size internette neyi görmek istediğinize karar verme şansı sunar. Artık reklamları ve tanıtımları izlemek zorunda değilsiniz. Görmek istemediklerinizi Adblock Plus'a bildirin yeter!">
+<!ENTITY homepage.label "Adblock Plus ana sayfası:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Yazar:">
+<!ENTITY contributors.label "Katkıda bulunanlar:">
+<!ENTITY developers.label "Geliştiriciler:">
+<!ENTITY designers.label "Grafik tasarımcılar:">
+<!ENTITY subscriptionAuthors.label "Süzgeç aboneliği yazarları:">
+<!ENTITY translators.label "Çevirmenler:">

=== added file 'chrome/locale/tr/composer.dtd'
--- chrome/locale/tr/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/tr/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Adblock Plus süzgeç kuralı ekle">
+<!ENTITY accept.label "Süzgeç ekle">
+<!ENTITY advanced.label "Gelişmiş görünüm">
+<!ENTITY basic.label "Temel görünüm">
+<!ENTITY disabled.warning "Adblock Plus şu an devre dışı. Yine de süzgeç ekleyebilirsiniz, ancak bunlar [link]Adblock Plus etkinleştirilene kadar[/link]uygulanmayacaktır.">
+<!ENTITY groupDisabled.warning "Süzgecin eklenmesi gereken &quot;?1?&quot; süzgeç grubu şu an devre dışı. Süzgeci şu an ekleyebilirsiniz ancak [link]süzgeç grubunu devreye soktuğunuzda[/link]kullanılabilecektir.">
+<!ENTITY filter.label "Yeni süzgeç:">
+<!ENTITY filter.accesskey "y">
+<!ENTITY preferences.label "Mevcut süzgeçleri göster...">
+<!ENTITY preferences.accesskey "S">
+<!ENTITY type.filter.label "Engelleyen süzgeç">
+<!ENTITY type.filter.accesskey "l">
+<!ENTITY type.whitelist.label "Hariç tutma kuralı">
+<!ENTITY type.whitelist.accesskey "h">
+<!ENTITY pattern.label "Aranacak örnek">
+<!ENTITY pattern.explanation "Bu örnek adresin herhangi bir bölümü olabilir ve * işareti joker görevi yapar. Süzgeç sadece örneğe uyan adreslere uygulanacak.">
+<!ENTITY regexp.warning "Girdiğiniz örnek düzenli ifade olarak yorumlanacak. Çok fazla düzenli ifade, taramayı yavaşlatabilir. Gerçekten düzenli ifade kullanmak istediğinizden emin değilseniz örneğin sonuna * işareti koyun.">
+<!ENTITY shortpattern.warning "Girdiğiniz örnek en iyileştirmek için çok kısa ve bu tür örnekler taramayı yavaşlatabilir. Bu süzgeç için daha uzun bir satır seçmeniz tavsiye edilir.">
+<!ENTITY custom.pattern.label "Özel:">
+<!ENTITY custom.pattern.accesskey "z">
+<!ENTITY anchors.label "Örneği sadece burada kabul et:">
+<!ENTITY anchor.start.label "adresin başında">
+<!ENTITY anchor.start.accesskey "b">
+<!ENTITY anchor.start.flexible.label "alan adının başında">
+<!ENTITY anchor.start.flexible.accesskey "b">
+<!ENTITY anchor.end.label "adresin sonunda">
+<!ENTITY anchor.end.accesskey "o">
+<!ENTITY options.label "Seçenekler">
+<!ENTITY domainRestriction.label "Alan adına kısıtlama:">
+<!ENTITY domainRestriction.accesskey "d">
+<!ENTITY domainRestriction.help "Aralarına &quot;|&quot; simgesi koyarak bir ya da daha fazla alan adı belirtin. Böylece süzgeç sadece bu sitelerde uygulanacaktır. Alan adından önce &quot;~&quot; simgesi kullanılması, süzgecin o alan adında kullanılmaması gerektiği anlamına gelir.">
+<!ENTITY firstParty.label "Sadece birinci kişilerden">
+<!ENTITY firstParty.accesskey "i">
+<!ENTITY thirdParty.label "Sadece üçüncü kişilerden">
+<!ENTITY thirdParty.accesskey "c">
+<!ENTITY matchCase.label "Birebir eşleşme">
+<!ENTITY matchCase.accesskey "e">
+<!ENTITY types.label "Bu türlere uygula:">
+<!ENTITY selectAllTypes.label "Tümünü seç">
+<!ENTITY unselectAllTypes.label "Hiçbirini seçme">
+<!ENTITY collapse.label "Engellenenleri kapat:">
+<!ENTITY collapse.accesskey "p">
+<!ENTITY collapse.default.yes.label "Öntanımlı kullan (evet)">
+<!ENTITY collapse.default.no.label "Öntanımlı kullan (hayır)">
+<!ENTITY collapse.yes.label "Evet">
+<!ENTITY collapse.no.label "Hayır">

=== added file 'chrome/locale/tr/global.properties'
--- chrome/locale/tr/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/tr/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=İçerik menüsünü açmak için tıklayın; etkinleştirmek ya da etkisizleştirmek için orta düğmeye tıklayın.
+action1_tooltip=Engellenebilir öğeleri açmak ya da kapatmak için tıklayın; etkinleştirmek ya da etkisizleştirmek için orta düğmeye tıklayın.
+action2_tooltip=Tercihler penceresini açmak için tıklayın; etkinleştirmek ya da etkisizleştirmek için orta düğmeye tıklayın.
+action3_tooltip=Adblock Plus'ı etkinleştirmek ya da etkisizleştirmek için orta düğmeye tıklayın.
+disabled_tooltip=Adblock Plus etkin değil.
+active_tooltip=Adblock Plus devrede ve ?1? süzgeç aboneliği ile ?2? özel süzgeç kullanıyor.
+whitelisted_tooltip=Adblock Plus etkin, ancak bu sayfada devre dışı.
+blocked_count_tooltip=?1? toplam ?2?
+blocked_count_addendum=(ayrıca ?1? tane ak listede, ?2? tane gizli)
+no_blocking_suggestions=Bakılan sayfada engellenebilecek bir öğe bulunmuyor
+whitelisted_page=Adblock Plus bakılan sayfa için devre dışı bırakıldı
+whitelist_description=Ayrıcalıklar
+filterlist_description=Reklam süzgeçleri
+invalid_description=Geçersiz süzgeçler
+elemhide_description=Öğe engelleme kuralları
+subscription_description=Süzgeç abonelikleri:
+subscription_wrong_version=Bazı süzgeçlerin düzgün çalışabilmesi için Adblock Plus ?1? gerekiyor.
+subscription_source=Kaynak:
+subscription_status=Durum:
+subscription_status_autodownload=Otomatik olarak güncellendi
+subscription_status_manualdownload=Elle güncellendi
+subscription_status_externaldownload=Dışarıdan güncellendi (başka bir eklenti tarafından)
+subscription_status_lastdownload=En son indiriş:
+subscription_status_lastdownload_inprogress=İndiriliyor...
+subscription_status_lastdownload_unknown=Yok
+remove_subscription_warning=Gerçekten abonelikten çıkmak istiyor musunuz?
+import_filters_wrong_version=Uyarı: Bazı süzgeçlerin düzgün çalışabilmesi için Adblock Plus ?1? gerekiyor. Bu listeyi içe aktarmadan önce büyük olasılıkla en güncel Adblock Plus sürümüne yükselmeniz gerekiyor.
+import_filters_warning=Geçerli süzgeçlerinizi değiştirmek mi yoksa yeni gelecekleri şu anki süzgeçlerin sonuna eklemek mi istersiniz?
+import_filters_title=Süzgeçleri içe aktar
+export_filters_title=Süzgeçleri dışa aktar
+invalid_filters_file=Bu geçerli bir Adblock Plus süzgeç dosyası değil.
+filters_write_error=Süzgeçler dosyaya yazılırken hatayla karşılaşıldı. Dosyanın yazmaya karşı korunup korunmadığından ve başka bir program tarafından kullanılıp kullanılmadığından emin olun.
+clearall_warning=Gerçekten listedeki bütün süzgeçleri kaldırmak istiyor musunuz?
+resethitcounts_warning=Bütün süzgeçlerin isabet istatistiklerini gerçekten sıfırlamak istiyor musunuz? Bu işlemden geri adım atılamaz!
+resethitcounts_selected_warning=Seçilen süzgeçlerin isabet istatistiklerini gerçekten sıfırlamak istiyor musunuz? Bu işlemden geri adım atılamaz!
+filter_regexp_tooltip=Süzgeç ya düzenli ifade ya da en iyileştirmek için çok kısa. Bu süzgeçlerden çok fazlası, taramanızı yavaşlatabilir.
+filter_elemhide_duplicate_id=Gizlenecek sadece bir bileşen kimliği belirtilebilir
+filter_elemhide_nocriteria=Gizlenecek bileşeni anlamak için hiçbir ölçüt belirtilmedi
+subscription_notAdded_warning=Hiçbir süzgece abone olmadınız. Adblock Plus'ta kendiniz süzgeç tanımlamanız gerekecek.
+subscription_notAdded_warning_addendum=Devam etmek istiyor musunuz?
+subscription_invalid_location=Dosya listesi konumu ne düzgün bir URL ne de düzgün bir ada sahip.
+synchronize_invalid_url=Olmadı. Bu geçerli bir adres değil.
+synchronize_connection_error=Olmadı. İndirmede sorun var.
+synchronize_invalid_data=Olmadı. Bu düzgün bir süzgeç listesi değil.
+synchronize_checksum_mismatch=Başarısız, checksum eşleşmedi
+synchronize_ok=Eşleme başarılı oldu.
+overwrite=Üstüne Yaz
+append=Ekle
+new_filter_group_title=Yeni süzgeç
+type_label_other=diğer
+type_label_script=betik
+type_label_image=resim
+type_label_stylesheet=biçem yaprağı
+type_label_object=nesne
+type_label_subdocument=çerçeve
+type_label_document=belge
+type_label_background=arka plan
+type_label_elemhide=gizli
+type_label_xbl=XBL bağlantısı
+type_label_ping=bağlantı yoklaması
+type_label_xmlhttprequest=XML isteği
+type_label_object_subrequest=nesne alt isteği
+type_label_dtd=DTD
+type_label_media=ses/görüntü
+type_label_font=yazıtipi
+fennec_status_enabled=Adblock Plus devrede.
+fennec_status_disabled=Adblock Plus devre dışı.
+fennec_status_enabled_site=Adblock Plus ?1? sitesinde devrede.
+fennec_status_disabled_site=Adblock Plus ?1? sitesinde devre dışı.

=== added file 'chrome/locale/tr/meta.properties'
--- chrome/locale/tr/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/tr/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Ahmet Serkan Tıratacı
+name=Adblock Plus
+description=Reklamlar geçmişte kaldı!
+description.short=Reklamlar rahatsız mı ediyor? İzlenmek sorun mu yaratıyor? Koca koca tanıtımlardan bıktınız mı? Hemen Adblock Plus'ı kurun ve internetin kontrolünü yeniden ele geçirin, sayfaların nasıl görüneceğine siz karar verin.
+description.long=Adblock Plus internetin kontrolünü yeniden ele geçirinmenize ve sayfaların nasıl görüneceğine karar vermesinize olanak tanır. Reklamları yok etmekten zararlı yazılım dağıtan siteleri engellemeye kadar birçok işi gören farklı dildeki 40'ı aşkın süzgeç, Adblock Plus'ın arkasında. Adblock Plus ayrıca çeşitli yararlı özellikler sayesinde süzgeçlerinizi düzenlemenize yardım eder. Bu özellikler arasında, sayfa üzerinden resim engelleme; Flash ve Java nesneleri için engelleme sekmesi; betik ve biçem sayfalarını (CSS) engellenecekler arasından çıkartmanızı sağlayan 'engellenebilir öğeler listesi' yer alır.

=== added file 'chrome/locale/tr/overlay.dtd'
--- chrome/locale/tr/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/tr/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Durum:">
+<!ENTITY blocked.tooltip "Bu sayfada engellenen öğeler:">
+<!ENTITY filters.tooltip "En etkin süzgeçler:">
+<!ENTITY menuitem.label "Adblock Plus">
+<!ENTITY menuitem.accesskey "A">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Engellenebilir öğeler">
+<!ENTITY context.image.label "Resmi engelle">
+<!ENTITY context.object.label "Nesneyi engelle">
+<!ENTITY context.frame.label "Çerçeveyi engelle">
+<!ENTITY context.media.label "Adblock Plus: Ses/Video engelle">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Bu sayfada devreye sok">
+<!ENTITY sidebar.title "Bu sayfadaki engellenebilecek öğeler">
+<!ENTITY settings.label "Tercihler">
+<!ENTITY settings.accesskey "T">
+<!ENTITY opensidebar.label "Engellenebilecek öğeleri göster">
+<!ENTITY opensidebar.accesskey "E">
+<!ENTITY closesidebar.label "Engellenebilecek öğeleri gizle">
+<!ENTITY closesidebar.accesskey "E">
+<!ENTITY whitelist.site.label "?1? sitesinde devre dışı kal">
+<!ENTITY whitelist.page.label "Sadece bu sayfada devre dışı kal">
+<!ENTITY objecttab.title "Engelle">
+<!ENTITY objecttab.tooltip "Bu nesneyi Adblock Plus ile engellemek için buraya tıklayın.">

=== added file 'chrome/locale/tr/settings.dtd'
--- chrome/locale/tr/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/tr/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus Tercihleri">
+<!ENTITY filters.label "Süzgeçler">
+<!ENTITY filters.accesskey "G">
+<!ENTITY add.label "Süzgeç ekle">
+<!ENTITY add.accesskey "K">
+<!ENTITY addsubscription.label "Süzgeç aboneliği ekle">
+<!ENTITY addsubscription.accesskey "E">
+<!ENTITY synchsubscriptions.label "Tüm abonelikleri güncelle">
+<!ENTITY synchsubscriptions.accesskey "C">
+<!ENTITY import.label "Süzgeçleri içe aktar">
+<!ENTITY import.accesskey "Z">
+<!ENTITY export.label "Süzgeçleri dışa aktar">
+<!ENTITY export.accesskey "D">
+<!ENTITY clearall.label "Tüm süzgeçleri kaldır">
+<!ENTITY clearall.accesskey "L">
+<!ENTITY resethitcounts.label "İstatistikleri sıfırla">
+<!ENTITY resethitcounts.accesskey "R">
+<!ENTITY edit.label "Düzen">
+<!ENTITY edit.accesskey "z">
+<!ENTITY cut.label "Kes">
+<!ENTITY cut.accesskey "e">
+<!ENTITY copy.label "Kopyala">
+<!ENTITY copy.accesskey "K">
+<!ENTITY paste.label "Yapıştır">
+<!ENTITY paste.accesskey "Y">
+<!ENTITY remove.label "Sil">
+<!ENTITY remove.accesskey "S">
+<!ENTITY menu.find.label "Bul">
+<!ENTITY menu.find.accesskey "B">
+<!ENTITY menu.findagain.label "Sonrakini bul">
+<!ENTITY menu.findagain.accesskey "A">
+<!ENTITY view.label "Görünüm">
+<!ENTITY view.accesskey "r">
+<!ENTITY sort.label "Sırala">
+<!ENTITY sort.accesskey "S">
+<!ENTITY sort.none.label "Sıralanmamış">
+<!ENTITY sort.none.accesskey "m">
+<!ENTITY sort.ascending.label "A&apos;da Z&apos;ye sıralama">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Z&apos;den A&apos;ya sıralama">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Seçenekler">
+<!ENTITY options.accesskey "S">
+<!ENTITY enable.label "Adblock Plus&apos;ı etkinleştir">
+<!ENTITY enable.accesskey "A">
+<!ENTITY showintoolbar.label "Araç çubuğunda göster">
+<!ENTITY showintoolbar.accesskey "R">
+<!ENTITY showinstatusbar.label "Durum çubuğunda göster">
+<!ENTITY showinstatusbar.accesskey "D">
+<!ENTITY objecttabs.label "Flash ve Java&apos;yı kulakçıklarla belirt">
+<!ENTITY objecttabs.accesskey "J">
+<!ENTITY collapse.label "Öğeleri kapat">
+<!ENTITY collapse.accesskey "T">
+<!ENTITY help.label "Yardım">
+<!ENTITY help.accesskey "A">
+<!ENTITY gettingStarted.label "İlk adım">
+<!ENTITY gettingStarted.accesskey "k">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Sıkça sorulan sorular">
+<!ENTITY faq.accesskey "S">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Adblock Plus süzgeç yazımı">
+<!ENTITY filterdoc.accesskey "z">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Adblock Plus hakkında">
+<!ENTITY about.accesskey "O">
+<!ENTITY description "Engellemek istediğiniz adresleri yazın. Öneriler için açılır menüye bakın. Daha genel süzgeçler tanımlamak için * işaretini kullanabilirsiniz. İleri düzeyde bilgiye sahip kullanıcılar düzenli ifadelere de (ör. /reklam\d+\.gif$/) başvurabilirler.">
+<!ENTITY filter.column "Süzgeç kuralı">
+<!ENTITY filter.accesskey "k">
+<!ENTITY slow.column "Süzgeçleri göster">
+<!ENTITY slow.accesskey "g">
+<!ENTITY enabled.column "Etkinlik">
+<!ENTITY enabled.accesskey "n">
+<!ENTITY hitcount.column "İsabet">
+<!ENTITY hitcount.accesskey "e">
+<!ENTITY lasthit.column "Son isabet">
+<!ENTITY lasthit.accesskey "i">
+<!ENTITY context.edit.label "Süzgeci düzenle">
+<!ENTITY context.resethitcount.label "İsabet istatistiği sıfırlanacak süzgeç:">
+<!ENTITY context.synchsubscription.label "Aboneliği eşle">
+<!ENTITY context.editsubscription.label "Aboneliği düzenle">
+<!ENTITY context.moveup.label "Yukarıya taşı">
+<!ENTITY context.movedown.label "Aşağıya taşı">
+<!ENTITY context.movegroupup.label "Öbeği yukarıya taşı">
+<!ENTITY context.movegroupdown.label "Öbeği aşağıya taşı">
+<!ENTITY context.enable.label "Devreye sok">
+<!ENTITY context.disable.label "Devreden çıkar">
+<!ENTITY apply.label "Uygula">
+<!ENTITY apply.accesskey "u">
+<!ENTITY fennec.subscription.label "Süzgeç aboneliği">

=== added file 'chrome/locale/tr/sidebar.dtd'
--- chrome/locale/tr/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/tr/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: Engellenebilecek öğeler (ayrıldı)">
+<!ENTITY detach.label "Ayır">
+<!ENTITY reattach.label "Birleştir">
+<!ENTITY search.label "Ara">
+<!ENTITY search.accesskey "A">
+<!ENTITY type.label "Tür">
+<!ENTITY address.label "Adres">
+<!ENTITY filter.label "Süzgeç">
+<!ENTITY state.label "Durum">
+<!ENTITY size.label "Boyut">
+<!ENTITY docDomain.label "Belge kaynağı">
+<!ENTITY noitems.label "Engellenebilecek öğe yok">
+<!ENTITY whitelisted.label "Ak listeye dahil bir sayfa">
+<!ENTITY tooltip.address.label "Konum:">
+<!ENTITY tooltip.type.label "Tür:">
+<!ENTITY tooltip.type.blocked "(engellendi)">
+<!ENTITY tooltip.type.whitelisted "(ak listede)">
+<!ENTITY tooltip.size.label "Boyut">
+<!ENTITY tooltip.docDomain.label "Belge kaynağı:">
+<!ENTITY tooltip.filter.label "Yürürlükteki süzgeç:">
+<!ENTITY tooltip.filterSource.label "Süzgeç kaynağı:">
+<!ENTITY context.block.label "Bu öğeyi engelle">
+<!ENTITY context.editfilter.label "Yürürlükteki süzgeci düzelt">
+<!ENTITY context.whitelist.label "Öğeye ayrıcalık tanı">
+<!ENTITY context.disablefilter.label "Süzgeci devre dışı bırak ?1?">
+<!ENTITY context.enablefilter.label "Süzgeci devreye sok ?1?">
+<!ENTITY context.disablefilteronsite.label "Bu süzgeci burada kullanma ?1?">
+<!ENTITY context.open.label "Yeni sekmede aç">
+<!ENTITY context.flash.label "Flash öğesinin sınırları">
+<!ENTITY context.copy.label "Öğenin konumunu kopyala">
+<!ENTITY context.copyFilter.label "Süzgeci kopyala">
+<!ENTITY context.selectAll.label "Tümünü seç">

=== added file 'chrome/locale/tr/subscriptionSelection.dtd'
--- chrome/locale/tr/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/tr/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Adblock Plus süzgeç aboneliği ekle">
+<!ENTITY dialog.title.edit "Süzgeç aboneliklerini düzenle">
+<!ENTITY description.newInstall "Adblock Plus herhangi bir süzgeç aboneliğiyle birlikte en etkin şekilde kullanılır. Bu abonelikler diğer Adblock Plus kullanıcıları tarafından ücretsiz sunulmaktadır. Dilinize en uygun abonelik seçilmiş durumda.">
+<!ENTITY adblock.warning "Adblock Plus, Adblock ya da Adblock Plus'un eski bir sürümünün kurulu olduğunu farketti. Aynı anda Adblock ve Adblock Plus'ı kullanmak sorunlara neden olabileceğinden bundan kaçınılmalıdır. Şimdi Adblock'u kaldırmanız tavsiye edilir.">
+<!ENTITY adblock.uninstall "Adblock'u kaldır">
+<!ENTITY filterset.g.warning "Filterset.G'yi kullandığınız anlaşılıyor. Bu süzgeç son birkaç yıldır pek fazla geliştirilmedi ve sitelerde sorun yaratıyor. Şimdi Filterset.G'yi kaldırmanız tavsiye edilir.">
+<!ENTITY filterset.g.moreinfo "Daha fazla bilgi">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Filterset.G'yi kaldır">
+<!ENTITY subscriptionSelector.label "Lütfen listeden bir süzgeç aboneliği seçin:">
+<!ENTITY viewList.label "Süzgeçlere bak">
+<!ENTITY visitHomepage.label "Ana sayfaya git">
+<!ENTITY addSubscription.label "Abone ol">
+<!ENTITY saveSubscription.label "Aboneliği kaydet">
+<!ENTITY other.label "Başka abonelik ekle">
+<!ENTITY other.accesskey "B">
+<!ENTITY list.download.failed "Adblock Plus abonelik listesini alamadı">
+<!ENTITY list.download.retry "Yeniden dene">
+<!ENTITY list.download.website "Siteye git">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Lütfen bu süzgeç aboneliğini eklemek istediğinizi teyit edin. Eklemeden önce abonelik adını ve konumunu değiştirebilirsiniz.">
+<!ENTITY edit.description "Abonelik adını ve konumunu gerekirse değiştirebilirsiniz.">
+<!ENTITY external.description "Bu harici bir süzgeç aboneliği ve aboneliği başlatan eklenti tarafından güncellenecek.">
+<!ENTITY title.label "Aboneliğin adı:">
+<!ENTITY title.accesskey "A">
+<!ENTITY location.label "Süzgeç listesi konumu:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "Otomatik olarak güncelle">
+<!ENTITY autodownload.accesskey "O">
+<!ENTITY supplementMessage "Bu süzgeç aboneliği henüz kullanmadığınız &quot;?1?&quot; süzgeç aboneliğiyle kullanılmak üzere hazırlanmış.">
+<!ENTITY addMain.label "&quot;?1?&quot; süzgeç aboneliğini de ekle">
+<!ENTITY addMain.accesskey "s">

=== added directory 'chrome/locale/uk'
=== removed directory 'chrome/locale/uk-UA'
=== removed file 'chrome/locale/uk-UA/about.dtd'
--- chrome/locale/uk-UA/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/uk-UA/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,13 +0,0 @@
-<!ENTITY dialog.title "Про Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Версія">
-<!ENTITY description "
-	З Adblock Plus Ви можете самі вирішувати, що ви хочете бачити в інтернеті
-	а що — ні. Не потрібно більше витрачати свій час і витрачати зайві гроші 
-	на викачування рекламних банерів, якщо ви не хочете їх бачити 
-	— Adblock Plus вам допоможе!
-">
-<!ENTITY homepage.label "Домашня сторінка проекту:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Розробник:">
-<!ENTITY contributors.label "Інші учасники:">

=== removed file 'chrome/locale/uk-UA/composer.dtd'
--- chrome/locale/uk-UA/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/uk-UA/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Додати правило фільтрування Adblock Plus">
-<!ENTITY accept.label "Додати фільтр">
-<!ENTITY advanced.label "Складний вигляд">
-<!ENTITY basic.label "Простий вигляд">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus наразі вимкнений. Ви все одно можете додавати фільтри, але вони не застосуються. Хіба що ви можете">
-<!ENTITY disabled.warning.link "увімкнути Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Група фільтрів &quot;&#37;S&quot; до котрої додається цей фільтр наразі вимкнена. Ви можете все одно додати його, але він не буде застосований. Хіба що ви можете">
-<!ENTITY groupDisabled.warning.link "увімкнути групу фільтрів">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Новий фільтр:">
-<!ENTITY filter.accesskey "ф">
-<!ENTITY preferences.label "Показати існуючі фільтри…">
-<!ENTITY preferences.accesskey "і">
-<!ENTITY type.filter.label "Правило блокування">
-<!ENTITY type.filter.accesskey "Б">
-<!ENTITY type.whitelist.label "Правило винятку">
-<!ENTITY type.whitelist.accesskey "в">
-<!ENTITY pattern.label "Шукати шаблон">
-<!ENTITY pattern.explanation "Шаблон може бути будь-якою частиною адреси, символ * працює як джокер. Фільтр буде застосовано лише до адрес що відповідають шаблону.">
-<!ENTITY regexp.warning "Шаблон що ви ввели буде інтерпретовано як регулярний вираз. Багато регулярних виразів можуть уповільнити перегляд сторінок. Додайте * на кінець шаблону якщо ви не збирались використовувати регулярний вираз.">
-<!ENTITY shortpattern.warning "Шаблон що ви ввели закороткий для оптимізування, багато таких шаблонів можуть уповільнити перегляд сторінок. Рекомендовано обрати довшу строку для цього фільтра">
-<!ENTITY custom.pattern.label "Інше">
-<!ENTITY custom.pattern.accesskey "н">
-<!ENTITY anchors.label "Шаблон має бути">
-<!ENTITY anchor.start.label "на початку адреси">
-<!ENTITY anchor.start.accesskey "п">
-<!ENTITY anchor.start.flexible.label "на початку імені домена">
-<!ENTITY anchor.start.flexible.accesskey "п">
-<!ENTITY anchor.end.label "при кінці адреси">
-<!ENTITY anchor.end.accesskey "к">
-<!ENTITY options.label "Настройки">
-<!ENTITY domainRestriction.label "Обмежити доменом">
-<!ENTITY domainRestriction.accesskey "м">
-<!ENTITY domainRestriction.help "Вкажіть один чи більше доменів, розділених символом „|“, фільтр буде застосовано лише на них. Символ „~“ перед іменем домена вказує що фільтр на цей домен не розповсюджується.">
-<!ENTITY firstParty.label "Той же сайт">
-<!ENTITY firstParty.accesskey "й">
-<!ENTITY thirdParty.label "Сторонній сайт">
-<!ENTITY thirdParty.accesskey "т">
-<!ENTITY matchCase.label "Враховувати регістр">
-<!ENTITY matchCase.accesskey "р">
-<!ENTITY types.label "Застосовувати до об’єктів:">
-<!ENTITY selectAllTypes.label "Вибрати все">
-<!ENTITY unselectAllTypes.label "Скинути все">
-<!ENTITY collapse.label "Згортати заблоковане:">
-<!ENTITY collapse.accesskey "г">
-<!ENTITY collapse.default.yes.label "Як завжди (так)">
-<!ENTITY collapse.default.no.label "Як завжди (ні)">
-<!ENTITY collapse.yes.label "Так">
-<!ENTITY collapse.no.label "Ні">

=== removed file 'chrome/locale/uk-UA/global.properties'
--- chrome/locale/uk-UA/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/uk-UA/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Скажи «НІ» рекламі!
-status_active_label=Adblock
-status_disabled_label=Вимкнений
-action0_tooltip=Клацніть, щоб відкрити контекстне меню. Середня клавіша миші — вкл/викл.
-action1_tooltip=Клацніть, щоб відкрити/закрити список елементів. Середня клавіша миші — вкл/викл.
-action2_tooltip=Клацніть, щоб відкрити вікно налаштувань.  Середня клавіша миші — вкл/викл.
-action3_tooltip=Клацніть, щоб увімкнути чи вимкнути Adblock Plus.
-active_tooltip=Adblock Plus увімкнено.
-disabled_tooltip=Adblock Plus вимкнено.
-whitelisted_tooltip=Adblock Plus увімкнено, проте не для цієї сторінки.
-blocked_count_tooltip=-- з --
-no_blocking_suggestions=На відкритій сторінці немає елементів, які можна було б заблокувати
-whitelisted_page=Adblock Plus вимкнено для цієї сторінки
-whitelist_description=Мої винятки
-filterlist_description=Мої фільтри реклами
-invalid_description=Мої помилкові фільтри
-elemhide_description=Правила приховування елементів
-subscription_description=Підписка:
-subscription_wrong_version=Деякі фільтри в цій підписці вимагають щонайменше Adblock Plus -- для коректної роботи!
-subscription_source=Джерело:
-subscription_status=Стан:
-subscription_status_autodownload=Оновлюється автоматично
-subscription_status_manualdownload=Оновлюється вручну
-subscription_status_externaldownload=Оновлюється іншим розширенням
-subscription_status_lastdownload=Останнє оновлення:
-subscription_status_lastdownload_inprogress=Завантажується…
-subscription_status_lastdownload_unknown=ніколи
-remove_subscription_warning=Ви впевнені, що хочете вилучити цю підписку?
-import_filters_wrong_version=Попередження: Деякі фільтри в цьому списку вимагають щонайменше Adblock Plus -- для коректної роботи. Можливо, вам краще оновити вашу версію Adblock Plus, перш ніж імпортувати цей список.
-import_filters_warning=Ви хочете замінити існуючі фільтри або додати фільтри, що імпортуються, в кінець?
-import_filters_title=Імпорт фільтрів
-export_filters_title=Експорт фільтрів
-invalid_filters_file=Файл не містить списку фільтрів для Adblock Plus.
-filters_write_error=При записі фільтрів у файл виникла помилка. Можливо на файлі встановлено захист від запису або він використовується іншою програмою.
-clearall_warning=Ви впевнені, що хочете стерти всі фільтри?
-resethitcounts_warning=Ви впевнені, що хочете обнулити статистику для всіх фільтрів? Зауважте, це необоротна дія!
-resethitcounts_selected_warning=Ви впевнені, що ви хочете обнулити статистику для відмічених фільтрів? Зауважте, це необоротна дія!
-filter_regexp_tooltip=Цей фільтр або регулярний вираз або закороткий для оптимізування. Забагато фільтрів можуть вповільнити перегляд сторінок
-filter_elemhide_duplicate_id=Можна вказати лише один ID приховуваного елемента
-filter_elemhide_nocriteria=Не вказаний критерій за яким упізнати приховуваний елемент
-subscription_no_location=Будь ласка введіть адресу, з якої повинен викачуватися список фільтрів.
-subscription_invalid_location=Не вдалося розпізнати введену адресу ні як інтернет адресу, ні як шлях до файлу.
-subscription_location_exists=Ви вже додали цю підписку.
-synchronize_invalid_url=Помилка, невірна адреса
-synchronize_connection_error=Помилка, неможливо викачати
-synchronize_invalid_data=Помилка, не список фільтрів
-synchronize_checksum_mismatch=Помилка, не збіглась контрольна сума
-synchronize_ok=OK
-overwrite=Замінити
-append=Додати
-new_filter_group_title=Новий фільтр
-type_label_other=Невідомий
-type_label_script=Скрипт
-type_label_image=Зображення
-type_label_stylesheet=Стилі
-type_label_object=Об’єкт
-type_label_subdocument=Фрейм
-type_label_document=Документ
-type_label_background=Тло
-type_label_elemhide=Приховане
-type_label_xbl=XBL
-type_label_ping=Клацання по посиланню
-type_label_xmlhttprequest=XML-запит
-type_label_object_subrequest=Запит об’єкта
-type_label_dtd=DTD
-type_label_media=аудіо/відео
-type_label_font=шрифт

=== removed file 'chrome/locale/uk-UA/overlay.dtd'
--- chrome/locale/uk-UA/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/uk-UA/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Статус:">
-<!ENTITY blocked.tooltip "Заблоковані елементи на цій сторінці:">
-<!ENTITY filters.tooltip "Найбільш часто застосовані фільтри:">
-<!ENTITY menuitem.label "Налаштування Adblock Plus">
-<!ENTITY menuitem.accesskey "A">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: елементи сторінки">
-<!ENTITY context.image.label "Adblock Plus: заблокувати зображення">
-<!ENTITY context.object.label "Adblock Plus: заблокувати об’єкт">
-<!ENTITY context.frame.label "Adblock Plus: заблокувати фрейм">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Знов увімкнути для цієї сторінки">
-<!ENTITY sidebar.title "Елементи відкритої сторінки">
-<!ENTITY settings.label "Налаштування">
-<!ENTITY settings.accesskey "ш">
-<!ENTITY opensidebar.label "Відкрити список елементів">
-<!ENTITY opensidebar.accesskey "п">
-<!ENTITY closesidebar.label "Закрити список елементів">
-<!ENTITY closesidebar.accesskey "п">
-<!ENTITY whitelist.site.label "Вимкнути: на --">
-<!ENTITY whitelist.page.label "Вимкнути: тільки на цій сторінці">
-<!ENTITY objecttab.title "Заблокувати">
-<!ENTITY objecttab.tooltip "Натисніть тут, щоб заблокувати цей об’єкт">

=== removed file 'chrome/locale/uk-UA/settings.dtd'
--- chrome/locale/uk-UA/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/uk-UA/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Adblock Plus - Налаштування">
-<!ENTITY filters.label "Фільтри">
-<!ENTITY filters.accesskey "і">
-<!ENTITY add.label "Додати фільтр">
-<!ENTITY add.accesskey "д">
-<!ENTITY addsubscription.label "Додати підписку">
-<!ENTITY addsubscription.accesskey "о">
-<!ENTITY synchsubscriptions.label "Викачати всі підписки">
-<!ENTITY synchsubscriptions.accesskey "п">
-<!ENTITY import.label "Імпорт фільтрів">
-<!ENTITY import.accesskey "м">
-<!ENTITY export.label "Експорт фільтрів">
-<!ENTITY export.accesskey "к">
-<!ENTITY clearall.label "Стерти всі фільтри">
-<!ENTITY clearall.accesskey "и">
-<!ENTITY resethitcounts.label "Обнулити статистику попадань">
-<!ENTITY resethitcounts.accesskey "у">
-<!ENTITY edit.label "Правка">
-<!ENTITY edit.accesskey "р">
-<!ENTITY cut.label "Вирізати">
-<!ENTITY cut.accesskey "р">
-<!ENTITY copy.label "Копіювати">
-<!ENTITY copy.accesskey "о">
-<!ENTITY paste.label "Вставити">
-<!ENTITY paste.accesskey "а">
-<!ENTITY remove.label "Вилучити">
-<!ENTITY remove.accesskey "и">
-<!ENTITY menu.find.label "Знайти фільтр">
-<!ENTITY menu.find.accesskey "н">
-<!ENTITY menu.findagain.label "Знайти наступний">
-<!ENTITY menu.findagain.accesskey "т">
-<!ENTITY view.label "Вигляд">
-<!ENTITY view.accesskey "В">
-<!ENTITY sort.label "Сортувати за">
-<!ENTITY sort.accesskey "С">
-<!ENTITY sort.none.label "Несортовано">
-<!ENTITY sort.none.accesskey "Н">
-<!ENTITY sort.ascending.label "Від А до Я">
-<!ENTITY sort.ascending.accesskey "А">
-<!ENTITY sort.descending.label "Від Я до А">
-<!ENTITY sort.descending.accesskey "Я">
-<!ENTITY options.label "Налаштування">
-<!ENTITY options.accesskey "а">
-<!ENTITY enable.label "Увімкнути Adblock Plus">
-<!ENTITY enable.accesskey "У">
-<!ENTITY showintoolbar.label "Показувати в панелі інструментів">
-<!ENTITY showintoolbar.accesskey "к">
-<!ENTITY showinstatusbar.label "Показувати в рядку стану">
-<!ENTITY showinstatusbar.accesskey "с">
-<!ENTITY objecttabs.label "Показувати ярлик на Flash і Java">
-<!ENTITY objecttabs.accesskey "я">
-<!ENTITY collapse.label "Згортати заблоковані елементи">
-<!ENTITY collapse.accesskey "о">
-<!ENTITY help.label "Довідка">
-<!ENTITY help.accesskey "о">
-<!ENTITY gettingStarted.label "Початківцям">
-<!ENTITY gettingStarted.accesskey "П">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Питання, що часто ставляться (англійською)">
-<!ENTITY faq.accesskey "и">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Складання фільтрів для Adblock Plus (англійською)">
-<!ENTITY filterdoc.accesskey "а">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Про Adblock Plus">
-<!ENTITY about.accesskey "о">
-<!ENTITY description "Наступні фільтри визначають які адреси блокуються та які дозволяються:">
-<!ENTITY filter.column "Правило фільтрування">
-<!ENTITY filter.accesskey "ф">
-<!ENTITY slow.column "Повільні фільтри">
-<!ENTITY slow.accesskey "і">
-<!ENTITY enabled.column "Увімкнено">
-<!ENTITY enabled.accesskey "в">
-<!ENTITY hitcount.column "Попадань">
-<!ENTITY hitcount.accesskey "п">
-<!ENTITY lasthit.column "Останнє попадання">
-<!ENTITY lasthit.accesskey "О">
-<!ENTITY context.edit.label "Редагувати фільтр">
-<!ENTITY context.resethitcount.label "Обнулити статистику попадань для фільтру">
-<!ENTITY context.synchsubscription.label "Викачати фільтри наново">
-<!ENTITY context.editsubscription.label "Редагувати підписку">
-<!ENTITY context.moveup.label "Зрушити вгору">
-<!ENTITY context.movedown.label "Зрушити вниз">
-<!ENTITY context.movegroupup.label "Зрушити групу вгору">
-<!ENTITY context.movegroupdown.label "Зрушити групу вниз">
-<!ENTITY context.enable.label "Увімкнути">
-<!ENTITY context.disable.label "Вимкнути">
-<!ENTITY apply.label "Застосувати">
-<!ENTITY apply.accesskey "т">

=== removed file 'chrome/locale/uk-UA/sidebar.dtd'
--- chrome/locale/uk-UA/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/uk-UA/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: елементи відкритої сторінки (від’єднані)">
-<!ENTITY detach.label "Від’єднати">
-<!ENTITY reattach.label "Приєднати">
-<!ENTITY search.label "Пошук:">
-<!ENTITY search.accesskey "о">
-<!ENTITY type.label "Тип">
-<!ENTITY address.label "Адреса">
-<!ENTITY filter.label "Фільтр">
-<!ENTITY state.label "Статус">
-<!ENTITY size.label "Розмір">
-<!ENTITY docDomain.label "Джерело документа">
-<!ENTITY noitems.label "Блокувати нічого">
-<!ENTITY whitelisted.label "Дозволений на цій сторінці">
-<!ENTITY tooltip.address.label "Адреса:">
-<!ENTITY tooltip.type.label "Тип:">
-<!ENTITY tooltip.type.blocked "(заблокований)">
-<!ENTITY tooltip.type.whitelisted "(виняток)">
-<!ENTITY tooltip.size.label "Розмір:">
-<!ENTITY tooltip.docDomain.label "Джерело документа:">
-<!ENTITY tooltip.filter.label "Застосований фільтр:">
-<!ENTITY tooltip.filterSource.label "Джерело фільтра:">
-<!ENTITY context.block.label "Заблокувати елемент">
-<!ENTITY context.editfilter.label "Відредагувати застосований фільтр">
-<!ENTITY context.whitelist.label "Вказати елемент як виняток">
-<!ENTITY context.disablefilter.label "Вимкнути фільтр --">
-<!ENTITY context.enablefilter.label "Знов увімкнути фільтр --">
-<!ENTITY context.disablefilteronsite.label "Вимкнути цей фільтр на --">
-<!ENTITY context.open.label "Відкрити в новій вкладці">
-<!ENTITY context.flash.label "Показати розташування елементу">
-<!ENTITY context.copy.label "Копіювати адресу">
-<!ENTITY context.copyFilter.label "Копіювати фільтр">
-<!ENTITY context.selectAll.label "Вибрати всі">

=== removed file 'chrome/locale/uk-UA/subscription.dtd'
--- chrome/locale/uk-UA/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/uk-UA/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,18 +0,0 @@
-<!ENTITY dialog.title "Редагувати підписку">
-<!ENTITY dialog.newtitle "Додати підписку">
-<!ENTITY new.description "Будь ласка введіть адресу в інтернеті або шлях до файлу, де розташований
-	список фільтрів для Adblock Plus.">
-<!ENTITY edit.description "Список фільтрів для цієї підписки викачуватиметься із заданої адреси.">
-<!ENTITY external.description "Це зовнішня підписка, вона актуалізуватиметься розширенням, яке
-	її додало.">
-<!ENTITY autodownload.description "Якщо вибрано «Оновлювати автоматично», то оновлення викачуватимуться
-	з цієї адреси щодня.  Без цієї опції викачування потрібно запускати
-	вручну з контекстного меню підписки.">
-<!ENTITY location.label "Адреса списку фільтрів:">
-<!ENTITY location.accesskey "е">
-<!ENTITY title.label "Назва підписки:">
-<!ENTITY title.accesskey "а">
-<!ENTITY autodownload.label "Оновлювати автоматично">
-<!ENTITY autodownload.accesskey "о">
-<!ENTITY enabled.label "Увімкнути фільтри">
-<!ENTITY enabled.accesskey "У">

=== removed file 'chrome/locale/uk-UA/tip_subscriptions.dtd'
--- chrome/locale/uk-UA/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/uk-UA/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,26 +0,0 @@
-<!ENTITY dialog.title "Додати підписку на фільтри Adblock Plus">
-<!ENTITY description.par1 "Дякую за встановлення Adblock Plus. Це розширення може
-	відфільтровувати 99&#37; інтернет-реклами. Проте, для забезпечення
-	ефективності фільтрації ви повинні встановити хороший набір фільтрів. 
-	Ви можете зробити це самостійно, чи просто підписатися на списки
-	фільтрів, складені іншими користувачами. Але в разі потреби ви завжди 
-	можете додати ваші власні фільтри або вимкнути/вилучити підписки 
-	на списки фільтрів.">
-<!ENTITY description.par2 "Ви можете вибрати одну підписку список рекомендованих підписок нижче
-	(більше підписок можна додати у налаштуваннях Adblock Plus пізніше,
-	проте зазвичай потреби в цьому не виникає):">
-<!ENTITY note "Примітка: Список фільтрів, як правило, найбільш ефективний на сторінках
-				того регіону, для якого він створювався.">
-<!ENTITY adblock.warning "Adblock Plus помітив що встановлено Adblock чи стару версію Adblock Plus. Паралельне використання Adblock та Adblock Plus может спричинити проблеми ти тому цього слід уникати. Рекомендуємо вам зараз вилучити Adblock.">
-<!ENTITY adblock.uninstall "Вилучити Adblock">
-<!ENTITY filterset.g.warning "Схоже що ви використовуєте Filterset.G. Цей список фільтрів ледве підтримується останні кілька років і є основною причиною проблем з веб-сайтами. Радимо вам вилучити зараз Filterset.G">
-<!ENTITY filterset.g.moreinfo "Докладніше">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Вилучити Filterset.G">
-<!ENTITY homepage.label "Домашня сторінка">
-<!ENTITY subscribe.label "Підписатися">
-<!ENTITY subscribe.accesskey "і">
-<!ENTITY other.label "Додати іншу підписку">
-<!ENTITY other.accesskey "о">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Переглянути всі підписки">

=== added file 'chrome/locale/uk/about.dtd'
--- chrome/locale/uk/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/uk/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Про Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Версія">
+<!ENTITY description "З Adblock Plus ви можете самі вирішувати, що ви хочете бачити в інтернеті, а що — ні. Якщо ви не бажаєте дивитись на рекламні банери — Adblock Plus вам допоможе!">
+<!ENTITY homepage.label "Домашня сторінка проекту:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Автор:">
+<!ENTITY contributors.label "Інші учасники:">
+<!ENTITY developers.label "Розробники:">
+<!ENTITY designers.label "Дизайнери графіки">
+<!ENTITY subscriptionAuthors.label "Автори фільтрів підписки:">
+<!ENTITY translators.label "Перекладачі:">

=== added file 'chrome/locale/uk/composer.dtd'
--- chrome/locale/uk/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/uk/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Додати правило фільтрування Adblock Plus">
+<!ENTITY accept.label "Додати фільтр">
+<!ENTITY advanced.label "Складний вигляд">
+<!ENTITY basic.label "Простий вигляд">
+<!ENTITY disabled.warning "Adblock Plus наразі вимкнений. Ви все одно можете додавати фільтри, але вони не застосуються. Хіба що ви можете [link]увімкнути Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Група фільтрів &quot;?1?&quot; до котрої додається цей фільтр наразі вимкнена. Ви можете все одно додати його, але він не буде застосований. Хіба що ви можете [link]увімкнути групу фільтрів[/link].">
+<!ENTITY filter.label "Новий фільтр:">
+<!ENTITY filter.accesskey "ф">
+<!ENTITY preferences.label "Показати існуючі фільтри…">
+<!ENTITY preferences.accesskey "і">
+<!ENTITY type.filter.label "Правило блокування">
+<!ENTITY type.filter.accesskey "Б">
+<!ENTITY type.whitelist.label "Правило винятку">
+<!ENTITY type.whitelist.accesskey "в">
+<!ENTITY pattern.label "Шукати шаблон">
+<!ENTITY pattern.explanation "Шаблон може бути будь-якою частиною адреси, символ * працює як джокер. Фільтр буде застосовано лише до адрес що відповідають шаблону.">
+<!ENTITY regexp.warning "Шаблон що ви ввели буде інтерпретовано як регулярний вираз. Багато регулярних виразів можуть уповільнити перегляд сторінок. Додайте * на кінець шаблону якщо ви не збирались використовувати регулярний вираз.">
+<!ENTITY shortpattern.warning "Шаблон що ви ввели закороткий для оптимізування, багато таких шаблонів можуть уповільнити перегляд сторінок. Рекомендовано обрати довшу строку для цього фільтра">
+<!ENTITY custom.pattern.label "Інше">
+<!ENTITY custom.pattern.accesskey "н">
+<!ENTITY anchors.label "Шаблон має бути">
+<!ENTITY anchor.start.label "на початку адреси">
+<!ENTITY anchor.start.accesskey "п">
+<!ENTITY anchor.start.flexible.label "на початку імені домена">
+<!ENTITY anchor.start.flexible.accesskey "п">
+<!ENTITY anchor.end.label "при кінці адреси">
+<!ENTITY anchor.end.accesskey "к">
+<!ENTITY options.label "Настройки">
+<!ENTITY domainRestriction.label "Обмежити доменом">
+<!ENTITY domainRestriction.accesskey "м">
+<!ENTITY domainRestriction.help "Вкажіть один чи більше доменів, розділених символом „|“, фільтр буде застосовано лише на них. Символ „~“ перед іменем домена вказує що фільтр на цей домен не розповсюджується.">
+<!ENTITY firstParty.label "Той же сайт">
+<!ENTITY firstParty.accesskey "й">
+<!ENTITY thirdParty.label "Сторонній сайт">
+<!ENTITY thirdParty.accesskey "т">
+<!ENTITY matchCase.label "Враховувати регістр">
+<!ENTITY matchCase.accesskey "р">
+<!ENTITY types.label "Застосовувати до об’єктів:">
+<!ENTITY selectAllTypes.label "Вибрати все">
+<!ENTITY unselectAllTypes.label "Скинути все">
+<!ENTITY collapse.label "Згортати заблоковане:">
+<!ENTITY collapse.accesskey "г">
+<!ENTITY collapse.default.yes.label "Як завжди (так)">
+<!ENTITY collapse.default.no.label "Як завжди (ні)">
+<!ENTITY collapse.yes.label "Так">
+<!ENTITY collapse.no.label "Ні">

=== added file 'chrome/locale/uk/global.properties'
--- chrome/locale/uk/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/uk/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Клацніть, щоб відкрити контекстне меню. Середня клавіша миші — вкл/викл.
+action1_tooltip=Клацніть, щоб відкрити/закрити список елементів. Середня клавіша миші — вкл/викл.
+action2_tooltip=Клацніть, щоб відкрити вікно налаштувань.  Середня клавіша миші — вкл/викл.
+action3_tooltip=Клацніть, щоб увімкнути чи вимкнути Adblock Plus.
+disabled_tooltip=Adblock Plus вимкнено.
+active_tooltip=Adblock Plus увімкнено, задіяно ?1? підписок та ?2? власних фільтрів.
+whitelisted_tooltip=Adblock Plus увімкнено, проте не для цієї сторінки.
+blocked_count_tooltip=?1? з ?2?
+blocked_count_addendum=(також відкрито: ?1?, приховано: ?2?)
+no_blocking_suggestions=На відкритій сторінці немає елементів, які можна було б заблокувати
+whitelisted_page=Adblock Plus вимкнено для цієї сторінки
+whitelist_description=Мої винятки
+filterlist_description=Мої фільтри реклами
+invalid_description=Мої помилкові фільтри
+elemhide_description=Правила приховування елементів
+subscription_description=Підписка:
+subscription_wrong_version=Деякі фільтри в цій підписці вимагають щонайменше Adblock Plus ?1? для коректної роботи
+subscription_source=Джерело:
+subscription_status=Стан:
+subscription_status_autodownload=Оновлюється автоматично
+subscription_status_manualdownload=Оновлюється вручну
+subscription_status_externaldownload=Оновлюється іншим розширенням
+subscription_status_lastdownload=Останнє оновлення:
+subscription_status_lastdownload_inprogress=Завантажується…
+subscription_status_lastdownload_unknown=ніколи
+remove_subscription_warning=Ви впевнені, що хочете вилучити цю підписку?
+import_filters_wrong_version=Попередження: Деякі фільтри в цьому списку вимагають щонайменше Adblock Plus ?1? для коректної роботи. Можливо, вам краще оновити вашу версію Adblock Plus, перш ніж імпортувати цей список.
+import_filters_warning=Ви хочете замінити існуючі фільтри або додати фільтри, що імпортуються, в кінець?
+import_filters_title=Імпорт фільтрів
+export_filters_title=Експорт фільтрів
+invalid_filters_file=Файл не містить списку фільтрів для Adblock Plus.
+filters_write_error=При записі фільтрів у файл виникла помилка. Можливо на файлі встановлено захист від запису або він використовується іншою програмою.
+clearall_warning=Ви впевнені, що хочете стерти всі фільтри?
+resethitcounts_warning=Ви впевнені, що хочете обнулити статистику для всіх фільтрів? Зауважте: це незворотня дія.
+resethitcounts_selected_warning=Ви впевнені, що ви хочете обнулити статистику для відмічених фільтрів? Зауважте, це незворотня дія!
+filter_regexp_tooltip=Цей фільтр або регулярний вираз або закороткий для оптимізування. Забагато фільтрів можуть вповільнити перегляд сторінок
+filter_elemhide_duplicate_id=Можна вказати лише один ID приховуваного елемента
+filter_elemhide_nocriteria=Не вказаний критерій за яким упізнати приховуваний елемент
+subscription_notAdded_warning=Ви не додали підписку на фільтри. Без підписки вам треба буде додавати фільтри Adblock Plus вручну.
+subscription_notAdded_warning_addendum=Хочете продовжити?
+subscription_invalid_location=Не вдалося розпізнати введену адресу ні як інтернет адресу, ні як шлях до файлу.
+synchronize_invalid_url=Помилка, невірна адреса
+synchronize_connection_error=Помилка, неможливо викачати
+synchronize_invalid_data=Помилка, не список фільтрів
+synchronize_checksum_mismatch=Помилка, не збіглась контрольна сума
+synchronize_ok=Успіх
+overwrite=Замінити
+append=Додати
+new_filter_group_title=Новий фільтр
+type_label_other=Невідомий
+type_label_script=Скрипт
+type_label_image=Зображення
+type_label_stylesheet=Стилі
+type_label_object=Об’єкт
+type_label_subdocument=Фрейм
+type_label_document=Документ
+type_label_background=Тло
+type_label_elemhide=Приховане
+type_label_xbl=XBL прив’язка
+type_label_ping=Клацання по посиланню
+type_label_xmlhttprequest=XML-запит
+type_label_object_subrequest=Запит об’єкта
+type_label_dtd=DTD
+type_label_media=аудіо/відео
+type_label_font=шрифт
+fennec_status_enabled=Adblock Plus увімкнено.
+fennec_status_disabled=Adblock Plus вимкнено.
+fennec_status_enabled_site=Adblock Plus увімкнено для ?1?.
+fennec_status_disabled_site=Adblock Plus вимкнено для ?1?.

=== added file 'chrome/locale/uk/meta.properties'
--- chrome/locale/uk/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/uk/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Тимофій Бабич
+name=Adblock Plus
+description=Скажи «НІ» рекламі!
+description.short=Дратують реклами? Непокоїть стеження? Набридли банери? Встановіть Adblock Plus щоб повернути собі владу над інтернетом, щоб змінити те, якою ви бачите мережу.\n\nКороткий відеоогляд знаходиться на http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Встановіть Adblock Plus щоб повернути собі владу над інтернетом, щоб бачити мережу такою, як вам того хочеться. До цього додатку є більше сорока фільтрових підписок десятками мов. Це дозволяє автоматично налаштувати його на будь-які потреби, від прибирання онлайнової реклами до блокування всіх відомих зловмисних сайтів. Adblock Plus також дозволяє настроювати ваші фільтри з допомогою безлічі корисних можливостей. Таких як контекстна команда для зображень, владка блокування для об’єктів Flash та Java та повний перелік елементів сторінки для блокування скриптів та стилів.

=== added file 'chrome/locale/uk/overlay.dtd'
--- chrome/locale/uk/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/uk/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Статус:">
+<!ENTITY blocked.tooltip "Заблоковані елементи на цій сторінці:">
+<!ENTITY filters.tooltip "Найбільш часто застосовані фільтри:">
+<!ENTITY menuitem.label "Налаштування Adblock Plus">
+<!ENTITY menuitem.accesskey "A">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: елементи сторінки">
+<!ENTITY context.image.label "Adblock Plus: заблокувати зображення">
+<!ENTITY context.object.label "Adblock Plus: заблокувати об’єкт">
+<!ENTITY context.frame.label "Adblock Plus: заблокувати фрейм">
+<!ENTITY context.media.label "Adblock Plus: Блокувати аудіо/відео">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Знов увімкнути для цієї сторінки">
+<!ENTITY sidebar.title "Елементи відкритої сторінки">
+<!ENTITY settings.label "Налаштування">
+<!ENTITY settings.accesskey "ш">
+<!ENTITY opensidebar.label "Відкрити список елементів">
+<!ENTITY opensidebar.accesskey "п">
+<!ENTITY closesidebar.label "Закрити список елементів">
+<!ENTITY closesidebar.accesskey "п">
+<!ENTITY whitelist.site.label "Вимкнути: на ?1?">
+<!ENTITY whitelist.page.label "Вимкнути: тільки на цій сторінці">
+<!ENTITY objecttab.title "Заблокувати">
+<!ENTITY objecttab.tooltip "Натисніть тут, щоб заблокувати цей об’єкт">

=== added file 'chrome/locale/uk/settings.dtd'
--- chrome/locale/uk/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/uk/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Adblock Plus - Налаштування">
+<!ENTITY filters.label "Фільтри">
+<!ENTITY filters.accesskey "і">
+<!ENTITY add.label "Додати фільтр">
+<!ENTITY add.accesskey "д">
+<!ENTITY addsubscription.label "Додати підписку">
+<!ENTITY addsubscription.accesskey "о">
+<!ENTITY synchsubscriptions.label "Викачати всі підписки">
+<!ENTITY synchsubscriptions.accesskey "п">
+<!ENTITY import.label "Імпорт фільтрів">
+<!ENTITY import.accesskey "м">
+<!ENTITY export.label "Експорт фільтрів">
+<!ENTITY export.accesskey "к">
+<!ENTITY clearall.label "Стерти всі фільтри">
+<!ENTITY clearall.accesskey "и">
+<!ENTITY resethitcounts.label "Обнулити статистику попадань">
+<!ENTITY resethitcounts.accesskey "у">
+<!ENTITY edit.label "Правка">
+<!ENTITY edit.accesskey "р">
+<!ENTITY cut.label "Вирізати">
+<!ENTITY cut.accesskey "р">
+<!ENTITY copy.label "Копіювати">
+<!ENTITY copy.accesskey "о">
+<!ENTITY paste.label "Вставити">
+<!ENTITY paste.accesskey "а">
+<!ENTITY remove.label "Вилучити">
+<!ENTITY remove.accesskey "и">
+<!ENTITY menu.find.label "Знайти фільтр">
+<!ENTITY menu.find.accesskey "н">
+<!ENTITY menu.findagain.label "Знайти наступний">
+<!ENTITY menu.findagain.accesskey "т">
+<!ENTITY view.label "Вигляд">
+<!ENTITY view.accesskey "В">
+<!ENTITY sort.label "Сортувати за">
+<!ENTITY sort.accesskey "С">
+<!ENTITY sort.none.label "Несортовано">
+<!ENTITY sort.none.accesskey "Н">
+<!ENTITY sort.ascending.label "Від А до Я">
+<!ENTITY sort.ascending.accesskey "А">
+<!ENTITY sort.descending.label "Від Я до А">
+<!ENTITY sort.descending.accesskey "Я">
+<!ENTITY options.label "Налаштування">
+<!ENTITY options.accesskey "а">
+<!ENTITY enable.label "Увімкнути Adblock Plus">
+<!ENTITY enable.accesskey "У">
+<!ENTITY showintoolbar.label "Показувати в панелі інструментів">
+<!ENTITY showintoolbar.accesskey "к">
+<!ENTITY showinstatusbar.label "Показувати в рядку стану">
+<!ENTITY showinstatusbar.accesskey "с">
+<!ENTITY objecttabs.label "Показувати ярлик на Flash і Java">
+<!ENTITY objecttabs.accesskey "я">
+<!ENTITY collapse.label "Згортати заблоковані елементи">
+<!ENTITY collapse.accesskey "о">
+<!ENTITY help.label "Довідка">
+<!ENTITY help.accesskey "о">
+<!ENTITY gettingStarted.label "Початківцям">
+<!ENTITY gettingStarted.accesskey "П">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Питання, що часто ставляться (англійською)">
+<!ENTITY faq.accesskey "и">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Складання фільтрів для Adblock Plus (англійською)">
+<!ENTITY filterdoc.accesskey "а">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Про Adblock Plus">
+<!ENTITY about.accesskey "о">
+<!ENTITY description "Наступні фільтри визначають які адреси блокуються та які дозволяються:">
+<!ENTITY filter.column "Правило фільтрування">
+<!ENTITY filter.accesskey "ф">
+<!ENTITY slow.column "Повільні фільтри">
+<!ENTITY slow.accesskey "і">
+<!ENTITY enabled.column "Увімкнено">
+<!ENTITY enabled.accesskey "в">
+<!ENTITY hitcount.column "Попадань">
+<!ENTITY hitcount.accesskey "п">
+<!ENTITY lasthit.column "Останнє попадання">
+<!ENTITY lasthit.accesskey "О">
+<!ENTITY context.edit.label "Редагувати фільтр">
+<!ENTITY context.resethitcount.label "Обнулити статистику попадань для фільтру">
+<!ENTITY context.synchsubscription.label "Викачати фільтри наново">
+<!ENTITY context.editsubscription.label "Редагувати підписку">
+<!ENTITY context.moveup.label "Зрушити вгору">
+<!ENTITY context.movedown.label "Зрушити вниз">
+<!ENTITY context.movegroupup.label "Зрушити групу вгору">
+<!ENTITY context.movegroupdown.label "Зрушити групу вниз">
+<!ENTITY context.enable.label "Увімкнути">
+<!ENTITY context.disable.label "Вимкнути">
+<!ENTITY apply.label "Застосувати">
+<!ENTITY apply.accesskey "т">
+<!ENTITY fennec.subscription.label "Фільтрові підписки">

=== added file 'chrome/locale/uk/sidebar.dtd'
--- chrome/locale/uk/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/uk/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: елементи відкритої сторінки (від’єднані)">
+<!ENTITY detach.label "Від’єднати">
+<!ENTITY reattach.label "Приєднати">
+<!ENTITY search.label "Пошук:">
+<!ENTITY search.accesskey "о">
+<!ENTITY type.label "Тип">
+<!ENTITY address.label "Адреса">
+<!ENTITY filter.label "Фільтр">
+<!ENTITY state.label "Статус">
+<!ENTITY size.label "Розмір">
+<!ENTITY docDomain.label "Джерело документа">
+<!ENTITY noitems.label "Блокувати нічого">
+<!ENTITY whitelisted.label "Дозволений на цій сторінці">
+<!ENTITY tooltip.address.label "Адреса:">
+<!ENTITY tooltip.type.label "Тип:">
+<!ENTITY tooltip.type.blocked "(заблокований)">
+<!ENTITY tooltip.type.whitelisted "(виняток)">
+<!ENTITY tooltip.size.label "Розмір:">
+<!ENTITY tooltip.docDomain.label "Джерело документа:">
+<!ENTITY tooltip.filter.label "Застосований фільтр:">
+<!ENTITY tooltip.filterSource.label "Джерело фільтра:">
+<!ENTITY context.block.label "Заблокувати елемент">
+<!ENTITY context.editfilter.label "Відредагувати застосований фільтр">
+<!ENTITY context.whitelist.label "Вказати елемент як виняток">
+<!ENTITY context.disablefilter.label "Вимкнути фільтр ?1?">
+<!ENTITY context.enablefilter.label "Знов увімкнути фільтр ?1?">
+<!ENTITY context.disablefilteronsite.label "Вимкнути цей фільтр на ?1?">
+<!ENTITY context.open.label "Відкрити в новій вкладці">
+<!ENTITY context.flash.label "Показати розташування елементу">
+<!ENTITY context.copy.label "Копіювати адресу">
+<!ENTITY context.copyFilter.label "Копіювати фільтр">
+<!ENTITY context.selectAll.label "Вибрати всі">

=== added file 'chrome/locale/uk/subscriptionSelection.dtd'
--- chrome/locale/uk/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/uk/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Додати підписку на фільтри Adblock Plus">
+<!ENTITY dialog.title.edit "Редагувати підписку">
+<!ENTITY description.newInstall "Adblok Plus буде найефективніший якщо ви додасте фільтрову підписку. Фільтрові підписки надаються іншими користувачами Adblock Plus безплатно. Найбільш підходящі для вашої мови підписки вже вибрані.">
+<!ENTITY adblock.warning "Adblock Plus помітив що встановлено Adblock чи стару версію Adblock Plus. Паралельне використання Adblock та Adblock Plus может спричинити проблеми ти тому цього слід уникати. Рекомендуємо вам зараз вилучити Adblock.">
+<!ENTITY adblock.uninstall "Вилучити Adblock">
+<!ENTITY filterset.g.warning "Схоже що ви використовуєте Filterset.G. Цей список фільтрів ледве підтримується останні кілька років і є основною причиною проблем з веб-сайтами. Радимо вам вилучити зараз Filterset.G">
+<!ENTITY filterset.g.moreinfo "Докладніше">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Вилучити Filterset.G">
+<!ENTITY subscriptionSelector.label "Будь ласка виберіть фільтрову підписку з переліку:">
+<!ENTITY viewList.label "Глянути фільтри">
+<!ENTITY visitHomepage.label "Відвідати домашню сторінку">
+<!ENTITY addSubscription.label "Додати підписку">
+<!ENTITY saveSubscription.label "Зберегти підписку">
+<!ENTITY other.label "Додати іншу підписку">
+<!ENTITY other.accesskey "о">
+<!ENTITY list.download.failed "Adblock Plus не зміг отримати перелік підписок">
+<!ENTITY list.download.retry "Спробувати ще раз">
+<!ENTITY list.download.website "Глянути сайт">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "Будь ласка підтвердіть що ви бажаєте додати цю фільтрову підписку. Ви можете змінити назву чи знаходження перед додаванням.">
+<!ENTITY edit.description "Ви можете змінити назву чи знаходження підписки якщо потрібно.">
+<!ENTITY external.description "Це зовнішня фільтрова підписка. Вона буде оновлюватись додатком що створив цю підписку.">
+<!ENTITY title.label "Назва підписки:">
+<!ENTITY title.accesskey "а">
+<!ENTITY location.label "Адреса списку фільтрів:">
+<!ENTITY location.accesskey "е">
+<!ENTITY autodownload.label "Оновлювати автоматично">
+<!ENTITY autodownload.accesskey "о">
+<!ENTITY supplementMessage "Ця фільтрова підписка призначеня для використання в парі з фільтровою підпискою «?1?», котру ви наразі не використовуєте.">
+<!ENTITY addMain.label "Додати також фільтрову підписку «?1?»">
+<!ENTITY addMain.accesskey "Д">

=== added directory 'chrome/locale/vi'
=== removed directory 'chrome/locale/vi-VN'
=== removed file 'chrome/locale/vi-VN/about.dtd'
--- chrome/locale/vi-VN/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/vi-VN/about.dtd	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-<!ENTITY dialog.title "Giới thiệu Adblock Plus">
-<!ENTITY caption.title "Adblock Plus">
-<!ENTITY version.title "Phiên bản">
-<!ENTITY description "Adblock Plus cho phép bạn quyết định những thứ bạn không muốn xem trên mạng. Bạn không cần phải tải tất cả các hình ảnh quảng cáo nữa. Nếu bạn không muốn chúng, chỉ cần nói với Adblock Plus!">
-<!ENTITY homepage.label "Trang chủ Adblock Plus:">
-<!ENTITY homepage.url "http://adblockplus.org/">
-<!ENTITY author.label "Tác giả:">
-<!ENTITY contributors.label "Những người đóng góp:">

=== removed file 'chrome/locale/vi-VN/composer.dtd'
--- chrome/locale/vi-VN/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/vi-VN/composer.dtd	1970-01-01 00:00:00 +0000
@@ -1,50 +0,0 @@
-<!ENTITY dialog.title "Thêm quy tắc lọc Adblock Plus">
-<!ENTITY accept.label "Thêm bộ lọc">
-<!ENTITY advanced.label "Hiển thị nâng cao">
-<!ENTITY basic.label "Hiển thị cơ bản">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus hiện đang bị vô hiệu hóa. Bạn vẫn có thể thêm các bộ lọc nhưng chúng sẽ không được áp dụng trừ khi bạn">
-<!ENTITY disabled.warning.link "kích hoạt Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "Nhóm bộ lọc &quot;&#37;S&quot;, mà bộ lọc này nên được đưa vào, hiện đang bị vô hiệu hóa. Bạn vẫn có thể thêm các bộ lọc nhưng chúng sẽ không được áp dụng trừ khi bạn">
-<!ENTITY groupDisabled.warning.link "kích hoạt nhóm bộ lọc">
-<!ENTITY groupDisabled.warning.afterLink ".">
-<!ENTITY filter.label "Bộ lọc mới:">
-<!ENTITY filter.accesskey "l">
-<!ENTITY preferences.label "Hiện các bộ lọc đang có...">
-<!ENTITY preferences.accesskey "H">
-<!ENTITY type.filter.label "Bộ lọc chặn">
-<!ENTITY type.filter.accesskey "B">
-<!ENTITY type.whitelist.label "Quy luật ngoại lệ">
-<!ENTITY type.whitelist.accesskey "Q">
-<!ENTITY pattern.label "Tìm mẫu">
-<!ENTITY pattern.explanation "Mẫu có thể là bất kì phần nào của địa chỉ, biểu tượng * được dùng như một mặt nạ. Bộ lọc sẽ chỉ được áp dụng cho những địa chỉ phù hợp với mẫu.">
-<!ENTITY regexp.warning "Mẫu bạn gõ vào sẽ được xem là biểu thức quy tắc. Nhiều biểu thức quy tắc có thể làm chậm việc duyệt web của bạn. Nếu bạn không định dùng biểu thức quy tắc, hãy thêm một biểu tượng * ở cuối mẫu.">
-<!ENTITY shortpattern.warning "Mẫu bạn gõ vào quá ngắn để tối ưu hóa, nhiều mẫu như vậy có thể làm chậm việc duyệt web của bạn. Lời khuyên là bạn hãy chọn một chuỗi dài hơn cho bộ lọc này.">
-<!ENTITY custom.pattern.label "Tùy biến:">
-<!ENTITY custom.pattern.accesskey "y">
-<!ENTITY anchors.label "Chỉ chấp nhận mẫu:">
-<!ENTITY anchor.start.label "ở đầu địa chỉ">
-<!ENTITY anchor.start.accesskey "u">
-<!ENTITY anchor.start.flexible.label "ở đầu tên miền">
-<!ENTITY anchor.start.flexible.accesskey "u">
-<!ENTITY anchor.end.label "ở cuối địa chỉ">
-<!ENTITY anchor.end.accesskey "i">
-<!ENTITY options.label "Tùy chọn">
-<!ENTITY domainRestriction.label "Giới hạn trên miền:">
-<!ENTITY domainRestriction.accesskey "r">
-<!ENTITY domainRestriction.help "Chọn một hay nhiều tên miền ngăn cách bằng dấu &quot;|&quot;, bộ lọc sẽ chỉ được áp dụng trên những tên miền này. Dấu &quot;~&quot; trước một tên miền có nghĩa là bộ lọc sẽ không được áp dụng cho tên miền đó.">
-<!ENTITY firstParty.label "Chỉ của bên thứ nhất">
-<!ENTITY firstParty.accesskey "n">
-<!ENTITY thirdParty.label "Chỉ của bên thứ ba">
-<!ENTITY thirdParty.accesskey "a">
-<!ENTITY matchCase.label "Phân biệt HOA thường">
-<!ENTITY matchCase.accesskey "P">
-<!ENTITY types.label "Áp dụng cho các kiểu:">
-<!ENTITY selectAllTypes.label "Chọn tất cả">
-<!ENTITY unselectAllTypes.label "Không chọn">
-<!ENTITY collapse.label "Thu gọn những mục bị chặn:">
-<!ENTITY collapse.accesskey "T">
-<!ENTITY collapse.default.yes.label "Dùng mặc định (có)">
-<!ENTITY collapse.default.no.label "Dùng mặc định (không)">
-<!ENTITY collapse.yes.label "Có">
-<!ENTITY collapse.no.label "Không">

=== removed file 'chrome/locale/vi-VN/global.properties'
--- chrome/locale/vi-VN/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/vi-VN/global.properties	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=Quảng cáo đã là dĩ vãng!
-status_active_label=Adblock
-status_disabled_label=Bị vô hiệu hóa
-action0_tooltip=Nhấn chuột trái để hiển thị trình đơn ngữ cảnh, nhấn chuột giữa để bật/tắt.
-action1_tooltip=Nhấn chuột trái để mở/đóng các mục có thể chặn được, nhấn chuột giữa để bật/tắt.
-action2_tooltip=Nhấn chuột trái để mở tùy chọn, nhấn chuột giữa để bật/tắt.
-action3_tooltip=Nhấn để bật/tắt Adblock Plus.
-active_tooltip=Adblock Plus đang hoạt động.
-disabled_tooltip=Adblock Plus đang tắt.
-whitelisted_tooltip=Adblock Plus đang hoạt động nhưng bị vô hiệu hóa trên trang hiện tại.
-blocked_count_tooltip=-- trong --
-no_blocking_suggestions=Không có mục nào trong trang hiện tại có thể chặn được
-whitelisted_page=Adblock Plus đã bị vô hiệu hóa cho trang hiện tại
-whitelist_description=Quy luật Ngoại lệ của Tôi
-filterlist_description=Quy luật Chặn quảng cáo của Tôi
-invalid_description=Quy luật Bất hợp lệ của Tôi
-elemhide_description=Quy luật Ẩn phần tử của Tôi
-subscription_description=Bộ lọc trọn gói:
-subscription_wrong_version=Một số bộ lọc trong bộ trọn gói này cần Adblock Plus -- để hoạt động đúng!
-subscription_source=Nguồn:
-subscription_status=Trạng thái:
-subscription_status_autodownload=Cập nhật tự động
-subscription_status_manualdownload=Cập nhật thủ công
-subscription_status_externaldownload=Cập nhật từ bên ngoài (phần mở rộng khác)
-subscription_status_lastdownload=Lần tải cuối:
-subscription_status_lastdownload_inprogress=Đang tải...
-subscription_status_lastdownload_unknown=N/A
-remove_subscription_warning=Bạn có thật sự muốn xóa bộ trọn gói này không?
-import_filters_wrong_version=Cảnh báo: một số bộ lọc trong danh sách này cần Adblock Plus -- để hoạt động đúng. Có lẽ bạn nên nâng cấp lên phiên bản mới nhất của Adblock Plus trước khi nhập danh sách này.
-import_filters_warning=Bạn muốn ghi đè lên các bộ lọc hiện tại hay chèn vào cuối danh sách?
-import_filters_title=Nhập bộ lọc
-export_filters_title=Xuất bộ lọc
-invalid_filters_file=Không phải là tập tin bộ lọc hợp lệ của Adblock Plus.
-filters_write_error=Có lỗi khi chép bộ lọc vào tập tin. Hãy chắc chắn rằng tập tin không bị chống ghi hay đang bị sử dụng bởi một chương trình khác.
-clearall_warning=Bạn có thật sự muốn xóa tất cả các bộ lọc trong danh sách không?
-resethitcounts_warning=Bạn có thật sự muốn đặt lại số lần hit của tất cả bộ lọc về 0? Thao tác này không thể hoàn tác được!
-resethitcounts_selected_warning=Bạn có thật sự muốn đặt lại số lần hit của các bộ lọc đã chọn về 0? Thao tác này không thể hoàn tác được!
-filter_regexp_tooltip=Bộ lọc này là một biểu thức quy tắc hoặc là do quá ngắn nên không tối ưu hóa được. Quá nhiều bộ lọc như thế này có thể làm chậm việc duyệt web của bạn.
-filter_elemhide_duplicate_id=Chỉ có thể xác định một ID của phần tử bị ẩn
-filter_elemhide_nocriteria=Không có chuẩn để nhận diện các phần tử bị ẩn
-subscription_no_location=Vui lòng nhập địa chỉ để tải bộ lọc.
-subscription_invalid_location=Địa chỉ để tải bộ lọc không phải là một URL hay tên tập tin hợp lệ.
-subscription_location_exists=Bạn đã đăng kí vào danh sách bộ lọc này.
-synchronize_invalid_url=Thất bại, không phải là địa chỉ hợp lệ
-synchronize_connection_error=Thất bại, tải xuống thất bại
-synchronize_invalid_data=Thất bại, không phải là danh sách bộ lọc hợp lệ
-synchronize_checksum_mismatch=Thất bại, mã băm không phù hợp
-synchronize_ok=Thành công
-overwrite=Ghi đè
-append=Chèn vào cuối
-new_filter_group_title=Bộ lọc mới
-type_label_other=khác
-type_label_script=script
-type_label_image=ảnh
-type_label_stylesheet=stylesheet
-type_label_object=đối tượng
-type_label_subdocument=khung
-type_label_document=tài liệu
-type_label_background=nền
-type_label_elemhide=ẩn
-type_label_xbl=XBL binding
-type_label_ping=ping liên kết
-type_label_xmlhttprequest=yêu cầu XML
-type_label_object_subrequest=subrequest đối tượng
-type_label_dtd=DTD
-type_label_media=tiếng/phim
-type_label_font=phông

=== removed file 'chrome/locale/vi-VN/overlay.dtd'
--- chrome/locale/vi-VN/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/vi-VN/overlay.dtd	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<!ENTITY status.tooltip "Trạng thái:">
-<!ENTITY blocked.tooltip "Các mục bị chặn trong trang này:">
-<!ENTITY filters.tooltip "Các bộ lọc có hiệu lực nhất:">
-<!ENTITY menuitem.label "Tùy chọn Adblock Plus">
-<!ENTITY menuitem.accesskey "P">
-<!ENTITY toolbarbutton.label "Adblock Plus">
-<!ENTITY view.blockableItems.label "Adblock Plus: Các Mục Có Thể Chặn">
-<!ENTITY context.image.label "Adblock Plus: Chặn Ảnh">
-<!ENTITY context.object.label "Adblock Plus: Chặn Đối Tượng">
-<!ENTITY context.frame.label "Adblock Plus: Chặn Khung">
-<!ENTITY context.removeWhitelist.label "Adblock Plus: Kích Hoạt Lại trên Trang Này">
-<!ENTITY sidebar.title "Các mục bị chặn trên trang hiện tại">
-<!ENTITY settings.label "Tùy chọn">
-<!ENTITY settings.accesskey "T">
-<!ENTITY opensidebar.label "Mở các mục có thể chặn được">
-<!ENTITY opensidebar.accesskey "m">
-<!ENTITY closesidebar.label "Đóng các mục có thể chặn được">
-<!ENTITY closesidebar.accesskey "m">
-<!ENTITY whitelist.site.label "Vô hiệu hóa trên --">
-<!ENTITY whitelist.page.label "Chỉ vô hiệu hóa trên trang này">
-<!ENTITY objecttab.title "Chặn">
-<!ENTITY objecttab.tooltip "Nhấn vào đây để chặn đối tượng này với Adblock Plus">

=== removed file 'chrome/locale/vi-VN/settings.dtd'
--- chrome/locale/vi-VN/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/vi-VN/settings.dtd	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-<!ENTITY dialog.title "Tùy chọn Adblock Plus">
-<!ENTITY filters.label "Bộ lọc">
-<!ENTITY filters.accesskey "B">
-<!ENTITY add.label "Thêm bộ lọc">
-<!ENTITY add.accesskey "T">
-<!ENTITY addsubscription.label "Thêm bộ lọc trọn gói">
-<!ENTITY addsubscription.accesskey "m">
-<!ENTITY synchsubscriptions.label "Cập nhật tất cả bộ lọc trọn gói">
-<!ENTITY synchsubscriptions.accesskey "C">
-<!ENTITY import.label "Nhập các bộ lọc">
-<!ENTITY import.accesskey "N">
-<!ENTITY export.label "Xuất các bộ lọc tùy biến">
-<!ENTITY export.accesskey "u">
-<!ENTITY clearall.label "Xóa tất cả bộ lọc tùy biến">
-<!ENTITY clearall.accesskey "X">
-<!ENTITY resethitcounts.label "Đặt lại số lần hit về 0">
-<!ENTITY resethitcounts.accesskey "l">
-<!ENTITY edit.label "Chỉnh sửa">
-<!ENTITY edit.accesskey "C">
-<!ENTITY cut.label "Cắt">
-<!ENTITY cut.accesskey "T">
-<!ENTITY copy.label "Chép">
-<!ENTITY copy.accesskey "C">
-<!ENTITY paste.label "Dán">
-<!ENTITY paste.accesskey "D">
-<!ENTITY remove.label "Xóa">
-<!ENTITY remove.accesskey "X">
-<!ENTITY menu.find.label "Tìm">
-<!ENTITY menu.find.accesskey "m">
-<!ENTITY menu.findagain.label "Tìm Lại">
-<!ENTITY menu.findagain.accesskey "i">
-<!ENTITY view.label "Hiển thị">
-<!ENTITY view.accesskey "H">
-<!ENTITY sort.label "Sắp xếp theo">
-<!ENTITY sort.accesskey "x">
-<!ENTITY sort.none.label "Chưa sắp xếp">
-<!ENTITY sort.none.accesskey "C">
-<!ENTITY sort.ascending.label "Thứ tự A &gt; Z">
-<!ENTITY sort.ascending.accesskey "A">
-<!ENTITY sort.descending.label "Thứ tự Z &gt; A">
-<!ENTITY sort.descending.accesskey "Z">
-<!ENTITY options.label "Tùy chọn">
-<!ENTITY options.accesskey "y">
-<!ENTITY enable.label "Bật Adblock Plus">
-<!ENTITY enable.accesskey "B">
-<!ENTITY showintoolbar.label "Hiện trong thanh công cụ">
-<!ENTITY showintoolbar.accesskey "c">
-<!ENTITY showinstatusbar.label "Hiện trong thanh trạng thái">
-<!ENTITY showinstatusbar.accesskey "r">
-<!ENTITY objecttabs.label "Hiện thẻ trên Flash và Java">
-<!ENTITY objecttabs.accesskey "t">
-<!ENTITY collapse.label "Thu gọn các phần tử bị chặn">
-<!ENTITY collapse.accesskey "u">
-<!ENTITY help.label "Trợ giúp">
-<!ENTITY help.accesskey "p">
-<!ENTITY gettingStarted.label "Bắt đầu">
-<!ENTITY gettingStarted.accesskey "B">
-<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
-<!ENTITY faq.label "Câu hỏi Thường gặp">
-<!ENTITY faq.accesskey "C">
-<!ENTITY faq.url "http://adblockplus.org/en/faq">
-<!ENTITY filterdoc.label "Hướng dẫn viết bộ lọc cho Adblock Plus">
-<!ENTITY filterdoc.accesskey "H">
-<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
-<!ENTITY about.label "Giới thiệu Adblock Plus">
-<!ENTITY about.accesskey "G">
-<!ENTITY description "Những bộ lọc sau xác định những địa chỉ nào sẽ bị chặn và những địa chỉ nào sẽ được cho phép:">
-<!ENTITY filter.column "Quy luật lọc">
-<!ENTITY filter.accesskey "Q">
-<!ENTITY slow.column "Bộ lọc chậm">
-<!ENTITY slow.accesskey "B">
-<!ENTITY enabled.column "Hiệu lực">
-<!ENTITY enabled.accesskey "H">
-<!ENTITY hitcount.column "Số lần hit">
-<!ENTITY hitcount.accesskey "S">
-<!ENTITY lasthit.column "Lần hit cuối">
-<!ENTITY lasthit.accesskey "L">
-<!ENTITY context.edit.label "Chỉnh sửa bộ lọc">
-<!ENTITY context.resethitcount.label "Đặt lại số lần hit của bộ lọc về 0">
-<!ENTITY context.synchsubscription.label "Cập nhật bộ trọn gói ngay bây giờ">
-<!ENTITY context.editsubscription.label "Chỉnh sửa bộ trọn gói">
-<!ENTITY context.moveup.label "Di chuyển bộ lọc lên trên">
-<!ENTITY context.movedown.label "Di chuyển bộ lọc xuống dưới">
-<!ENTITY context.movegroupup.label "Di chuyển nhóm lên trên">
-<!ENTITY context.movegroupdown.label "Di chuyển nhóm xuống dưới">
-<!ENTITY context.enable.label "Kích hoạt">
-<!ENTITY context.disable.label "Vô hiệu hóa">
-<!ENTITY apply.label "Áp dụng">
-<!ENTITY apply.accesskey "d">

=== removed file 'chrome/locale/vi-VN/sidebar.dtd'
--- chrome/locale/vi-VN/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/vi-VN/sidebar.dtd	1970-01-01 00:00:00 +0000
@@ -1,32 +0,0 @@
-<!ENTITY detached.title "Adblock Plus: các mục có thể chặn (tách rời)">
-<!ENTITY detach.label "Tách rời">
-<!ENTITY reattach.label "Đính lại">
-<!ENTITY search.label "Tìm:">
-<!ENTITY search.accesskey "m">
-<!ENTITY type.label "Kiểu">
-<!ENTITY address.label "Địa chỉ">
-<!ENTITY filter.label "Bộ lọc">
-<!ENTITY state.label "Tình trạng">
-<!ENTITY size.label "Kích thước">
-<!ENTITY docDomain.label "Nguồn tài liệu">
-<!ENTITY noitems.label "Không có mục nào có thể chặn được">
-<!ENTITY whitelisted.label "Trang nằm trong sổ trắng">
-<!ENTITY tooltip.address.label "Địa chỉ:">
-<!ENTITY tooltip.type.label "Kiểu:">
-<!ENTITY tooltip.type.blocked "(đã chặn)">
-<!ENTITY tooltip.type.whitelisted "(sổ trắng)">
-<!ENTITY tooltip.size.label "Kích thước:">
-<!ENTITY tooltip.docDomain.label "Nguồn tài liệu:">
-<!ENTITY tooltip.filter.label "Bộ lọc đang chặn:">
-<!ENTITY tooltip.filterSource.label "Nguồn bộ lọc:">
-<!ENTITY context.block.label "Chặn mục này">
-<!ENTITY context.editfilter.label "Chỉnh sửa bộ lọc đang chặn">
-<!ENTITY context.whitelist.label "Thêm quy luật ngoại lệ cho mục">
-<!ENTITY context.disablefilter.label "Vô hiệu hóa bộ lọc --">
-<!ENTITY context.enablefilter.label "Kích hoạt lại bộ lọc --">
-<!ENTITY context.disablefilteronsite.label "Vô hiệu hóa bộ lọc này trên --">
-<!ENTITY context.open.label "Mở trong Thẻ Mới">
-<!ENTITY context.flash.label "Nhấp nháy quanh viền của mục này">
-<!ENTITY context.copy.label "Chép địa chỉ của mục này">
-<!ENTITY context.copyFilter.label "Chép bộ lọc">
-<!ENTITY context.selectAll.label "Chọn tất cả">

=== removed file 'chrome/locale/vi-VN/subscription.dtd'
--- chrome/locale/vi-VN/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/vi-VN/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-<!ENTITY dialog.title "Chỉnh sửa bộ lọc trọn gói">
-<!ENTITY dialog.newtitle "Thêm bộ lọc trọn gói">
-<!ENTITY new.description "Vui lòng nhập địa chỉ web hay tập tin chứa danh sách bộ lọc cho Adblock Plus.">
-<!ENTITY edit.description "Danh sách bộ lọc cho bộ trọn gói này sẽ được tải từ địa chỉ đã cho.">
-<!ENTITY external.description "Đây là một bộ lọc trọn gói từ bên ngoài, danh sách bộ lọc của nó sẽ được cập nhật bởi phần mở rộng đã tạo ra bộ lọc đăng kí này.">
-<!ENTITY autodownload.description "Nếu bạn chọn &apos;Cập nhật tự động&apos;, địa chỉ này sẽ được kiểm tra để tìm bản cập nhật mỗi ngày. Nếu tùy chọn này bị vô hiệu hóa, bạn vẫn có thể kích hoạt cập nhật thủ công từ trình đơn ngữ cảnh của bộ lọc trọn gói.">
-<!ENTITY location.label "Địa chỉ của danh sách bộ lọc:">
-<!ENTITY location.accesskey "a">
-<!ENTITY title.label "Tiêu đề của bộ trọn gói:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "Cập nhật tự động">
-<!ENTITY autodownload.accesskey "C">
-<!ENTITY enabled.label "Kích hoạt các bộ lọc">
-<!ENTITY enabled.accesskey "K">

=== removed file 'chrome/locale/vi-VN/tip_subscriptions.dtd'
--- chrome/locale/vi-VN/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/vi-VN/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "Thêm bộ lọc trọn gói cho Adblock Plus">
-<!ENTITY description.par1 "Cám ơn bạn đã cài đặt Adblock Plus. Phần mở rộng này có thể triệt 99&#37; các hình ảnh quảng cáo mà bạn thấy trên mạng. Tuy nhiên, quá trình lọc quảng cáo một cách hiệu quả cần bạn phải định nghĩa một tập hợp các bộ lọc tốt. Bạn có thể tự tạo, hoặc chỉ cần đăng kí vào danh sách bộ lọc trọn gói mà những người khác đang duy trì. Bạn vẫn có thể thêm bộ lọc của chính mình cũng như vô hiệu hóa/xóa các bộ trọn gói khi cần thiết.">
-<!ENTITY description.par2 "Bạn có thể chọn một bộ trọn gói từ danh sách bên dưới (những bộ trọn gói khác vẫn có thể được thêm vào Tùy chọn Adblock Plus sau, mặc dù thông thường điều này là không cần thiết):">
-<!ENTITY note "Chú ý: Một danh sách bộ lọc thông thường có hiệu quả nhất khi áp dụng cho các trang web đến từ cùng khu vực mà danh sách bộ lọc đó được tạo ra. Bạn có thể vào &quot;Xem tất cả các bộ trọn gói&quot; để tải bộ dành riêng cho Việt Nam.">
-<!ENTITY adblock.warning "Adblock Plus nhận thấy Adblock hoặc một phiên bản cũ của Adblock Plus đã được cài. Chạy song song Adblock và Adblock Plus có thể gây ra vấn đề, cho nên hãy tránh làm vậy. Lời khuyên là bạn hãy gỡ bỏ Adblock ngay bây giờ.">
-<!ENTITY adblock.uninstall "Gỡ bỏ Adblock">
-<!ENTITY filterset.g.warning "Có vẻ như bạn đang dùng Filterset.G. Danh sách bộ lọc này đã không được duy trì trong suốt vài năm qua và là một nguyên nhân gây ra vấn đề với các trang web. Lời khuyên là bạn hãy gỡ bỏ Filterset.G ngay bây giờ.">
-<!ENTITY filterset.g.moreinfo "Thêm thông tin">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "Gỡ bỏ Filterset.G">
-<!ENTITY homepage.label "Trang chủ">
-<!ENTITY subscribe.label "Đăng kí">
-<!ENTITY subscribe.accesskey "k">
-<!ENTITY other.label "Thêm bộ lọc trọn gói khác">
-<!ENTITY other.accesskey "T">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "Xem tất cả các bộ trọn gói (có cả Việt Nam)">

=== added file 'chrome/locale/vi/about.dtd'
--- chrome/locale/vi/about.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/vi/about.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,12 @@
+<!ENTITY dialog.title "Giới thiệu Adblock Plus">
+<!ENTITY caption.title "Adblock Plus">
+<!ENTITY version.title "Phiên bản">
+<!ENTITY description "Adblock Plus cho phép bạn quyết định những thứ bạn không muốn xem trên mạng. Bạn không cần phải tải tất cả các hình ảnh quảng cáo nữa. Nếu bạn không muốn chúng, chỉ cần nói với Adblock Plus!">
+<!ENTITY homepage.label "Trang chủ Adblock Plus:">
+<!ENTITY homepage.url "http://adblockplus.org/">
+<!ENTITY author.label "Tác giả:">
+<!ENTITY contributors.label "Những người đóng góp:">
+<!ENTITY developers.label "Nhà phát triển:">
+<!ENTITY designers.label "Thiết kế đồ họa:">
+<!ENTITY subscriptionAuthors.label "Tác giả bộ lọc trọn gói:">
+<!ENTITY translators.label "Người dịch:">

=== added file 'chrome/locale/vi/composer.dtd'
--- chrome/locale/vi/composer.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/vi/composer.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,46 @@
+<!ENTITY dialog.title "Thêm quy tắc lọc Adblock Plus">
+<!ENTITY accept.label "Thêm bộ lọc">
+<!ENTITY advanced.label "Hiển thị nâng cao">
+<!ENTITY basic.label "Hiển thị cơ bản">
+<!ENTITY disabled.warning "Adblock Plus hiện đang bị vô hiệu hóa. Bạn vẫn có thể thêm các bộ lọc nhưng chúng sẽ không được áp dụng trừ khi bạn [link]kích hoạt Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "Nhóm bộ lọc &quot;?1?&quot;, mà bộ lọc này nên được đưa vào, hiện đang bị vô hiệu hóa. Bạn vẫn có thể thêm các bộ lọc nhưng chúng sẽ không được áp dụng trừ khi bạn [link]kích hoạt nhóm bộ lọc[/link].">
+<!ENTITY filter.label "Bộ lọc mới:">
+<!ENTITY filter.accesskey "l">
+<!ENTITY preferences.label "Hiện các bộ lọc đang có...">
+<!ENTITY preferences.accesskey "H">
+<!ENTITY type.filter.label "Bộ lọc chặn">
+<!ENTITY type.filter.accesskey "B">
+<!ENTITY type.whitelist.label "Quy luật ngoại lệ">
+<!ENTITY type.whitelist.accesskey "Q">
+<!ENTITY pattern.label "Tìm mẫu">
+<!ENTITY pattern.explanation "Mẫu có thể là bất kì phần nào của địa chỉ, biểu tượng * được dùng như một mặt nạ. Bộ lọc sẽ chỉ được áp dụng cho những địa chỉ phù hợp với mẫu.">
+<!ENTITY regexp.warning "Mẫu bạn gõ vào sẽ được xem là biểu thức quy tắc. Nhiều biểu thức quy tắc có thể làm chậm việc duyệt web của bạn. Nếu bạn không định dùng biểu thức quy tắc, hãy thêm một biểu tượng * ở cuối mẫu.">
+<!ENTITY shortpattern.warning "Mẫu bạn gõ vào quá ngắn để tối ưu hóa, nhiều mẫu như vậy có thể làm chậm việc duyệt web của bạn. Lời khuyên là bạn hãy chọn một chuỗi dài hơn cho bộ lọc này.">
+<!ENTITY custom.pattern.label "Tùy biến:">
+<!ENTITY custom.pattern.accesskey "y">
+<!ENTITY anchors.label "Chỉ chấp nhận mẫu:">
+<!ENTITY anchor.start.label "ở đầu địa chỉ">
+<!ENTITY anchor.start.accesskey "u">
+<!ENTITY anchor.start.flexible.label "ở đầu tên miền">
+<!ENTITY anchor.start.flexible.accesskey "u">
+<!ENTITY anchor.end.label "ở cuối địa chỉ">
+<!ENTITY anchor.end.accesskey "i">
+<!ENTITY options.label "Tùy chọn">
+<!ENTITY domainRestriction.label "Giới hạn trên miền:">
+<!ENTITY domainRestriction.accesskey "r">
+<!ENTITY domainRestriction.help "Chọn một hay nhiều tên miền ngăn cách bằng dấu &quot;|&quot;, bộ lọc sẽ chỉ được áp dụng trên những tên miền này. Dấu &quot;~&quot; trước một tên miền có nghĩa là bộ lọc sẽ không được áp dụng cho tên miền đó.">
+<!ENTITY firstParty.label "Chỉ của bên thứ nhất">
+<!ENTITY firstParty.accesskey "n">
+<!ENTITY thirdParty.label "Chỉ của bên thứ ba">
+<!ENTITY thirdParty.accesskey "a">
+<!ENTITY matchCase.label "Phân biệt HOA thường">
+<!ENTITY matchCase.accesskey "P">
+<!ENTITY types.label "Áp dụng cho các kiểu:">
+<!ENTITY selectAllTypes.label "Chọn tất cả">
+<!ENTITY unselectAllTypes.label "Không chọn">
+<!ENTITY collapse.label "Thu gọn những mục bị chặn:">
+<!ENTITY collapse.accesskey "T">
+<!ENTITY collapse.default.yes.label "Dùng mặc định (có)">
+<!ENTITY collapse.default.no.label "Dùng mặc định (không)">
+<!ENTITY collapse.yes.label "Có">
+<!ENTITY collapse.no.label "Không">

=== added file 'chrome/locale/vi/global.properties'
--- chrome/locale/vi/global.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/vi/global.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,70 @@
+default_dialog_title=Adblock Plus
+action0_tooltip=Nhấn chuột trái để hiển thị trình đơn ngữ cảnh, nhấn chuột giữa để bật/tắt.
+action1_tooltip=Nhấn chuột trái để mở/đóng các mục có thể chặn được, nhấn chuột giữa để bật/tắt.
+action2_tooltip=Nhấn chuột trái để mở tùy chọn, nhấn chuột giữa để bật/tắt.
+action3_tooltip=Nhấn để bật/tắt Adblock Plus.
+disabled_tooltip=Adblock Plus đang tắt.
+active_tooltip=Adblock Plus đang hoạt động, ?1? bộ lọc trọn gói và ?2? bộ lọc tùy biến đang được dùng.
+whitelisted_tooltip=Adblock Plus đang hoạt động nhưng bị vô hiệu hóa trên trang hiện tại.
+blocked_count_tooltip=?1? trong ?2?
+blocked_count_addendum=(trong danh sách trắng: ?1?, bị ẩn: ?2?)
+no_blocking_suggestions=Không có mục nào trong trang hiện tại có thể chặn được
+whitelisted_page=Adblock Plus đã bị vô hiệu hóa cho trang hiện tại
+whitelist_description=Quy luật Ngoại lệ của Tôi
+filterlist_description=Quy luật Chặn quảng cáo của Tôi
+invalid_description=Quy luật Bất hợp lệ của Tôi
+elemhide_description=Quy luật Ẩn phần tử của Tôi
+subscription_description=Bộ lọc trọn gói:
+subscription_wrong_version=Một số bộ lọc trong bộ trọn gói này cần Adblock Plus ?1? để hoạt động đúng!
+subscription_source=Nguồn:
+subscription_status=Trạng thái:
+subscription_status_autodownload=Cập nhật tự động
+subscription_status_manualdownload=Cập nhật thủ công
+subscription_status_externaldownload=Cập nhật từ bên ngoài (phần mở rộng khác)
+subscription_status_lastdownload=Lần tải cuối:
+subscription_status_lastdownload_inprogress=Đang tải...
+subscription_status_lastdownload_unknown=N/A
+remove_subscription_warning=Bạn có thật sự muốn xóa bộ trọn gói này không?
+import_filters_wrong_version=Cảnh báo: một số bộ lọc trong danh sách này cần Adblock Plus ?1? để hoạt động đúng. Có lẽ bạn nên nâng cấp lên phiên bản mới nhất của Adblock Plus trước khi nhập danh sách này.
+import_filters_warning=Bạn muốn ghi đè lên các bộ lọc hiện tại hay chèn vào cuối danh sách?
+import_filters_title=Nhập bộ lọc
+export_filters_title=Xuất bộ lọc
+invalid_filters_file=Không phải là tập tin bộ lọc hợp lệ của Adblock Plus.
+filters_write_error=Có lỗi khi chép bộ lọc vào tập tin. Hãy chắc chắn rằng tập tin không bị chống ghi hay đang bị sử dụng bởi một chương trình khác.
+clearall_warning=Bạn có thật sự muốn xóa tất cả các bộ lọc trong danh sách không?
+resethitcounts_warning=Bạn có thật sự muốn đặt lại số lần hit của tất cả bộ lọc về 0? Thao tác này không thể hoàn tác được!
+resethitcounts_selected_warning=Bạn có thật sự muốn đặt lại số lần hit của các bộ lọc đã chọn về 0? Thao tác này không thể hoàn tác được!
+filter_regexp_tooltip=Bộ lọc này là một biểu thức quy tắc hoặc là do quá ngắn nên không tối ưu hóa được. Quá nhiều bộ lọc như thế này có thể làm chậm việc duyệt web của bạn.
+filter_elemhide_duplicate_id=Chỉ có thể xác định một ID của phần tử bị ẩn
+filter_elemhide_nocriteria=Không có chuẩn để nhận diện các phần tử bị ẩn
+subscription_notAdded_warning=Bạn đã không thêm một bộ lọc trọn gói. Nếu không có bộ lọc trọn gói, bạn sẽ cần phải tự tạo bộ lọc Adblock Plus riêng.
+subscription_notAdded_warning_addendum=Bạn có muốn tiếp tục không?
+subscription_invalid_location=Địa chỉ để tải bộ lọc không phải là một URL hay tên tập tin hợp lệ.
+synchronize_invalid_url=Thất bại, không phải là địa chỉ hợp lệ
+synchronize_connection_error=Thất bại, tải xuống thất bại
+synchronize_invalid_data=Thất bại, không phải là danh sách bộ lọc hợp lệ
+synchronize_checksum_mismatch=Thất bại, mã băm không phù hợp
+synchronize_ok=Thành công
+overwrite=Ghi đè
+append=Chèn vào cuối
+new_filter_group_title=Bộ lọc mới
+type_label_other=khác
+type_label_script=script
+type_label_image=ảnh
+type_label_stylesheet=stylesheet
+type_label_object=đối tượng
+type_label_subdocument=khung
+type_label_document=tài liệu
+type_label_background=nền
+type_label_elemhide=ẩn
+type_label_xbl=XBL binding
+type_label_ping=ping liên kết
+type_label_xmlhttprequest=yêu cầu XML
+type_label_object_subrequest=subrequest đối tượng
+type_label_dtd=DTD
+type_label_media=tiếng/phim
+type_label_font=phông
+fennec_status_enabled=Adblock Plus đang bật.
+fennec_status_disabled=Adblock Plus đang tắt.
+fennec_status_enabled_site=Adblock Plus đang bật trên ?1?.
+fennec_status_disabled_site=Adblock Plus đang tắt trên ?1?.

=== added file 'chrome/locale/vi/meta.properties'
--- chrome/locale/vi/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/vi/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Nguyễn Mạnh Hùng
+name=Adblock Plus
+description=Quảng cáo đã là dĩ vãng!
+description.short=Bực bội vì quảng cáo? Khó chịu vì bị theo dõi? Phiền vì biểu ngữ (banner)? Cài đặt Adblock Plus ngay để giành lại quyền kiểm soát internet và thay đổi cách thức mà bạn xem web.\n\nXem đoạn phim giới thiệu ở http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus cho phép bạn giành lại quyền kiểm soát internet và xem web theo cách bạn muốn. Tiện ích này được hỗ trợ bởi hơn bốn mươi bộ lọc trọn gói với hàng chục ngôn ngữ, sẽ tự động cấu hình cho các mục đích từ gỡ bỏ quảng cáo trực tuyến cho đến việc chặn các tên miền chứa phần mềm độc hại. Adblock Plus cũng cho phép bạn tùy biến bộ lọc với sự hỗ trợ của nhiều tính năng hữu ích khác nhau, bao gồm tùy chọn ngữ cảnh cho hình ảnh, thẻ chặn đối với các đối tượng Flash và Java, và một danh sách các mục có thể chặn được để gỡ bỏ script và stylesheet.

=== added file 'chrome/locale/vi/overlay.dtd'
--- chrome/locale/vi/overlay.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/vi/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,23 @@
+<!ENTITY status.tooltip "Trạng thái:">
+<!ENTITY blocked.tooltip "Các mục bị chặn trong trang này:">
+<!ENTITY filters.tooltip "Các bộ lọc có hiệu lực nhất:">
+<!ENTITY menuitem.label "Tùy chọn Adblock Plus">
+<!ENTITY menuitem.accesskey "P">
+<!ENTITY toolbarbutton.label "Adblock Plus">
+<!ENTITY view.blockableItems.label "Adblock Plus: Các Mục Có Thể Chặn">
+<!ENTITY context.image.label "Adblock Plus: Chặn Ảnh">
+<!ENTITY context.object.label "Adblock Plus: Chặn Đối Tượng">
+<!ENTITY context.frame.label "Adblock Plus: Chặn Khung">
+<!ENTITY context.media.label "Adblock Plus: Chặn nhạc/phim">
+<!ENTITY context.removeWhitelist.label "Adblock Plus: Kích Hoạt Lại trên Trang Này">
+<!ENTITY sidebar.title "Các mục bị chặn trên trang hiện tại">
+<!ENTITY settings.label "Tùy chọn">
+<!ENTITY settings.accesskey "T">
+<!ENTITY opensidebar.label "Mở các mục có thể chặn được">
+<!ENTITY opensidebar.accesskey "m">
+<!ENTITY closesidebar.label "Đóng các mục có thể chặn được">
+<!ENTITY closesidebar.accesskey "m">
+<!ENTITY whitelist.site.label "Vô hiệu hóa trên ?1?">
+<!ENTITY whitelist.page.label "Chỉ vô hiệu hóa trên trang này">
+<!ENTITY objecttab.title "Chặn">
+<!ENTITY objecttab.tooltip "Nhấn vào đây để chặn đối tượng này với Adblock Plus">

=== added file 'chrome/locale/vi/settings.dtd'
--- chrome/locale/vi/settings.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/vi/settings.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,90 @@
+<!ENTITY dialog.title "Tùy chọn Adblock Plus">
+<!ENTITY filters.label "Bộ lọc">
+<!ENTITY filters.accesskey "B">
+<!ENTITY add.label "Thêm bộ lọc">
+<!ENTITY add.accesskey "T">
+<!ENTITY addsubscription.label "Thêm bộ lọc trọn gói">
+<!ENTITY addsubscription.accesskey "m">
+<!ENTITY synchsubscriptions.label "Cập nhật tất cả bộ lọc trọn gói">
+<!ENTITY synchsubscriptions.accesskey "C">
+<!ENTITY import.label "Nhập các bộ lọc">
+<!ENTITY import.accesskey "N">
+<!ENTITY export.label "Xuất các bộ lọc tùy biến">
+<!ENTITY export.accesskey "u">
+<!ENTITY clearall.label "Xóa tất cả bộ lọc tùy biến">
+<!ENTITY clearall.accesskey "X">
+<!ENTITY resethitcounts.label "Đặt lại số lần hit về 0">
+<!ENTITY resethitcounts.accesskey "l">
+<!ENTITY edit.label "Chỉnh sửa">
+<!ENTITY edit.accesskey "C">
+<!ENTITY cut.label "Cắt">
+<!ENTITY cut.accesskey "T">
+<!ENTITY copy.label "Chép">
+<!ENTITY copy.accesskey "C">
+<!ENTITY paste.label "Dán">
+<!ENTITY paste.accesskey "D">
+<!ENTITY remove.label "Xóa">
+<!ENTITY remove.accesskey "X">
+<!ENTITY menu.find.label "Tìm">
+<!ENTITY menu.find.accesskey "m">
+<!ENTITY menu.findagain.label "Tìm Lại">
+<!ENTITY menu.findagain.accesskey "i">
+<!ENTITY view.label "Hiển thị">
+<!ENTITY view.accesskey "H">
+<!ENTITY sort.label "Sắp xếp theo">
+<!ENTITY sort.accesskey "x">
+<!ENTITY sort.none.label "Chưa sắp xếp">
+<!ENTITY sort.none.accesskey "C">
+<!ENTITY sort.ascending.label "Thứ tự A &gt; Z">
+<!ENTITY sort.ascending.accesskey "A">
+<!ENTITY sort.descending.label "Thứ tự Z &gt; A">
+<!ENTITY sort.descending.accesskey "Z">
+<!ENTITY options.label "Tùy chọn">
+<!ENTITY options.accesskey "y">
+<!ENTITY enable.label "Bật Adblock Plus">
+<!ENTITY enable.accesskey "B">
+<!ENTITY showintoolbar.label "Hiện trong thanh công cụ">
+<!ENTITY showintoolbar.accesskey "c">
+<!ENTITY showinstatusbar.label "Hiện trong thanh trạng thái">
+<!ENTITY showinstatusbar.accesskey "r">
+<!ENTITY objecttabs.label "Hiện thẻ trên Flash và Java">
+<!ENTITY objecttabs.accesskey "t">
+<!ENTITY collapse.label "Thu gọn các phần tử bị chặn">
+<!ENTITY collapse.accesskey "u">
+<!ENTITY help.label "Trợ giúp">
+<!ENTITY help.accesskey "p">
+<!ENTITY gettingStarted.label "Bắt đầu">
+<!ENTITY gettingStarted.accesskey "B">
+<!ENTITY gettingStarted.url "http://adblockplus.org/en/getting_started">
+<!ENTITY faq.label "Câu hỏi Thường gặp">
+<!ENTITY faq.accesskey "C">
+<!ENTITY faq.url "http://adblockplus.org/en/faq">
+<!ENTITY filterdoc.label "Hướng dẫn viết bộ lọc cho Adblock Plus">
+<!ENTITY filterdoc.accesskey "H">
+<!ENTITY filterdoc.url "http://adblockplus.org/en/filters">
+<!ENTITY about.label "Giới thiệu Adblock Plus">
+<!ENTITY about.accesskey "G">
+<!ENTITY description "Những bộ lọc sau xác định những địa chỉ nào sẽ bị chặn và những địa chỉ nào sẽ được cho phép:">
+<!ENTITY filter.column "Quy luật lọc">
+<!ENTITY filter.accesskey "Q">
+<!ENTITY slow.column "Bộ lọc chậm">
+<!ENTITY slow.accesskey "B">
+<!ENTITY enabled.column "Hiệu lực">
+<!ENTITY enabled.accesskey "H">
+<!ENTITY hitcount.column "Số lần hit">
+<!ENTITY hitcount.accesskey "S">
+<!ENTITY lasthit.column "Lần hit cuối">
+<!ENTITY lasthit.accesskey "L">
+<!ENTITY context.edit.label "Chỉnh sửa bộ lọc">
+<!ENTITY context.resethitcount.label "Đặt lại số lần hit của bộ lọc về 0">
+<!ENTITY context.synchsubscription.label "Cập nhật bộ trọn gói ngay bây giờ">
+<!ENTITY context.editsubscription.label "Chỉnh sửa bộ trọn gói">
+<!ENTITY context.moveup.label "Di chuyển bộ lọc lên trên">
+<!ENTITY context.movedown.label "Di chuyển bộ lọc xuống dưới">
+<!ENTITY context.movegroupup.label "Di chuyển nhóm lên trên">
+<!ENTITY context.movegroupdown.label "Di chuyển nhóm xuống dưới">
+<!ENTITY context.enable.label "Kích hoạt">
+<!ENTITY context.disable.label "Vô hiệu hóa">
+<!ENTITY apply.label "Áp dụng">
+<!ENTITY apply.accesskey "d">
+<!ENTITY fennec.subscription.label "Bộ lọc trọn gói">

=== added file 'chrome/locale/vi/sidebar.dtd'
--- chrome/locale/vi/sidebar.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/vi/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY detached.title "Adblock Plus: các mục có thể chặn (tách rời)">
+<!ENTITY detach.label "Tách rời">
+<!ENTITY reattach.label "Đính lại">
+<!ENTITY search.label "Tìm:">
+<!ENTITY search.accesskey "m">
+<!ENTITY type.label "Kiểu">
+<!ENTITY address.label "Địa chỉ">
+<!ENTITY filter.label "Bộ lọc">
+<!ENTITY state.label "Tình trạng">
+<!ENTITY size.label "Kích thước">
+<!ENTITY docDomain.label "Nguồn tài liệu">
+<!ENTITY noitems.label "Không có mục nào có thể chặn được">
+<!ENTITY whitelisted.label "Trang nằm trong sổ trắng">
+<!ENTITY tooltip.address.label "Địa chỉ:">
+<!ENTITY tooltip.type.label "Kiểu:">
+<!ENTITY tooltip.type.blocked "(đã chặn)">
+<!ENTITY tooltip.type.whitelisted "(sổ trắng)">
+<!ENTITY tooltip.size.label "Kích thước:">
+<!ENTITY tooltip.docDomain.label "Nguồn tài liệu:">
+<!ENTITY tooltip.filter.label "Bộ lọc đang chặn:">
+<!ENTITY tooltip.filterSource.label "Nguồn bộ lọc:">
+<!ENTITY context.block.label "Chặn mục này">
+<!ENTITY context.editfilter.label "Chỉnh sửa bộ lọc đang chặn">
+<!ENTITY context.whitelist.label "Thêm quy luật ngoại lệ cho mục">
+<!ENTITY context.disablefilter.label "Vô hiệu hóa bộ lọc ?1?">
+<!ENTITY context.enablefilter.label "Kích hoạt lại bộ lọc ?1?">
+<!ENTITY context.disablefilteronsite.label "Vô hiệu hóa bộ lọc này trên ?1?">
+<!ENTITY context.open.label "Mở trong Thẻ Mới">
+<!ENTITY context.flash.label "Nhấp nháy quanh viền của mục này">
+<!ENTITY context.copy.label "Chép địa chỉ của mục này">
+<!ENTITY context.copyFilter.label "Chép bộ lọc">
+<!ENTITY context.selectAll.label "Chọn tất cả">

=== added file 'chrome/locale/vi/subscriptionSelection.dtd'
--- chrome/locale/vi/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/vi/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "Thêm bộ lọc trọn gói cho Adblock Plus">
+<!ENTITY dialog.title.edit "Chỉnh sửa bộ lọc trọn gói">
+<!ENTITY description.newInstall "Adblock Plus sẽ có hiệu quả nhất khi bạn cài một bộ lọc trọn gói. Bộ lọc trọn gói được cung cấp miễn phí bởi những người dùng Adblock Plus khác. Bộ lọc phù hợp nhất cho ngôn ngữ của bạn đã được chọn sẵn.">
+<!ENTITY adblock.warning "Adblock Plus nhận thấy Adblock hoặc một phiên bản cũ của Adblock Plus đã được cài. Chạy song song Adblock và Adblock Plus có thể gây ra vấn đề, cho nên hãy tránh làm vậy. Lời khuyên là bạn hãy gỡ bỏ Adblock ngay bây giờ.">
+<!ENTITY adblock.uninstall "Gỡ bỏ Adblock">
+<!ENTITY filterset.g.warning "Có vẻ như bạn đang dùng Filterset.G. Danh sách bộ lọc này đã không được duy trì trong suốt vài năm qua và là một nguyên nhân gây ra vấn đề với các trang web. Lời khuyên là bạn hãy gỡ bỏ Filterset.G ngay bây giờ.">
+<!ENTITY filterset.g.moreinfo "Thêm thông tin">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "Gỡ bỏ Filterset.G">
+<!ENTITY subscriptionSelector.label "Vui lòng chọn một bộ lọc trọn gói từ danh sách:">
+<!ENTITY viewList.label "Xem bộ lọc">
+<!ENTITY visitHomepage.label "Vào trang chủ">
+<!ENTITY addSubscription.label "Thêm bộ trọn gói">
+<!ENTITY saveSubscription.label "Lưu bộ trọn gói">
+<!ENTITY other.label "Thêm bộ lọc trọn gói khác">
+<!ENTITY other.accesskey "T">
+<!ENTITY list.download.failed "Adblock Plus không thể lấy danh sách bộ lọc trọn gói.">
+<!ENTITY list.download.retry "Thử lại">
+<!ENTITY list.download.website "Xem trang web">
+<!ENTITY list.website.url "http://code.google.com/p/adblockplus-vietnam/">
+<!ENTITY fromWeb.description "Vui lòng xác nhận rằng bạn muốn thêm bộ lọc trọn gói này. Bạn có thể thay đổi tiêu đề hoặc địa chỉ trước khi thêm nó.">
+<!ENTITY edit.description "Bạn có thể thay đổi tiêu đề hoặc địa chỉ của bộ trọn gói nếu cần.">
+<!ENTITY external.description "Đây là bộ lọc trọn gói bên ngoài; nó sẽ được cập nhật bởi phần mở rộng tạo ra nó.">
+<!ENTITY title.label "Tiêu đề của bộ trọn gói:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "Địa chỉ của danh sách bộ lọc:">
+<!ENTITY location.accesskey "a">
+<!ENTITY autodownload.label "Cập nhật tự động">
+<!ENTITY autodownload.accesskey "C">
+<!ENTITY supplementMessage "Bộ lọc trọn gói này chỉ nên dùng kèm với bộ lọc trọn gói &quot;?1?&quot; - cái mà bạn chưa sử dụng.">
+<!ENTITY addMain.label "Kèm thêm bộ lọc trọn gói &quot;?1?&quot;">
+<!ENTITY addMain.accesskey "g">

=== modified file 'chrome/locale/zh-CN/about.dtd'
--- chrome/locale/zh-CN/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-CN/about.dtd	2010-05-04 14:45:07 +0000
@@ -8,3 +8,7 @@
 <!ENTITY homepage.url "http://adblockplus.org/">
 <!ENTITY author.label "作者:">
 <!ENTITY contributors.label "贡献者:">
+<!ENTITY developers.label "开发者：">
+<!ENTITY designers.label "美工设计者：">
+<!ENTITY subscriptionAuthors.label "过滤规则订阅作者：">
+<!ENTITY translators.label "翻译者：">

=== modified file 'chrome/locale/zh-CN/composer.dtd'
--- chrome/locale/zh-CN/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-CN/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "添加规则">
 <!ENTITY advanced.label "高级视图">
 <!ENTITY basic.label "基本视图">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus 目前处于禁用状态。您可以继续添加过滤规则，但是这些规则无法生效。">
-<!ENTITY disabled.warning.link "启用 Adblock Plus">
-<!ENTITY disabled.warning.afterLink ".">
-<!ENTITY groupDisabled.warning.beforeLink "该过滤规则将被添加到过滤规则组 group &quot;&#37;S&quot;，该组目前是禁用状态。 您仍然可以添加该过滤规则，但是该规则不会被应用，除非您启用它。">
-<!ENTITY groupDisabled.warning.link "启用过滤器分组">
-<!ENTITY groupDisabled.warning.afterLink ".">
+<!ENTITY disabled.warning "Adblock Plus 目前处于禁用状态。您可以继续添加过滤规则，但是这些规则无法生效。[link]启用 Adblock Plus[/link].">
+<!ENTITY groupDisabled.warning "该过滤规则将被添加到过滤规则组 group &quot;?1?&quot;，该组目前是禁用状态。 您仍然可以添加该过滤规则，但是该规则不会被应用，除非您启用它。[link]启用过滤器分组[/link].">
 <!ENTITY filter.label "新建过滤规则:">
 <!ENTITY filter.accesskey "f">
 <!ENTITY preferences.label "显示现有过滤规则...">

=== modified file 'chrome/locale/zh-CN/global.properties'
--- chrome/locale/zh-CN/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-CN/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,13 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=广告已成往事！
-status_active_label=Adblock
-status_disabled_label=禁用
+default_dialog_title=Adblock Plus
 action0_tooltip=点击弹出快捷菜单，中键点击切换启用/禁用。
 action1_tooltip=点击打开/关闭可过滤项目，中键点击切换启用/禁用。
 action2_tooltip=点击打开首选项，中键点击切换启用/禁用。
 action3_tooltip=启用/禁用Adblock Plus。
-active_tooltip=Adblock Plus已启用。
 disabled_tooltip=Adblock Plus已禁用。
+active_tooltip=Adblock Plus 处于激活状态，正在使用?1? 过滤规则订阅，?2? 自定义过滤规则。
 whitelisted_tooltip=Adblock Plus已启用但在当前页禁用。
-blocked_count_tooltip=-- 项，共 -- 项
+blocked_count_tooltip=?1? 项，共 ?2? 项
+blocked_count_addendum=(白名单：?1?，隐藏: ?2?)
 no_blocking_suggestions=当前页面无可过滤项目
 whitelisted_page=Adblock Plus在当前页面已禁用
 whitelist_description=白名单
@@ -16,7 +15,7 @@
 invalid_description=无效过滤规则
 elemhide_description=元素隐藏规则
 subscription_description=过滤规则订阅:
-subscription_wrong_version=该订阅中的某些过滤规则需要 Adblock Plus -- 才能正常工作！
+subscription_wrong_version=该订阅中的某些过滤规则需要 Adblock Plus ?1? 才能正常工作！
 subscription_source=源:
 subscription_status=状态:
 subscription_status_autodownload=自动更新
@@ -26,7 +25,7 @@
 subscription_status_lastdownload_inprogress=下载中……
 subscription_status_lastdownload_unknown=N/A
 remove_subscription_warning=你真的希望移除该订阅么？
-import_filters_wrong_version=警告：列表中某些过滤规则需要Adblock Plus -- 才能正常工作。您或许应该在导入该列表前升级到最新版的Adblock Plus。
+import_filters_wrong_version=警告：列表中某些过滤规则需要Adblock Plus ?1? 才能正常工作。您或许应该在导入该列表前升级到最新版的Adblock Plus。
 import_filters_warning=你希望替换当前的过滤规则还是把新规则附加到列表底部？
 import_filters_title=导入过滤规则
 export_filters_title=导出过滤规则
@@ -38,9 +37,9 @@
 filter_regexp_tooltip=该过滤规则是正则表达式或者太短而不能优化。如果这种类型的过滤规则太多会降低您浏览的速度。
 filter_elemhide_duplicate_id=仅可以指定一个要被隐藏的元素ID
 filter_elemhide_nocriteria=没有指定要被隐藏元素的识别标准
-subscription_no_location=请输入下载过滤规则的位置
+subscription_notAdded_warning=您不能添加过滤规则订阅。没有过滤规则订阅的情况下，您需要手动添加 Adblock Plus 过滤规则。
+subscription_notAdded_warning_addendum=您希望继续么？
 subscription_invalid_location=过滤规则列表的位置不是有效的URL或有效的文件名
-subscription_location_exists=你已经订阅该过滤规则列表。
 synchronize_invalid_url=失败，不是有效地址
 synchronize_connection_error=失败，下载失败
 synchronize_invalid_data=失败，不是有效的过滤规则列表
@@ -65,3 +64,7 @@
 type_label_dtd=DTD
 type_label_media=音频/视频
 type_label_font=字体
+fennec_status_enabled=Adblock Plus 已启用。
+fennec_status_disabled=Adblock Plus 已禁用。
+fennec_status_enabled_site=Adblock Plus 在 ?1? 上启用。
+fennec_status_disabled_site=Adblock Plus 在 ?1? 上禁用。

=== added file 'chrome/locale/zh-CN/meta.properties'
--- chrome/locale/zh-CN/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/zh-CN/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=blackdire
+name=Adblock Plus
+description=广告已成往事！
+description.short=被广告弄得搓火吗？被跟随鼠标的标语弄得烦心吗？被横幅弄得感到厌恶吗？立即安装 Adblock Plus 来重新取得 Internet 的控制权并且改变您浏览网页的方式。\n\n在 http://www.youtube.com/watch?v=oNvb2SjVjjI 上有简短的视频可供参考
+description.long=Adblock Plus 让您重新取得 Internet 的控制权和您查看网页的方式。本附加组件支持多语言，有超过40个的过滤规则订阅，这些过滤规则会进行自动配置，为您过滤所有来自已知有恶意域的在线广告。Adblock Plus 也允许您通过各种有用的特性来自定义您的过滤规则，这些特性包括：图片的右键菜单、Flash 和 Java 对象的过滤标签、用于移除脚本和样式表的可过滤项目列表。

=== modified file 'chrome/locale/zh-CN/overlay.dtd'
--- chrome/locale/zh-CN/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-CN/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -8,6 +8,7 @@
 <!ENTITY context.image.label "过滤图片(Adblock Plus)">
 <!ENTITY context.object.label "过滤对象(Adblock Plus)">
 <!ENTITY context.frame.label "过滤帧(Adblock Plus)">
+<!ENTITY context.media.label "过滤视频/音频(Adblock Plus)">
 <!ENTITY context.removeWhitelist.label "Adblock Plus: 在此页面上重新启用">
 <!ENTITY sidebar.title "本页可过滤的项目">
 <!ENTITY settings.label "首选项">
@@ -16,7 +17,7 @@
 <!ENTITY opensidebar.accesskey "B">
 <!ENTITY closesidebar.label "关闭可过滤项目">
 <!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "在 -- 禁用Adblock Plus">
+<!ENTITY whitelist.site.label "在 ?1? 禁用Adblock Plus">
 <!ENTITY whitelist.page.label "仅在本页禁用Adblock Plus">
 <!ENTITY objecttab.title "过滤">
 <!ENTITY objecttab.tooltip "点击这里使 Adblock Plus 过滤该对象">

=== modified file 'chrome/locale/zh-CN/settings.dtd'
--- chrome/locale/zh-CN/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-CN/settings.dtd	2010-05-04 14:45:07 +0000
@@ -89,3 +89,4 @@
 <!ENTITY context.disable.label "禁用">
 <!ENTITY apply.label "应用">
 <!ENTITY apply.accesskey "P">
+<!ENTITY fennec.subscription.label "过滤规则订阅">

=== modified file 'chrome/locale/zh-CN/sidebar.dtd'
--- chrome/locale/zh-CN/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-CN/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "过滤该项">
 <!ENTITY context.editfilter.label "编辑过滤规则有效">
 <!ENTITY context.whitelist.label "将该项加入白名单">
-<!ENTITY context.disablefilter.label "禁用过滤规则 --">
-<!ENTITY context.enablefilter.label "重新启用过滤规则 --">
-<!ENTITY context.disablefilteronsite.label "在 -- 禁用该过滤规则">
+<!ENTITY context.disablefilter.label "禁用过滤规则 ?1?">
+<!ENTITY context.enablefilter.label "重新启用过滤规则 ?1?">
+<!ENTITY context.disablefilteronsite.label "在 ?1? 禁用该过滤规则">
 <!ENTITY context.open.label "在新标签页打开">
 <!ENTITY context.flash.label "闪动显示该项目的边框">
 <!ENTITY context.copy.label "复制项目地址">

=== removed file 'chrome/locale/zh-CN/subscription.dtd'
--- chrome/locale/zh-CN/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-CN/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,15 +0,0 @@
-<!ENTITY dialog.title "编辑过滤规则订阅">
-<!ENTITY dialog.newtitle "添加过滤规则订阅">
-<!ENTITY new.description "请输入包含Adblock Plus过滤规则列表的网址或文件。">
-<!ENTITY edit.description "该订阅的过滤规则列表将从给出的位置下载。">
-<!ENTITY external.description "这是一个外部过滤规则订阅，它的过滤规则列表将由创建该订阅的扩展保持最新状态。">
-<!ENTITY autodownload.description "如果你选择“自动更新”，将每天在这个位置检查更新。
-	禁用该选项，你仍可以在订阅的右键菜单中进行手动更新。">
-<!ENTITY location.label "过滤规则列表位置:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "订阅的标题:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "自动更新">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.label "启用过滤规则">
-<!ENTITY enabled.accesskey "N">

=== added file 'chrome/locale/zh-CN/subscriptionSelection.dtd'
--- chrome/locale/zh-CN/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/zh-CN/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "添加 Adblock Plus 过滤规则订阅">
+<!ENTITY dialog.title.edit "编辑过滤规则订阅">
+<!ENTITY description.newInstall "要使 Adblock Plus 发挥最大功效，您应该添加规律规则订阅。这些规律规则订阅由其他 Adblock Plus 用户免费提供。大多数适用于您的语言的过滤过则订阅已经选择了。">
+<!ENTITY adblock.warning "Adblock Plus 检测出您已经安装了 Adblock 或旧版本的 Adblock Plus。同时运行 Adblock 和 Adblock Plus 会导致问题，应该避免此类问题发生。推荐现在卸载 Adblock。">
+<!ENTITY adblock.uninstall "卸载 Adblock">
+<!ENTITY filterset.g.warning "您正在使用 Filterset.G。该过滤规则列表由于网站问题已经很久不维护了。推荐您现在卸载 Filterset.G now。">
+<!ENTITY filterset.g.moreinfo "更多信息">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "卸载 Filterset.G">
+<!ENTITY subscriptionSelector.label "从列表中选择过滤规则订阅：">
+<!ENTITY viewList.label "查看过滤规则">
+<!ENTITY visitHomepage.label "查看主页">
+<!ENTITY addSubscription.label "添加订阅">
+<!ENTITY saveSubscription.label "保存订阅">
+<!ENTITY other.label "添加订阅">
+<!ENTITY other.accesskey "f">
+<!ENTITY list.download.failed "获取订阅列表失败。">
+<!ENTITY list.download.retry "重试">
+<!ENTITY list.download.website "查看站点">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "请确认您希望添加该过滤规则订阅。在添加之前，您可以更改订阅标题或位置。">
+<!ENTITY edit.description "您可以更改订阅挑剔或位置">
+<!ENTITY external.description "这是外部的过滤规则订阅，由该订阅创建的过滤规则列表将会由扩展自动更新">
+<!ENTITY title.label "订阅的标题:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "过滤规则列表位置:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "自动更新">
+<!ENTITY autodownload.accesskey "P">
+<!ENTITY supplementMessage "该规律规则订阅意味着该订阅将与您未添加的过滤规则订阅 &quot;?1?&quot; 一起使用。">
+<!ENTITY addMain.label "同时添加过滤规则订阅&quot;?1?&quot;">
+<!ENTITY addMain.accesskey "s">

=== removed file 'chrome/locale/zh-CN/tip_subscriptions.dtd'
--- chrome/locale/zh-CN/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-CN/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "欢迎使用Adblock Plus">
-<!ENTITY description.par1 "感谢您安装 Adblock Plus。本扩展可以去除 99&#37; 网页上您看到的广告。但是，要对广告进行有效地过滤需要您定义一组好的过滤规则。您可以自己定义，或者您可以简单地订阅别人为您维护的过滤规则列表。只要需要，您仍可以添加您自己的过滤规则或者移除订阅。">
-<!ENTITY description.par2 "您可以从下面推荐的订阅列表中选择一项订阅（以后，您还可以在 Adblock Plus 选项中可以添加更多的订阅）：">
-<!ENTITY note "注意：对于某地区的网站，应用专门为之创建的过滤规则列表，会有非常好的效果。">
-<!ENTITY adblock.warning "Adblock Plus 检测出您已经安装了 Adblock 或旧版本的 Adblock Plus。同时运行 Adblock 和 Adblock Plus 会导致问题，应该避免此类问题发生。推荐现在卸载 Adblock。">
-<!ENTITY adblock.uninstall "卸载 Adblock">
-<!ENTITY filterset.g.warning "您正在使用 Filterset.G。该过滤规则列表由于网站问题已经很久不维护了。推荐您现在卸载 Filterset.G now。">
-<!ENTITY filterset.g.moreinfo "更多信息">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "卸载 Filterset.G">
-<!ENTITY homepage.label "主页">
-<!ENTITY subscribe.label "订阅">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "添加订阅">
-<!ENTITY other.accesskey "f">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "查看所有订阅">

=== modified file 'chrome/locale/zh-TW/about.dtd'
--- chrome/locale/zh-TW/about.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-TW/about.dtd	2010-05-04 14:45:07 +0000
@@ -1,12 +1,14 @@
 <!ENTITY dialog.title "關於 Adblock Plus">
 <!ENTITY caption.title "Adblock Plus">
 <!ENTITY version.title "版本">
-<!ENTITY description "
-	Adblock Plus 讓您自行決定甚麼東西才能出現在畫面上，
+<!ENTITY description "Adblock Plus 讓您自行決定甚麼東西才能出現在畫面上，
 	再也不用浪費時間下載礙眼的廣告。
-	討人厭的廣告佔滿網頁？ — 讓 Adblock Plus 幫您解決！
-">
+	討人厭的廣告佔滿網頁？ — 讓 Adblock Plus 幫您解決！">
 <!ENTITY homepage.label "Adblock Plus 首頁:">
 <!ENTITY homepage.url "http://adblockplus.org/">
 <!ENTITY author.label "程式作者:">
 <!ENTITY contributors.label "貢獻者:">
+<!ENTITY developers.label "開發者:">
+<!ENTITY designers.label "圖形設計:">
+<!ENTITY subscriptionAuthors.label "過濾條件集作者:">
+<!ENTITY translators.label "翻譯者:">

=== modified file 'chrome/locale/zh-TW/composer.dtd'
--- chrome/locale/zh-TW/composer.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-TW/composer.dtd	2010-05-04 14:45:07 +0000
@@ -2,12 +2,8 @@
 <!ENTITY accept.label "新增過濾條件">
 <!ENTITY advanced.label "進階檢視">
 <!ENTITY basic.label "基本檢視">
-<!ENTITY disabled.warning.beforeLink "Adblock Plus 目前已停用。您還是可以新增過濾條件，但不會有任何作用，除非您">
-<!ENTITY disabled.warning.link "啟用 Adblock Plus">
-<!ENTITY disabled.warning.afterLink "。">
-<!ENTITY groupDisabled.warning.beforeLink "此過濾條件應加到過濾條件組 &quot;&#37;S&quot; 中，但該過濾條件組目前已停用。您還是可以新增過濾條件，但不會有任何作用，除非您">
-<!ENTITY groupDisabled.warning.link "啟用該過濾條件組">
-<!ENTITY groupDisabled.warning.afterLink "。">
+<!ENTITY disabled.warning "Adblock Plus 目前已停用。您還是可以新增過濾條件，但不會有任何作用，除非您[link]啟用 Adblock Plus[/link]。">
+<!ENTITY groupDisabled.warning "此過濾條件應加到過濾條件組 &quot;?1?&quot; 中，但該過濾條件組目前已停用。您還是可以新增過濾條件，但不會有任何作用，除非您[link]啟用該過濾條件組[/link]。">
 <!ENTITY filter.label "新過濾條件:">
 <!ENTITY filter.accesskey "f">
 <!ENTITY preferences.label "顯示已有的條件...">

=== modified file 'chrome/locale/zh-TW/global.properties'
--- chrome/locale/zh-TW/global.properties	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-TW/global.properties	2010-05-04 14:45:07 +0000
@@ -1,14 +1,13 @@
-extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description=廣告已成過去式！
-status_active_label=Adblock
-status_disabled_label=已停用
+default_dialog_title=Adblock Plus
 action0_tooltip=按一下會跳出功能表，按中鍵則可啟用或停用 Adblock Plus。
 action1_tooltip=按一下會開啟或關閉可封鎖項目清單，按中鍵則可啟用或停用 Adblock Plus。
 action2_tooltip=按一下開啟偏好設定視窗，按中鍵則可啟用或停用 Adblock Plus。
 action3_tooltip=按一下可啟用或停用 Adblock Plus。
-active_tooltip=Adblock Plus 已啟用。
 disabled_tooltip=Adblock Plus 已停用。
+active_tooltip=Adblock Plus 已啟用，?1? 份條件集已訂閱，?2? 條自訂條件已使用。
 whitelisted_tooltip=Adblock Plus 已啟用但本頁已設為白名單。
-blocked_count_tooltip=-- 項共 -- 項
+blocked_count_tooltip=?1? 項共 ?2? 項
+blocked_count_addendum=(以及白名單: ?1?, 已隱藏: ?2?)
 no_blocking_suggestions=此頁面無可阻擋的物件
 whitelisted_page=此頁面為白名單，Adblock Plus 暫時停用
 whitelist_description=我的例外規則 (白名單)
@@ -16,7 +15,7 @@
 invalid_description=我的無效規則
 elemhide_description=我的元素隱藏規則
 subscription_description=已訂閱條件集:
-subscription_wrong_version=此過濾條件集的某些條件需要 Adblock Plus 方可正常運作！
+subscription_wrong_version=此過濾條件集的某些條件需要 Adblock Plus ?1? 方能正確運作！
 subscription_source=訂閱來源:
 subscription_status=狀態:
 subscription_status_autodownload=自動更新
@@ -26,7 +25,7 @@
 subscription_status_lastdownload_inprogress=下載中...
 subscription_status_lastdownload_unknown=N/A
 remove_subscription_warning=您確定要移除此訂閱項目嗎？
-import_filters_wrong_version=警告: 此清單中的某些過濾條件需要 Adblock Plus 方能正確運作。在匯入此清單前請先將 Adblock Plus 升級到最新版。
+import_filters_wrong_version=警告: 此清單中的某些過濾條件需要 Adblock Plus ?1? 方能正確運作。在匯入此清單前請先將 Adblock Plus 升級到最新版。
 import_filters_warning=您確定要覆蓋現有的過濾條件或追加條件於清單最末端？
 import_filters_title=匯入過濾條件
 export_filters_title=匯出過濾條件
@@ -38,9 +37,9 @@
 filter_regexp_tooltip=此過濾條件可能含正規表示式或太短需要最佳化，太多這類過濾條件會拖慢瀏覽速度。
 filter_elemhide_duplicate_id=只能隱藏一次擁有此 ID 的元素
 filter_elemhide_nocriteria=未指定規則已辨認出要隱藏的元素
-subscription_no_location=請輸入要訂閱的過濾條件集位址。
+subscription_notAdded_warning=您未訂閱過濾條件集。不訂閱則您必須手動加入 Adblock Plus 過濾條件。
+subscription_notAdded_warning_addendum=您確定要繼續嗎?
 subscription_invalid_location=過濾條件集網址或檔名無效。
-subscription_location_exists=您已訂閱此過濾條件集。
 synchronize_invalid_url=失敗，無效的位址
 synchronize_connection_error=失敗，檔案下載失敗
 synchronize_invalid_data=失敗，無效的過濾條件集
@@ -65,3 +64,7 @@
 type_label_dtd=DTD
 type_label_media=聲音/影片
 type_label_font=字體
+fennec_status_enabled=Adblock Plus 已啟用。
+fennec_status_disabled=Adblock Plus 已停用。
+fennec_status_enabled_site=Adblock Plus 已啟用於 ?1?。
+fennec_status_disabled_site=Adblock Plus 已停用於 ?1?。

=== added file 'chrome/locale/zh-TW/meta.properties'
--- chrome/locale/zh-TW/meta.properties	1970-01-01 00:00:00 +0000
+++ chrome/locale/zh-TW/meta.properties	2010-05-04 14:45:07 +0000
@@ -0,0 +1,5 @@
+translator=Jose Sun
+name=Adblock Plus
+description=廣告已成過去式！
+description.short=討厭擾人的廣告嗎？害怕被追蹤嗎？痛恨一大片的橫幅廣告嗎？快安裝 Adblock Plus 讓您重拾網路控制權，自己決定想看的內容。\n\nAdblock Plus 的一分鐘影片介紹（英文）：http://www.youtube.com/watch?v=oNvb2SjVjjI
+description.long=Adblock Plus 讓您重拾網路控制權，自己決定想看的內容。此附加元件內含 40 種以上不同國家及語言的過濾條件集，能自動設定從移除線上廣告到封鎖惡意網域等過濾範圍。Adblock Plus 也允許自訂您自己的過濾條件，並有許多好用的功能協助您阻擋廣告，例如圖片右鍵阻擋、Flash 及 Java 物件的頁籤阻擋、提供可阻擋項目清單以便您移除程式碼和樣式表。

=== modified file 'chrome/locale/zh-TW/overlay.dtd'
--- chrome/locale/zh-TW/overlay.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-TW/overlay.dtd	2010-05-04 14:45:07 +0000
@@ -8,6 +8,7 @@
 <!ENTITY context.image.label "Adblock Plus: 阻擋圖片">
 <!ENTITY context.object.label "Adblock Plus: 阻擋物件">
 <!ENTITY context.frame.label "Adblock Plus: 阻擋頁框">
+<!ENTITY context.media.label "Adblock Plus: 阻擋影音">
 <!ENTITY context.removeWhitelist.label "Adblock Plus: 此頁不設為白名單">
 <!ENTITY sidebar.title "本頁可阻擋項目">
 <!ENTITY settings.label "偏好設定">
@@ -16,7 +17,7 @@
 <!ENTITY opensidebar.accesskey "B">
 <!ENTITY closesidebar.label "關閉可阻擋項目">
 <!ENTITY closesidebar.accesskey "B">
-<!ENTITY whitelist.site.label "此網域設為白名單: --">
+<!ENTITY whitelist.site.label "此網域設為白名單: ?1?">
 <!ENTITY whitelist.page.label "只將此頁面設為白名單">
 <!ENTITY objecttab.title "封鎖">
 <!ENTITY objecttab.tooltip "請按這裡用 Adblock Plus 封鎖此物件">

=== modified file 'chrome/locale/zh-TW/settings.dtd'
--- chrome/locale/zh-TW/settings.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-TW/settings.dtd	2010-05-04 14:45:07 +0000
@@ -87,3 +87,4 @@
 <!ENTITY context.disable.label "停用">
 <!ENTITY apply.label "套用">
 <!ENTITY apply.accesskey "P">
+<!ENTITY fennec.subscription.label "過濾條件訂閱">

=== modified file 'chrome/locale/zh-TW/sidebar.dtd'
--- chrome/locale/zh-TW/sidebar.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-TW/sidebar.dtd	2010-05-04 14:45:07 +0000
@@ -22,9 +22,9 @@
 <!ENTITY context.block.label "阻擋此項目">
 <!ENTITY context.editfilter.label "編輯作用中的條件">
 <!ENTITY context.whitelist.label "將此項目加為例外規則">
-<!ENTITY context.disablefilter.label "停用過濾條件 --">
-<!ENTITY context.enablefilter.label "重新啟用過濾條件 --">
-<!ENTITY context.disablefilteronsite.label "停用此條件 --">
+<!ENTITY context.disablefilter.label "停用過濾條件 ?1?">
+<!ENTITY context.enablefilter.label "重新啟用過濾條件 ?1?">
+<!ENTITY context.disablefilteronsite.label "停用此條件 ?1?">
 <!ENTITY context.open.label "於新分頁開啟">
 <!ENTITY context.flash.label "Flash 物件框線">
 <!ENTITY context.copy.label "複製項目位址">

=== removed file 'chrome/locale/zh-TW/subscription.dtd'
--- chrome/locale/zh-TW/subscription.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-TW/subscription.dtd	1970-01-01 00:00:00 +0000
@@ -1,15 +0,0 @@
-<!ENTITY dialog.title "編輯過濾條件集">
-<!ENTITY dialog.newtitle "訂閱過濾條件集">
-<!ENTITY new.description "請輸入含有 Adblock Plus 過濾條件集的網址或檔案位址。">
-<!ENTITY edit.description "這是此過濾條件集的下載來源。">
-<!ENTITY external.description "此為外部過濾條件集，這些過濾條件由外部套件自動訂閱並定期更新。">
-<!ENTITY autodownload.description "如果您勾選了「自動更新」選項，則此過濾條件集每天會自動檢查有無新版本。
-	若您停用此選項，還是可以於清單上按右鍵手動更新。">
-<!ENTITY location.label "過濾條件集位址:">
-<!ENTITY location.accesskey "L">
-<!ENTITY title.label "訂閱項目名稱:">
-<!ENTITY title.accesskey "T">
-<!ENTITY autodownload.label "自動更新">
-<!ENTITY autodownload.accesskey "P">
-<!ENTITY enabled.label "啟用此條件集">
-<!ENTITY enabled.accesskey "N">

=== added file 'chrome/locale/zh-TW/subscriptionSelection.dtd'
--- chrome/locale/zh-TW/subscriptionSelection.dtd	1970-01-01 00:00:00 +0000
+++ chrome/locale/zh-TW/subscriptionSelection.dtd	2010-05-04 14:45:07 +0000
@@ -0,0 +1,32 @@
+<!ENTITY dialog.title "訂閱 Adblock Plus 過濾條件集">
+<!ENTITY dialog.title.edit "編輯過濾條件集">
+<!ENTITY description.newInstall "為了讓 Adblock Plus 發揮最大效果，您應該訂閱過濾條件集。下列這些條件集是由其他 Adblock Plus 使用者免費提供，最適合您使用語言的過濾條件集會被自動選擇。">
+<!ENTITY adblock.warning "Adblock Plus 發現您已安裝 Adblock 或舊版的 Adblock Plus。同時執行 Adblock 及 Adblock Plus 會造成無法避免的問題。建議您立刻移除 Adblock。">
+<!ENTITY adblock.uninstall "移除 Adblock">
+<!ENTITY filterset.g.warning "您似乎正在使用 Filterset.G。此過濾條件清單最近幾年幾乎沒有更新過，而且常常在瀏覽網站時造成問題。建議您立刻移除 Filterset.G。">
+<!ENTITY filterset.g.moreinfo "更多資訊">
+<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
+<!ENTITY filterset.g.uninstall "移除 Filterset.G">
+<!ENTITY subscriptionSelector.label "請從清單中選擇過濾條件集:">
+<!ENTITY viewList.label "檢視過濾條件">
+<!ENTITY visitHomepage.label "瀏覽首頁">
+<!ENTITY addSubscription.label "新增過濾條件集">
+<!ENTITY saveSubscription.label "儲存過濾條件集">
+<!ENTITY other.label "新增其他訂閱來源">
+<!ENTITY other.accesskey "f">
+<!ENTITY list.download.failed "取回過濾條件集清單失敗。">
+<!ENTITY list.download.retry "再試一次">
+<!ENTITY list.download.website "瀏覽網站">
+<!ENTITY list.website.url "http://adblockplus.org/en/subscriptions">
+<!ENTITY fromWeb.description "請確認您要訂閱的過濾條件集。訂閱前您可以變更條件集標題或位址。">
+<!ENTITY edit.description "您需要的話可以變更條件集標題或位址。">
+<!ENTITY external.description "這次一份外部過濾條件集，這份條件集會由擴充套件建立並更新。">
+<!ENTITY title.label "訂閱項目名稱:">
+<!ENTITY title.accesskey "T">
+<!ENTITY location.label "過濾條件集位址:">
+<!ENTITY location.accesskey "L">
+<!ENTITY autodownload.label "自動更新">
+<!ENTITY autodownload.accesskey "P">
+<!ENTITY supplementMessage "該過濾條件集需要同時使用您未訂閱的條件集「?1?」。">
+<!ENTITY addMain.label "一併訂閱「?1?」條件集">
+<!ENTITY addMain.accesskey "s">

=== removed file 'chrome/locale/zh-TW/tip_subscriptions.dtd'
--- chrome/locale/zh-TW/tip_subscriptions.dtd	2010-01-07 17:25:17 +0000
+++ chrome/locale/zh-TW/tip_subscriptions.dtd	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<!ENTITY dialog.title "訂閱 Adblock Plus 過濾條件集">
-<!ENTITY description.par1 "感謝你安裝 Adblock Plus，本套件能阻擋超過 99&#37; 網路上的擾人廣告，但首先你需要一份有效的過濾條件清單。你可以自己設定，或是從我們提供的條件集中選一份使用。就算使用我們提供的過濾條件集，你還是可以自己增刪過濾條件以符合你自己的需求。">
-<!ENTITY description.par2 "你可以從下列的推薦清單中選一份訂閱，雖然我們認為一份就夠用，但是你還是可以稍候再訂閱更多的條件集：">
-<!ENTITY note "註: 請依照你所在的地區選擇過濾條件集，因為過濾條件集通常對當地的網站最有效。">
-<!ENTITY adblock.warning "Adblock Plus 發現您已安裝 Adblock 或舊版的 Adblock Plus。同時執行 Adblock 及 Adblock Plus 會造成無法避免的問題。建議您立刻移除 Adblock。">
-<!ENTITY adblock.uninstall "移除 Adblock">
-<!ENTITY filterset.g.warning "您似乎正在使用 Filterset.G。此過濾條件清單最近幾年幾乎沒有更新過，而且常常在瀏覽網站時造成問題。建議您立刻移除 Filterset.G。">
-<!ENTITY filterset.g.moreinfo "更多資訊">
-<!ENTITY filterset.g.moreinfo.url "http://adblockplus.org/en/faq_project#filterset.g">
-<!ENTITY filterset.g.uninstall "移除 Filterset.G">
-<!ENTITY homepage.label "首頁">
-<!ENTITY subscribe.label "訂閱">
-<!ENTITY subscribe.accesskey "R">
-<!ENTITY other.label "新增其他訂閱來源">
-<!ENTITY other.accesskey "f">
-<!ENTITY full-list.url "http://adblockplus.org/en/subscriptions">
-<!ENTITY full-list.label "檢視所有訂閱來源">

=== modified file 'chrome/skin/about.css'
--- chrome/skin/about.css	2010-01-07 17:25:17 +0000
+++ chrome/skin/about.css	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -31,27 +31,15 @@
 
 #mainGroup {
   margin-top: 15px;
+  width: 450px;
+  height: 400px;
+  overflow: auto;
 }
 
 #homepageTitle, #authorTitle, #contributorsTitle {
   font-weight: bold;
 }
 
-#description, #homepage, #author {
+#description, #homepage, #author, #developersBox, #designersBox, #subscriptionAuthorsBox {
   margin-bottom: 10px;
 }
-
-#description {
-  width: 450px;
-}
-
-#homepage {
-  color: #0000E0;
-  text-decoration: underline;
-  cursor: pointer;
-}
-
-#contributorsBox {
-  height: 200px;
-  overflow: auto;
-}

=== added file 'chrome/skin/abp-icon-big.png'
Binary files chrome/skin/abp-icon-big.png and chrome/skin/abp-icon-big.png differ
=== modified file 'chrome/skin/composer.css'
--- chrome/skin/composer.css	2010-01-07 17:25:17 +0000
+++ chrome/skin/composer.css	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):

=== modified file 'chrome/skin/overlay.css'
--- chrome/skin/overlay.css	2010-01-07 17:25:17 +0000
+++ chrome/skin/overlay.css	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -24,40 +24,28 @@
 
 @namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");
 
-#abp-status *
+#abp-status
 {
   cursor: pointer;
 }
-#abp-status:hover
-{
-  text-decoration: underline;
-}
-#abp-status[abpstate="disabled"]
-{
-  color: #999999;
-}
-#abp-status[abpstate="whitelisted"]
-{
-  color: #008000;
-}
-#abp-status label {
-  display: none;
-}
 
 toolbar[iconsize="small"] #abp-toolbarbutton,
 #PersonalToolbar #abp-toolbarbutton,
-#abp-status image {
+#header-view-toolbar > #abp-toolbarbutton,
+#abp-status {
   list-style-image: url("abp-status-16.png");
   -moz-image-region: rect(0px, 16px, 16px, 0px);
 }
 toolbar[iconsize="small"] #abp-toolbarbutton[abpstate="disabled"],
 #PersonalToolbar #abp-toolbarbutton[abpstate="disabled"],
-#abp-status[abpstate="disabled"] image {
+#header-view-toolbar > #abp-toolbarbutton[abpstate="disabled"],
+#abp-status[abpstate="disabled"] {
   -moz-image-region: rect(16px, 16px, 32px, 0px);
 }
 toolbar[iconsize="small"] #abp-toolbarbutton[abpstate="whitelisted"],
 #PersonalToolbar #abp-toolbarbutton[abpstate="whitelisted"],
-#abp-status[abpstate="whitelisted"] image {
+#header-view-toolbar > #abp-toolbarbutton[abpstate="whitelisted"],
+#abp-status[abpstate="whitelisted"] {
   -moz-image-region: rect(32px, 16px, 48px, 0px);
 }
 
@@ -74,18 +62,55 @@
   font-weight: bold;
 }
 
-#abp-toolbarbutton {
+#abp-toolbarbutton,
+.abp-site-info {
   list-style-image: url("abp-status.png");
   -moz-image-region: rect(0px, 24px, 24px, 0px);
-  width: auto;
 }
-#abp-toolbarbutton[abpstate="disabled"] {
+#abp-toolbarbutton[abpstate="disabled"],
+.abp-site-info[abpstate="disabled"] {
   -moz-image-region: rect(24px, 24px, 48px, 0px);
 }
-#abp-toolbarbutton[abpstate="whitelisted"] {
+#abp-toolbarbutton[abpstate="whitelisted"],
+.abp-site-info[abpstate="disabled_site"] {
   -moz-image-region: rect(48px, 24px, 72px, 0px);
 }
 
+/* Thunderbird-specific toolbar icon styles */
+#header-view-toolbar > #abp-toolbarbutton
+{
+  -moz-appearance: dualbutton;
+  padding: 0px !important;
+}
+
+/* Hide toolbar icon text in Thunderbird to save space */
+#header-view-toolbar > #abp-toolbarbutton .toolbarbutton-text
+{
+  display: none;
+}
+
+/* SeaMonkey expects the icon to be rather large, add margin */
+#mail-toolbox #abp-toolbarbutton .toolbarbutton-icon
+{
+  margin-top: 5px;
+}
+
+#abp-status-image {
+  margin-left: 10px;
+  margin-right: 10px;
+}
+
+#abp-site-info1 .pageaction-image {
+  width: 32px;
+  height: 32px;
+  padding: 4px;
+}
+
+#abp-toolbarbutton > toolbarbutton {
+  /* Argh, Songbird defines image region directly on the anonymous toolbarbutton element */
+  -moz-image-region: inherit !important;
+}
+
 #abp-tooltip {
   max-width: none;
 }

=== removed file 'chrome/skin/seaMonkeyHack.css'
--- chrome/skin/seaMonkeyHack.css	2010-01-07 17:25:17 +0000
+++ chrome/skin/seaMonkeyHack.css	1970-01-01 00:00:00 +0000
@@ -1,41 +0,0 @@
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is Adblock Plus.
- *
- * The Initial Developer of the Original Code is
- * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *
- * ***** END LICENSE BLOCK ***** */
-
-@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");
-
-#abp-toolbarbutton .toolbarbutton-icon
-{
-  margin-top: 5px;
-}
-#abp-toolbarbutton > .toolbarbutton-menubutton-stack > .toolbarbutton-menubutton-dropmarker
-{
-  margin-bottom: 0px;
-}
-@-moz-document domain("mail")
-{
-  #abp-toolbarbutton .toolbarbutton-menubutton-button
-  {
-    -moz-box-orient: vertical;
-  }
-}

=== modified file 'chrome/skin/settings.css'
--- chrome/skin/settings.css	2010-01-07 17:25:17 +0000
+++ chrome/skin/settings.css	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):

=== modified file 'chrome/skin/sidebar.css'
--- chrome/skin/sidebar.css	2010-01-07 17:25:17 +0000
+++ chrome/skin/sidebar.css	2010-05-04 14:45:07 +0000
@@ -15,7 +15,7 @@
  *
  * The Initial Developer of the Original Code is
  * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):

=== removed file 'chrome/skin/subscription.css'
--- chrome/skin/subscription.css	2010-01-07 17:25:17 +0000
+++ chrome/skin/subscription.css	1970-01-01 00:00:00 +0000
@@ -1,34 +0,0 @@
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is Adblock Plus.
- *
- * The Initial Developer of the Original Code is
- * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *
- * ***** END LICENSE BLOCK ***** */
-
-@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");
-
-textbox {
-  min-width: 300px;
-}
-
-description {
-  width: 400px;
-  margin-bottom: 20px;
-}

=== added file 'chrome/skin/subscriptionSelection.css'
--- chrome/skin/subscriptionSelection.css	1970-01-01 00:00:00 +0000
+++ chrome/skin/subscriptionSelection.css	2010-05-04 14:45:07 +0000
@@ -0,0 +1,92 @@
+/* ***** BEGIN LICENSE BLOCK *****
+ * Version: MPL 1.1
+ *
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
+ *
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ *
+ * The Original Code is Adblock Plus.
+ *
+ * The Initial Developer of the Original Code is
+ * Wladimir Palant.
+ * Portions created by the Initial Developer are Copyright (C) 2006-2010
+ * the Initial Developer. All Rights Reserved.
+ *
+ * Contributor(s):
+ *
+ * ***** END LICENSE BLOCK ***** */
+
+@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");
+
+dialog
+{
+  min-width: 550px;
+}
+
+dialog[newInstall]
+{
+  background-image: url(abp-icon-big.png);
+  background-repeat: no-repeat;
+  background-position: 95% 5%;
+}
+
+#description-newInstall,
+#adblock-warning,
+#filtersetg-warning
+{
+  margin-bottom: 10px;
+}
+
+*[invisible="true"]
+{
+  visibility: hidden;
+}
+
+#adblock-warning,
+#filtersetg-warning,
+#supplementMessage
+{
+  color: #F00000;
+}
+
+.localeMatch
+{
+  font-weight: bold;
+}
+
+#all-subscriptions-loading
+{
+  margin: 50px;
+}
+
+#all-subscriptions
+{
+  min-height: 200px;
+}
+#all-subscriptions  > richlistitem > .variant
+{
+  width: 200px;
+}
+#all-subscriptions > richlistitem:not(:first-child) > .title,
+#all-subscriptions > richlistitem:not(:first-child) > .title + .variant
+{
+  border-top: 1px dashed black;
+  margin-top: 0px;
+  padding-top: 4px;
+}
+
+#supplementMessage
+{
+  margin-top: 5px;
+}
+#supplementMessage > label
+{
+  margin-left: 0px;
+  margin-right: 0px;
+}

=== removed file 'chrome/skin/tip_subscriptions.css'
--- chrome/skin/tip_subscriptions.css	2010-01-07 17:25:17 +0000
+++ chrome/skin/tip_subscriptions.css	1970-01-01 00:00:00 +0000
@@ -1,89 +0,0 @@
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is Adblock Plus.
- *
- * The Initial Developer of the Original Code is
- * Wladimir Palant.
- * Portions created by the Initial Developer are Copyright (C) 2006-2009
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *
- * ***** END LICENSE BLOCK ***** */
-
-@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");
-
-dialog {
-  max-width: 600px;
-}
-
-#icon {
-  list-style-image: url(adblockplus.png);
-  margin: 15px;
-}
-
-#subscriptions {
-  margin-top: 10px;
-  margin-bottom: 10px;
-}
-
-#subscriptionsScrollbox {
-  overflow: auto;
-}
-
-#adblock-warning,
-#filtersetg-warning {
-  color: #F00000;
-}
-
-#adblock-uninstall,
-#filtersetg-uninstall {
-  margin-left: 20px;
-}
-
-template+.container, .containerAdded {
-  border-top: 1px solid black;
-}
-
-.container, .containerAdded {
-  padding-top: 5px;
-  padding-bottom: 5px;
-  margin: 0px;
-}
-
-.container {
-  border-bottom: 1px solid black;
-}
-
-.fulllist, .location, .homepage, .moreinfo {
-  color: #0000E0;
-  text-decoration: underline;
-  cursor: pointer;
-}
-
-radiogroup {
-  -moz-box-align: stretch;
-}
-
-radio .radio-label-box {
-  display: none;
-}
-
-radio + vbox {
-  border: 1px solid transparent;
-}
-radio[focused="true"] + vbox {
-  border: 1px dotted ThreeDDarkShadow;
-}
-

=== modified file 'components/AdblockPlus.js'
--- components/AdblockPlus.js	2010-01-07 17:25:17 +0000
+++ components/AdblockPlus.js	2010-05-04 14:45:07 +0000
@@ -35,22 +35,32 @@
 const Element = Ci.nsIDOMElement;
 const Window = Ci.nsIDOMWindow;
 
-const loader = Cc["@mozilla.org/moz/jssubscript-loader;1"].getService(Ci.mozIJSSubScriptLoader);
-const ioService = Cc["@mozilla.org/network/io-service;1"].getService(Ci.nsIIOService);
-const versionComparator = Cc["@mozilla.org/xpcom/version-comparator;1"].createInstance(Ci.nsIVersionComparator);
-var windowMediator = Cc["@mozilla.org/appshell/window-mediator;1"].getService(Ci.nsIWindowMediator);
-var windowWatcher= Cc["@mozilla.org/embedcomp/window-watcher;1"].getService(Ci.nsIWindowWatcher);
-try
-{
-  var headerParser = Cc["@mozilla.org/messenger/headerparser;1"].getService(Ci.nsIMsgHeaderParser);
-}
-catch(e)
-{
-  headerParser = null;
-}
-
 Cu.import("resource://gre/modules/XPCOMUtils.jsm");
 
+// Gecko 1.9.0/1.9.1 compatibility - add XPCOMUtils.defineLazyServiceGetter
+if (!("defineLazyServiceGetter" in XPCOMUtils))
+{
+  XPCOMUtils.defineLazyServiceGetter = function XPCU_defineLazyServiceGetter(obj, prop, contract, iface)
+  {
+    obj.__defineGetter__(prop, function XPCU_serviceGetter()
+    {
+      delete obj[prop];
+      return obj[prop] = Cc[contract].getService(Ci[iface]);
+    });
+  };
+}
+
+XPCOMUtils.defineLazyServiceGetter(this, "loader", "@mozilla.org/moz/jssubscript-loader;1", "mozIJSSubScriptLoader");
+XPCOMUtils.defineLazyServiceGetter(this, "ioService", "@mozilla.org/network/io-service;1", "nsIIOService");
+XPCOMUtils.defineLazyServiceGetter(this, "versionComparator", "@mozilla.org/xpcom/version-comparator;1", "nsIVersionComparator");
+XPCOMUtils.defineLazyServiceGetter(this, "windowMediator", "@mozilla.org/appshell/window-mediator;1", "nsIWindowMediator");
+XPCOMUtils.defineLazyServiceGetter(this, "windowWatcher", "@mozilla.org/embedcomp/window-watcher;1", "nsIWindowWatcher");
+
+if ("@mozilla.org/messenger/headerparser;1" in Cc)
+  XPCOMUtils.defineLazyServiceGetter(this, "headerParser", "@mozilla.org/messenger/headerparser;1", "nsIMsgHeaderParser");
+else
+  this.headerParser = null;
+
 /**
  * Application startup/shutdown observer, triggers init()/shutdown() methods in abp object.
  * @constructor
@@ -312,7 +322,7 @@
    * Version comparator instance.
    * @type nsIVersionComparator
    */
-  versionComparator: versionComparator,
+  get versionComparator() versionComparator,
 
   /**
    * Initializes the component, called on application startup.
@@ -412,10 +422,12 @@
       {
         dlg.focus();
       }
-      catch (e)
+      catch (e) {}
+
+      if (windowMediator.getMostRecentWindow(null) != dlg)
       {
         // There must be some modal dialog open
-        dlg = windowMediator.getMostRecentWindow("abp:subscription") || windowMediator.getMostRecentWindow("abp:about");
+        dlg = windowMediator.getMostRecentWindow("abp:subscriptionSelection") || windowMediator.getMostRecentWindow("abp:about");
         if (dlg)
           dlg.focus();
       }
@@ -429,16 +441,28 @@
 
   /**
    * Opens a URL in the browser window. If browser window isn't passed as parameter,
-   * this function attempts to find a browser window.
+   * this function attempts to find a browser window. If an event is passed in
+   * it should be passed in to the browser if possible (will e.g. open a tab in
+   * background depending on modifiers keys).
    */
-  loadInBrowser: function(/**String*/ url, /**Window*/ currentWindow)
+  loadInBrowser: function(/**String*/ url, /**Window*/ currentWindow, /**Event*/ event)
   {
-    currentWindow = currentWindow ||
-                    windowMediator.getMostRecentWindow("navigator:browser") ||
-                    windowMediator.getMostRecentWindow("Songbird:Main") ||
-                    windowMediator.getMostRecentWindow("emusic:window");
     let abpHooks = currentWindow ? currentWindow.document.getElementById("abp-hooks") : null;
-    if (!abpHooks || !abpHooks.addTab || abpHooks.addTab(url) === false)
+    if (!abpHooks || !abpHooks.addTab)
+    {
+      let enumerator = windowMediator.getZOrderDOMWindowEnumerator(null, true);
+      while (enumerator.hasMoreElements())
+      {
+        let window = enumerator.getNext().QueryInterface(Ci.nsIDOMWindow);
+        abpHooks = window.document.getElementById("abp-hooks");
+        if (abpHooks && abpHooks.addTab)
+          break;
+      }
+    }
+
+    if (abpHooks && abpHooks.addTab)
+      abpHooks.addTab(url, event);
+    else
     {
       let protocolService = Cc["@mozilla.org/uriloader/external-protocol-service;1"].getService(Ci.nsIExternalProtocolService);
       protocolService.loadURI(makeURL(url), null);
@@ -479,17 +503,18 @@
 /*
  * Loading additional files
  */
-loader.loadSubScript('chrome://adblockplus/content/utils.js');
-loader.loadSubScript('chrome://adblockplus/content/filterClasses.js');
-loader.loadSubScript('chrome://adblockplus/content/subscriptionClasses.js');
-loader.loadSubScript('chrome://adblockplus/content/filterStorage.js');
-loader.loadSubScript('chrome://adblockplus/content/matcher.js');
-loader.loadSubScript('chrome://adblockplus/content/elemhide.js');
-loader.loadSubScript('chrome://adblockplus/content/filterListener.js');
-loader.loadSubScript('chrome://adblockplus/content/policy.js');
-loader.loadSubScript('chrome://adblockplus/content/requests.js');
-loader.loadSubScript('chrome://adblockplus/content/prefs.js');
-loader.loadSubScript('chrome://adblockplus/content/synchronizer.js');
+loader.loadSubScript('chrome://adblockplus/content/utils.js', this);
+loader.loadSubScript('chrome://adblockplus/content/filterClasses.js', this);
+loader.loadSubScript('chrome://adblockplus/content/subscriptionClasses.js', this);
+loader.loadSubScript('chrome://adblockplus/content/filterStorage.js', this);
+loader.loadSubScript('chrome://adblockplus/content/matcher.js', this);
+loader.loadSubScript('chrome://adblockplus/content/elemhide.js', this);
+loader.loadSubScript('chrome://adblockplus/content/filterListener.js', this);
+loader.loadSubScript('chrome://adblockplus/content/objtabs.js', this);
+loader.loadSubScript('chrome://adblockplus/content/policy.js', this);
+loader.loadSubScript('chrome://adblockplus/content/requests.js', this);
+loader.loadSubScript('chrome://adblockplus/content/prefs.js', this);
+loader.loadSubScript('chrome://adblockplus/content/synchronizer.js', this);
 
 /*
  * Core Routines

=== modified file 'defaults/preferences/adblockplus.js'
--- defaults/preferences/adblockplus.js	2010-01-07 17:25:17 +0000
+++ defaults/preferences/adblockplus.js	2010-05-04 14:45:07 +0000
@@ -20,7 +20,8 @@
 pref("extensions.adblockplus.patternsbackupinterval", 24);
 pref("extensions.adblockplus.whitelistschemes", "about chrome file irc news resource snews x-jsd addbook cid imap mailbox nntp pop data javascript moz-icon");
 pref("extensions.adblockplus.hideimagemanager", true);
-pref("extensions.adblockplus.subscriptions_fallbackurl", "https://adblockplus.org/getSubscription?url=%SUBSCRIPTION%&downloadURL=%URL%&error=%ERROR%&channelStatus=%CHANNELSTATUS%&responseStatus=%RESPONSESTATUS%");
+pref("extensions.adblockplus.subscriptions_listurl", "https://adblockplus.org/subscriptions.xml");
+pref("extensions.adblockplus.subscriptions_fallbackurl", "https://adblockplus.org/getSubscription?version=%VERSION%&url=%SUBSCRIPTION%&downloadURL=%URL%&error=%ERROR%&channelStatus=%CHANNELSTATUS%&responseStatus=%RESPONSESTATUS%");
 pref("extensions.adblockplus.subscriptions_fallbackerrors", 5);
 pref("extensions.adblockplus.savestats", true);
 pref("extensions.adblockplus.composer_default", 2);

=== modified file 'install.rdf'
--- install.rdf	2010-01-07 17:25:17 +0000
+++ install.rdf	2010-05-04 14:45:07 +0000
@@ -7,7 +7,22 @@
   
   <em:id>{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}</em:id>
   <em:version>{{VERSION}}</em:version>
-  
+  <em:name>{{NAME}}</em:name>
+  <em:description>{{DESCRIPTION}}</em:description>
+  <em:creator>Wladimir Palant</em:creator>
+  <em:homepageURL>http://adblockplus.org/</em:homepageURL>
+
+  <em:contributor>Rob Brown</em:contributor>
+  <em:contributor>Nickolay Ponomarev</em:contributor>
+  <em:contributor>Fabrice Desré</em:contributor>
+
+{{LOCALIZED}}
+
+  <!-- Front End Integration Hooks (used by Extension Manager)-->
+  <em:iconURL>chrome://adblockplus/skin/adblockplus.png</em:iconURL>
+  <em:aboutURL>chrome://adblockplus/content/ui/about.xul</em:aboutURL>
+  <em:optionsURL>chrome://adblockplus/content/ui/settings.xul</em:optionsURL>
+
   <!-- Target Application this extension can install into, 
     with minimum and maximum supported versions. --> 
   
@@ -16,7 +31,7 @@
     <Description>
     <em:id>{ec8030f7-c20a-464f-9b0e-13a3a9e97384}</em:id>
     <em:minVersion>3.0.12</em:minVersion>
-    <em:maxVersion>3.7a1pre</em:maxVersion>
+    <em:maxVersion>3.7a5pre</em:maxVersion>
     </Description>
   </em:targetApplication>
   
@@ -34,7 +49,7 @@
     <Description>
     <em:id>{3550f703-e582-4d05-9a08-453d09bdfdc6}</em:id>
     <em:minVersion>3.0</em:minVersion>
-    <em:maxVersion>3.1a1pre</em:maxVersion>
+    <em:maxVersion>3.2a1pre</em:maxVersion>
     </Description>
   </em:targetApplication>
 
@@ -43,7 +58,7 @@
     <Description>
     <em:id>songbird@songbirdnest.com</em:id>
     <em:minVersion>1.4.0</em:minVersion>
-    <em:maxVersion>1.7.0a</em:maxVersion>
+    <em:maxVersion>1.8.0a</em:maxVersion>
     </Description>
   </em:targetApplication>
 
@@ -91,21 +106,9 @@
   <em:targetApplication>
     <Description>
       <em:id>{a23983c0-fd0e-11dc-95ff-0800200c9a66}</em:id>
-      <em:minVersion>1.0b6pre</em:minVersion>
-      <em:maxVersion>1.0.*</em:maxVersion>
+      <em:minVersion>1.0</em:minVersion>
+      <em:maxVersion>1.1.*</em:maxVersion>
     </Description>
   </em:targetApplication>
-  
-  <!-- Front End MetaData -->
-  <em:name>Adblock Plus</em:name>
-  <em:description>Ads were yesterday!</em:description>
-  <em:creator>Wladimir Palant</em:creator>
-  <em:homepageURL>http://adblockplus.org/</em:homepageURL>
-  
-  <!-- Front End Integration Hooks (used by Extension Manager)-->
-  <em:iconURL>chrome://adblockplus/skin/adblockplus.png</em:iconURL>
-  <em:aboutURL>chrome://adblockplus/content/ui/about.xul</em:aboutURL>
-  <em:optionsURL>chrome://adblockplus/content/ui/settings.xul</em:optionsURL>
-
   </Description>  
 </RDF>

=== modified file 'make_babelzilla_build.pl'
--- make_babelzilla_build.pl	2010-01-07 17:25:17 +0000
+++ make_babelzilla_build.pl	2010-05-04 14:45:07 +0000
@@ -1,70 +1,11 @@
 #!/usr/bin/perl
 
-#############################################################################
-# This script will create a special development build meant only for upload #
-# to Babelzilla.                                                            #
-#############################################################################
-
-use strict;
-use warnings;
-use lib qw(buildtools);
-use Packager;
-
-sub Packager::fixLocales() {}
-
-my $manifest = readFile("chrome.manifest");
-unless ($manifest =~ /\bjar:chrome\/(\S+?)\.jar\b/)
-{
-  die "Could not find JAR file name in chrome.manifest";
-}
-my $baseName = $1;
-
-my %params = ();
-$params{version} = shift @ARGV;
-die "Please specify version number on command line" unless $params{version};
-
-my $xpiFile = "$baseName-$params{version}.xpi";
-
-my $pkg = Packager->new(\%params);
-$pkg->readLocales('chrome/locale', 1);
-
-chdir('chrome');
-$pkg->makeJAR("$baseName.jar", 'content', 'skin', 'locale', '-/tests', '-/mochitest', '-/.incomplete');
-chdir('..');
-
-my @files = grep {-e $_} ('components', 'defaults', 'install.rdf', 'chrome.manifest', 'icon.png');
-
-my $targetAppNum = 0;
-$pkg->{postprocess_line} = \&postprocessInstallRDF;
-$pkg->makeXPI($xpiFile, "chrome/$baseName.jar", @files);
-unlink("chrome/$baseName.jar");
-
-sub postprocessInstallRDF
-{
-  my ($file, $line) = @_;
-
-  return $line unless $file eq "install.rdf";
-
-  if ($line =~ /\btargetApplication\b/)
-  {
-    $targetAppNum++;
-    return "" if $targetAppNum > 6;
-  }
-
-  return "" if $targetAppNum > 6 && $targetAppNum % 2 == 1;
-
-  return $line;
-}
-
-sub readFile
-{
-  my $file = shift;
-
-  open(local *FILE, "<", $file) || die "Could not read file '$file'";
-  binmode(FILE);
-  local $/;
-  my $result = <FILE>;
-  close(FILE);
-
-  return $result;
-}
+# This is a dummy, its purpose is to call a script with the same name in the buildtools repository
+
+$0 =~ s/(.*[\\\/])//g;
+chdir($1) if $1;
+
+system("hg", "clone", "https://hg.adblockplus.org/buildtools/") unless -e "buildtools";
+
+do "buildtools/$0";
+die $@ if $@;

=== added file 'normalizeLocales.pl'
--- normalizeLocales.pl	1970-01-01 00:00:00 +0000
+++ normalizeLocales.pl	2010-05-04 14:45:07 +0000
@@ -0,0 +1,57 @@
+#!/usr/bin/perl
+
+# This script will adjust the locales as received from Babelzilla - normalize
+# newlines and remove comments that have been pointlessly copied over from
+# en-US.
+ 
+use strict;
+use warnings;
+
+$0 =~ s/(.*[\\\/])//g;
+chdir($1) if $1;
+
+opendir(local* LOCALES, "chrome/locale") or die "Failed to open directory chrome/locale";
+foreach my $locale (readdir(LOCALES))
+{
+  next if $locale =~ /^\./ || $locale eq "en-US" || $locale eq "de" || $locale eq "ru";
+
+  foreach my $file (<chrome/locale/$locale/*.properties>)
+  {
+    my $data = readFile($file);
+    $data =~ s/\r//g;                   # Normalize newlines
+    $data =~ s/^\s*#.*\n*//gm;          # Remove pointless comments
+    writeFile($file, $data);
+  }
+
+  foreach my $file (<chrome/locale/$locale/*.dtd>)
+  {
+    my $data = readFile($file);
+    $data =~ s/\r//g;                         # Normalize newlines
+    $data =~ s/[^\S\n]*<!--.*?-->\s*?\n*//gs; # Remove pointless comments
+    writeFile($file, $data);
+  }
+}
+closedir(LOCALES);
+
+sub readFile
+{
+  my $file = shift;
+
+  open(local *FILE, "<", $file) || die "Could not read file '$file'";
+  binmode(FILE);
+  local $/;
+  my $result = <FILE>;
+  close(FILE);
+
+  return $result;
+}
+
+sub writeFile
+{
+  my ($file, $contents) = @_;
+
+  open(local *FILE, ">", $file) || die "Could not write file '$file'";
+  binmode(FILE);
+  print FILE $contents;
+  close(FILE);
+}

=== modified file 'remove_string.pl'
--- remove_string.pl	2010-01-07 17:25:17 +0000
+++ remove_string.pl	2010-05-04 14:45:07 +0000
@@ -9,19 +9,21 @@
 closedir(DIR);
 
 foreach my $locale (@locales) {
-  open(local *FILE, "chrome/locale/$locale/$file") or die "Could not open file chrome/locale/$locale/$file";
+  open(local *FILE, "chrome/locale/$locale/$file") or ((warn "Could not open file chrome/locale/$locale/$file") && next);
+  binmode(FILE);
   local $/;
   my $data = <FILE>;
   close(FILE);
 
   if ($file =~ /\.dtd$/) {
-    $data =~ s/<!ENTITY\s+$string\s+"[^"]*">\s*//gs or (warn "String $string not found in file chrome/locale/$locale/$file" && next);
+    $data =~ s/<!ENTITY\s+$string\s+"[^"]*">\s*//gs or ((warn "String $string not found in file chrome/locale/$locale/$file") && next);
   }
   else {
     $data =~ s/^$string=.*\n//gm or (warn "String $string not found in file chrome/locale/$locale/$file" && next);
   }
 
   open(FILE, ">chrome/locale/$locale/$file") or die "Could not write file chrome/locale/$locale/$file";
+  binmode(FILE);
   print FILE $data;
   close(FILE);
 }

=== modified file 'search_and_replace.pl'
--- search_and_replace.pl	2010-01-07 17:25:17 +0000
+++ search_and_replace.pl	2010-05-04 14:45:07 +0000
@@ -2,8 +2,17 @@
 
 use strict;
 
-die "Usage: $^X $0 <regexp> <replaceBy>\n" unless @ARGV >= 2;
+my $exec = 0;
+for (my $i = 0; $i < @ARGV; $i++)
+{
+  if ($ARGV[$i] eq "-e")
+  {
+    $exec = 1;
+    splice(@ARGV, $i--, 1);
+  }
+}
 
+die "Usage: $^X $0 [-e] <regexp> <replaceBy>\n" unless @ARGV >= 2;
 my ($from, $to) = @ARGV;
 
 doDir('.');
@@ -15,7 +24,7 @@
   opendir(local *DIR, $dir) or die "Could not open directory $dir";
   foreach (readdir(DIR))
   {
-    next if !/[^.]/;
+    next if /^\./;
 
     my $path = "$dir/$_";
     if (-f $path)
@@ -39,7 +48,15 @@
   binmode(FILE);
   local $/;
   my $data = <FILE>;
-  my $count = ($data =~ s/$from/$to/g);
+  my $count;
+  if ($exec)
+  {
+    $count = ($data =~ s/$from/$to/gee);
+  }
+  else
+  {
+    $count = ($data =~ s/$from/$to/g);
+  }
   close(FILE);
 
   if ($count)

=== modified file 'test_locales.pl'
--- test_locales.pl	2010-01-07 17:25:17 +0000
+++ test_locales.pl	2010-05-04 14:45:07 +0000
@@ -1,13 +1,22 @@
 #!/usr/bin/perl
 
 use strict;
+use warnings;
+use lib qw(buildtools);
+
+$0 =~ s/(.*[\\\/])//g;
+chdir($1) if $1;
+
+system("hg", "clone", "https://hg.adblockplus.org/buildtools/") unless -e "buildtools";
+
+require LocaleTester;
 
 my %paths = (
   abp => 'chrome/locale',
   ehh => '../elemhidehelper/chrome/locale',
 );
 
-my @must_differ = (
+my @mustDiffer = (
   ['abp:overlay:opensidebar.accesskey', 'abp:overlay:settings.accesskey', 'abp:settings:options.accesskey', 'abp:settings:enable.accesskey', 'ehh:overlay:selectelement.accesskey'],
   ['abp:settings:filters.accesskey', 'abp:settings:edit.accesskey', 'abp:settings:view.accesskey', 'abp:settings:options.accesskey', 'abp:settings:help.accesskey', 'abp:settings:add.accesskey', 'abp:settings:apply.accesskey'],
   ['abp:settings:add.accesskey', 'abp:settings:addsubscription.accesskey', 'abp:settings:synchsubscriptions.accesskey', 'abp:settings:import.accesskey', 'abp:settings:export.accesskey', 'abp:settings:clearall.accesskey', 'abp:settings:resethitcounts.accesskey'],
@@ -16,28 +25,22 @@
   ['abp:settings:sort.none.accesskey', 'abp:settings:filter.accesskey', 'abp:settings:slow.accesskey', 'abp:settings:enabled.accesskey', 'abp:settings:hitcount.accesskey', 'abp:settings:lasthit.accesskey', 'abp:settings:sort.ascending.accesskey', 'abp:settings:sort.descending.accesskey'],
   ['abp:settings:enable.accesskey', 'abp:settings:showintoolbar.accesskey', 'abp:settings:showinstatusbar.accesskey', 'abp:settings:objecttabs.accesskey', 'abp:settings:collapse.accesskey'],
   ['abp:settings:gettingStarted.accesskey', 'abp:settings:faq.accesskey', 'abp:settings:filterdoc.accesskey', 'abp:settings:about.accesskey'],
-  ['abp:subscription:location.accesskey', 'abp:subscription:title.accesskey', 'abp:subscription:autodownload.accesskey', 'abp:subscription:enabled.accesskey'],
+  ['abp:subscriptionSelection:other.accesskey', 'abp:subscriptionSelection:title.accesskey', 'abp:subscriptionSelection:location.accesskey', 'abp:subscriptionSelection:autodownload.accesskey', 'abp:subscriptionSelection:addMain.accesskey'],
   ['abp:composer:filter.accesskey', 'abp:composer:preferences.accesskey', 'abp:composer:type.filter.accesskey', 'abp:composer:type.whitelist.accesskey', 'abp:composer:custom.pattern.accesskey', 'abp:composer:anchor.start.accesskey', 'abp:composer:anchor.end.accesskey', 'abp:composer:domainRestriction.accesskey', 'abp:composer:firstParty.accesskey', 'abp:composer:thirdParty.accesskey', 'abp:composer:matchCase.accesskey', 'abp:composer:collapse.accesskey'],
   ['ehh:global:command.select.key', 'ehh:global:command.wider.key', 'ehh:global:command.narrower.key', 'ehh:global:command.quit.key', 'ehh:global:command.blinkElement.key', 'ehh:global:command.viewSource.key', 'ehh:global:command.viewSourceWindow.key', 'ehh:global:command.showMenu.key'],
 );
 
-my @must_equal = (
+my @mustEqual = (
   ['abp:overlay:opensidebar.accesskey', 'abp:overlay:closesidebar.accesskey'],
   ['abp:composer:anchor.start.accesskey', 'abp:composer:anchor.start.flexible.accesskey'],
   ['ehh:overlay:selectelement.accesskey', 'ehh:overlay:stopselection.accesskey'],
 );
 
-my %keepAccessKeys = map {$_ => $_} (
-  'ja-JP',
-  'ko-KR',
-  'zh-CN',
-  'zh-TW',
-);
-
 my @ignoreUntranslated = (
   qr/\.url$/,
   quotemeta("abp:about:caption.title"),
   quotemeta("abp:about:version.title"),
+  quotemeta("abp:global:default_dialog_title"),
   quotemeta("abp:global:status_active_label"),
   quotemeta("abp:global:type_label_document"),
   quotemeta("abp:global:type_label_dtd"),
@@ -51,257 +54,21 @@
   quotemeta("abp:overlay:toolbarbutton.label"),
   quotemeta("abp:settings:filters.label"),
   quotemeta("abp:sidebar:filter.label"),
+  quotemeta("abp:meta:name"),
   quotemeta("ehh:composer:nodes-tree.class.label"),
   quotemeta("ehh:composer:nodes-tree.id.label"),
   quotemeta("ehh:global:noabp_warning_title"),
 );
 
-my @locales = sort {$a cmp $b} makeLocaleList();
-
-my $referenceLocale = readLocaleFiles("en-US");
-
-foreach my $locale (@locales)
-{
-  my $currentLocale = $locale eq "en-US" ? $referenceLocale : readLocaleFiles($locale);
-
-  compareLocales($locale, $currentLocale, $referenceLocale) unless $currentLocale == $referenceLocale;
-
-  foreach my $entry (@must_differ)
-  {
-    my %values = ();
-    foreach my $key (@$entry)
-    {
-      my ($dir, $file, $name) = split(/:/, $key);
-      next unless exists($currentLocale->{"$dir:$file"}) && exists($currentLocale->{"$dir:$file"}{$name});
-      my $value = lc($currentLocale->{"$dir:$file"}{$name});
-
-      print "$locale: values for '$values{$value}' and '$key' are identical, must differ\n" if exists $values{$value};
-      $values{$value} = $key;
-    }
-  }
-
-  foreach my $entry (@must_equal)
-  {
-    my $stdValue;
-    my $stdName;
-    foreach my $key (@$entry)
-    {
-      my ($dir, $file, $name) = split(/:/, $key);
-      next unless exists($currentLocale->{"$dir:$file"}) && exists($currentLocale->{"$dir:$file"}{$name});
-      my $value = lc($currentLocale->{"$dir:$file"}{$name});
-
-      $stdValue = $value unless defined $stdValue;
-      $stdName = $key unless defined $stdName;
-      print "$locale: values for '$stdName' and '$key' differ, must be equal\n" if $value ne $stdValue;
-    }
-  }
-
-  foreach my $file (keys %$currentLocale)
-  {
-    my $fileData = $currentLocale->{$file};
-    foreach my $key (keys %$fileData)
-    {
-      if (($key =~ /\.accesskey$/ || $key =~ /\.key$/) && length($fileData->{$key}) != 1)
-      {
-        print "$locale: Length of accesskey '$file:$key' isn't 1 character\n";
-      }
-
-      if ($key =~ /\.accesskey$/)
-      {
-        if (exists($keepAccessKeys{$locale}))
-        {
-          if (exists($referenceLocale->{$file}{$key}) && lc($fileData->{$key}) ne lc($referenceLocale->{$file}{$key}))
-          {
-            print "$locale: Accesskey '$file:$key' should be the same as in the reference locale\n";
-          }
-        }
-        else
-        {
-          my $labelKey = $key;
-          $labelKey =~ s/\.accesskey$/.label/;
-          if (exists($fileData->{$labelKey}) && $fileData->{$labelKey} !~ /\Q$fileData->{$key}/i)
-          {
-            print "$locale: Accesskey '$file:$key' not found in the corresponding label '$file:$labelKey'\n";
-          }
-        }
-      }
-
-      if ($currentLocale != $referenceLocale && $locale ne "en-GB" && length($fileData->{$key}) > 1 && $fileData->{$key} eq $referenceLocale->{$file}{$key})
-      {
-        my $ignore = 0;
-        foreach my $re (@ignoreUntranslated)
-        {
-          $ignore = 1 if "$file:$key" =~ $re;
-        }
-        print "$locale: Value of '$file:$key' is the same as in the reference locale, probably an untranslated string\n" unless $ignore;
-      }
-    }
-  }
-}
-
-sub makeLocaleList
-{
-  return @ARGV if @ARGV;
-
-  my %locales = ();
-  foreach my $dir (keys %paths)
-  {
-    opendir(local* DIR, $paths{$dir}) or next;
-    my @locales = grep {!/[^\w\-]/ && !-e("$paths{$dir}/$_/.incomplete")} readdir(DIR);
-    $locales{$_} = 1 foreach @locales;
-    closedir(DIR);
-  }
-  return keys %locales;
-}
-
-sub readFile
-{
-  my $file = shift;
-
-  open(local *FILE, "<", $file) || die "Could not read file '$file'";
-  binmode(FILE);
-  local $/;
-  my $result = <FILE>;
-  close(FILE);
-
-  print "Byte Order Mark found in file '$file'\n" if $result =~ /\xEF\xBB\xBF/;
-  print "File '$file' is not valid UTF-8\n" unless (utf8::decode($result));
-
-  return $result;
-}
-
-sub parseDTDFile
-{
-  my $file = shift;
-  
-  my %result = ();
-
-  my $data = readFile($file);
-
-  my $S = qr/[\x20\x09\x0D\x0A]/;
-  my $Name = qr/[A-Za-z_:][\w.\-:]*/;
-  my $Reference = qr/&$Name;|&#\d+;|&#x[\da-fA-F]+;/;
-  my $PEReference = qr/%$Name;/;
-  my $EntityValue = qr/"((?:[^%&"]|$PEReference|$Reference)*)"|'((?:[^%&']|$PEReference|$Reference)*)'/;
-
-  # Remove comments
-  $data =~ s/<!--([^\-]|-[^\-])*-->//gs;
-
-  # Process entities
-  while ($data =~ /<!ENTITY$S+($Name)$S+$EntityValue$S*>/gs)
-  {
-    $result{$1} = $2 || $3;
-    $result{$1} =~ s/&apos;/'/g;
-  }
-
-  # Remove entities
-  $data =~ s/<!ENTITY$S+$Name$S+$EntityValue$S*>//gs;
-
-  # Remove spaces
-  $data =~ s/^\s+//gs;
-  $data =~ s/\s+$//gs;
-  $data =~ s/\s+/ /gs;
-
-  print "Unrecognized data in file '$file': $data\n" if $data ne '';
-
-  return \%result;
-}
-
-sub parsePropertiesFile
-{
-  my $file = shift;
-
-  my %result = ();
-
-  my $data = readFile($file);
-  while ($data =~ /^(.*)$/mg)
-  {
-    my $line = $1;
-
-    # ignore comments
-    next if $line =~ /^\s*[#!]/;
-
-    if ($line =~ /=/)
-    {
-      my ($key, $value) = split(/=/, $line, 2);
-      $result{$key} = $value;
-    }
-    elsif ($line =~ /\S/)
-    {
-      print "Unrecognized data in file '$file': $line\n";
-    }
-  }
-  close(FILE);
-
-  return \%result;
-}
-
-sub readLocaleFiles
-{
-  my $locale = shift;
-
-  my %result = ();
-  foreach my $dir (keys %paths)
-  {
-    opendir(local *DIR, "$paths{$dir}/$locale") or next;
-    foreach my $file (readdir(DIR))
-    {
-      if ($file =~ /(.*)\.dtd$/)
-      {
-        $result{"$dir:$1"} = parseDTDFile("$paths{$dir}/$locale/$file");
-      }
-      elsif ($file =~ /(.*)\.properties$/)
-      {
-        $result{"$dir:$1"} = parsePropertiesFile("$paths{$dir}/$locale/$file");
-      }
-    }
-    closedir(DIR);
-  }
-
-  return \%result;
-}
-
-sub compareLocales
-{
-  my ($locale, $current, $reference) = @_;
-
-  my %hasFile = ();
-  foreach my $file (keys %$current)
-  {
-    unless (exists($reference->{$file}))
-    {
-      print "$locale: Extra file '$file'\n";
-      next;
-    }
-    $hasFile{$file} = 1;
-
-    my %hasValue = ();
-    foreach my $key (keys %{$current->{$file}})
-    {
-      unless (exists($reference->{$file}{$key}))
-      {
-        print "$locale: Extra value '$file:$key'\n";
-        next;
-      }
-      $hasValue{$key} = 1;
-    }
-
-    foreach my $key (keys %{$reference->{$file}})
-    {
-      unless (exists($current->{$file}{$key}))
-      {
-        print "$locale: Missing value '$file:$key'\n";
-        next;
-      }
-    }
-  }
-
-  foreach my $file (keys %$reference)
-  {
-    unless (exists($current->{$file}))
-    {
-      print "$locale: Missing file '$file'\n";
-      next;
-    }
-  }
-}
+my %lengthRestrictions = (
+  'abp:meta:description.short' => 250,
+);
+ 
+LocaleTester::testLocales(
+  paths => \%paths,
+  locales => \@ARGV,
+  mustDiffer => \@mustDiffer,
+  mustEqual => \@mustEqual,
+  ignoreUntranslated => \@ignoreUntranslated,
+  lengthRestrictions => \%lengthRestrictions,
+);

=== modified file 'version'
--- version	2010-01-07 17:25:17 +0000
+++ version	2010-05-04 14:45:07 +0000
@@ -1,1 +1,1 @@
-1.1.3
\ No newline at end of file
+1.2
\ No newline at end of file

